package org.apache.poi;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.security.GeneralSecurityException;
import java.util.List;
import org.apache.poi.hpsf.DocumentSummaryInformation;
import org.apache.poi.hpsf.PropertySet;
import org.apache.poi.hpsf.PropertySetFactory;
import org.apache.poi.hpsf.SummaryInformation;
import org.apache.poi.hpsf.WritingNotSupportedException;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.crypt.Encryptor;
import org.apache.poi.poifs.crypt.cryptoapi.CryptoAPIDecryptor;
import org.apache.poi.poifs.crypt.cryptoapi.CryptoAPIEncryptor;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.OPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public abstract class POIDocument implements Closeable {
    public static final POILogger logger = POILogFactory.getLogger(POIDocument.class);
    public DirectoryNode directory;
    public DocumentSummaryInformation dsInf;
    public boolean initialized;
    public SummaryInformation sInf;

    public POIDocument(DirectoryNode directoryNode) {
        this.directory = directoryNode;
    }

    private <T> T readPropertySet(Class<T> cls, String str) {
        String substring = cls.getName().substring(cls.getName().lastIndexOf(46) + 1);
        try {
            T t = (T) getPropertySet(str);
            if (cls.isInstance(t)) {
                return t;
            }
            if (t != null) {
                POILogger pOILogger = logger;
                pOILogger.log(5, substring + " property set came back with wrong class - " + t.getClass().getName());
                return null;
            }
            POILogger pOILogger2 = logger;
            pOILogger2.log(5, substring + " property set came back as null");
            return null;
        } catch (IOException e2) {
            logger.log(7, "can't retrieve property set", e2);
            return null;
        }
    }

    @Internal
    public void clearDirectory() {
        this.directory = null;
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        DirectoryNode directoryNode = this.directory;
        if (directoryNode != null && directoryNode.getNFileSystem() != null) {
            this.directory.getNFileSystem().close();
            clearDirectory();
        }
    }

    public void createInformationProperties() {
        if (!this.initialized) {
            readProperties();
        }
        if (this.sInf == null) {
            this.sInf = PropertySetFactory.newSummaryInformation();
        }
        if (this.dsInf == null) {
            this.dsInf = PropertySetFactory.newDocumentSummaryInformation();
        }
    }

    @Internal
    public DirectoryNode getDirectory() {
        return this.directory;
    }

    public DocumentSummaryInformation getDocumentSummaryInformation() {
        if (!this.initialized) {
            readProperties();
        }
        return this.dsInf;
    }

    public String getEncryptedPropertyStreamName() {
        return "encryption";
    }

    public EncryptionInfo getEncryptionInfo() {
        return null;
    }

    public PropertySet getPropertySet(String str) {
        return getPropertySet(str, getEncryptionInfo());
    }

    public SummaryInformation getSummaryInformation() {
        if (!this.initialized) {
            readProperties();
        }
        return this.sInf;
    }

    @Internal
    public boolean initDirectory() {
        if (this.directory != null) {
            return false;
        }
        this.directory = new NPOIFSFileSystem().getRoot();
        return true;
    }

    public void readProperties() {
        if (!this.initialized) {
            DocumentSummaryInformation documentSummaryInformation = (DocumentSummaryInformation) readPropertySet(DocumentSummaryInformation.class, DocumentSummaryInformation.DEFAULT_STREAM_NAME);
            if (documentSummaryInformation != null) {
                this.dsInf = documentSummaryInformation;
            }
            SummaryInformation summaryInformation = (SummaryInformation) readPropertySet(SummaryInformation.class, SummaryInformation.DEFAULT_STREAM_NAME);
            if (summaryInformation != null) {
                this.sInf = summaryInformation;
            }
            this.initialized = true;
        }
    }

    @Internal
    public DirectoryNode replaceDirectory(DirectoryNode directoryNode) {
        DirectoryNode directoryNode2 = this.directory;
        this.directory = directoryNode;
        return directoryNode2;
    }

    public void validateInPlaceWritePossible() {
        DirectoryNode directoryNode = this.directory;
        if (directoryNode == null) {
            throw new IllegalStateException("Newly created Document, cannot save in-place");
        } else if (directoryNode.getParent() != null) {
            throw new IllegalStateException("This is not the root Document, cannot save embedded resource in-place");
        } else if (this.directory.getFileSystem() == null || !this.directory.getFileSystem().isInPlaceWriteable()) {
            throw new IllegalStateException("Opened read-only or via an InputStream, a Writeable File is required");
        }
    }

    public abstract void write();

    public abstract void write(File file);

    public abstract void write(OutputStream outputStream);

    public void writeProperties() {
        validateInPlaceWritePossible();
        writeProperties(this.directory.getFileSystem(), null);
    }

    public void writePropertySet(String str, PropertySet propertySet, NPOIFSFileSystem nPOIFSFileSystem) {
        try {
            PropertySet propertySet2 = new PropertySet(propertySet);
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            propertySet2.write(byteArrayOutputStream);
            byte[] byteArray = byteArrayOutputStream.toByteArray();
            nPOIFSFileSystem.createOrUpdateDocument(new ByteArrayInputStream(byteArray), str);
            POILogger pOILogger = logger;
            pOILogger.log(3, "Wrote property set " + str + " of size " + byteArray.length);
        } catch (WritingNotSupportedException unused) {
            logger.log(7, a.b("Couldn't write property set with name ", str, " as not supported by HPSF yet"));
        }
    }

    /* JADX INFO: finally extract failed */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0048, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x004a, code lost:
        r7 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:34:0x0074, code lost:
        r7 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:35:0x0075, code lost:
        r2 = r8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:0x0099, code lost:
        r7 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:48:?, code lost:
        throw r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:49:?, code lost:
        throw r7;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x004a A[ExcHandler: IOException (r7v6 'e' java.io.IOException A[CUSTOM_DECLARE]), Splitter:B:2:0x0007] */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x0074 A[ExcHandler: all (th java.lang.Throwable), Splitter:B:10:0x0023] */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x0099 A[Catch:{ IOException -> 0x0099, Exception -> 0x0071, all -> 0x0074, IOException -> 0x004a, Exception -> 0x0044, all -> 0x0046 }, ExcHandler: IOException (r7v2 'e' java.io.IOException A[CUSTOM_DECLARE, Catch:{  }]), Splitter:B:10:0x0023] */
    public PropertySet getPropertySet(String str, EncryptionInfo encryptionInfo) {
        Exception e2;
        POIFSFileSystem pOIFSFileSystem;
        DirectoryNode directoryNode = this.directory;
        String str2 = "getting";
        POIFSFileSystem pOIFSFileSystem2 = null;
        if (encryptionInfo != null) {
            try {
                if (encryptionInfo.isDocPropsEncrypted()) {
                    String encryptedPropertyStreamName = getEncryptedPropertyStreamName();
                    if (directoryNode.hasEntry(encryptedPropertyStreamName)) {
                        pOIFSFileSystem = ((CryptoAPIDecryptor) encryptionInfo.getDecryptor()).getSummaryEntries(directoryNode, encryptedPropertyStreamName);
                        try {
                            directoryNode = pOIFSFileSystem.getRoot();
                            if (directoryNode != null || !directoryNode.hasEntry(str)) {
                                IOUtils.closeQuietly(pOIFSFileSystem);
                                return null;
                            }
                            DocumentInputStream createDocumentInputStream = directoryNode.createDocumentInputStream(directoryNode.getEntry(str));
                            try {
                                PropertySet create = PropertySetFactory.create(createDocumentInputStream);
                                createDocumentInputStream.close();
                                IOUtils.closeQuietly(pOIFSFileSystem);
                                return create;
                            } catch (Throwable th) {
                                createDocumentInputStream.close();
                                throw th;
                            }
                        } catch (IOException e3) {
                        } catch (Exception e4) {
                            e2 = e4;
                            pOIFSFileSystem2 = pOIFSFileSystem;
                            str2 = "getting encrypted";
                            throw new IOException("Error " + str2 + " property set with name " + str, e2);
                        } catch (Throwable th2) {
                        }
                    } else {
                        throw new EncryptedDocumentException("can't find encrypted property stream '" + encryptedPropertyStreamName + "'");
                    }
                }
            } catch (IOException e32) {
            } catch (Exception e5) {
                e2 = e5;
                pOIFSFileSystem2 = pOIFSFileSystem;
                throw new IOException("Error " + str2 + " property set with name " + str, e2);
            } catch (IOException e6) {
            } catch (Exception e7) {
                e2 = e7;
                str2 = "getting encrypted";
                throw new IOException("Error " + str2 + " property set with name " + str, e2);
            } catch (Throwable th3) {
                Throwable th4 = th3;
                IOUtils.closeQuietly(pOIFSFileSystem2);
                throw th4;
            }
        }
        pOIFSFileSystem = null;
        if (directoryNode != null) {
        }
        IOUtils.closeQuietly(pOIFSFileSystem);
        return null;
    }

    public POIDocument(OPOIFSFileSystem oPOIFSFileSystem) {
        this(oPOIFSFileSystem.getRoot());
    }

    public void writeProperties(NPOIFSFileSystem nPOIFSFileSystem) {
        writeProperties(nPOIFSFileSystem, null);
    }

    public POIDocument(NPOIFSFileSystem nPOIFSFileSystem) {
        this(nPOIFSFileSystem.getRoot());
    }

    public void writeProperties(NPOIFSFileSystem nPOIFSFileSystem, List<String> list) {
        EncryptionInfo encryptionInfo = getEncryptionInfo();
        boolean z = encryptionInfo != null && encryptionInfo.isDocPropsEncrypted();
        NPOIFSFileSystem nPOIFSFileSystem2 = z ? new NPOIFSFileSystem() : nPOIFSFileSystem;
        SummaryInformation summaryInformation = getSummaryInformation();
        if (summaryInformation != null) {
            writePropertySet(SummaryInformation.DEFAULT_STREAM_NAME, summaryInformation, nPOIFSFileSystem2);
            if (list != null) {
                list.add(SummaryInformation.DEFAULT_STREAM_NAME);
            }
        }
        DocumentSummaryInformation documentSummaryInformation = getDocumentSummaryInformation();
        if (documentSummaryInformation != null) {
            writePropertySet(DocumentSummaryInformation.DEFAULT_STREAM_NAME, documentSummaryInformation, nPOIFSFileSystem2);
            if (list != null) {
                list.add(DocumentSummaryInformation.DEFAULT_STREAM_NAME);
            }
        }
        if (z) {
            writePropertySet(DocumentSummaryInformation.DEFAULT_STREAM_NAME, PropertySetFactory.newDocumentSummaryInformation(), nPOIFSFileSystem);
            if (nPOIFSFileSystem.getRoot().hasEntry(SummaryInformation.DEFAULT_STREAM_NAME)) {
                nPOIFSFileSystem.getRoot().getEntry(SummaryInformation.DEFAULT_STREAM_NAME).delete();
            }
            Encryptor encryptor = encryptionInfo.getEncryptor();
            if (encryptor instanceof CryptoAPIEncryptor) {
                try {
                    ((CryptoAPIEncryptor) encryptor).setSummaryEntries(nPOIFSFileSystem.getRoot(), getEncryptedPropertyStreamName(), nPOIFSFileSystem2);
                    nPOIFSFileSystem2.close();
                } catch (GeneralSecurityException e2) {
                    throw new IOException(e2);
                } catch (Throwable th) {
                    nPOIFSFileSystem2.close();
                    throw th;
                }
            } else {
                StringBuilder b2 = a.b("Using ");
                b2.append(encryptionInfo.getEncryptionMode());
                b2.append(" encryption. Only CryptoAPI encryption supports encrypted property sets!");
                throw new EncryptedDocumentException(b2.toString());
            }
        }
    }

    public POIDocument(POIFSFileSystem pOIFSFileSystem) {
        this(pOIFSFileSystem.getRoot());
    }
}
