package org.apache.poi;

import java.io.Closeable;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.exceptions.OpenXML4JException;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.openxml4j.opc.PackageAccess;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.openxml4j.opc.PackageRelationshipCollection;
import org.apache.poi.poifs.filesystem.DocumentFactoryHelper;
import org.apache.xmlbeans.impl.common.SystemCache;

public abstract class POIXMLDocument extends POIXMLDocumentPart implements Closeable {
    public static final String DOCUMENT_CREATOR = "Apache POI";
    public static final String OLE_OBJECT_REL_TYPE = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/oleObject";
    public static final String PACK_OBJECT_REL_TYPE = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/package";
    public OPCPackage pkg;
    public POIXMLProperties properties;

    public POIXMLDocument(OPCPackage oPCPackage) {
        super(oPCPackage);
        init(oPCPackage);
    }

    @Deprecated
    public static boolean hasOOXMLHeader(InputStream inputStream) {
        return DocumentFactoryHelper.hasOOXMLHeader(inputStream);
    }

    private void init(OPCPackage oPCPackage) {
        this.pkg = oPCPackage;
        SystemCache.get().setSaxLoader(null);
    }

    public static OPCPackage openPackage(String str) {
        try {
            return OPCPackage.open(str);
        } catch (InvalidFormatException e2) {
            throw new IOException(e2.toString(), e2);
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        OPCPackage oPCPackage = this.pkg;
        if (oPCPackage != null) {
            if (oPCPackage.getPackageAccess() == PackageAccess.READ) {
                this.pkg.revert();
            } else {
                this.pkg.close();
            }
            this.pkg = null;
        }
    }

    public abstract List<PackagePart> getAllEmbedds();

    public PackagePart getCorePart() {
        return getPackagePart();
    }

    public OPCPackage getPackage() {
        return this.pkg;
    }

    public POIXMLProperties getProperties() {
        if (this.properties == null) {
            try {
                this.properties = new POIXMLProperties(this.pkg);
            } catch (Exception e2) {
                throw new POIXMLException(e2);
            }
        }
        return this.properties;
    }

    public PackagePart[] getRelatedByType(String str) {
        PackageRelationshipCollection relationshipsByType = getPackagePart().getRelationshipsByType(str);
        PackagePart[] packagePartArr = new PackagePart[relationshipsByType.size()];
        Iterator<PackageRelationship> it = relationshipsByType.iterator();
        int i2 = 0;
        while (it.hasNext()) {
            packagePartArr[i2] = getPackagePart().getRelatedPart(it.next());
            i2++;
        }
        return packagePartArr;
    }

    public final void load(POIXMLFactory pOIXMLFactory) {
        HashMap hashMap = new HashMap();
        try {
            read(pOIXMLFactory, hashMap);
            onDocumentRead();
            hashMap.clear();
        } catch (OpenXML4JException e2) {
            throw new POIXMLException(e2);
        }
    }

    public final void write(OutputStream outputStream) {
        OPCPackage oPCPackage = getPackage();
        if (oPCPackage != null) {
            HashSet hashSet = new HashSet();
            onSave(hashSet);
            hashSet.clear();
            getProperties().commit();
            oPCPackage.save(outputStream);
            return;
        }
        throw new IOException("Cannot write data, document seems to have been closed already");
    }

    public POIXMLDocument(OPCPackage oPCPackage, String str) {
        super(oPCPackage, str);
        init(oPCPackage);
    }
}
