package org.apache.poi;

import b.b.a.a.a;
import java.io.IOException;
import java.net.URI;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.exceptions.PartAlreadyExistsException;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.PackagePartName;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.openxml4j.opc.PackageRelationshipCollection;
import org.apache.poi.openxml4j.opc.PackagingURIHelper;
import org.apache.poi.openxml4j.opc.TargetMode;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class POIXMLDocumentPart {
    public static final POILogger logger = POILogFactory.getLogger(POIXMLDocumentPart.class);
    public String coreDocumentRel;
    public PackagePart packagePart;
    public POIXMLDocumentPart parent;
    public int relationCounter;
    public Map<String, RelationPart> relations;

    public static class RelationPart {
        public final POIXMLDocumentPart documentPart;
        public final PackageRelationship relationship;

        public RelationPart(PackageRelationship packageRelationship, POIXMLDocumentPart pOIXMLDocumentPart) {
            this.relationship = packageRelationship;
            this.documentPart = pOIXMLDocumentPart;
        }

        public <T extends POIXMLDocumentPart> T getDocumentPart() {
            return (T) this.documentPart;
        }

        public PackageRelationship getRelationship() {
            return this.relationship;
        }
    }

    public POIXMLDocumentPart(OPCPackage oPCPackage) {
        this(oPCPackage, "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument");
    }

    @Internal
    @Deprecated
    public static void _invokeOnDocumentRead(POIXMLDocumentPart pOIXMLDocumentPart) {
        pOIXMLDocumentPart.onDocumentRead();
    }

    public static PackagePart getPartFromOPCPackage(OPCPackage oPCPackage, String str) {
        PackageRelationship relationship = oPCPackage.getRelationshipsByType(str).getRelationship(0);
        if (relationship != null) {
            PackagePart part = oPCPackage.getPart(relationship);
            if (part != null) {
                return part;
            }
            StringBuilder b2 = a.b("OOXML file structure broken/invalid - core document '");
            b2.append(relationship.getTargetURI());
            b2.append("' not found.");
            throw new POIXMLException(b2.toString());
        } else if (oPCPackage.getRelationshipsByType("http://purl.oclc.org/ooxml/officeDocument/relationships/officeDocument").getRelationship(0) != null) {
            throw new POIXMLException("Strict OOXML isn't currently supported, please see bug #57699");
        } else {
            throw new POIXMLException("OOXML file structure broken/invalid - no core document found!");
        }
    }

    public final RelationPart addRelation(String str, POIXMLRelation pOIXMLRelation, POIXMLDocumentPart pOIXMLDocumentPart) {
        PackageRelationship findExistingRelation = this.packagePart.findExistingRelation(pOIXMLDocumentPart.getPackagePart());
        if (findExistingRelation == null) {
            findExistingRelation = this.packagePart.addRelationship(pOIXMLDocumentPart.getPackagePart().getPartName(), TargetMode.INTERNAL, pOIXMLRelation.getRelation(), str);
        }
        addRelation(findExistingRelation, pOIXMLDocumentPart);
        return new RelationPart(findExistingRelation, pOIXMLDocumentPart);
    }

    public void commit() {
    }

    public final POIXMLDocumentPart createRelationship(POIXMLRelation pOIXMLRelation, POIXMLFactory pOIXMLFactory) {
        return createRelationship(pOIXMLRelation, pOIXMLFactory, -1, false).getDocumentPart();
    }

    public int decrementRelationCounter() {
        int i2 = this.relationCounter - 1;
        this.relationCounter = i2;
        return i2;
    }

    public final int getNextPartNumber(POIXMLRelation pOIXMLRelation, int i2) {
        OPCPackage oPCPackage = this.packagePart.getPackage();
        try {
            String defaultFileName = pOIXMLRelation.getDefaultFileName();
            if (!defaultFileName.equals(pOIXMLRelation.getFileName(9999))) {
                int size = i2 + oPCPackage.getParts().size();
                for (int i3 = i2 < 0 ? 1 : i2; i3 <= size; i3++) {
                    if (!oPCPackage.containPart(PackagingURIHelper.createPartName(pOIXMLRelation.getFileName(i3)))) {
                        return i3;
                    }
                }
                return -1;
            } else if (oPCPackage.containPart(PackagingURIHelper.createPartName(defaultFileName))) {
                return -1;
            } else {
                return 0;
            }
        } catch (InvalidFormatException e2) {
            throw new POIXMLException(e2);
        }
    }

    public final PackagePart getPackagePart() {
        return this.packagePart;
    }

    public final POIXMLDocumentPart getParent() {
        return this.parent;
    }

    public final POIXMLDocumentPart getRelationById(String str) {
        RelationPart relationPart = this.relations.get(str);
        if (relationPart == null) {
            return null;
        }
        return relationPart.getDocumentPart();
    }

    public int getRelationCounter() {
        return this.relationCounter;
    }

    public final String getRelationId(POIXMLDocumentPart pOIXMLDocumentPart) {
        for (RelationPart relationPart : this.relations.values()) {
            if (relationPart.getDocumentPart() == pOIXMLDocumentPart) {
                return relationPart.getRelationship().getId();
            }
        }
        return null;
    }

    public final List<RelationPart> getRelationParts() {
        return Collections.unmodifiableList(new ArrayList(this.relations.values()));
    }

    public final List<POIXMLDocumentPart> getRelations() {
        ArrayList arrayList = new ArrayList();
        for (RelationPart relationPart : this.relations.values()) {
            arrayList.add(relationPart.getDocumentPart());
        }
        return Collections.unmodifiableList(arrayList);
    }

    public PackagePart getTargetPart(PackageRelationship packageRelationship) {
        return getPackagePart().getRelatedPart(packageRelationship);
    }

    public int incrementRelationCounter() {
        int i2 = this.relationCounter + 1;
        this.relationCounter = i2;
        return i2;
    }

    public void onDocumentCreate() {
    }

    public void onDocumentRead() {
    }

    public void onDocumentRemove() {
    }

    public final void onSave(Set<PackagePart> set) {
        prepareForCommit();
        commit();
        set.add(getPackagePart());
        for (RelationPart relationPart : this.relations.values()) {
            POIXMLDocumentPart documentPart = relationPart.getDocumentPart();
            if (!set.contains(documentPart.getPackagePart())) {
                documentPart.onSave(set);
            }
        }
    }

    public void prepareForCommit() {
        PackagePart packagePart2 = getPackagePart();
        if (packagePart2 != null) {
            packagePart2.clear();
        }
    }

    public void read(POIXMLFactory pOIXMLFactory, Map<PackagePart, POIXMLDocumentPart> map) {
        PackagePartName packagePartName;
        PackagePart packagePart2 = getPackagePart();
        POIXMLDocumentPart put = map.put(packagePart2, this);
        if (put != null && put != this) {
            throw new POIXMLException("Unique PackagePart-POIXMLDocumentPart relation broken!");
        } else if (packagePart2.hasRelationships()) {
            PackageRelationshipCollection relationships = this.packagePart.getRelationships();
            ArrayList arrayList = new ArrayList();
            Iterator<PackageRelationship> it = relationships.iterator();
            while (it.hasNext()) {
                PackageRelationship next = it.next();
                if (next.getTargetMode() == TargetMode.INTERNAL) {
                    URI targetURI = next.getTargetURI();
                    if (targetURI.getRawFragment() != null) {
                        packagePartName = PackagingURIHelper.createPartName(targetURI.getPath());
                    } else {
                        packagePartName = PackagingURIHelper.createPartName(targetURI);
                    }
                    PackagePart part = this.packagePart.getPackage().getPart(packagePartName);
                    if (part == null) {
                        POILogger pOILogger = logger;
                        StringBuilder b2 = a.b("Skipped invalid entry ");
                        b2.append(next.getTargetURI());
                        pOILogger.log(7, b2.toString());
                    } else {
                        POIXMLDocumentPart pOIXMLDocumentPart = map.get(part);
                        if (pOIXMLDocumentPart == null) {
                            pOIXMLDocumentPart = pOIXMLFactory.createDocumentPart(this, part);
                            pOIXMLDocumentPart.parent = this;
                            map.put(part, pOIXMLDocumentPart);
                            arrayList.add(pOIXMLDocumentPart);
                        }
                        addRelation(next, pOIXMLDocumentPart);
                    }
                }
            }
            Iterator it2 = arrayList.iterator();
            while (it2.hasNext()) {
                ((POIXMLDocumentPart) it2.next()).read(pOIXMLFactory, map);
            }
        }
    }

    public final void rebase(OPCPackage oPCPackage) {
        PackageRelationshipCollection relationshipsByType = this.packagePart.getRelationshipsByType(this.coreDocumentRel);
        if (relationshipsByType.size() == 1) {
            this.packagePart = this.packagePart.getRelatedPart(relationshipsByType.getRelationship(0));
            return;
        }
        StringBuilder b2 = a.b("Tried to rebase using ");
        b2.append(this.coreDocumentRel);
        b2.append(" but found ");
        b2.append(relationshipsByType.size());
        b2.append(" parts of the right type");
        throw new IllegalStateException(b2.toString());
    }

    public final void removeRelation(POIXMLDocumentPart pOIXMLDocumentPart) {
        removeRelation(pOIXMLDocumentPart, true);
    }

    public String toString() {
        PackagePart packagePart2 = this.packagePart;
        return packagePart2 == null ? "" : packagePart2.toString();
    }

    public POIXMLDocumentPart(OPCPackage oPCPackage, String str) {
        this(getPartFromOPCPackage(oPCPackage, str));
        this.coreDocumentRel = str;
    }

    public final POIXMLDocumentPart createRelationship(POIXMLRelation pOIXMLRelation, POIXMLFactory pOIXMLFactory, int i2) {
        return createRelationship(pOIXMLRelation, pOIXMLFactory, i2, false).getDocumentPart();
    }

    public final boolean removeRelation(POIXMLDocumentPart pOIXMLDocumentPart, boolean z) {
        String relationId = getRelationId(pOIXMLDocumentPart);
        if (relationId == null) {
            return false;
        }
        pOIXMLDocumentPart.decrementRelationCounter();
        getPackagePart().removeRelationship(relationId);
        this.relations.remove(relationId);
        if (!z || pOIXMLDocumentPart.getRelationCounter() != 0) {
            return true;
        }
        try {
            pOIXMLDocumentPart.onDocumentRemove();
            getPackagePart().getPackage().removePart(pOIXMLDocumentPart.getPackagePart());
            return true;
        } catch (IOException e2) {
            throw new POIXMLException(e2);
        }
    }

    public final RelationPart createRelationship(POIXMLRelation pOIXMLRelation, POIXMLFactory pOIXMLFactory, int i2, boolean z) {
        try {
            PackagePartName createPartName = PackagingURIHelper.createPartName(pOIXMLRelation.getFileName(i2));
            PackageRelationship packageRelationship = null;
            PackagePart createPart = this.packagePart.getPackage().createPart(createPartName, pOIXMLRelation.getContentType());
            if (!z) {
                packageRelationship = this.packagePart.addRelationship(createPartName, TargetMode.INTERNAL, pOIXMLRelation.getRelation());
            }
            POIXMLDocumentPart newDocumentPart = pOIXMLFactory.newDocumentPart(pOIXMLRelation);
            newDocumentPart.packagePart = createPart;
            newDocumentPart.parent = this;
            if (!z) {
                addRelation(packageRelationship, newDocumentPart);
            }
            return new RelationPart(packageRelationship, newDocumentPart);
        } catch (PartAlreadyExistsException e2) {
            throw e2;
        } catch (Exception e3) {
            throw new POIXMLException(e3);
        }
    }

    public POIXMLDocumentPart() {
        this.coreDocumentRel = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";
        this.relations = new LinkedHashMap();
        this.relationCounter = 0;
    }

    private void addRelation(PackageRelationship packageRelationship, POIXMLDocumentPart pOIXMLDocumentPart) {
        this.relations.put(packageRelationship.getId(), new RelationPart(packageRelationship, pOIXMLDocumentPart));
        pOIXMLDocumentPart.incrementRelationCounter();
    }

    public POIXMLDocumentPart(PackagePart packagePart2) {
        this((POIXMLDocumentPart) null, packagePart2);
    }

    public POIXMLDocumentPart(POIXMLDocumentPart pOIXMLDocumentPart, PackagePart packagePart2) {
        this.coreDocumentRel = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";
        this.relations = new LinkedHashMap();
        this.relationCounter = 0;
        this.packagePart = packagePart2;
        this.parent = pOIXMLDocumentPart;
    }
}
