package org.apache.poi;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
import java.io.StringReader;
import java.net.URL;
import java.util.Collections;
import java.util.HashMap;
import org.apache.poi.javax.xml.stream.XMLStreamReader;
import org.apache.poi.openxml4j.opc.PackageNamespaces;
import org.apache.poi.openxml4j.opc.PackageRelationshipTypes;
import org.apache.poi.util.DocumentHelper;
import org.apache.poi.xslf.usermodel.XSLFShape;
import org.apache.xmlbeans.SchemaType;
import org.apache.xmlbeans.SchemaTypeLoader;
import org.apache.xmlbeans.XmlBeans;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.apache.xmlbeans.xml.stream.XMLInputStream;
import org.w3c.dom.Node;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

public class POIXMLTypeLoader {
    public static final XmlOptions DEFAULT_XML_OPTIONS;
    public static ThreadLocal<ClassLoader> classLoader = new ThreadLocal<>();

    static {
        XmlOptions xmlOptions = new XmlOptions();
        DEFAULT_XML_OPTIONS = xmlOptions;
        xmlOptions.setSaveOuter();
        DEFAULT_XML_OPTIONS.setUseDefaultNamespace();
        DEFAULT_XML_OPTIONS.setSaveAggressiveNamespaces();
        DEFAULT_XML_OPTIONS.setCharacterEncoding("UTF-8");
        HashMap hashMap = new HashMap();
        hashMap.put("http://schemas.openxmlformats.org/drawingml/2006/main", "a");
        hashMap.put("http://schemas.openxmlformats.org/drawingml/2006/chart", "c");
        hashMap.put("http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing", "wp");
        hashMap.put(PackageNamespaces.MARKUP_COMPATIBILITY, "ve");
        hashMap.put("http://schemas.openxmlformats.org/officeDocument/2006/math", "m");
        hashMap.put(PackageRelationshipTypes.CORE_PROPERTIES_ECMA376_NS, "r");
        hashMap.put("http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes", "vt");
        hashMap.put(XSLFShape.PML_NS, "p");
        hashMap.put("http://schemas.openxmlformats.org/wordprocessingml/2006/main", "w");
        hashMap.put("http://schemas.microsoft.com/office/word/2006/wordml", "wne");
        hashMap.put("urn:schemas-microsoft-com:office:office", "o");
        hashMap.put("urn:schemas-microsoft-com:office:excel", "x");
        hashMap.put("urn:schemas-microsoft-com:office:word", "w10");
        hashMap.put("urn:schemas-microsoft-com:vml", "v");
        DEFAULT_XML_OPTIONS.setSaveSuggestedPrefixes(Collections.unmodifiableMap(hashMap));
    }

    public static SchemaTypeLoader getTypeLoader() {
        ClassLoader classLoader2 = classLoader.get();
        return classLoader2 == null ? XmlBeans.getContextTypeLoader() : XmlBeans.typeLoaderForClassLoader(classLoader2);
    }

    public static XmlOptions getXmlOptions(XmlOptions xmlOptions) {
        return xmlOptions == null ? DEFAULT_XML_OPTIONS : xmlOptions;
    }

    public static XmlObject newInstance(SchemaType schemaType, XmlOptions xmlOptions) {
        return getTypeLoader().newInstance(schemaType, getXmlOptions(xmlOptions));
    }

    public static XMLInputStream newValidatingXMLInputStream(XMLInputStream xMLInputStream, SchemaType schemaType, XmlOptions xmlOptions) {
        return getTypeLoader().newValidatingXMLInputStream(xMLInputStream, schemaType, getXmlOptions(xmlOptions));
    }

    public static XmlObject parse(String str, SchemaType schemaType, XmlOptions xmlOptions) {
        try {
            return parse(new StringReader(str), schemaType, xmlOptions);
        } catch (IOException e2) {
            throw new XmlException("Unable to parse xml bean", e2);
        }
    }

    public static void setClassLoader(ClassLoader classLoader2) {
        classLoader.set(classLoader2);
    }

    public static XmlObject parse(File file, SchemaType schemaType, XmlOptions xmlOptions) {
        FileInputStream fileInputStream = new FileInputStream(file);
        try {
            return parse(fileInputStream, schemaType, xmlOptions);
        } finally {
            fileInputStream.close();
        }
    }

    public static XmlObject parse(URL url, SchemaType schemaType, XmlOptions xmlOptions) {
        InputStream openStream = url.openStream();
        try {
            return parse(openStream, schemaType, xmlOptions);
        } finally {
            openStream.close();
        }
    }

    public static XmlObject parse(InputStream inputStream, SchemaType schemaType, XmlOptions xmlOptions) {
        try {
            return getTypeLoader().parse(DocumentHelper.readDocument(inputStream).getDocumentElement(), schemaType, getXmlOptions(xmlOptions));
        } catch (SAXException e2) {
            throw new IOException("Unable to parse xml bean", e2);
        }
    }

    public static XmlObject parse(XMLStreamReader xMLStreamReader, SchemaType schemaType, XmlOptions xmlOptions) {
        return getTypeLoader().parse(xMLStreamReader, schemaType, getXmlOptions(xmlOptions));
    }

    public static XmlObject parse(Reader reader, SchemaType schemaType, XmlOptions xmlOptions) {
        try {
            return getTypeLoader().parse(DocumentHelper.readDocument(new InputSource(reader)).getDocumentElement(), schemaType, getXmlOptions(xmlOptions));
        } catch (SAXException e2) {
            throw new XmlException("Unable to parse xml bean", e2);
        }
    }

    public static XmlObject parse(Node node, SchemaType schemaType, XmlOptions xmlOptions) {
        return getTypeLoader().parse(node, schemaType, getXmlOptions(xmlOptions));
    }

    public static XmlObject parse(XMLInputStream xMLInputStream, SchemaType schemaType, XmlOptions xmlOptions) {
        return getTypeLoader().parse(xMLInputStream, schemaType, getXmlOptions(xmlOptions));
    }
}
