package org.apache.poi.extractor;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.PushbackInputStream;
import java.util.ArrayList;
import java.util.Iterator;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.POIOLE2TextExtractor;
import org.apache.poi.POITextExtractor;
import org.apache.poi.POIXMLTextExtractor;
import org.apache.poi.hsmf.datatypes.AttachmentChunks;
import org.apache.poi.hsmf.extractor.OutlookTextExtactor;
import org.apache.poi.hssf.extractor.ExcelExtractor;
import org.apache.poi.hssf.record.crypto.Biff8EncryptionKey;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.extractor.WordExtractor;
import org.apache.poi.openxml4j.exceptions.OpenXML4JException;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.openxml4j.opc.PackageAccess;
import org.apache.poi.openxml4j.opc.PackageRelationshipCollection;
import org.apache.poi.poifs.crypt.Decryptor;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentFactoryHelper;
import org.apache.poi.poifs.filesystem.Entry;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.NotOLE2FileException;
import org.apache.poi.poifs.filesystem.OPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.NotImplemented;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.xdgf.extractor.XDGFVisioExtractor;
import org.apache.poi.xslf.extractor.XSLFPowerPointExtractor;
import org.apache.poi.xslf.usermodel.XSLFRelation;
import org.apache.poi.xslf.usermodel.XSLFSlideShow;
import org.apache.poi.xssf.extractor.XSSFBEventBasedExcelExtractor;
import org.apache.poi.xssf.extractor.XSSFEventBasedExcelExtractor;
import org.apache.poi.xssf.extractor.XSSFExcelExtractor;
import org.apache.poi.xssf.usermodel.XSSFRelation;
import org.apache.poi.xwpf.extractor.XWPFWordExtractor;
import org.apache.poi.xwpf.usermodel.XWPFRelation;
import org.apache.xmlbeans.XmlException;

public class ExtractorFactory {
    public static final String CORE_DOCUMENT_REL = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";
    public static final String STRICT_DOCUMENT_REL = "http://purl.oclc.org/ooxml/officeDocument/relationships/officeDocument";
    public static final String VISIO_DOCUMENT_REL = "http://schemas.microsoft.com/visio/2010/relationships/document";
    public static final POILogger logger = POILogFactory.getLogger(ExtractorFactory.class);

    public static POIXMLTextExtractor createEncyptedOOXMLExtractor(NPOIFSFileSystem nPOIFSFileSystem) {
        String currentUserPassword = Biff8EncryptionKey.getCurrentUserPassword();
        if (currentUserPassword == null) {
            currentUserPassword = Decryptor.DEFAULT_PASSWORD;
        }
        Decryptor decryptor = new EncryptionInfo(nPOIFSFileSystem).getDecryptor();
        try {
            if (decryptor.verifyPassword(currentUserPassword)) {
                InputStream dataStream = decryptor.getDataStream(nPOIFSFileSystem);
                POIXMLTextExtractor createExtractor = createExtractor(OPCPackage.open(dataStream));
                IOUtils.closeQuietly(dataStream);
                return createExtractor;
            }
            throw new EncryptedDocumentException("Invalid password specified - use Biff8EncryptionKey.setCurrentUserPassword() before calling extractor");
        } catch (IOException e2) {
            throw e2;
        } catch (Exception e3) {
            throw new EncryptedDocumentException(e3);
        } catch (Throwable th) {
            IOUtils.closeQuietly(null);
            throw th;
        }
    }

    public static POITextExtractor createExtractor(File file) {
        OpenXML4JException e2;
        XmlException e3;
        IOException e4;
        RuntimeException e5;
        NPOIFSFileSystem nPOIFSFileSystem = null;
        try {
            NPOIFSFileSystem nPOIFSFileSystem2 = new NPOIFSFileSystem(file);
            try {
                if (nPOIFSFileSystem2.getRoot().hasEntry("EncryptedPackage")) {
                    return createEncyptedOOXMLExtractor(nPOIFSFileSystem2);
                }
                POIOLE2TextExtractor createExtractor = createExtractor(nPOIFSFileSystem2);
                createExtractor.setFilesystem(nPOIFSFileSystem2);
                return createExtractor;
            } catch (OfficeXmlFileException unused) {
                nPOIFSFileSystem = nPOIFSFileSystem2;
                IOUtils.closeQuietly(nPOIFSFileSystem);
                return createExtractor(OPCPackage.open(file.toString(), PackageAccess.READ));
            } catch (NotOLE2FileException unused2) {
                nPOIFSFileSystem = nPOIFSFileSystem2;
                IOUtils.closeQuietly(nPOIFSFileSystem);
                throw new IllegalArgumentException("Your File was neither an OLE2 file, nor an OOXML file");
            } catch (OpenXML4JException e6) {
                e2 = e6;
                nPOIFSFileSystem = nPOIFSFileSystem2;
                IOUtils.closeQuietly(nPOIFSFileSystem);
                throw e2;
            } catch (XmlException e7) {
                e3 = e7;
                nPOIFSFileSystem = nPOIFSFileSystem2;
                IOUtils.closeQuietly(nPOIFSFileSystem);
                throw e3;
            } catch (IOException e8) {
                e4 = e8;
                nPOIFSFileSystem = nPOIFSFileSystem2;
                IOUtils.closeQuietly(nPOIFSFileSystem);
                throw e4;
            } catch (RuntimeException e9) {
                e5 = e9;
                nPOIFSFileSystem = nPOIFSFileSystem2;
                IOUtils.closeQuietly(nPOIFSFileSystem);
                throw e5;
            }
        } catch (OfficeXmlFileException unused3) {
            IOUtils.closeQuietly(nPOIFSFileSystem);
            return createExtractor(OPCPackage.open(file.toString(), PackageAccess.READ));
        } catch (NotOLE2FileException unused4) {
            IOUtils.closeQuietly(nPOIFSFileSystem);
            throw new IllegalArgumentException("Your File was neither an OLE2 file, nor an OOXML file");
        } catch (OpenXML4JException e10) {
            e2 = e10;
            IOUtils.closeQuietly(nPOIFSFileSystem);
            throw e2;
        } catch (XmlException e11) {
            e3 = e11;
            IOUtils.closeQuietly(nPOIFSFileSystem);
            throw e3;
        } catch (IOException e12) {
            e4 = e12;
            IOUtils.closeQuietly(nPOIFSFileSystem);
            throw e4;
        } catch (RuntimeException e13) {
            e5 = e13;
            IOUtils.closeQuietly(nPOIFSFileSystem);
            throw e5;
        }
    }

    public static Boolean getAllThreadsPreferEventExtractors() {
        return OLE2ExtractorFactory.getAllThreadsPreferEventExtractors();
    }

    public static POITextExtractor[] getEmbededDocsTextExtractors(POIOLE2TextExtractor pOIOLE2TextExtractor) {
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        DirectoryEntry root = pOIOLE2TextExtractor.getRoot();
        if (root != null) {
            if (pOIOLE2TextExtractor instanceof ExcelExtractor) {
                Iterator<Entry> entries = root.getEntries();
                while (entries.hasNext()) {
                    Entry next = entries.next();
                    if (next.getName().startsWith("MBD")) {
                        arrayList.add(next);
                    }
                }
            } else if (pOIOLE2TextExtractor instanceof WordExtractor) {
                try {
                    Iterator<Entry> entries2 = ((DirectoryEntry) root.getEntry(HWPFDocumentCore.STREAM_OBJECT_POOL)).getEntries();
                    while (entries2.hasNext()) {
                        Entry next2 = entries2.next();
                        if (next2.getName().startsWith("_")) {
                            arrayList.add(next2);
                        }
                    }
                } catch (FileNotFoundException e2) {
                    logger.log(3, "Ignoring FileNotFoundException while extracting Word document", e2.getLocalizedMessage());
                }
            } else if (pOIOLE2TextExtractor instanceof OutlookTextExtactor) {
                AttachmentChunks[] attachmentFiles = ((OutlookTextExtactor) pOIOLE2TextExtractor).getMAPIMessage().getAttachmentFiles();
                for (AttachmentChunks attachmentChunks : attachmentFiles) {
                    if (attachmentChunks.getAttachData() != null) {
                        arrayList2.add(new ByteArrayInputStream(attachmentChunks.getAttachData().getValue()));
                    } else if (attachmentChunks.getAttachmentDirectory() != null) {
                        arrayList.add(attachmentChunks.getAttachmentDirectory().getDirectory());
                    }
                }
            }
            if (arrayList.size() == 0 && arrayList2.size() == 0) {
                return new POITextExtractor[0];
            }
            ArrayList arrayList3 = new ArrayList();
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                arrayList3.add(createExtractor((DirectoryNode) ((Entry) it.next())));
            }
            Iterator it2 = arrayList2.iterator();
            while (it2.hasNext()) {
                try {
                    arrayList3.add(createExtractor((InputStream) it2.next()));
                } catch (IllegalArgumentException e3) {
                    logger.log(3, "Format not supported yet", e3.getLocalizedMessage());
                } catch (XmlException e4) {
                    throw new IOException(e4.getMessage(), e4);
                } catch (OpenXML4JException e5) {
                    throw new IOException(e5.getMessage(), e5);
                }
            }
            return (POITextExtractor[]) arrayList3.toArray(new POITextExtractor[arrayList3.size()]);
        }
        throw new IllegalStateException("The extractor didn't know which POIFS it came from!");
    }

    public static boolean getPreferEventExtractor() {
        return OLE2ExtractorFactory.getPreferEventExtractor();
    }

    public static boolean getThreadPrefersEventExtractors() {
        return OLE2ExtractorFactory.getThreadPrefersEventExtractors();
    }

    public static void setAllThreadsPreferEventExtractors(Boolean bool) {
        OLE2ExtractorFactory.setAllThreadsPreferEventExtractors(bool);
    }

    public static void setThreadPrefersEventExtractors(boolean z) {
        OLE2ExtractorFactory.setThreadPrefersEventExtractors(z);
    }

    public static POITextExtractor createExtractor(InputStream inputStream) {
        if (!inputStream.markSupported()) {
            inputStream = new PushbackInputStream(inputStream, 8);
        }
        if (NPOIFSFileSystem.hasPOIFSHeader(inputStream)) {
            NPOIFSFileSystem nPOIFSFileSystem = new NPOIFSFileSystem(inputStream);
            return nPOIFSFileSystem.getRoot().hasEntry("EncryptedPackage") ? createEncyptedOOXMLExtractor(nPOIFSFileSystem) : createExtractor(nPOIFSFileSystem);
        } else if (DocumentFactoryHelper.hasOOXMLHeader(inputStream)) {
            return createExtractor(OPCPackage.open(inputStream));
        } else {
            throw new IllegalArgumentException("Your InputStream was neither an OLE2 stream, nor an OOXML stream");
        }
    }

    public static POIXMLTextExtractor createExtractor(OPCPackage oPCPackage) {
        try {
            PackageRelationshipCollection relationshipsByType = oPCPackage.getRelationshipsByType("http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument");
            if (relationshipsByType.size() == 0) {
                relationshipsByType = oPCPackage.getRelationshipsByType("http://purl.oclc.org/ooxml/officeDocument/relationships/officeDocument");
            }
            if (relationshipsByType.size() == 0) {
                relationshipsByType = oPCPackage.getRelationshipsByType("http://schemas.microsoft.com/visio/2010/relationships/document");
                if (relationshipsByType.size() == 1) {
                    return new XDGFVisioExtractor(oPCPackage);
                }
            }
            if (relationshipsByType.size() == 1) {
                String contentType = oPCPackage.getPart(relationshipsByType.getRelationship(0)).getContentType();
                for (XSSFRelation xSSFRelation : XSSFExcelExtractor.SUPPORTED_TYPES) {
                    if (xSSFRelation.getContentType().equals(contentType)) {
                        if (getPreferEventExtractor()) {
                            return new XSSFEventBasedExcelExtractor(oPCPackage);
                        } else {
                            return new XSSFExcelExtractor(oPCPackage);
                        }
                    }
                }
                for (XWPFRelation xWPFRelation : XWPFWordExtractor.SUPPORTED_TYPES) {
                    if (xWPFRelation.getContentType().equals(contentType)) {
                        return new XWPFWordExtractor(oPCPackage);
                    }
                }
                for (XSLFRelation xSLFRelation : XSLFPowerPointExtractor.SUPPORTED_TYPES) {
                    if (xSLFRelation.getContentType().equals(contentType)) {
                        return new XSLFPowerPointExtractor(oPCPackage);
                    }
                }
                if (XSLFRelation.THEME_MANAGER.getContentType().equals(contentType)) {
                    return new XSLFPowerPointExtractor(new XSLFSlideShow(oPCPackage));
                }
                for (XSSFRelation xSSFRelation2 : XSSFBEventBasedExcelExtractor.SUPPORTED_TYPES) {
                    if (xSSFRelation2.getContentType().equals(contentType)) {
                        return new XSSFBEventBasedExcelExtractor(oPCPackage);
                    }
                }
                throw new IllegalArgumentException("No supported documents found in the OOXML package (found " + contentType + ")");
            }
            throw new IllegalArgumentException("Invalid OOXML Package received - expected 1 core document, found " + relationshipsByType.size());
        } catch (IOException e2) {
            oPCPackage.revert();
            throw e2;
        } catch (OpenXML4JException e3) {
            oPCPackage.revert();
            throw e3;
        } catch (XmlException e4) {
            oPCPackage.revert();
            throw e4;
        } catch (RuntimeException e5) {
            oPCPackage.revert();
            throw e5;
        }
    }

    @NotImplemented
    public static POITextExtractor[] getEmbededDocsTextExtractors(POIXMLTextExtractor pOIXMLTextExtractor) {
        throw new IllegalStateException("Not yet supported");
    }

    public static POIOLE2TextExtractor createExtractor(POIFSFileSystem pOIFSFileSystem) {
        return OLE2ExtractorFactory.createExtractor(pOIFSFileSystem);
    }

    public static POIOLE2TextExtractor createExtractor(NPOIFSFileSystem nPOIFSFileSystem) {
        return OLE2ExtractorFactory.createExtractor(nPOIFSFileSystem);
    }

    public static POIOLE2TextExtractor createExtractor(OPOIFSFileSystem oPOIFSFileSystem) {
        return OLE2ExtractorFactory.createExtractor(oPOIFSFileSystem);
    }

    public static POITextExtractor createExtractor(DirectoryNode directoryNode) {
        for (String str : directoryNode.getEntryNames()) {
            if (str.equals("Package")) {
                return createExtractor(OPCPackage.open(directoryNode.createDocumentInputStream("Package")));
            }
        }
        return OLE2ExtractorFactory.createExtractor(directoryNode);
    }
}
