package org.apache.poi.hemf.record;

import org.apache.poi.hemf.record.HemfCommentPublic;
import org.apache.poi.hpsf.Filetime;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianInputStream;
import org.apache.poi.util.RecordFormatException;

@Internal
public class HemfCommentRecord implements HemfRecord {
    public static final long COMMENT_EMFPLUS = 726027589;
    public static final long COMMENT_EMFSPOOL = 0;
    public static final long COMMENT_PUBLIC = 1128875079;
    public static final int MAX_RECORD_LENGTH = 1000000;
    public AbstractHemfComment comment;

    public static class CommentPublicParser {
        public static final long BEGINGROUP = 2;
        public static final long ENDGROUP = 3;
        public static final long MULTIFORMATS = 1073741828;
        public static final long UNICODE_END = 128;
        public static final long UNICODE_STRING = 64;
        public static final long WINDOWS_METAFILE = 2147483649L;

        public static AbstractHemfComment parse(byte[] bArr) {
            long uInt = LittleEndian.getUInt(bArr, 0);
            if (uInt == WINDOWS_METAFILE) {
                return new HemfCommentPublic.WindowsMetafile(bArr);
            }
            if (uInt == 2) {
                return new HemfCommentPublic.BeginGroup(bArr);
            }
            if (uInt == 3) {
                return new HemfCommentPublic.EndGroup(bArr);
            }
            if (uInt == MULTIFORMATS) {
                return new HemfCommentPublic.MultiFormats(bArr);
            }
            if (uInt == 64 || uInt == 128) {
                throw new RuntimeException("UNICODE_STRING/UNICODE_END values are reserved in CommentPublic records");
            }
            throw new RuntimeException("Unrecognized public comment type:" + uInt + " ; " + WINDOWS_METAFILE);
        }
    }

    private byte[] readToByteArray(byte[] bArr, LittleEndianInputStream littleEndianInputStream, long j, long j2) {
        if (j > 2147483647L) {
            throw new RecordFormatException("Data size can't be > Integer.MAX_VALUE");
        } else if (j2 > 2147483647L) {
            throw new RecordFormatException("Record size can't be > Integer.MAX_VALUE");
        } else if (j2 == 0) {
            return new byte[0];
        } else {
            int i2 = (int) j;
            int i3 = (int) j2;
            byte[] safelyAllocate = IOUtils.safelyAllocate((long) (bArr.length + i2), 1000000);
            System.arraycopy(bArr, 0, safelyAllocate, 0, bArr.length);
            if (((long) IOUtils.readFully(littleEndianInputStream, safelyAllocate, bArr.length, i2)) == ((long) i2)) {
                long j3 = (long) (i3 - i2);
                if (j3 == IOUtils.skipFully(littleEndianInputStream, j3)) {
                    return safelyAllocate;
                }
                throw new RecordFormatException("InputStream ended before full record could be read");
            }
            throw new RecordFormatException("InputStream ended before full record could be read");
        }
    }

    public AbstractHemfComment getComment() {
        return this.comment;
    }

    @Override // org.apache.poi.hemf.record.HemfRecord
    public HemfRecordType getRecordType() {
        return HemfRecordType.comment;
    }

    @Override // org.apache.poi.hemf.record.HemfRecord
    public long init(LittleEndianInputStream littleEndianInputStream, long j, long j2) {
        long readUInt = littleEndianInputStream.readUInt();
        byte[] bArr = new byte[4];
        littleEndianInputStream.readFully(bArr);
        long j3 = readUInt - 4;
        long j4 = (j2 - 4) - 4;
        long j5 = ((long) LittleEndian.getInt(bArr)) & Filetime.UINT_MASK;
        if (j5 == 0) {
            this.comment = new HemfCommentEMFSpool(readToByteArray(littleEndianInputStream, j3, j4));
        } else if (j5 == COMMENT_EMFPLUS) {
            this.comment = new HemfCommentEMFPlus(readToByteArray(littleEndianInputStream, j3, j4));
        } else if (j5 == COMMENT_PUBLIC) {
            this.comment = CommentPublicParser.parse(readToByteArray(littleEndianInputStream, j3, j4));
        } else {
            this.comment = new HemfComment(readToByteArray(bArr, littleEndianInputStream, j3, j4));
        }
        return j4;
    }

    private byte[] readToByteArray(LittleEndianInputStream littleEndianInputStream, long j, long j2) {
        if (j2 == 0) {
            return new byte[0];
        }
        byte[] safelyAllocate = IOUtils.safelyAllocate(j, 1000000);
        if (((long) IOUtils.readFully(littleEndianInputStream, safelyAllocate)) == j) {
            long j3 = j2 - j;
            if (j3 == IOUtils.skipFully(littleEndianInputStream, j3)) {
                return safelyAllocate;
            }
            throw new RecordFormatException("InputStream ended before full record could be read");
        }
        throw new RecordFormatException("InputStream ended before full record could be read");
    }
}
