package org.apache.poi.hemf.record;

import java.io.ByteArrayInputStream;
import java.io.EOFException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.nio.charset.Charset;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianInputStream;
import org.apache.poi.util.RecordFormatException;

@Internal
public class HemfText {
    public static final int MAX_RECORD_LENGTH = 1000000;
    public static final Charset UTF16LE = Charset.forName("UTF-16LE");

    public static class EmrTextObject {
        public int numChars;
        public byte[] rawTextBytes;
        public long x;
        public long y;

        public EmrTextObject(byte[] bArr, Charset charset, int i2) {
            this.x = LittleEndian.getUInt(bArr, 0);
            this.y = LittleEndian.getUInt(bArr, 4);
            long uInt = LittleEndian.getUInt(bArr, 8);
            int uInt2 = (((int) LittleEndian.getUInt(bArr, 12)) - 16) - i2;
            int i3 = (uInt > 0 ? 1 : (uInt == 0 ? 0 : -1));
            if (i3 == 0) {
                this.rawTextBytes = new byte[0];
                this.numChars = 0;
            } else if (uInt > 2147483647L) {
                throw new RecordFormatException("Number of characters can't be > Integer.MAX_VALUE");
            } else if (i3 >= 0) {
                this.numChars = (int) uInt;
                byte[] safelyAllocate = IOUtils.safelyAllocate((long) (bArr.length - uInt2), 1000000);
                this.rawTextBytes = safelyAllocate;
                System.arraycopy(bArr, uInt2, safelyAllocate, 0, bArr.length - uInt2);
            } else {
                throw new RecordFormatException("Number of characters can't be < 0");
            }
        }

        private int readCodePoint(Reader reader) {
            int read = reader.read();
            if (read != -1) {
                char c = (char) read;
                if (!Character.isHighSurrogate(c)) {
                    return read;
                }
                int read2 = reader.read();
                if (read2 != -1) {
                    char c2 = (char) read2;
                    if (Character.isLowSurrogate(c2)) {
                        return Character.toCodePoint(c, c2);
                    }
                    throw new RecordFormatException("Expected low surrogate after high surrogate");
                }
                throw new EOFException("Tried to read beyond byte array");
            }
            throw new EOFException("Tried to read beyond byte array");
        }

        public String getText(Charset charset) {
            Throwable th;
            StringBuilder sb = new StringBuilder();
            InputStreamReader inputStreamReader = null;
            try {
                InputStreamReader inputStreamReader2 = new InputStreamReader(new ByteArrayInputStream(this.rawTextBytes), charset);
                for (int i2 = 0; i2 < this.numChars; i2++) {
                    try {
                        sb.appendCodePoint(readCodePoint(inputStreamReader2));
                    } catch (Throwable th2) {
                        th = th2;
                        inputStreamReader = inputStreamReader2;
                        IOUtils.closeQuietly(inputStreamReader);
                        throw th;
                    }
                }
                IOUtils.closeQuietly(inputStreamReader2);
                return sb.toString();
            } catch (Throwable th3) {
                th = th3;
                IOUtils.closeQuietly(inputStreamReader);
                throw th;
            }
        }
    }

    public static class ExtCreateFontIndirectW extends UnimplementedHemfRecord {
    }

    public static class ExtTextOutA implements HemfRecord {
        public long bottom;
        public long exScale;
        public long eyScale;
        public long graphicsMode;
        public long left;
        public long right;
        public EmrTextObject textObject;
        public long top;

        public long getBottom() {
            return this.bottom;
        }

        public Charset getEncodingHint() {
            return null;
        }

        public long getExScale() {
            return this.exScale;
        }

        public long getEyScale() {
            return this.eyScale;
        }

        public long getGraphicsMode() {
            return this.graphicsMode;
        }

        public long getLeft() {
            return this.left;
        }

        @Override // org.apache.poi.hemf.record.HemfRecord
        public HemfRecordType getRecordType() {
            return HemfRecordType.exttextouta;
        }

        public long getRight() {
            return this.right;
        }

        public String getText(Charset charset) {
            return this.textObject.getText(charset);
        }

        public long getTop() {
            return this.top;
        }

        public long getX() {
            return this.textObject.x;
        }

        public long getY() {
            return this.textObject.y;
        }

        @Override // org.apache.poi.hemf.record.HemfRecord
        public long init(LittleEndianInputStream littleEndianInputStream, long j, long j2) {
            this.left = (long) littleEndianInputStream.readInt();
            this.top = (long) littleEndianInputStream.readInt();
            this.right = (long) littleEndianInputStream.readInt();
            this.bottom = (long) littleEndianInputStream.readInt();
            this.graphicsMode = littleEndianInputStream.readUInt();
            this.exScale = littleEndianInputStream.readUInt();
            this.eyScale = littleEndianInputStream.readUInt();
            if (j2 < 2147483647L) {
                byte[] safelyAllocate = IOUtils.safelyAllocate((long) (((int) j2) - 28), 1000000);
                IOUtils.readFully(littleEndianInputStream, safelyAllocate);
                this.textObject = new EmrTextObject(safelyAllocate, getEncodingHint(), 20);
                return j2;
            }
            throw new RecordFormatException("can't have text length > Integer.MAX_VALUE");
        }
    }

    public static class ExtTextOutW extends ExtTextOutA {
        @Override // org.apache.poi.hemf.record.HemfText.ExtTextOutA
        public Charset getEncodingHint() {
            return HemfText.UTF16LE;
        }

        @Override // org.apache.poi.hemf.record.HemfRecord, org.apache.poi.hemf.record.HemfText.ExtTextOutA
        public HemfRecordType getRecordType() {
            return HemfRecordType.exttextoutw;
        }

        public String getText() {
            return getText(HemfText.UTF16LE);
        }
    }

    public static class PolyTextOutA extends UnimplementedHemfRecord {
    }

    public static class PolyTextOutW extends UnimplementedHemfRecord {
    }

    public static class SetTextAlign extends UnimplementedHemfRecord {
    }

    public static class SetTextColor extends UnimplementedHemfRecord {
    }

    public static class SetTextJustification extends UnimplementedHemfRecord {
    }
}
