package org.apache.poi.hpsf;

import i.a.a.a.m.a;
import java.io.UnsupportedEncodingException;
import java.math.BigInteger;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.poi.util.CodePageUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class CustomProperties implements Map<String, Object> {
    public static final POILogger LOG = POILogFactory.getLogger(CustomProperties.class);
    public int codepage = -1;
    public final a<Long, String> dictionary = new a<>();
    public boolean isPure = true;
    public final HashMap<Long, CustomProperty> props = new HashMap<>();

    private void checkCodePage(String str) {
        String str2;
        int codepage2 = getCodepage();
        if (codepage2 == -1) {
            codepage2 = 1252;
        }
        if (codepage2 != 1200) {
            try {
                str2 = CodePageUtil.codepageToEncoding(codepage2, false);
            } catch (UnsupportedEncodingException unused) {
                LOG.log(7, b.b.a.a.a.b("Codepage '", codepage2, "' can't be found."));
                str2 = "";
            }
            if (str2.isEmpty() || !Charset.forName(str2).newEncoder().canEncode(str)) {
                LOG.log(1, b.b.a.a.a.b("Charset '", str2, "' can't encode '", str, "' - switching to unicode."));
                setCodepage(1200);
            }
        }
    }

    public void clear() {
        this.props.clear();
    }

    public boolean containsKey(Object obj) {
        return ((obj instanceof Long) && this.dictionary.containsKey(obj)) || this.dictionary.containsValue(obj);
    }

    public boolean containsValue(Object obj) {
        if (obj instanceof CustomProperty) {
            return this.props.containsValue(obj);
        }
        for (CustomProperty customProperty : this.props.values()) {
            if (customProperty.getValue() == obj) {
                return true;
            }
        }
        return false;
    }

    @Override // java.util.Map
    public Set<Map.Entry<String, Object>> entrySet() {
        LinkedHashMap linkedHashMap = new LinkedHashMap(this.props.size());
        for (Map.Entry<Long, String> entry : this.dictionary.entrySet()) {
            linkedHashMap.put(entry.getValue(), this.props.get(entry.getKey()).getValue());
        }
        return Collections.unmodifiableSet(linkedHashMap.entrySet());
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof CustomProperties)) {
            return false;
        }
        return this.props.equals(((CustomProperties) obj).props);
    }

    @Override // java.util.Map
    public Object get(Object obj) {
        CustomProperty customProperty = this.props.get(this.dictionary.c(obj));
        if (customProperty != null) {
            return customProperty.getValue();
        }
        return null;
    }

    public int getCodepage() {
        return this.codepage;
    }

    public Map<Long, String> getDictionary() {
        return this.dictionary;
    }

    public int hashCode() {
        return this.props.hashCode();
    }

    public Set<Long> idSet() {
        return Collections.unmodifiableSet(this.dictionary.keySet());
    }

    public boolean isEmpty() {
        return this.props.isEmpty();
    }

    public boolean isPure() {
        return this.isPure;
    }

    /* Return type fixed from 'java.util.Set' to match base method */
    @Override // java.util.Map
    public Set<String> keySet() {
        return Collections.unmodifiableSet(this.dictionary.values());
    }

    public Set<String> nameSet() {
        return Collections.unmodifiableSet(this.dictionary.values());
    }

    public List<CustomProperty> properties() {
        ArrayList arrayList = new ArrayList(this.props.size());
        for (Long l : this.dictionary.keySet()) {
            arrayList.add(this.props.get(l));
        }
        return Collections.unmodifiableList(arrayList);
    }

    @Override // java.util.Map
    public void putAll(Map<? extends String, ? extends Object> map) {
        for (Map.Entry<? extends String, ? extends Object> entry : map.entrySet()) {
            put((String) entry.getKey(), entry.getValue());
        }
    }

    public void setCodepage(int i2) {
        this.codepage = i2;
    }

    public void setPure(boolean z) {
        this.isPure = z;
    }

    public int size() {
        return this.props.size();
    }

    @Override // java.util.Map
    public Collection<Object> values() {
        ArrayList arrayList = new ArrayList(this.props.size());
        for (Long l : this.dictionary.keySet()) {
            arrayList.add(this.props.get(l).getValue());
        }
        return Collections.unmodifiableCollection(arrayList);
    }

    public CustomProperty put(String str, CustomProperty customProperty) {
        if (str == null) {
            this.isPure = false;
            return null;
        } else if (str.equals(customProperty.getName())) {
            checkCodePage(str);
            this.props.remove(this.dictionary.c(str));
            this.dictionary.put(Long.valueOf(customProperty.getID()), str);
            return this.props.put(Long.valueOf(customProperty.getID()), customProperty);
        } else {
            StringBuilder d2 = b.b.a.a.a.d("Parameter \"name\" (", str, ") and custom property's name (");
            d2.append(customProperty.getName());
            d2.append(") do not match.");
            throw new IllegalArgumentException(d2.toString());
        }
    }

    /* Return type fixed from 'org.apache.poi.hpsf.CustomProperty' to match base method */
    @Override // java.util.Map
    public Object remove(Object obj) {
        return this.props.remove(this.dictionary.b(obj));
    }

    public Object put(String str, Object obj) {
        int i2 = 64;
        if (obj instanceof String) {
            i2 = 30;
        } else if (obj instanceof Short) {
            i2 = 2;
        } else if (obj instanceof Integer) {
            i2 = 3;
        } else if (obj instanceof Long) {
            i2 = 20;
        } else if (obj instanceof Float) {
            i2 = 4;
        } else if (obj instanceof Double) {
            i2 = 5;
        } else if (obj instanceof Boolean) {
            i2 = 11;
        } else {
            if (obj instanceof BigInteger) {
                BigInteger bigInteger = (BigInteger) obj;
                if (bigInteger.bitLength() <= 64 && bigInteger.compareTo(BigInteger.ZERO) >= 0) {
                    i2 = 21;
                }
            }
            if (!(obj instanceof Date)) {
                throw new IllegalStateException("unsupported datatype - currently String,Short,Integer,Long,Float,Double,Boolean,BigInteger(unsigned long),Date can be processed.");
            }
        }
        return put(new CustomProperty(new MutableProperty(-1, (long) i2, obj), str));
    }

    private Object put(CustomProperty customProperty) {
        Long l;
        String name = customProperty.getName();
        if (name == null) {
            l = null;
        } else {
            l = this.dictionary.c(name);
        }
        if (l != null) {
            customProperty.setID(l.longValue());
        } else {
            customProperty.setID(Math.max(this.dictionary.isEmpty() ? 0 : this.dictionary.b().longValue(), 31L) + 1);
        }
        return put(name, customProperty);
    }
}
