package org.apache.poi.hpsf;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.UnsupportedEncodingException;
import java.nio.charset.Charset;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.concurrent.TimeUnit;
import javax.xml.bind.DatatypeConverter;
import org.apache.poi.hpsf.wellknown.PropertyIDMap;
import org.apache.poi.util.CodePageUtil;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayInputStream;
import org.apache.poi.util.LocaleUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class Property {
    public static final int DEFAULT_CODEPAGE = 1252;
    public static final POILogger LOG = POILogFactory.getLogger(Property.class);
    public long id;
    public long type;
    public Object value;

    public Property() {
    }

    private String decodeValueFromID() {
        try {
            int id2 = (int) getID();
            if (id2 == Integer.MIN_VALUE) {
                return LocaleUtil.getLocaleFromLCID(((Number) this.value).intValue());
            }
            if (id2 != 1) {
                return null;
            }
            return CodePageUtil.codepageToEncoding(((Number) this.value).intValue());
        } catch (Exception unused) {
            POILogger pOILogger = LOG;
            StringBuilder b2 = a.b("Can't decode id ");
            b2.append(getID());
            pOILogger.log(5, b2.toString());
            return null;
        }
    }

    private String getVariantName() {
        if (getID() == 0) {
            return "dictionary";
        }
        return Variant.getVariantName(getType());
    }

    private boolean typesAreEqual(long j, long j2) {
        return j == j2 || (j == 30 && j2 == 31) || (j2 == 30 && j == 31);
    }

    public static int unpaddedLength(byte[] bArr) {
        int length = bArr.length;
        while (length > 0 && length > bArr.length - 4 && bArr[length - 1] == 0) {
            length--;
        }
        return length;
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof Property)) {
            return false;
        }
        Property property = (Property) obj;
        Object value2 = property.getValue();
        long id2 = property.getID();
        long j = this.id;
        if (j == id2 && (j == 0 || typesAreEqual(this.type, property.getType()))) {
            if (this.value == null && value2 == null) {
                return true;
            }
            Object obj2 = this.value;
            if (!(obj2 == null || value2 == null)) {
                Class<?> cls = obj2.getClass();
                Class<?> cls2 = value2.getClass();
                if (!(cls.isAssignableFrom(cls2) || cls2.isAssignableFrom(cls))) {
                    return false;
                }
                Object obj3 = this.value;
                if (!(obj3 instanceof byte[])) {
                    return obj3.equals(value2);
                }
                byte[] bArr = (byte[]) obj3;
                byte[] bArr2 = (byte[]) value2;
                int unpaddedLength = unpaddedLength(bArr);
                if (unpaddedLength != unpaddedLength(bArr2)) {
                    return false;
                }
                for (int i2 = 0; i2 < unpaddedLength; i2++) {
                    if (bArr[i2] != bArr2[i2]) {
                        return false;
                    }
                }
                return true;
            }
        }
        return false;
    }

    public long getID() {
        return this.id;
    }

    public int getSize(int i2) {
        int variantLength = Variant.getVariantLength(this.type);
        if (variantLength < 0) {
            long j = this.type;
            if (j != 0) {
                if (variantLength == -2) {
                    throw new WritingNotSupportedException(this.type, null);
                } else if (j == 30 || j == 31) {
                    try {
                        int write = write(new ByteArrayOutputStream(), i2) - 8;
                        return write + ((4 - (write & 3)) & 3);
                    } catch (IOException unused) {
                        throw new WritingNotSupportedException(this.type, this.value);
                    }
                } else {
                    throw new WritingNotSupportedException(this.type, this.value);
                }
            }
        }
        return variantLength;
    }

    public long getType() {
        return this.type;
    }

    public Object getValue() {
        return this.value;
    }

    public int hashCode() {
        long j = this.id + 0 + this.type;
        Object obj = this.value;
        if (obj != null) {
            j += (long) obj.hashCode();
        }
        return (int) (j & Filetime.UINT_MASK);
    }

    public void setID(long j) {
        this.id = j;
    }

    public void setType(long j) {
        this.type = j;
    }

    public void setValue(Object obj) {
        this.value = obj;
    }

    public String toString() {
        return toString(1252, null);
    }

    public int write(OutputStream outputStream, int i2) {
        long type2 = getType();
        if (type2 == 30 && i2 != 1200) {
            if (!Charset.forName(CodePageUtil.codepageToEncoding(i2 > 0 ? i2 : 1252)).newEncoder().canEncode((String) this.value)) {
                type2 = 31;
            }
        }
        LittleEndian.putUInt(type2, outputStream);
        return VariantSupport.write(outputStream, type2, getValue(), i2) + 4;
    }

    public Property(Property property) {
        this(property.id, property.type, property.value);
    }

    public String toString(int i2, PropertyIDMap propertyIDMap) {
        String str;
        StringBuilder d2 = a.d("Property[", "id: ");
        d2.append(this.id);
        if (propertyIDMap == null) {
            str = null;
        } else {
            str = propertyIDMap.get((Object) Long.valueOf(this.id));
        }
        if (str == null) {
            str = PropertyIDMap.getFallbackProperties().get((Object) Long.valueOf(this.id));
        }
        if (str != null) {
            d2.append(" (");
            d2.append(str);
            d2.append(")");
        }
        d2.append(", type: ");
        d2.append(getType());
        d2.append(" (");
        d2.append(getVariantName());
        d2.append(") ");
        Object value2 = getValue();
        d2.append(", value: ");
        if (value2 instanceof String) {
            d2.append((String) value2);
            d2.append("\n");
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                write(byteArrayOutputStream, i2);
            } catch (Exception e2) {
                LOG.log(5, "can't serialize string", e2);
            }
            if (byteArrayOutputStream.size() > 8) {
                d2.append(HexDump.dump(byteArrayOutputStream.toByteArray(), -8, 8));
            }
        } else if (value2 instanceof byte[]) {
            d2.append("\n");
            byte[] bArr = (byte[]) value2;
            if (bArr.length > 0) {
                d2.append(HexDump.dump(bArr, 0, 0));
            }
        } else if (value2 instanceof Date) {
            Date date = (Date) value2;
            long dateToFileTime = Filetime.dateToFileTime(date);
            if (Filetime.isUndefined(date)) {
                d2.append("<undefined>");
            } else if ((dateToFileTime >>> 32) == 0) {
                long j = dateToFileTime * 100;
                TimeUnit timeUnit = TimeUnit.NANOSECONDS;
                long hours = timeUnit.toHours(j);
                long nanos = j - TimeUnit.HOURS.toNanos(hours);
                long minutes = timeUnit.toMinutes(nanos);
                long nanos2 = nanos - TimeUnit.MINUTES.toNanos(minutes);
                long seconds = timeUnit.toSeconds(nanos2);
                long millis = timeUnit.toMillis(nanos2 - TimeUnit.SECONDS.toNanos(seconds));
                d2.append(String.format(Locale.ROOT, "%02d:%02d:%02d.%03d", Long.valueOf(hours), Long.valueOf(minutes), Long.valueOf(seconds), Long.valueOf(millis)));
            } else {
                Calendar instance = Calendar.getInstance(LocaleUtil.TIMEZONE_UTC, Locale.ROOT);
                instance.setTime(date);
                d2.append(DatatypeConverter.printDateTime(instance));
            }
        } else {
            long j2 = this.type;
            if (j2 == 0 || j2 == 1 || value2 == null) {
                d2.append("null");
            } else {
                d2.append(value2.toString());
                String decodeValueFromID = decodeValueFromID();
                if (decodeValueFromID != null) {
                    d2.append(" (");
                    d2.append(decodeValueFromID);
                    d2.append(")");
                }
            }
        }
        d2.append(']');
        return d2.toString();
    }

    public Property(long j, long j2, Object obj) {
        this.id = j;
        this.type = j2;
        this.value = obj;
    }

    public Property(long j, byte[] bArr, long j2, int i2, int i3) {
        this.id = j;
        if (j != 0) {
            int i4 = (int) j2;
            long uInt = LittleEndian.getUInt(bArr, i4);
            this.type = uInt;
            try {
                this.value = VariantSupport.read(bArr, i4 + 4, i2, (long) ((int) uInt), i3);
            } catch (UnsupportedVariantTypeException e2) {
                VariantSupport.writeUnsupportedTypeMessage(e2);
                this.value = e2.getValue();
            }
        } else {
            throw new UnsupportedEncodingException("Dictionary not allowed here");
        }
    }

    public Property(long j, LittleEndianByteArrayInputStream littleEndianByteArrayInputStream, int i2, int i3) {
        this.id = j;
        if (j != 0) {
            long readUInt = littleEndianByteArrayInputStream.readUInt();
            this.type = readUInt;
            try {
                this.value = VariantSupport.read(littleEndianByteArrayInputStream, i2, (long) ((int) readUInt), i3);
            } catch (UnsupportedVariantTypeException e2) {
                VariantSupport.writeUnsupportedTypeMessage(e2);
                this.value = e2.getValue();
            }
        } else {
            throw new UnsupportedEncodingException("Dictionary not allowed here");
        }
    }
}
