package org.apache.poi.hpsf;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.poi.EmptyFileException;
import org.apache.poi.hpsf.wellknown.PropertyIDMap;
import org.apache.poi.hpsf.wellknown.SectionIDMap;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.util.CodePageUtil;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.NotImplemented;

public class PropertySet {
    public static final int BYTE_ORDER_ASSERTION = 65534;
    public static final int FORMAT_ASSERTION = 0;
    public static final int OFFSET_HEADER = 28;
    public static final int OS_MACINTOSH = 1;
    public static final int OS_WIN16 = 0;
    public static final int OS_WIN32 = 2;
    public int byteOrder;
    public ClassID classID;
    public int format;
    public int osVersion;
    public final List<Section> sections;

    public PropertySet() {
        this.sections = new ArrayList();
        this.byteOrder = 65534;
        this.format = 0;
        this.osVersion = 133636;
        this.classID = new ClassID();
        addSection(new MutableSection());
    }

    private void init(byte[] bArr, int i2, int i3) {
        this.byteOrder = LittleEndian.getUShort(bArr, i2);
        int i4 = i2 + 2;
        this.format = LittleEndian.getUShort(bArr, i4);
        int i5 = i4 + 2;
        this.osVersion = (int) LittleEndian.getUInt(bArr, i5);
        int i6 = i5 + 4;
        this.classID = new ClassID(bArr, i6);
        int i7 = i6 + 16;
        int i8 = LittleEndian.getInt(bArr, i7);
        int i9 = i7 + 4;
        if (i8 >= 0) {
            for (int i10 = 0; i10 < i8; i10++) {
                MutableSection mutableSection = new MutableSection(bArr, i9);
                i9 += 20;
                this.sections.add(mutableSection);
            }
            return;
        }
        throw new HPSFRuntimeException(a.b("Section count ", i8, " is negative."));
    }

    public static boolean isPropertySetStream(InputStream inputStream) {
        try {
            byte[] peekFirstNBytes = IOUtils.peekFirstNBytes(inputStream, 50);
            return isPropertySetStream(peekFirstNBytes, 0, peekFirstNBytes.length);
        } catch (EmptyFileException unused) {
            return false;
        }
    }

    public static boolean matchesSummary(ClassID classID2, ClassID... classIDArr) {
        for (ClassID classID3 : classIDArr) {
            if (classID3.equals(classID2) || classID3.equalsInverted(classID2)) {
                return true;
            }
        }
        return false;
    }

    public static void putClassId(OutputStream outputStream, ClassID classID2) {
        byte[] bArr = new byte[16];
        classID2.write(bArr, 0);
        outputStream.write(bArr, 0, 16);
    }

    public void addSection(Section section) {
        this.sections.add(section);
    }

    public void clearSections() {
        this.sections.clear();
    }

    public boolean equals(Object obj) {
        if (obj != null && (obj instanceof PropertySet)) {
            PropertySet propertySet = (PropertySet) obj;
            int byteOrder2 = propertySet.getByteOrder();
            int byteOrder3 = getByteOrder();
            ClassID classID2 = propertySet.getClassID();
            ClassID classID3 = getClassID();
            int format2 = propertySet.getFormat();
            int format3 = getFormat();
            int oSVersion = propertySet.getOSVersion();
            int oSVersion2 = getOSVersion();
            int sectionCount = propertySet.getSectionCount();
            int sectionCount2 = getSectionCount();
            if (byteOrder2 == byteOrder3 && classID2.equals(classID3) && format2 == format3 && oSVersion == oSVersion2 && sectionCount == sectionCount2) {
                return getSections().containsAll(propertySet.getSections());
            }
        }
        return false;
    }

    public int getByteOrder() {
        return this.byteOrder;
    }

    public ClassID getClassID() {
        return this.classID;
    }

    public Section getFirstSection() {
        if (!this.sections.isEmpty()) {
            return this.sections.get(0);
        }
        throw new MissingSectionException("Property set does not contain any sections.");
    }

    public int getFormat() {
        return this.format;
    }

    public int getOSVersion() {
        return this.osVersion;
    }

    public Property[] getProperties() {
        return getFirstSection().getProperties();
    }

    public Object getProperty(int i2) {
        return getFirstSection().getProperty((long) i2);
    }

    public boolean getPropertyBooleanValue(int i2) {
        return getFirstSection().getPropertyBooleanValue(i2);
    }

    public int getPropertyIntValue(int i2) {
        return getFirstSection().getPropertyIntValue((long) i2);
    }

    public PropertyIDMap getPropertySetIDMap() {
        return null;
    }

    public String getPropertyStringValue(int i2) {
        return getPropertyStringValue(getProperty(i2));
    }

    public int getSectionCount() {
        return this.sections.size();
    }

    public List<Section> getSections() {
        return Collections.unmodifiableList(this.sections);
    }

    public Section getSingleSection() {
        int sectionCount = getSectionCount();
        if (sectionCount == 1) {
            return this.sections.get(0);
        }
        throw new NoSingleSectionException(a.b("Property set contains ", sectionCount, " sections."));
    }

    @NotImplemented
    public int hashCode() {
        throw new UnsupportedOperationException("FIXME: Not yet implemented.");
    }

    public boolean isDocumentSummaryInformation() {
        return !this.sections.isEmpty() && matchesSummary(getFirstSection().getFormatID(), SectionIDMap.DOCUMENT_SUMMARY_INFORMATION_ID);
    }

    public boolean isSummaryInformation() {
        if (!this.sections.isEmpty()) {
            if (matchesSummary(getFirstSection().getFormatID(), SectionIDMap.SUMMARY_INFORMATION_ID)) {
                return true;
            }
        }
        return false;
    }

    public void remove1stProperty(long j) {
        getFirstSection().removeProperty(j);
    }

    public void set1stProperty(long j, String str) {
        getFirstSection().setProperty((int) j, str);
    }

    public void setByteOrder(int i2) {
        this.byteOrder = i2;
    }

    public void setClassID(ClassID classID2) {
        this.classID = classID2;
    }

    public void setFormat(int i2) {
        this.format = i2;
    }

    public void setOSVersion(int i2) {
        this.osVersion = i2;
    }

    /* JADX INFO: finally extract failed */
    public InputStream toInputStream() {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            write(byteArrayOutputStream);
            byteArrayOutputStream.close();
            return new ByteArrayInputStream(byteArrayOutputStream.toByteArray());
        } catch (Throwable th) {
            byteArrayOutputStream.close();
            throw th;
        }
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        int sectionCount = getSectionCount();
        sb.append(getClass().getName());
        sb.append('[');
        sb.append("byteOrder: ");
        sb.append(getByteOrder());
        sb.append(", classID: ");
        sb.append(getClassID());
        sb.append(", format: ");
        sb.append(getFormat());
        sb.append(", OSVersion: ");
        sb.append(getOSVersion());
        sb.append(", sectionCount: ");
        sb.append(sectionCount);
        sb.append(", sections: [\n");
        for (Section section : getSections()) {
            sb.append(section.toString(getPropertySetIDMap()));
        }
        sb.append(']');
        sb.append(']');
        return sb.toString();
    }

    public boolean wasNull() {
        return getFirstSection().wasNull();
    }

    public void write(OutputStream outputStream) {
        int sectionCount = getSectionCount();
        LittleEndian.putShort(outputStream, (short) getByteOrder());
        LittleEndian.putShort(outputStream, (short) getFormat());
        LittleEndian.putInt(getOSVersion(), outputStream);
        putClassId(outputStream, getClassID());
        LittleEndian.putInt(sectionCount, outputStream);
        int i2 = (sectionCount * 20) + 28;
        for (Section section : getSections()) {
            ClassID formatID = section.getFormatID();
            if (formatID != null) {
                putClassId(outputStream, formatID);
                LittleEndian.putUInt((long) i2, outputStream);
                try {
                    i2 += section.getSize();
                } catch (HPSFRuntimeException e2) {
                    Throwable reason = e2.getReason();
                    if (reason instanceof UnsupportedEncodingException) {
                        throw new IllegalPropertySetDataException(reason);
                    }
                    throw e2;
                }
            } else {
                throw new NoFormatIDException();
            }
        }
        for (Section section2 : getSections()) {
            section2.write(outputStream);
        }
        outputStream.close();
    }

    public void set1stProperty(long j, int i2) {
        getFirstSection().setProperty((int) j, i2);
    }

    public static String getPropertyStringValue(Object obj) {
        if (obj == null) {
            return null;
        }
        if (obj instanceof String) {
            return (String) obj;
        }
        if (!(obj instanceof byte[])) {
            return obj.toString();
        }
        byte[] bArr = (byte[]) obj;
        int length = bArr.length;
        if (length == 0) {
            return "";
        }
        if (length == 1) {
            return Byte.toString(bArr[0]);
        }
        if (length == 2) {
            return Integer.toString(LittleEndian.getUShort(bArr));
        }
        if (length == 4) {
            return Long.toString(LittleEndian.getUInt(bArr));
        }
        try {
            return CodePageUtil.getStringFromCodePage(bArr, 1252);
        } catch (UnsupportedEncodingException unused) {
            return "";
        }
    }

    public static boolean isPropertySetStream(byte[] bArr, int i2, int i3) {
        int uShort = LittleEndian.getUShort(bArr, i2);
        int i4 = i2 + 2;
        if (uShort != 65534) {
            return false;
        }
        int uShort2 = LittleEndian.getUShort(bArr, i4);
        int i5 = i4 + 2;
        if (uShort2 == 0 && LittleEndian.getUInt(bArr, i5 + 4 + 16) >= 0) {
            return true;
        }
        return false;
    }

    public void set1stProperty(long j, boolean z) {
        getFirstSection().setProperty((int) j, z);
    }

    public void set1stProperty(long j, byte[] bArr) {
        getFirstSection().setProperty((int) j, bArr);
    }

    public PropertySet(InputStream inputStream) {
        this.sections = new ArrayList();
        if (isPropertySetStream(inputStream)) {
            byte[] byteArray = IOUtils.toByteArray(inputStream);
            init(byteArray, 0, byteArray.length);
            return;
        }
        throw new NoPropertySetStreamException();
    }

    public PropertySet(byte[] bArr, int i2, int i3) {
        this.sections = new ArrayList();
        if (isPropertySetStream(bArr, i2, i3)) {
            init(bArr, i2, i3);
            return;
        }
        throw new NoPropertySetStreamException();
    }

    public PropertySet(byte[] bArr) {
        this(bArr, 0, bArr.length);
    }

    public PropertySet(PropertySet propertySet) {
        this.sections = new ArrayList();
        setByteOrder(propertySet.getByteOrder());
        setFormat(propertySet.getFormat());
        setOSVersion(propertySet.getOSVersion());
        setClassID(propertySet.getClassID());
        for (Section section : propertySet.getSections()) {
            this.sections.add(new MutableSection(section));
        }
    }

    public void write(DirectoryEntry directoryEntry, String str) {
        if (directoryEntry.hasEntry(str)) {
            directoryEntry.getEntry(str).delete();
        }
        directoryEntry.createDocument(str, toInputStream());
    }
}
