package org.apache.poi.hslf.model;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Composite;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.GraphicsConfiguration;
import java.awt.GraphicsEnvironment;
import java.awt.Image;
import java.awt.Paint;
import java.awt.Polygon;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import java.awt.Shape;
import java.awt.Stroke;
import java.awt.Toolkit;
import java.awt.font.FontRenderContext;
import java.awt.font.GlyphVector;
import java.awt.font.TextLayout;
import java.awt.geom.AffineTransform;
import java.awt.geom.Arc2D;
import java.awt.geom.Ellipse2D;
import java.awt.geom.GeneralPath;
import java.awt.geom.Line2D;
import java.awt.geom.Path2D;
import java.awt.geom.RoundRectangle2D;
import java.awt.image.BufferedImage;
import java.awt.image.BufferedImageOp;
import java.awt.image.ImageObserver;
import java.awt.image.RenderedImage;
import java.awt.image.renderable.RenderableImage;
import java.text.AttributedCharacterIterator;
import java.util.Map;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.usermodel.HSLFFreeformShape;
import org.apache.poi.hslf.usermodel.HSLFGroupShape;
import org.apache.poi.hslf.usermodel.HSLFShape;
import org.apache.poi.hslf.usermodel.HSLFSimpleShape;
import org.apache.poi.hslf.usermodel.HSLFTextBox;
import org.apache.poi.hslf.usermodel.HSLFTextParagraph;
import org.apache.poi.hslf.usermodel.HSLFTextRun;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.sl.draw.DrawPaint;
import org.apache.poi.sl.usermodel.StrokeStyle;
import org.apache.poi.sl.usermodel.VerticalAlignment;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.NotImplemented;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.SuppressForbidden;

public final class PPGraphics2D extends Graphics2D implements Cloneable {
    public static final POILogger LOG = POILogFactory.getLogger(PPGraphics2D.class);
    public Color _background = Color.black;
    public Font _font = new Font(HSSFFont.FONT_ARIAL, 0, 12);
    public Color _foreground = Color.white;
    public HSLFGroupShape _group;
    public RenderingHints _hints = new RenderingHints((Map) null);
    public Paint _paint = Color.black;
    public Stroke _stroke = new BasicStroke();
    public AffineTransform _transform = new AffineTransform();

    public PPGraphics2D(HSLFGroupShape hSLFGroupShape) {
        this._group = hSLFGroupShape;
    }

    public void addRenderingHints(Map<?, ?> map) {
        this._hints.putAll(map);
    }

    public void applyPaint(HSLFSimpleShape hSLFSimpleShape) {
        if (this._paint instanceof Color) {
            hSLFSimpleShape.getFill().setForegroundColor((Color) this._paint);
        }
    }

    public void applyStroke(HSLFSimpleShape hSLFSimpleShape) {
        BasicStroke basicStroke = this._stroke;
        if (basicStroke instanceof BasicStroke) {
            BasicStroke basicStroke2 = basicStroke;
            hSLFSimpleShape.setLineWidth((double) basicStroke2.getLineWidth());
            if (basicStroke2.getDashArray() != null) {
                hSLFSimpleShape.setLineDash(StrokeStyle.LineDash.DASH);
            }
        }
    }

    public void clearRect(int i2, int i3, int i4, int i5) {
        Paint paint = getPaint();
        setColor(getBackground());
        fillRect(i2, i3, i4, i5);
        setPaint(paint);
    }

    @NotImplemented
    public void clip(Shape shape) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
    }

    public void clipRect(int i2, int i3, int i4, int i5) {
        clip(new Rectangle(i2, i3, i4, i5));
    }

    public void copyArea(int i2, int i3, int i4, int i5, int i6, int i7) {
    }

    public Graphics create() {
        try {
            return (Graphics) clone();
        } catch (CloneNotSupportedException e2) {
            throw new HSLFException(e2);
        }
    }

    public void dispose() {
    }

    public void draw(Shape shape) {
        Path2D.Double r0 = new Path2D.Double(this._transform.createTransformedShape(shape));
        HSLFFreeformShape hSLFFreeformShape = new HSLFFreeformShape(this._group);
        hSLFFreeformShape.setPath(r0);
        hSLFFreeformShape.getFill().setForegroundColor(null);
        applyStroke(hSLFFreeformShape);
        Paint paint = this._paint;
        if (paint instanceof Color) {
            hSLFFreeformShape.setLineColor((Color) paint);
        }
        this._group.addShape((HSLFShape) hSLFFreeformShape);
    }

    public void drawArc(int i2, int i3, int i4, int i5, int i6, int i7) {
        draw(new Arc2D.Float((float) i2, (float) i3, (float) i4, (float) i5, (float) i6, (float) i7, 0));
    }

    public void drawGlyphVector(GlyphVector glyphVector, float f2, float f3) {
        fill(glyphVector.getOutline(f2, f3));
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, Color color, ImageObserver imageObserver) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
        return false;
    }

    public void drawLine(int i2, int i3, int i4, int i5) {
        draw(new Line2D.Float((float) i2, (float) i3, (float) i4, (float) i5));
    }

    public void drawOval(int i2, int i3, int i4, int i5) {
        draw(new Ellipse2D.Float((float) i2, (float) i3, (float) i4, (float) i5));
    }

    public void drawPolygon(int[] iArr, int[] iArr2, int i2) {
        draw(new Polygon(iArr, iArr2, i2));
    }

    public void drawPolyline(int[] iArr, int[] iArr2, int i2) {
        if (i2 > 0) {
            GeneralPath generalPath = new GeneralPath();
            generalPath.moveTo((float) iArr[0], (float) iArr2[0]);
            for (int i3 = 1; i3 < i2; i3++) {
                generalPath.lineTo((float) iArr[i3], (float) iArr2[i3]);
            }
            draw(generalPath);
        }
    }

    public void drawRect(int i2, int i3, int i4, int i5) {
        draw(new Rectangle(i2, i3, i4, i5));
    }

    @NotImplemented
    public void drawRenderableImage(RenderableImage renderableImage, AffineTransform affineTransform) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
    }

    @NotImplemented
    public void drawRenderedImage(RenderedImage renderedImage, AffineTransform affineTransform) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
    }

    public void drawRoundRect(int i2, int i3, int i4, int i5, int i6, int i7) {
        draw(new RoundRectangle2D.Float((float) i2, (float) i3, (float) i4, (float) i5, (float) i6, (float) i7));
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: org.apache.poi.hslf.usermodel.HSLFTextBox */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r1v2, types: [org.apache.poi.hslf.usermodel.HSLFSheet] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void drawString(String str, float f2, float f3) {
        HSLFTextBox hSLFTextBox = new HSLFTextBox(this._group);
        hSLFTextBox.setSheet(this._group.getSheet());
        hSLFTextBox.setText(str);
        HSLFTextRun hSLFTextRun = ((HSLFTextParagraph) hSLFTextBox.getTextParagraphs().get(0)).getTextRuns().get(0);
        hSLFTextRun.setFontSize(Double.valueOf((double) this._font.getSize()));
        hSLFTextRun.setFontFamily(this._font.getFamily());
        if (getColor() != null) {
            hSLFTextRun.setFontColor(DrawPaint.createSolidPaint(getColor()));
        }
        if (this._font.isBold()) {
            hSLFTextRun.setBold(true);
        }
        if (this._font.isItalic()) {
            hSLFTextRun.setItalic(true);
        }
        hSLFTextBox.setBottomInset(NumericFunction.LOG_10_TO_BASE_e);
        hSLFTextBox.setTopInset(NumericFunction.LOG_10_TO_BASE_e);
        hSLFTextBox.setLeftInset(NumericFunction.LOG_10_TO_BASE_e);
        hSLFTextBox.setRightInset(NumericFunction.LOG_10_TO_BASE_e);
        hSLFTextBox.setWordWrap(false);
        hSLFTextBox.setHorizontalCentered(false);
        hSLFTextBox.setVerticalAlignment(VerticalAlignment.MIDDLE);
        TextLayout textLayout = new TextLayout(str, this._font, getFontRenderContext());
        float ascent = textLayout.getAscent();
        float f4 = ascent * 2.0f;
        hSLFTextBox.setAnchor(new Rectangle((int) f2, (int) (f3 - ((ascent / 2.0f) + (f4 / 2.0f))), (int) ((float) Math.floor((double) textLayout.getAdvance())), (int) f4));
        this._group.addShape((HSLFShape) hSLFTextBox);
    }

    public void fill(Shape shape) {
        Path2D.Double r0 = new Path2D.Double(this._transform.createTransformedShape(shape));
        HSLFFreeformShape hSLFFreeformShape = new HSLFFreeformShape(this._group);
        hSLFFreeformShape.setPath(r0);
        applyPaint(hSLFFreeformShape);
        hSLFFreeformShape.setLineColor(null);
        this._group.addShape((HSLFShape) hSLFFreeformShape);
    }

    public void fillArc(int i2, int i3, int i4, int i5, int i6, int i7) {
        fill(new Arc2D.Float((float) i2, (float) i3, (float) i4, (float) i5, (float) i6, (float) i7, 2));
    }

    public void fillOval(int i2, int i3, int i4, int i5) {
        fill(new Ellipse2D.Float((float) i2, (float) i3, (float) i4, (float) i5));
    }

    public void fillPolygon(int[] iArr, int[] iArr2, int i2) {
        fill(new Polygon(iArr, iArr2, i2));
    }

    public void fillRect(int i2, int i3, int i4, int i5) {
        fill(new Rectangle(i2, i3, i4, i5));
    }

    public void fillRoundRect(int i2, int i3, int i4, int i5, int i6, int i7) {
        fill(new RoundRectangle2D.Float((float) i2, (float) i3, (float) i4, (float) i5, (float) i6, (float) i7));
    }

    public Color getBackground() {
        return this._background;
    }

    @NotImplemented
    public Shape getClip() {
        if (!LOG.check(5)) {
            return null;
        }
        LOG.log(5, "Not implemented");
        return null;
    }

    public Rectangle getClipBounds() {
        Shape clip = getClip();
        if (clip == null) {
            return null;
        }
        return clip.getBounds();
    }

    public Color getColor() {
        return this._foreground;
    }

    @NotImplemented
    public Composite getComposite() {
        if (!LOG.check(5)) {
            return null;
        }
        LOG.log(5, "Not implemented");
        return null;
    }

    public GraphicsConfiguration getDeviceConfiguration() {
        return GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice().getDefaultConfiguration();
    }

    public Font getFont() {
        return this._font;
    }

    @SuppressForbidden
    public FontMetrics getFontMetrics(Font font) {
        return Toolkit.getDefaultToolkit().getFontMetrics(font);
    }

    public FontRenderContext getFontRenderContext() {
        return new FontRenderContext(new AffineTransform(), RenderingHints.VALUE_TEXT_ANTIALIAS_ON.equals(getRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING)), RenderingHints.VALUE_FRACTIONALMETRICS_ON.equals(getRenderingHint(RenderingHints.KEY_FRACTIONALMETRICS)));
    }

    public Paint getPaint() {
        return this._paint;
    }

    public Object getRenderingHint(RenderingHints.Key key) {
        return this._hints.get(key);
    }

    public RenderingHints getRenderingHints() {
        return this._hints;
    }

    public HSLFGroupShape getShapeGroup() {
        return this._group;
    }

    public Stroke getStroke() {
        return this._stroke;
    }

    public AffineTransform getTransform() {
        return new AffineTransform(this._transform);
    }

    public boolean hit(Rectangle rectangle, Shape shape, boolean z) {
        if (z) {
            shape = getStroke().createStrokedShape(shape);
        }
        return getTransform().createTransformedShape(shape).intersects(rectangle);
    }

    public void rotate(double d2) {
        this._transform.rotate(d2);
    }

    public void scale(double d2, double d3) {
        this._transform.scale(d2, d3);
    }

    public void setBackground(Color color) {
        if (color != null) {
            this._background = color;
        }
    }

    @NotImplemented
    public void setClip(Shape shape) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
    }

    public void setColor(Color color) {
        setPaint(color);
    }

    @NotImplemented
    public void setComposite(Composite composite) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
    }

    public void setFont(Font font) {
        this._font = font;
    }

    public void setPaint(Paint paint) {
        if (paint != null) {
            this._paint = paint;
            if (paint instanceof Color) {
                this._foreground = (Color) paint;
            }
        }
    }

    @NotImplemented
    public void setPaintMode() {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
    }

    public void setRenderingHint(RenderingHints.Key key, Object obj) {
        this._hints.put(key, obj);
    }

    public void setRenderingHints(Map<?, ?> map) {
        RenderingHints renderingHints = new RenderingHints((Map) null);
        this._hints = renderingHints;
        renderingHints.putAll(map);
    }

    public void setStroke(Stroke stroke) {
        this._stroke = stroke;
    }

    public void setTransform(AffineTransform affineTransform) {
        this._transform = new AffineTransform(affineTransform);
    }

    @NotImplemented
    public void setXORMode(Color color) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
    }

    public void shear(double d2, double d3) {
        this._transform.shear(d2, d3);
    }

    public void transform(AffineTransform affineTransform) {
        this._transform.concatenate(affineTransform);
    }

    public void translate(int i2, int i3) {
        this._transform.translate((double) i2, (double) i3);
    }

    public void rotate(double d2, double d3, double d4) {
        this._transform.rotate(d2, d3, d4);
    }

    public void translate(double d2, double d3) {
        this._transform.translate(d2, d3);
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, Color color, ImageObserver imageObserver) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
        return false;
    }

    public void setClip(int i2, int i3, int i4, int i5) {
        setClip(new Rectangle(i2, i3, i4, i5));
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9, ImageObserver imageObserver) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
        return false;
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9, Color color, ImageObserver imageObserver) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
        return false;
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, ImageObserver imageObserver) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
        return false;
    }

    public void drawImage(BufferedImage bufferedImage, BufferedImageOp bufferedImageOp, int i2, int i3) {
        drawImage((Image) bufferedImageOp.filter(bufferedImage, (BufferedImage) null), i2, i3, (ImageObserver) null);
    }

    @NotImplemented
    public boolean drawImage(Image image, AffineTransform affineTransform, ImageObserver imageObserver) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
        return false;
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, ImageObserver imageObserver) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
        return false;
    }

    public void drawString(String str, int i2, int i3) {
        drawString(str, (float) i2, (float) i3);
    }

    public void drawString(AttributedCharacterIterator attributedCharacterIterator, int i2, int i3) {
        drawString(attributedCharacterIterator, (float) i2, (float) i3);
    }

    @NotImplemented
    public void drawString(AttributedCharacterIterator attributedCharacterIterator, float f2, float f3) {
        if (LOG.check(5)) {
            LOG.log(5, "Not implemented");
        }
    }
}
