package org.apache.poi.hslf.model.textproperties;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.ss.util.NormalisedDecimal;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class TextPropCollection {
    public static final POILogger LOG = POILogFactory.getLogger(TextPropCollection.class);
    public static final TextProp[] characterTextPropTypes = {new TextProp(0, 1048576, "pp10ext"), new TextProp(0, 16777216, "newAsian.font.index"), new TextProp(0, 33554432, "cs.font.index"), new TextProp(0, 67108864, "pp11ext"), new CharFlagsTextProp(), new TextProp(2, 65536, "font.index"), new TextProp(2, 2097152, "asian.font.index"), new TextProp(2, 4194304, "ansi.font.index"), new TextProp(2, NormalisedDecimal.FRAC_HALF, "symbol.font.index"), new TextProp(2, 131072, "font.size"), new TextProp(4, 262144, "font.color"), new TextProp(2, 524288, "superscript")};
    public static final TextProp[] paragraphTextPropTypes = {new ParagraphFlagsTextProp(), new TextProp(2, 128, "bullet.char"), new TextProp(2, 16, "bullet.font"), new TextProp(2, 64, "bullet.size"), new TextProp(4, 32, "bullet.color"), new TextAlignmentProp(), new TextProp(2, 4096, "linespacing"), new TextProp(2, 8192, "spacebefore"), new TextProp(2, 16384, "spaceafter"), new TextProp(2, 256, "text.offset"), new TextProp(2, 1024, "bullet.offset"), new TextProp(2, 32768, "defaultTabSize"), new TabStopPropCollection(), new FontAlignmentProp(), new WrapFlagsTextProp(), new TextProp(2, 2097152, "textDirection"), new TextProp(0, NormalisedDecimal.FRAC_HALF, "bullet.blip"), new TextProp(0, 16777216, "bullet.scheme"), new TextProp(0, 33554432, "hasBulletScheme")};
    public int charactersCovered;
    public short indentLevel = 0;
    public int maskSpecial = 0;
    public final TextPropType textPropType;
    public final Map<String, TextProp> textProps = new HashMap();

    public enum TextPropType {
        paragraph,
        character
    }

    public TextPropCollection(int i2, TextPropType textPropType2) {
        this.charactersCovered = i2;
        this.textPropType = textPropType2;
    }

    private TextProp[] getPotentialProperties() {
        return this.textPropType == TextPropType.paragraph ? paragraphTextPropTypes : characterTextPropTypes;
    }

    private TextProp validatePropName(String str) {
        TextProp[] potentialProperties = getPotentialProperties();
        for (TextProp textProp : potentialProperties) {
            if (textProp.getName().equals(str)) {
                return textProp;
            }
        }
        throw new HSLFException("No TextProp with name " + str + " is defined to add from. " + "Character and paragraphs have their own properties/names.");
    }

    public final void addProp(TextProp textProp) {
        if (textProp != null) {
            String name = textProp.getName();
            validatePropName(name);
            this.textProps.put(name, textProp);
            return;
        }
        throw new HSLFException("TextProp must not be null");
    }

    public final TextProp addWithName(String str) {
        TextProp findByName = findByName(str);
        if (findByName != null) {
            return findByName;
        }
        TextProp clone = validatePropName(str).clone();
        this.textProps.put(str, clone);
        return clone;
    }

    public int buildTextPropList(int i2, byte[] bArr, int i3) {
        int i4;
        TextProp[] potentialProperties = getPotentialProperties();
        int i5 = 0;
        for (TextProp textProp : potentialProperties) {
            if ((textProp.getMask() & i2) != 0) {
                int i6 = i3 + i5;
                if (i6 >= bArr.length) {
                    this.maskSpecial |= textProp.getMask();
                    return i5;
                }
                TextProp clone = textProp.clone();
                if (clone.getSize() == 2) {
                    i4 = LittleEndian.getShort(bArr, i6);
                } else if (clone.getSize() == 4) {
                    i4 = LittleEndian.getInt(bArr, i6);
                } else if (clone.getSize() != 0 || (clone instanceof TabStopPropCollection)) {
                    i4 = 0;
                } else {
                    this.maskSpecial = textProp.getMask() | this.maskSpecial;
                }
                if (clone instanceof BitMaskTextProp) {
                    ((BitMaskTextProp) clone).setValueWithMask(i4, i2);
                } else if (clone instanceof TabStopPropCollection) {
                    ((TabStopPropCollection) clone).parseProperty(bArr, i6);
                } else {
                    clone.setValue(i4);
                }
                i5 += clone.getSize();
                addProp(clone);
            }
        }
        return i5;
    }

    public void copy(TextPropCollection textPropCollection) {
        if (textPropCollection == null) {
            throw new HSLFException("trying to copy null TextPropCollection");
        } else if (this != textPropCollection) {
            this.charactersCovered = textPropCollection.charactersCovered;
            this.indentLevel = textPropCollection.indentLevel;
            this.maskSpecial = textPropCollection.maskSpecial;
            this.textProps.clear();
            for (TextProp textProp : textPropCollection.textProps.values()) {
                addProp(textProp instanceof BitMaskTextProp ? ((BitMaskTextProp) textProp).cloneAll() : textProp.clone());
            }
        }
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || TextPropCollection.class != obj.getClass()) {
            return false;
        }
        TextPropCollection textPropCollection = (TextPropCollection) obj;
        if (textPropCollection.maskSpecial == this.maskSpecial && textPropCollection.indentLevel == this.indentLevel) {
            return this.textProps.equals(textPropCollection.textProps);
        }
        return false;
    }

    public final TextProp findByName(String str) {
        return this.textProps.get(str);
    }

    public int getCharactersCovered() {
        return this.charactersCovered;
    }

    public short getIndentLevel() {
        return this.indentLevel;
    }

    public int getSpecialMask() {
        return this.maskSpecial;
    }

    public List<TextProp> getTextPropList() {
        ArrayList arrayList = new ArrayList();
        for (TextProp textProp : getPotentialProperties()) {
            TextProp textProp2 = this.textProps.get(textProp.getName());
            if (textProp2 != null) {
                arrayList.add(textProp2);
            }
        }
        return arrayList;
    }

    public final TextPropType getTextPropType() {
        return this.textPropType;
    }

    public int hashCode() {
        int i2 = (((((this.charactersCovered + 31) * 31) + this.maskSpecial) * 31) + this.indentLevel) * 31;
        Map<String, TextProp> map = this.textProps;
        return i2 + (map == null ? 0 : map.hashCode());
    }

    public final TextProp removeByName(String str) {
        return this.textProps.remove(str);
    }

    public void setIndentLevel(short s) {
        if (this.textPropType != TextPropType.character) {
            this.indentLevel = s;
            return;
        }
        throw new RuntimeException("trying to set an indent on a character collection.");
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        StringBuilder b2 = a.b("  chars covered: ");
        b2.append(getCharactersCovered());
        sb.append(b2.toString());
        sb.append("  special mask flags: 0x" + HexDump.toHex(getSpecialMask()) + "\n");
        if (this.textPropType == TextPropType.paragraph) {
            StringBuilder b3 = a.b("  indent level: ");
            b3.append((int) getIndentLevel());
            b3.append("\n");
            sb.append(b3.toString());
        }
        Iterator<TextProp> it = getTextPropList().iterator();
        while (true) {
            if (!it.hasNext()) {
                break;
            }
            TextProp next = it.next();
            StringBuilder b4 = a.b("    ");
            b4.append(next.getName());
            b4.append(" = ");
            b4.append(next.getValue());
            sb.append(b4.toString());
            sb.append(" (0x" + HexDump.toHex(next.getValue()) + ")\n");
            if (next instanceof BitMaskTextProp) {
                BitMaskTextProp bitMaskTextProp = (BitMaskTextProp) next;
                String[] subPropNames = bitMaskTextProp.getSubPropNames();
                int i2 = 0;
                for (String str : subPropNames) {
                    if (bitMaskTextProp.getSubPropMatches()[i2]) {
                        StringBuilder d2 = a.d("          ", str, " = ");
                        d2.append(bitMaskTextProp.getSubValue(i2));
                        d2.append("\n");
                        sb.append(d2.toString());
                    }
                    i2++;
                }
            }
        }
        sb.append("  bytes that would be written: \n");
        try {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            writeOut(byteArrayOutputStream);
            sb.append(HexDump.dump(byteArrayOutputStream.toByteArray(), 0, 0));
        } catch (IOException e2) {
            LOG.log(7, "can't dump TextPropCollection", e2);
        }
        return sb.toString();
    }

    public void updateTextSize(int i2) {
        this.charactersCovered = i2;
    }

    public void writeOut(OutputStream outputStream) {
        writeOut(outputStream, false);
    }

    public void writeOut(OutputStream outputStream, boolean z) {
        short s;
        if (!z) {
            Record.writeLittleEndian(this.charactersCovered, outputStream);
        }
        if (this.textPropType == TextPropType.paragraph && (s = this.indentLevel) > -1) {
            Record.writeLittleEndian(s, outputStream);
        }
        int i2 = this.maskSpecial;
        for (TextProp textProp : this.textProps.values()) {
            i2 |= textProp.getWriteMask();
        }
        Record.writeLittleEndian(i2, outputStream);
        for (TextProp textProp2 : getTextPropList()) {
            int value = textProp2.getValue();
            if (!(textProp2 instanceof BitMaskTextProp) || textProp2.getWriteMask() != 0) {
                if (textProp2.getSize() == 2) {
                    Record.writeLittleEndian((short) value, outputStream);
                } else if (textProp2.getSize() == 4) {
                    Record.writeLittleEndian(value, outputStream);
                }
            }
        }
    }
}
