package org.apache.poi.hslf.record;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import org.apache.poi.POIXMLDocument;
import org.apache.poi.hslf.exceptions.CorruptPowerPointFileException;
import org.apache.poi.hslf.exceptions.OldPowerPointFormatException;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentEntry;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;

public class CurrentUserAtom {
    public static final byte[] atomHeader = {0, 0, -10, 15};
    public static final byte[] encHeaderToken = {-33, -60, -47, -13};
    public static final byte[] headerToken = {95, -64, -111, -29};
    public static final POILogger logger = POILogFactory.getLogger(CurrentUserAtom.class);
    public static final byte[] ppt97FileVer = {8, 0, -13, 3, 3, 0};
    public byte[] _contents;
    public long currentEditOffset;
    public int docFinalVersion;
    public byte docMajorNo;
    public byte docMinorNo;
    public boolean isEncrypted;
    public String lastEditUser;
    public long releaseVersion;

    public CurrentUserAtom() {
        this._contents = new byte[0];
        this.docFinalVersion = 1012;
        this.docMajorNo = 3;
        this.docMinorNo = 0;
        this.releaseVersion = 8;
        this.currentEditOffset = 0;
        this.lastEditUser = POIXMLDocument.DOCUMENT_CREATOR;
        this.isEncrypted = false;
    }

    private void init() {
        this.isEncrypted = LittleEndian.getInt(encHeaderToken) == LittleEndian.getInt(this._contents, 12);
        this.currentEditOffset = LittleEndian.getUInt(this._contents, 16);
        this.docFinalVersion = LittleEndian.getUShort(this._contents, 22);
        byte[] bArr = this._contents;
        this.docMajorNo = bArr[24];
        this.docMinorNo = bArr[25];
        long uShort = (long) LittleEndian.getUShort(bArr, 20);
        if (uShort > 512) {
            POILogger pOILogger = logger;
            pOILogger.log(5, "Warning - invalid username length " + uShort + " found, treating as if there was no username set");
            uShort = 0;
        }
        byte[] bArr2 = this._contents;
        int i2 = (int) uShort;
        int i3 = i2 + 28;
        int i4 = i3 + 4;
        if (bArr2.length >= i4) {
            this.releaseVersion = LittleEndian.getUInt(bArr2, i3);
        } else {
            this.releaseVersion = 0;
        }
        int i5 = i2 * 2;
        byte[] bArr3 = this._contents;
        if (bArr3.length >= i4 + i5) {
            byte[] bArr4 = new byte[i5];
            System.arraycopy(bArr3, i4, bArr4, 0, i5);
            this.lastEditUser = StringUtil.getFromUnicodeLE(bArr4);
            return;
        }
        byte[] bArr5 = new byte[i2];
        System.arraycopy(bArr3, 28, bArr5, 0, i2);
        this.lastEditUser = StringUtil.getFromCompressedUnicode(bArr5, 0, i2);
    }

    public long getCurrentEditOffset() {
        return this.currentEditOffset;
    }

    public int getDocFinalVersion() {
        return this.docFinalVersion;
    }

    public byte getDocMajorNo() {
        return this.docMajorNo;
    }

    public byte getDocMinorNo() {
        return this.docMinorNo;
    }

    public String getLastEditUsername() {
        return this.lastEditUser;
    }

    public long getReleaseVersion() {
        return this.releaseVersion;
    }

    public boolean isEncrypted() {
        return this.isEncrypted;
    }

    public void setCurrentEditOffset(long j) {
        this.currentEditOffset = j;
    }

    public void setEncrypted(boolean z) {
        this.isEncrypted = z;
    }

    public void setLastEditUsername(String str) {
        this.lastEditUser = str;
    }

    public void setReleaseVersion(long j) {
        this.releaseVersion = j;
    }

    public void writeOut(OutputStream outputStream) {
        byte[] bArr = new byte[((this.lastEditUser.length() * 3) + 32)];
        this._contents = bArr;
        System.arraycopy(atomHeader, 0, bArr, 0, 4);
        LittleEndian.putInt(this._contents, 4, this.lastEditUser.length() + 24);
        LittleEndian.putInt(this._contents, 8, 20);
        System.arraycopy(this.isEncrypted ? encHeaderToken : headerToken, 0, this._contents, 12, 4);
        LittleEndian.putInt(this._contents, 16, (int) this.currentEditOffset);
        int length = this.lastEditUser.length();
        byte[] bArr2 = new byte[length];
        StringUtil.putCompressedUnicode(this.lastEditUser, bArr2, 0);
        LittleEndian.putShort(this._contents, 20, (short) length);
        LittleEndian.putShort(this._contents, 22, (short) this.docFinalVersion);
        byte[] bArr3 = this._contents;
        bArr3[24] = this.docMajorNo;
        bArr3[25] = this.docMinorNo;
        bArr3[26] = 0;
        bArr3[27] = 0;
        System.arraycopy(bArr2, 0, bArr3, 28, length);
        int i2 = length + 28;
        LittleEndian.putInt(this._contents, i2, (int) this.releaseVersion);
        int length2 = this.lastEditUser.length() * 2;
        byte[] bArr4 = new byte[length2];
        StringUtil.putUnicodeLE(this.lastEditUser, bArr4, 0);
        System.arraycopy(bArr4, 0, this._contents, i2 + 4, length2);
        outputStream.write(this._contents);
    }

    public void writeToFS(NPOIFSFileSystem nPOIFSFileSystem) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        writeOut(byteArrayOutputStream);
        nPOIFSFileSystem.createOrUpdateDocument(new ByteArrayInputStream(byteArrayOutputStream.toByteArray()), "Current User");
    }

    public CurrentUserAtom(DirectoryNode directoryNode) {
        DocumentEntry documentEntry = (DocumentEntry) directoryNode.getEntry("Current User");
        if (documentEntry.getSize() <= 131072) {
            int size = documentEntry.getSize();
            this._contents = new byte[size];
            DocumentInputStream createDocumentInputStream = directoryNode.createDocumentInputStream("Current User");
            int read = createDocumentInputStream.read(this._contents);
            createDocumentInputStream.close();
            if (size != read) {
                throw new IOException(a.b("Current User input stream ended prematurely - expected ", size, " bytes - received ", read, " bytes"));
            } else if (this._contents.length < 28) {
                boolean hasEntry = directoryNode.hasEntry("PP40");
                if (!hasEntry) {
                    byte[] bArr = this._contents;
                    if (bArr.length >= 4) {
                        hasEntry = LittleEndian.getInt(bArr) + 4 == this._contents.length;
                    }
                }
                if (hasEntry) {
                    throw new OldPowerPointFormatException("Based on the Current User stream, you seem to have supplied a PowerPoint95 file, which isn't supported");
                }
                StringBuilder b2 = a.b("The Current User stream must be at least 28 bytes long, but was only ");
                b2.append(this._contents.length);
                throw new CorruptPowerPointFileException(b2.toString());
            } else {
                init();
            }
        } else {
            StringBuilder b3 = a.b("The Current User stream is implausably long. It's normally 28-200 bytes long, but was ");
            b3.append(documentEntry.getSize());
            b3.append(" bytes");
            throw new CorruptPowerPointFileException(b3.toString());
        }
    }
}
