package org.apache.poi.hslf.record;

import java.io.OutputStream;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import org.apache.poi.hslf.exceptions.CorruptPowerPointFileException;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public abstract class Record {
    public static final POILogger logger = POILogFactory.getLogger(Record.class);

    public static Record buildRecordAtOffset(byte[] bArr, int i2) {
        long uShort = (long) LittleEndian.getUShort(bArr, i2 + 2);
        int uInt = (int) LittleEndian.getUInt(bArr, i2 + 4);
        if (uInt < 0) {
            uInt = 0;
        }
        return createRecordForType(uShort, bArr, i2, uInt + 8);
    }

    public static Record createRecordForType(long j, byte[] bArr, int i2, int i3) {
        if (i2 + i3 > bArr.length) {
            POILogger pOILogger = logger;
            pOILogger.log(5, "Warning: Skipping record of type " + j + " at position " + i2 + " which claims to be longer than the file! (" + i3 + " vs " + (bArr.length - i2) + ")");
            return null;
        }
        try {
            Class<? extends Record> cls = RecordTypes.forTypeID((short) ((int) j)).handlingClass;
            if (cls == null) {
                cls = RecordTypes.UnknownRecordPlaceholder.handlingClass;
            }
            Record record = (Record) cls.getDeclaredConstructor(byte[].class, Integer.TYPE, Integer.TYPE).newInstance(bArr, Integer.valueOf(i2), Integer.valueOf(i3));
            if (record instanceof PositionDependentRecord) {
                ((PositionDependentRecord) record).setLastOnDiskOffset(i2);
            }
            return record;
        } catch (InstantiationException e2) {
            throw new HSLFException("Couldn't instantiate the class for type with id " + j + " on class " + ((Object) null) + " : " + e2, e2);
        } catch (InvocationTargetException e3) {
            throw new HSLFException("Couldn't instantiate the class for type with id " + j + " on class " + ((Object) null) + " : " + e3 + "\nCause was : " + e3.getCause(), e3);
        } catch (IllegalAccessException e4) {
            throw new HSLFException("Couldn't access the constructor for type with id " + j + " on class " + ((Object) null) + " : " + e4, e4);
        } catch (NoSuchMethodException e5) {
            throw new HSLFException("Couldn't access the constructor for type with id " + j + " on class " + ((Object) null) + " : " + e5, e5);
        }
    }

    public static Record[] findChildRecords(byte[] bArr, int i2, int i3) {
        ArrayList arrayList = new ArrayList(5);
        int i4 = i2;
        while (i4 <= (i2 + i3) - 8) {
            long uShort = (long) LittleEndian.getUShort(bArr, i4 + 2);
            int uInt = (int) LittleEndian.getUInt(bArr, i4 + 4);
            if (uInt < 0) {
                uInt = 0;
            }
            if (i4 == 0 && uShort == 0 && uInt == 65535) {
                throw new CorruptPowerPointFileException("Corrupt document - starts with record of type 0000 and length 0xFFFF");
            }
            Record createRecordForType = createRecordForType(uShort, bArr, i4, uInt + 8);
            if (createRecordForType != null) {
                arrayList.add(createRecordForType);
            }
            i4 = i4 + 8 + uInt;
        }
        return (Record[]) arrayList.toArray(new Record[arrayList.size()]);
    }

    public static void writeLittleEndian(int i2, OutputStream outputStream) {
        byte[] bArr = new byte[4];
        LittleEndian.putInt(bArr, 0, i2);
        outputStream.write(bArr);
    }

    public abstract Record[] getChildRecords();

    public abstract long getRecordType();

    public abstract boolean isAnAtom();

    public abstract void writeOut(OutputStream outputStream);

    public static void writeLittleEndian(short s, OutputStream outputStream) {
        byte[] bArr = new byte[2];
        LittleEndian.putShort(bArr, 0, s);
        outputStream.write(bArr);
    }
}
