package org.apache.poi.hslf.usermodel;

import b.b.a.a.a;
import java.awt.Dimension;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.common.usermodel.fonts.FontInfo;
import org.apache.poi.ddf.EscherBSERecord;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.hpsf.ClassID;
import org.apache.poi.hslf.exceptions.CorruptPowerPointFileException;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.model.HeadersFooters;
import org.apache.poi.hslf.record.Document;
import org.apache.poi.hslf.record.DocumentAtom;
import org.apache.poi.hslf.record.ExAviMovie;
import org.apache.poi.hslf.record.ExControl;
import org.apache.poi.hslf.record.ExEmbed;
import org.apache.poi.hslf.record.ExMCIMovie;
import org.apache.poi.hslf.record.ExObjList;
import org.apache.poi.hslf.record.ExObjListAtom;
import org.apache.poi.hslf.record.ExOleObjAtom;
import org.apache.poi.hslf.record.ExOleObjStg;
import org.apache.poi.hslf.record.ExVideoContainer;
import org.apache.poi.hslf.record.FontCollection;
import org.apache.poi.hslf.record.MainMaster;
import org.apache.poi.hslf.record.Notes;
import org.apache.poi.hslf.record.PersistPtrHolder;
import org.apache.poi.hslf.record.PositionDependentRecord;
import org.apache.poi.hslf.record.PositionDependentRecordContainer;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.RecordContainer;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.record.Slide;
import org.apache.poi.hslf.record.SlideListWithText;
import org.apache.poi.hslf.record.SlidePersistAtom;
import org.apache.poi.hslf.record.TxMasterStyleAtom;
import org.apache.poi.hslf.record.UserEditAtom;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.sl.usermodel.MasterSheet;
import org.apache.poi.sl.usermodel.PictureData;
import org.apache.poi.sl.usermodel.Resources;
import org.apache.poi.sl.usermodel.SlideShow;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Units;

public final class HSLFSlideShow implements SlideShow<HSLFShape, HSLFTextParagraph>, Closeable {
    public static final String POWERPOINT_DOCUMENT = "PowerPoint Document";
    public static final ThreadLocal<LoadSavePhase> loadSavePhase = new ThreadLocal<>();
    public static final POILogger logger = POILogFactory.getLogger(HSLFSlideShow.class);
    public Document _documentRecord;
    public FontCollection _fonts;
    public final HSLFSlideShowImpl _hslfSlideShow;
    public final List<HSLFSlideMaster> _masters;
    public Record[] _mostRecentCoreRecords;
    public final List<HSLFNotes> _notes;
    public Map<Integer, Integer> _sheetIdToCoreRecordsLookup;
    public final List<HSLFSlide> _slides;
    public final List<HSLFTitleMaster> _titleMasters;

    public enum LoadSavePhase {
        INIT,
        LOADED
    }

    public HSLFSlideShow(HSLFSlideShowImpl hSLFSlideShowImpl) {
        this._masters = new ArrayList();
        this._titleMasters = new ArrayList();
        this._slides = new ArrayList();
        this._notes = new ArrayList();
        loadSavePhase.set(LoadSavePhase.INIT);
        this._hslfSlideShow = hSLFSlideShowImpl;
        Record[] records = hSLFSlideShowImpl.getRecords();
        for (Record record : records) {
            if (record instanceof RecordContainer) {
                RecordContainer.handleParentAwareRecords((RecordContainer) record);
            }
        }
        findMostRecentCoreRecords();
        buildSlidesAndNotes();
        loadSavePhase.set(LoadSavePhase.LOADED);
    }

    private void buildSlidesAndNotes() {
        if (this._documentRecord != null) {
            findMasterSlides();
            HashMap hashMap = new HashMap();
            findNotesSlides(hashMap);
            findSlides(hashMap);
            return;
        }
        throw new CorruptPowerPointFileException("The PowerPoint file didn't contain a Document Record in its PersistPtr blocks. It is probably corrupt.");
    }

    private void findMasterSlides() {
        SlideListWithText masterSlideListWithText = this._documentRecord.getMasterSlideListWithText();
        if (masterSlideListWithText != null) {
            SlideListWithText.SlideAtomsSet[] slideAtomsSets = masterSlideListWithText.getSlideAtomsSets();
            for (SlideListWithText.SlideAtomsSet slideAtomsSet : slideAtomsSets) {
                Record coreRecordForSAS = getCoreRecordForSAS(slideAtomsSet);
                int slideIdentifier = slideAtomsSet.getSlidePersistAtom().getSlideIdentifier();
                if (coreRecordForSAS instanceof Slide) {
                    HSLFTitleMaster hSLFTitleMaster = new HSLFTitleMaster((Slide) coreRecordForSAS, slideIdentifier);
                    hSLFTitleMaster.setSlideShow(this);
                    this._titleMasters.add(hSLFTitleMaster);
                } else if (coreRecordForSAS instanceof MainMaster) {
                    HSLFSlideMaster hSLFSlideMaster = new HSLFSlideMaster((MainMaster) coreRecordForSAS, slideIdentifier);
                    hSLFSlideMaster.setSlideShow(this);
                    this._masters.add(hSLFSlideMaster);
                }
            }
        }
    }

    private void findMostRecentCoreRecords() {
        HashMap hashMap = new HashMap();
        Record[] records = this._hslfSlideShow.getRecords();
        for (Record record : records) {
            if (record instanceof PersistPtrHolder) {
                PersistPtrHolder persistPtrHolder = (PersistPtrHolder) record;
                int[] knownSlideIDs = persistPtrHolder.getKnownSlideIDs();
                for (int i2 : knownSlideIDs) {
                    if (hashMap.containsKey(Integer.valueOf(i2))) {
                        hashMap.remove(Integer.valueOf(i2));
                    }
                }
                Map<Integer, Integer> slideLocationsLookup = persistPtrHolder.getSlideLocationsLookup();
                for (int i3 : knownSlideIDs) {
                    hashMap.put(Integer.valueOf(i3), slideLocationsLookup.get(Integer.valueOf(i3)));
                }
            }
        }
        this._mostRecentCoreRecords = new Record[hashMap.size()];
        this._sheetIdToCoreRecordsLookup = new HashMap();
        Integer[] numArr = (Integer[]) hashMap.keySet().toArray(new Integer[hashMap.size()]);
        Arrays.sort(numArr);
        for (int i4 = 0; i4 < numArr.length; i4++) {
            this._sheetIdToCoreRecordsLookup.put(numArr[i4], Integer.valueOf(i4));
        }
        HashMap hashMap2 = new HashMap(hashMap.size());
        for (Map.Entry entry : hashMap.entrySet()) {
            hashMap2.put(entry.getValue(), entry.getKey());
        }
        Record[] records2 = this._hslfSlideShow.getRecords();
        for (Record record2 : records2) {
            if (record2 instanceof PositionDependentRecord) {
                PositionDependentRecord positionDependentRecord = (PositionDependentRecord) record2;
                Integer num = (Integer) hashMap2.get(Integer.valueOf(positionDependentRecord.getLastOnDiskOffset()));
                if (num != null) {
                    int intValue = this._sheetIdToCoreRecordsLookup.get(num).intValue();
                    if (positionDependentRecord instanceof PositionDependentRecordContainer) {
                        ((PositionDependentRecordContainer) record2).setSheetId(num.intValue());
                    }
                    this._mostRecentCoreRecords[intValue] = record2;
                }
            }
        }
        Record[] recordArr = this._mostRecentCoreRecords;
        for (Record record3 : recordArr) {
            if (record3 != null && record3.getRecordType() == ((long) RecordTypes.Document.typeID)) {
                Document document = (Document) record3;
                this._documentRecord = document;
                this._fonts = document.getEnvironment().getFontCollection();
            }
        }
    }

    private void findNotesSlides(Map<Integer, Integer> map) {
        SlideListWithText notesSlideListWithText = this._documentRecord.getNotesSlideListWithText();
        if (notesSlideListWithText != null) {
            int i2 = -1;
            SlideListWithText.SlideAtomsSet[] slideAtomsSets = notesSlideListWithText.getSlideAtomsSets();
            for (SlideListWithText.SlideAtomsSet slideAtomsSet : slideAtomsSets) {
                i2++;
                Record coreRecordForSAS = getCoreRecordForSAS(slideAtomsSet);
                SlidePersistAtom slidePersistAtom = slideAtomsSet.getSlidePersistAtom();
                StringBuilder a = a.a("A Notes SlideAtomSet at ", i2, " said its record was at refID ");
                a.append(slidePersistAtom.getRefID());
                String sb = a.toString();
                if (coreRecordForSAS == null) {
                    logger.log(5, a.b(sb, ", but that record didn't exist - record ignored."));
                } else if (!(coreRecordForSAS instanceof Notes)) {
                    logger.log(7, sb + ", but that was actually a " + coreRecordForSAS);
                } else {
                    map.put(Integer.valueOf(slidePersistAtom.getSlideIdentifier()), Integer.valueOf(i2));
                    HSLFNotes hSLFNotes = new HSLFNotes((Notes) coreRecordForSAS);
                    hSLFNotes.setSlideShow(this);
                    this._notes.add(hSLFNotes);
                }
            }
        }
    }

    private void findSlides(Map<Integer, Integer> map) {
        HSLFNotes hSLFNotes;
        SlideListWithText slideSlideListWithText = this._documentRecord.getSlideSlideListWithText();
        if (slideSlideListWithText != null) {
            int i2 = -1;
            SlideListWithText.SlideAtomsSet[] slideAtomsSets = slideSlideListWithText.getSlideAtomsSets();
            for (SlideListWithText.SlideAtomsSet slideAtomsSet : slideAtomsSets) {
                i2++;
                SlidePersistAtom slidePersistAtom = slideAtomsSet.getSlidePersistAtom();
                Record coreRecordForSAS = getCoreRecordForSAS(slideAtomsSet);
                if (!(coreRecordForSAS instanceof Slide)) {
                    POILogger pOILogger = logger;
                    StringBuilder a = a.a("A Slide SlideAtomSet at ", i2, " said its record was at refID ");
                    a.append(slidePersistAtom.getRefID());
                    a.append(", but that was actually a ");
                    a.append(coreRecordForSAS);
                    pOILogger.log(7, a.toString());
                } else {
                    Slide slide = (Slide) coreRecordForSAS;
                    int notesID = slide.getSlideAtom().getNotesID();
                    if (notesID != 0) {
                        Integer num = map.get(Integer.valueOf(notesID));
                        if (num == null || num.intValue() < 0 || num.intValue() >= this._notes.size()) {
                            logger.log(7, a.c("Notes not found for noteId=", notesID));
                        } else {
                            hSLFNotes = this._notes.get(num.intValue());
                            HSLFSlide hSLFSlide = new HSLFSlide(slide, hSLFNotes, slideAtomsSet, slidePersistAtom.getSlideIdentifier(), i2 + 1);
                            hSLFSlide.setSlideShow(this);
                            this._slides.add(hSLFSlide);
                        }
                    }
                    hSLFNotes = null;
                    HSLFSlide hSLFSlide2 = new HSLFSlide(slide, hSLFNotes, slideAtomsSet, slidePersistAtom.getSlideIdentifier(), i2 + 1);
                    hSLFSlide2.setSlideShow(this);
                    this._slides.add(hSLFSlide2);
                }
            }
        }
    }

    private Record getCoreRecordForRefID(int i2) {
        Integer num = this._sheetIdToCoreRecordsLookup.get(Integer.valueOf(i2));
        if (num != null) {
            return this._mostRecentCoreRecords[num.intValue()];
        }
        logger.log(7, a.c("We tried to look up a reference to a core record, but there was no core ID for reference ID ", i2));
        return null;
    }

    private Record getCoreRecordForSAS(SlideListWithText.SlideAtomsSet slideAtomsSet) {
        return getCoreRecordForRefID(slideAtomsSet.getSlidePersistAtom().getRefID());
    }

    public static LoadSavePhase getLoadSavePhase() {
        return loadSavePhase.get();
    }

    public static Map<String, ClassID> getOleMap() {
        HashMap hashMap = new HashMap();
        hashMap.put(POWERPOINT_DOCUMENT, ClassID.PPT_SHOW);
        hashMap.put("Workbook", ClassID.EXCEL97);
        hashMap.put("WORKBOOK", ClassID.EXCEL97);
        hashMap.put("BOOK", ClassID.EXCEL97);
        return hashMap;
    }

    private void writeDirtyParagraphs(HSLFShapeContainer hSLFShapeContainer) {
        for (HSLFShape hSLFShape : hSLFShapeContainer.getShapes()) {
            if (hSLFShape instanceof HSLFShapeContainer) {
                writeDirtyParagraphs((HSLFShapeContainer) hSLFShape);
            } else if (hSLFShape instanceof HSLFTextShape) {
                HSLFTextShape hSLFTextShape = (HSLFTextShape) hSLFShape;
                boolean z = false;
                for (HSLFTextParagraph hSLFTextParagraph : hSLFTextShape.getTextParagraphs()) {
                    z |= hSLFTextParagraph.isDirty();
                }
                if (z) {
                    hSLFTextShape.storeText();
                }
            }
        }
    }

    public int addControl(String str, String str2) {
        ExControl exControl = new ExControl();
        exControl.setProgId(str2);
        exControl.setMenuName(str);
        exControl.setClipboardName(str);
        ExOleObjAtom exOleObjAtom = exControl.getExOleObjAtom();
        exOleObjAtom.setDrawAspect(1);
        exOleObjAtom.setType(2);
        exOleObjAtom.setSubType(0);
        int addToObjListAtom = addToObjListAtom(exControl);
        exOleObjAtom.setObjID(addToObjListAtom);
        return addToObjListAtom;
    }

    public int addEmbed(POIFSFileSystem pOIFSFileSystem) {
        DirectoryNode root = pOIFSFileSystem.getRoot();
        if (new ClassID().equals(root.getStorageClsid())) {
            ClassID classID = null;
            Iterator<Map.Entry<String, ClassID>> it = getOleMap().entrySet().iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                Map.Entry<String, ClassID> next = it.next();
                if (root.hasEntry(next.getKey())) {
                    classID = next.getValue();
                    break;
                }
            }
            if (classID != null) {
                root.setStorageClsid(classID);
            } else {
                throw new IllegalArgumentException("Unsupported embedded document");
            }
        }
        ExEmbed exEmbed = new ExEmbed();
        Record[] childRecords = exEmbed.getChildRecords();
        exEmbed.removeChild(childRecords[2]);
        exEmbed.removeChild(childRecords[3]);
        exEmbed.removeChild(childRecords[4]);
        exEmbed.getExEmbedAtom().setCantLockServerB(true);
        ExOleObjAtom exOleObjAtom = exEmbed.getExOleObjAtom();
        exOleObjAtom.setDrawAspect(1);
        exOleObjAtom.setType(0);
        exOleObjAtom.setOptions(1226240);
        ExOleObjStg exOleObjStg = new ExOleObjStg();
        try {
            if (!root.hasEntry("\u0001Ole")) {
                pOIFSFileSystem.createDocument(new ByteArrayInputStream(new byte[]{1, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}), "\u0001Ole");
            }
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            pOIFSFileSystem.writeFilesystem(byteArrayOutputStream);
            exOleObjStg.setData(byteArrayOutputStream.toByteArray());
            int addPersistentObject = addPersistentObject(exOleObjStg);
            exOleObjStg.setPersistId(addPersistentObject);
            exOleObjAtom.setObjStgDataRef(addPersistentObject);
            int addToObjListAtom = addToObjListAtom(exEmbed);
            exOleObjAtom.setObjID(addToObjListAtom);
            return addToObjListAtom;
        } catch (IOException e2) {
            throw new HSLFException(e2);
        }
    }

    public HSLFFontInfo addFont(FontInfo fontInfo) {
        return getDocumentRecord().getEnvironment().getFontCollection().addFont(fontInfo);
    }

    public int addMovie(String str, int i2) {
        ExMCIMovie exMCIMovie;
        if (i2 == 1) {
            exMCIMovie = new ExMCIMovie();
        } else if (i2 == 2) {
            exMCIMovie = new ExAviMovie();
        } else {
            throw new IllegalArgumentException(a.c("Unsupported Movie: ", i2));
        }
        ExVideoContainer exVideo = exMCIMovie.getExVideo();
        exVideo.getExMediaAtom().setMask(15204352);
        exVideo.getPathAtom().setText(str);
        int addToObjListAtom = addToObjListAtom(exMCIMovie);
        exVideo.getExMediaAtom().setObjectId(addToObjListAtom);
        return addToObjListAtom;
    }

    public int addPersistentObject(PositionDependentRecord positionDependentRecord) {
        positionDependentRecord.setLastOnDiskOffset(-1);
        this._hslfSlideShow.appendRootLevelRecord((Record) positionDependentRecord);
        HashMap hashMap = new HashMap();
        try {
            this._hslfSlideShow.updateAndWriteDependantRecords(null, hashMap);
            UserEditAtom userEditAtom = (UserEditAtom) hashMap.get(RecordTypes.UserEditAtom);
            int maxPersistWritten = userEditAtom.getMaxPersistWritten() + 1;
            userEditAtom.setLastViewType(1);
            userEditAtom.setMaxPersistWritten(maxPersistWritten);
            int lastOnDiskOffset = positionDependentRecord.getLastOnDiskOffset();
            positionDependentRecord.setLastOnDiskOffset(lastOnDiskOffset);
            ((PersistPtrHolder) hashMap.get(RecordTypes.PersistPtrIncrementalBlock)).addSlideLookup(maxPersistWritten, lastOnDiskOffset);
            logger.log(3, a.c("New slide/object ended up at ", lastOnDiskOffset));
            return maxPersistWritten;
        } catch (IOException e2) {
            throw new HSLFException(e2);
        }
    }

    public int addToObjListAtom(RecordContainer recordContainer) {
        ExObjList exObjList = getDocumentRecord().getExObjList(true);
        ExObjListAtom exObjListAtom = exObjList.getExObjListAtom();
        int objectIDSeed = ((int) exObjListAtom.getObjectIDSeed()) + 1;
        exObjListAtom.setObjectIDSeed(objectIDSeed);
        exObjList.addChildAfter(recordContainer, exObjListAtom);
        return objectIDSeed;
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        this._hslfSlideShow.close();
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public MasterSheet<HSLFShape, HSLFTextParagraph> createMasterSheet() {
        return null;
    }

    public Document getDocumentRecord() {
        return this._documentRecord;
    }

    public HSLFObjectData[] getEmbeddedObjects() {
        return this._hslfSlideShow.getEmbeddedObjects();
    }

    public HSLFFontInfo getFont(int i2) {
        return getDocumentRecord().getEnvironment().getFontCollection().getFontInfo(i2);
    }

    public FontCollection getFontCollection() {
        return this._fonts;
    }

    public Record[] getMostRecentCoreRecords() {
        return this._mostRecentCoreRecords;
    }

    public List<HSLFNotes> getNotes() {
        return this._notes;
    }

    public HeadersFooters getNotesHeadersFooters() {
        if (this._notes.isEmpty()) {
            return new HeadersFooters(this, (short) 79);
        }
        return new HeadersFooters((HSLFSheet) this._notes.get(0), (short) 79);
    }

    public int getNumberOfFonts() {
        return getDocumentRecord().getEnvironment().getFontCollection().getNumberOfFonts();
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public Dimension getPageSize() {
        DocumentAtom documentAtom = this._documentRecord.getDocumentAtom();
        return new Dimension((int) Units.masterToPoints((int) documentAtom.getSlideSizeX()), (int) Units.masterToPoints((int) documentAtom.getSlideSizeY()));
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public List<HSLFPictureData> getPictureData() {
        return this._hslfSlideShow.getPictureData();
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public Resources getResources() {
        return null;
    }

    public HeadersFooters getSlideHeadersFooters() {
        return new HeadersFooters(this, (short) 63);
    }

    /* Return type fixed from 'java.util.List<org.apache.poi.hslf.usermodel.HSLFSlideMaster>' to match base method */
    @Override // org.apache.poi.sl.usermodel.SlideShow
    public List<? extends MasterSheet<HSLFShape, HSLFTextParagraph>> getSlideMasters() {
        return this._masters;
    }

    @Internal
    public HSLFSlideShowImpl getSlideShowImpl() {
        return this._hslfSlideShow;
    }

    /* Return type fixed from 'java.util.List<org.apache.poi.hslf.usermodel.HSLFSlide>' to match base method */
    @Override // org.apache.poi.sl.usermodel.SlideShow
    public List<? extends org.apache.poi.sl.usermodel.Slide<HSLFShape, HSLFTextParagraph>> getSlides() {
        return this._slides;
    }

    public HSLFSoundData[] getSoundData() {
        return HSLFSoundData.find(this._documentRecord);
    }

    public List<HSLFTitleMaster> getTitleMasters() {
        return this._titleMasters;
    }

    public HSLFSlide removeSlide(int i2) {
        int size = this._slides.size() - 1;
        if (i2 < 0 || i2 > size) {
            throw new IllegalArgumentException(a.b("Slide index (", i2, ") is out of range (0..", size, ")"));
        }
        SlideListWithText slideSlideListWithText = this._documentRecord.getSlideSlideListWithText();
        SlideListWithText.SlideAtomsSet[] slideAtomsSets = slideSlideListWithText.getSlideAtomsSets();
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList(Arrays.asList(slideAtomsSets));
        HSLFSlide remove = this._slides.remove(i2);
        this._notes.remove(remove.getNotes());
        arrayList2.remove(i2);
        int i3 = 0;
        for (HSLFSlide hSLFSlide : this._slides) {
            hSLFSlide.setSlideNumber(i3);
            i3++;
        }
        Iterator it = arrayList2.iterator();
        while (it.hasNext()) {
            SlideListWithText.SlideAtomsSet slideAtomsSet = (SlideListWithText.SlideAtomsSet) it.next();
            arrayList.add(slideAtomsSet.getSlidePersistAtom());
            arrayList.addAll(Arrays.asList(slideAtomsSet.getSlideRecords()));
        }
        if (arrayList2.isEmpty()) {
            this._documentRecord.removeSlideListWithText(slideSlideListWithText);
        } else {
            slideSlideListWithText.setSlideAtomsSets((SlideListWithText.SlideAtomsSet[]) arrayList2.toArray(new SlideListWithText.SlideAtomsSet[arrayList2.size()]));
            slideSlideListWithText.setChildRecord((Record[]) arrayList.toArray(new Record[arrayList.size()]));
        }
        int notesID = remove.getSlideRecord().getSlideAtom().getNotesID();
        if (notesID != 0) {
            SlideListWithText notesSlideListWithText = this._documentRecord.getNotesSlideListWithText();
            ArrayList arrayList3 = new ArrayList();
            ArrayList arrayList4 = new ArrayList();
            SlideListWithText.SlideAtomsSet[] slideAtomsSets2 = notesSlideListWithText.getSlideAtomsSets();
            for (SlideListWithText.SlideAtomsSet slideAtomsSet2 : slideAtomsSets2) {
                if (slideAtomsSet2.getSlidePersistAtom().getSlideIdentifier() != notesID) {
                    arrayList4.add(slideAtomsSet2);
                    arrayList3.add(slideAtomsSet2.getSlidePersistAtom());
                    if (slideAtomsSet2.getSlideRecords() != null) {
                        arrayList3.addAll(Arrays.asList(slideAtomsSet2.getSlideRecords()));
                    }
                }
            }
            if (arrayList4.isEmpty()) {
                this._documentRecord.removeSlideListWithText(notesSlideListWithText);
            } else {
                notesSlideListWithText.setSlideAtomsSets((SlideListWithText.SlideAtomsSet[]) arrayList4.toArray(new SlideListWithText.SlideAtomsSet[arrayList4.size()]));
                notesSlideListWithText.setChildRecord((Record[]) arrayList3.toArray(new Record[arrayList3.size()]));
            }
        }
        return remove;
    }

    public void reorderSlide(int i2, int i3) {
        if (i2 < 1 || i3 < 1) {
            throw new IllegalArgumentException("Old and new slide numbers must be greater than 0");
        } else if (i2 > this._slides.size() || i3 > this._slides.size()) {
            StringBuilder b2 = a.b("Old and new slide numbers must not exceed the number of slides (");
            b2.append(this._slides.size());
            b2.append(")");
            throw new IllegalArgumentException(b2.toString());
        } else {
            SlideListWithText slideSlideListWithText = this._documentRecord.getSlideSlideListWithText();
            SlideListWithText.SlideAtomsSet[] slideAtomsSets = slideSlideListWithText.getSlideAtomsSets();
            int i4 = i2 - 1;
            SlideListWithText.SlideAtomsSet slideAtomsSet = slideAtomsSets[i4];
            int i5 = i3 - 1;
            slideAtomsSets[i4] = slideAtomsSets[i5];
            slideAtomsSets[i5] = slideAtomsSet;
            Collections.swap(this._slides, i4, i5);
            this._slides.get(i5).setSlideNumber(i3);
            this._slides.get(i4).setSlideNumber(i2);
            ArrayList arrayList = new ArrayList();
            for (SlideListWithText.SlideAtomsSet slideAtomsSet2 : slideAtomsSets) {
                arrayList.add(slideAtomsSet2.getSlidePersistAtom());
                arrayList.addAll(Arrays.asList(slideAtomsSet2.getSlideRecords()));
            }
            slideSlideListWithText.setChildRecord((Record[]) arrayList.toArray(new Record[arrayList.size()]));
        }
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public void setPageSize(Dimension dimension) {
        DocumentAtom documentAtom = this._documentRecord.getDocumentAtom();
        documentAtom.setSlideSizeX((long) Units.pointsToMaster((double) dimension.width));
        documentAtom.setSlideSizeY((long) Units.pointsToMaster((double) dimension.height));
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public void write(OutputStream outputStream) {
        Iterator<? extends org.apache.poi.sl.usermodel.Slide<HSLFShape, HSLFTextParagraph>> it = getSlides().iterator();
        while (it.hasNext()) {
            writeDirtyParagraphs((HSLFSlide) it.next());
        }
        Iterator<? extends MasterSheet<HSLFShape, HSLFTextParagraph>> it2 = getSlideMasters().iterator();
        while (it2.hasNext()) {
            HSLFSlideMaster hSLFSlideMaster = (HSLFSlideMaster) it2.next();
            boolean z = false;
            for (List<HSLFTextParagraph> list : hSLFSlideMaster.getTextParagraphs()) {
                for (HSLFTextParagraph hSLFTextParagraph : list) {
                    z |= hSLFTextParagraph.isDirty();
                }
            }
            if (z) {
                TxMasterStyleAtom[] txMasterStyleAtoms = hSLFSlideMaster.getTxMasterStyleAtoms();
                for (TxMasterStyleAtom txMasterStyleAtom : txMasterStyleAtoms) {
                    if (txMasterStyleAtom != null) {
                        txMasterStyleAtom.updateStyles();
                    }
                }
            }
        }
        this._hslfSlideShow.write(outputStream);
    }

    /* Return type fixed from 'org.apache.poi.hslf.usermodel.HSLFSlide' to match base method */
    @Override // org.apache.poi.sl.usermodel.SlideShow
    public org.apache.poi.sl.usermodel.Slide<HSLFShape, HSLFTextParagraph> createSlide() {
        int i2;
        SlideListWithText slideSlideListWithText = this._documentRecord.getSlideSlideListWithText();
        if (slideSlideListWithText == null) {
            slideSlideListWithText = new SlideListWithText();
            slideSlideListWithText.setInstance(0);
            this._documentRecord.addSlideListWithText(slideSlideListWithText);
        }
        SlidePersistAtom slidePersistAtom = null;
        for (SlideListWithText.SlideAtomsSet slideAtomsSet : slideSlideListWithText.getSlideAtomsSets()) {
            SlidePersistAtom slidePersistAtom2 = slideAtomsSet.getSlidePersistAtom();
            if (slidePersistAtom2.getSlideIdentifier() >= 0) {
                if (slidePersistAtom == null) {
                    slidePersistAtom = slidePersistAtom2;
                }
                if (slidePersistAtom.getSlideIdentifier() < slidePersistAtom2.getSlideIdentifier()) {
                    slidePersistAtom = slidePersistAtom2;
                }
            }
        }
        SlidePersistAtom slidePersistAtom3 = new SlidePersistAtom();
        if (slidePersistAtom == null) {
            i2 = 256;
        } else {
            i2 = slidePersistAtom.getSlideIdentifier() + 1;
        }
        slidePersistAtom3.setSlideIdentifier(i2);
        slideSlideListWithText.addSlidePersistAtom(slidePersistAtom3);
        HSLFSlide hSLFSlide = new HSLFSlide(slidePersistAtom3.getSlideIdentifier(), slidePersistAtom3.getRefID(), this._slides.size() + 1);
        hSLFSlide.setSlideShow(this);
        hSLFSlide.onCreate();
        this._slides.add(hSLFSlide);
        POILogger pOILogger = logger;
        StringBuilder b2 = a.b("Added slide ");
        b2.append(this._slides.size());
        b2.append(" with ref ");
        b2.append(slidePersistAtom3.getRefID());
        b2.append(" and identifier ");
        b2.append(slidePersistAtom3.getSlideIdentifier());
        pOILogger.log(3, b2.toString());
        Slide slideRecord = hSLFSlide.getSlideRecord();
        int addPersistentObject = addPersistentObject(slideRecord);
        slidePersistAtom3.setRefID(addPersistentObject);
        slideRecord.setSheetId(addPersistentObject);
        hSLFSlide.setMasterSheet(this._masters.get(0));
        return hSLFSlide;
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public HSLFPictureData findPictureData(byte[] bArr) {
        byte[] checksum = HSLFPictureData.getChecksum(bArr);
        for (HSLFPictureData hSLFPictureData : getPictureData()) {
            if (Arrays.equals(hSLFPictureData.getUID(), checksum)) {
                return hSLFPictureData;
            }
        }
        return null;
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public HSLFPictureData addPicture(byte[] bArr, PictureData.PictureType pictureType) {
        if (pictureType == null || pictureType.nativeId == -1) {
            throw new IllegalArgumentException("Unsupported picture format: " + pictureType);
        }
        HSLFPictureData findPictureData = findPictureData(bArr);
        if (findPictureData != null) {
            return findPictureData;
        }
        EscherContainerRecord dggContainer = this._documentRecord.getPPDrawingGroup().getDggContainer();
        EscherContainerRecord escherContainerRecord = (EscherContainerRecord) HSLFShape.getEscherChild(dggContainer, -4095);
        if (escherContainerRecord == null) {
            escherContainerRecord = new EscherContainerRecord();
            escherContainerRecord.setRecordId(EscherContainerRecord.BSTORE_CONTAINER);
            dggContainer.addChildBefore(escherContainerRecord, -4085);
        }
        HSLFPictureData create = HSLFPictureData.create(pictureType);
        create.setData(bArr);
        int addPicture = this._hslfSlideShow.addPicture(create);
        EscherBSERecord escherBSERecord = new EscherBSERecord();
        escherBSERecord.setRecordId(EscherBSERecord.RECORD_ID);
        escherBSERecord.setOptions((short) ((pictureType.nativeId << 4) | 2));
        escherBSERecord.setSize(create.getRawData().length + 8);
        escherBSERecord.setUid(HSLFPictureData.getChecksum(bArr));
        escherBSERecord.setBlipTypeMacOS((byte) pictureType.nativeId);
        escherBSERecord.setBlipTypeWin32((byte) pictureType.nativeId);
        if (pictureType == PictureData.PictureType.EMF) {
            escherBSERecord.setBlipTypeMacOS((byte) PictureData.PictureType.PICT.nativeId);
        } else if (pictureType == PictureData.PictureType.WMF) {
            escherBSERecord.setBlipTypeMacOS((byte) PictureData.PictureType.PICT.nativeId);
        } else if (pictureType == PictureData.PictureType.PICT) {
            escherBSERecord.setBlipTypeWin32((byte) PictureData.PictureType.WMF.nativeId);
        }
        escherBSERecord.setRef(0);
        escherBSERecord.setOffset(addPicture);
        escherBSERecord.setRemainingData(new byte[0]);
        escherContainerRecord.addChildRecord(escherBSERecord);
        escherContainerRecord.setOptions((short) ((escherContainerRecord.getChildRecords().size() << 4) | 15));
        return create;
    }

    public HSLFSlideShow() {
        this(HSLFSlideShowImpl.create());
    }

    public HSLFSlideShow(InputStream inputStream) {
        this(new HSLFSlideShowImpl(inputStream));
    }

    public HSLFSlideShow(NPOIFSFileSystem nPOIFSFileSystem) {
        this(new HSLFSlideShowImpl(nPOIFSFileSystem));
    }

    public HSLFSlideShow(DirectoryNode directoryNode) {
        this(new HSLFSlideShowImpl(directoryNode));
    }

    @Override // org.apache.poi.sl.usermodel.SlideShow
    public HSLFPictureData addPicture(InputStream inputStream, PictureData.PictureType pictureType) {
        if (pictureType != null && pictureType.nativeId != -1) {
            return addPicture(IOUtils.toByteArray(inputStream), pictureType);
        }
        throw new IllegalArgumentException("Unsupported picture format: " + pictureType);
    }

    /* JADX INFO: finally extract failed */
    @Override // org.apache.poi.sl.usermodel.SlideShow
    public HSLFPictureData addPicture(File file, PictureData.PictureType pictureType) {
        if (pictureType == null || pictureType.nativeId == -1) {
            throw new IllegalArgumentException("Unsupported picture format: " + pictureType);
        }
        byte[] bArr = new byte[((int) file.length())];
        FileInputStream fileInputStream = new FileInputStream(file);
        try {
            IOUtils.readFully(fileInputStream, bArr);
            fileInputStream.close();
            return addPicture(bArr, pictureType);
        } catch (Throwable th) {
            fileInputStream.close();
            throw th;
        }
    }
}
