package org.apache.poi.hslf.usermodel;

import java.io.Closeable;
import java.io.OutputStream;
import java.security.GeneralSecurityException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Map;
import java.util.NavigableMap;
import java.util.TreeMap;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.hslf.exceptions.CorruptPowerPointFileException;
import org.apache.poi.hslf.exceptions.EncryptedPowerPointFileException;
import org.apache.poi.hslf.record.DocumentEncryptionAtom;
import org.apache.poi.hslf.record.PersistPtrHolder;
import org.apache.poi.hslf.record.PositionDependentRecord;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.UserEditAtom;
import org.apache.poi.hssf.record.crypto.Biff8EncryptionKey;
import org.apache.poi.poifs.crypt.ChunkedCipherInputStream;
import org.apache.poi.poifs.crypt.ChunkedCipherOutputStream;
import org.apache.poi.poifs.crypt.Decryptor;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.crypt.Encryptor;
import org.apache.poi.util.BitField;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayInputStream;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;

@Internal
public class HSLFSlideShowEncrypted implements Closeable {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int[] BLIB_STORE_ENTRY_PARTS = {1, 1, 16, 2, 4, 4, 4, 1, 1, 1, 1};
    public static final BitField fieldRecInst = new BitField(65520);
    public EncryptionInfo _encryptionInfo;
    public ChunkedCipherOutputStream cyos = null;
    public DocumentEncryptionAtom dea;

    public HSLFSlideShowEncrypted(DocumentEncryptionAtom documentEncryptionAtom) {
        this.dea = documentEncryptionAtom;
    }

    public static Record[] addEncryptionRecord(Record[] recordArr, DocumentEncryptionAtom documentEncryptionAtom) {
        int i2 = -1;
        int i3 = -1;
        int i4 = -1;
        int i5 = -1;
        for (Record record : recordArr) {
            i2++;
            if (record instanceof UserEditAtom) {
                i3 = i2;
            } else if (record instanceof PersistPtrHolder) {
                i4 = i2;
            } else if (record instanceof DocumentEncryptionAtom) {
                i5 = i2;
            }
        }
        if (i5 != -1) {
            documentEncryptionAtom.setLastOnDiskOffset(((DocumentEncryptionAtom) recordArr[i5]).getLastOnDiskOffset());
            recordArr[i5] = documentEncryptionAtom;
            return recordArr;
        }
        PersistPtrHolder persistPtrHolder = (PersistPtrHolder) recordArr[i4];
        UserEditAtom userEditAtom = (UserEditAtom) recordArr[i3];
        documentEncryptionAtom.setLastOnDiskOffset(persistPtrHolder.getLastOnDiskOffset() - 1);
        int maxPersistWritten = userEditAtom.getMaxPersistWritten() + 1;
        persistPtrHolder.addSlideLookup(maxPersistWritten, persistPtrHolder.getLastOnDiskOffset() - 1);
        userEditAtom.setEncryptSessionPersistIdRef(maxPersistWritten);
        userEditAtom.setMaxPersistWritten(maxPersistWritten);
        Record[] recordArr2 = new Record[(recordArr.length + 1)];
        if (i4 > 0) {
            System.arraycopy(recordArr, 0, recordArr2, 0, i4);
        }
        if (i4 < recordArr.length - 1) {
            System.arraycopy(recordArr, i4, recordArr2, i4 + 1, recordArr.length - i4);
        }
        recordArr2[i4] = documentEncryptionAtom;
        return recordArr2;
    }

    private void decryptPicBytes(byte[] bArr, int i2, int i3) {
        LittleEndianByteArrayInputStream littleEndianByteArrayInputStream = new LittleEndianByteArrayInputStream(bArr, i2);
        ChunkedCipherInputStream chunkedCipherInputStream = (ChunkedCipherInputStream) getEncryptionInfo().getDecryptor().getDataStream(littleEndianByteArrayInputStream, i3, 0);
        readFully(chunkedCipherInputStream, bArr, i2, i3);
        chunkedCipherInputStream.close();
        littleEndianByteArrayInputStream.close();
    }

    public static Record[] normalizeRecords(Record[] recordArr) {
        TreeMap treeMap = new TreeMap();
        TreeMap treeMap2 = new TreeMap();
        ArrayList arrayList = new ArrayList();
        UserEditAtom userEditAtom = null;
        PersistPtrHolder persistPtrHolder = null;
        int i2 = 0;
        for (Record record : recordArr) {
            PositionDependentRecord positionDependentRecord = (PositionDependentRecord) record;
            if (positionDependentRecord instanceof UserEditAtom) {
                userEditAtom = (UserEditAtom) positionDependentRecord;
            } else if (positionDependentRecord instanceof PersistPtrHolder) {
                if (persistPtrHolder != null) {
                    i2++;
                }
                PersistPtrHolder persistPtrHolder2 = (PersistPtrHolder) positionDependentRecord;
                for (Map.Entry<Integer, Integer> entry : persistPtrHolder2.getSlideLocationsLookup().entrySet()) {
                    Integer num = (Integer) treeMap.put(entry.getKey(), entry.getValue());
                    if (num != null) {
                        arrayList.add(num);
                    }
                }
                persistPtrHolder = persistPtrHolder2;
            } else {
                treeMap2.put(Integer.valueOf(positionDependentRecord.getLastOnDiskOffset()), record);
            }
        }
        if (userEditAtom == null || persistPtrHolder == null || userEditAtom.getPersistPointersOffset() != persistPtrHolder.getLastOnDiskOffset()) {
            throw new EncryptedDocumentException("UserEditAtom and PersistPtrHolder must exist and their offset need to match.");
        }
        treeMap2.put(Integer.valueOf(persistPtrHolder.getLastOnDiskOffset()), persistPtrHolder);
        treeMap2.put(Integer.valueOf(userEditAtom.getLastOnDiskOffset()), userEditAtom);
        if (i2 == 0 && arrayList.isEmpty()) {
            return recordArr;
        }
        userEditAtom.setLastUserEditAtomOffset(0);
        persistPtrHolder.clear();
        for (Map.Entry entry2 : treeMap.entrySet()) {
            persistPtrHolder.addSlideLookup(((Integer) entry2.getKey()).intValue(), ((Integer) entry2.getValue()).intValue());
        }
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            treeMap2.remove((Integer) it.next());
        }
        return (Record[]) treeMap2.values().toArray(new Record[treeMap2.size()]);
    }

    public static void readFully(ChunkedCipherInputStream chunkedCipherInputStream, byte[] bArr, int i2, int i3) {
        if (IOUtils.readFully(chunkedCipherInputStream, bArr, i2, i3) == -1) {
            throw new EncryptedPowerPointFileException("unexpected EOF");
        }
    }

    public static Record[] removeEncryptionRecord(Record[] recordArr) {
        ArrayList arrayList = new ArrayList();
        PersistPtrHolder persistPtrHolder = null;
        int i2 = -1;
        UserEditAtom userEditAtom = null;
        int i3 = -1;
        int i4 = -1;
        for (Record record : recordArr) {
            if (record instanceof DocumentEncryptionAtom) {
                i4 = ((DocumentEncryptionAtom) record).getLastOnDiskOffset();
            } else {
                if (record instanceof UserEditAtom) {
                    userEditAtom = (UserEditAtom) record;
                    i3 = userEditAtom.getEncryptSessionPersistIdRef();
                    userEditAtom.setEncryptSessionPersistIdRef(-1);
                } else if (record instanceof PersistPtrHolder) {
                    persistPtrHolder = (PersistPtrHolder) record;
                }
                arrayList.add(record);
            }
        }
        if (persistPtrHolder == null || userEditAtom == null) {
            throw new EncryptedDocumentException("UserEditAtom or PersistPtrholder not found.");
        } else if (i3 == -1 && i4 == -1) {
            return recordArr;
        } else {
            TreeMap treeMap = new TreeMap(persistPtrHolder.getSlideLocationsLookup());
            persistPtrHolder.clear();
            for (Map.Entry entry : treeMap.entrySet()) {
                if (!(((Integer) entry.getKey()).intValue() == i3 || ((Integer) entry.getValue()).intValue() == i4)) {
                    persistPtrHolder.addSlideLookup(((Integer) entry.getKey()).intValue(), ((Integer) entry.getValue()).intValue());
                    i2 = Math.max(((Integer) entry.getKey()).intValue(), i2);
                }
            }
            userEditAtom.setMaxPersistWritten(i2);
            return (Record[]) arrayList.toArray(new Record[arrayList.size()]);
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        ChunkedCipherOutputStream chunkedCipherOutputStream = this.cyos;
        if (chunkedCipherOutputStream != null) {
            chunkedCipherOutputStream.close();
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:36:0x0083 A[Catch:{ Exception -> 0x00a7 }, LOOP:1: B:35:0x0081->B:36:0x0083, LOOP_END] */
    public void decryptPicture(byte[] bArr, int i2) {
        int i3;
        if (this.dea != null) {
            try {
                decryptPicBytes(bArr, i2, 8);
                int value = fieldRecInst.getValue(LittleEndian.getUShort(bArr, i2));
                int uShort = LittleEndian.getUShort(bArr, i2 + 2);
                int i4 = i2 + 8;
                int uInt = ((int) LittleEndian.getUInt(bArr, i2 + 4)) + i4;
                if (uShort == 61447) {
                    for (int i5 : BLIB_STORE_ENTRY_PARTS) {
                        decryptPicBytes(bArr, i4, i5);
                    }
                    int i6 = i4 + 36;
                    int uShort2 = LittleEndian.getUShort(bArr, i6 - 3);
                    if (uShort2 > 0) {
                        decryptPicBytes(bArr, i6, uShort2);
                        i6 += uShort2;
                    }
                    if (i6 != uInt) {
                        decryptPicBytes(bArr, i6, 8);
                        value = fieldRecInst.getValue(LittleEndian.getUShort(bArr, i6));
                        uShort = LittleEndian.getUShort(bArr, i6 + 2);
                        i4 = i6 + 8;
                    } else {
                        return;
                    }
                }
                int i7 = 1;
                if (!(value == 535 || value == 981 || value == 1131 || value == 1347 || value == 1761 || value == 1763 || value == 1765)) {
                    if (value != 1961) {
                        i3 = 1;
                        for (int i8 = 0; i8 < i3; i8++) {
                            decryptPicBytes(bArr, i4, 16);
                            i4 += 16;
                        }
                        if (uShort == 61466 || uShort == 61467 || uShort == 61468) {
                            i7 = 34;
                        }
                        decryptPicBytes(bArr, i4, i7);
                        int i9 = i4 + i7;
                        decryptPicBytes(bArr, i9, uInt - i9);
                    }
                }
                i3 = 2;
                while (i8 < i3) {
                }
                i7 = 34;
                decryptPicBytes(bArr, i4, i7);
                int i92 = i4 + i7;
                decryptPicBytes(bArr, i92, uInt - i92);
            } catch (Exception e2) {
                throw new CorruptPowerPointFileException(e2);
            }
        }
    }

    public void decryptRecord(byte[] bArr, int i2, int i3) {
        Throwable th;
        Exception e2;
        if (this.dea != null) {
            Decryptor decryptor = getEncryptionInfo().getDecryptor();
            decryptor.setChunkSize(-1);
            LittleEndianByteArrayInputStream littleEndianByteArrayInputStream = new LittleEndianByteArrayInputStream(bArr, i3);
            ChunkedCipherInputStream chunkedCipherInputStream = null;
            try {
                ChunkedCipherInputStream chunkedCipherInputStream2 = (ChunkedCipherInputStream) decryptor.getDataStream(littleEndianByteArrayInputStream, bArr.length - i3, 0);
                try {
                    chunkedCipherInputStream2.initCipherForBlock(i2);
                    readFully(chunkedCipherInputStream2, bArr, i3, 8);
                    readFully(chunkedCipherInputStream2, bArr, i3 + 8, (int) LittleEndian.getUInt(bArr, i3 + 4));
                    IOUtils.closeQuietly(chunkedCipherInputStream2);
                    IOUtils.closeQuietly(littleEndianByteArrayInputStream);
                } catch (Exception e3) {
                    e2 = e3;
                    chunkedCipherInputStream = chunkedCipherInputStream2;
                    try {
                        throw new EncryptedPowerPointFileException(e2);
                    } catch (Throwable th2) {
                        th = th2;
                        IOUtils.closeQuietly(chunkedCipherInputStream);
                        IOUtils.closeQuietly(littleEndianByteArrayInputStream);
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    chunkedCipherInputStream = chunkedCipherInputStream2;
                    IOUtils.closeQuietly(chunkedCipherInputStream);
                    IOUtils.closeQuietly(littleEndianByteArrayInputStream);
                    throw th;
                }
            } catch (Exception e4) {
                e2 = e4;
                throw new EncryptedPowerPointFileException(e2);
            }
        }
    }

    public void encryptPicture(byte[] bArr, int i2) {
        int i3;
        if (this.dea != null) {
            LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream = new LittleEndianByteArrayOutputStream(bArr, i2);
            try {
                Encryptor encryptor = getEncryptionInfo().getEncryptor();
                encryptor.setChunkSize(-1);
                ChunkedCipherOutputStream dataStream = encryptor.getDataStream(littleEndianByteArrayOutputStream, 0);
                int value = fieldRecInst.getValue(LittleEndian.getUShort(bArr, i2));
                int uShort = LittleEndian.getUShort(bArr, i2 + 2);
                dataStream.write(bArr, i2, 8);
                dataStream.flush();
                int i4 = i2 + 8;
                int uInt = ((int) LittleEndian.getUInt(bArr, i2 + 4)) + i4;
                if (uShort == 61447) {
                    int uShort2 = LittleEndian.getUShort(bArr, i4 + 33);
                    int[] iArr = BLIB_STORE_ENTRY_PARTS;
                    for (int i5 : iArr) {
                        dataStream.write(bArr, i4, i5);
                        dataStream.flush();
                        i4 += i5;
                    }
                    if (uShort2 > 0) {
                        dataStream.write(bArr, i4, uShort2);
                        dataStream.flush();
                        i4 += uShort2;
                    }
                    if (i4 == uInt) {
                        IOUtils.closeQuietly(dataStream);
                        IOUtils.closeQuietly(littleEndianByteArrayOutputStream);
                        return;
                    }
                    value = fieldRecInst.getValue(LittleEndian.getUShort(bArr, i4));
                    uShort = LittleEndian.getUShort(bArr, i4 + 2);
                    dataStream.write(bArr, i4, 8);
                    dataStream.flush();
                    i4 += 8;
                }
                int i6 = (value == 535 || value == 981 || value == 1131 || value == 1347 || value == 1761 || value == 1763 || value == 1765 || value == 1961) ? 2 : 1;
                for (int i7 = 0; i7 < i6; i7++) {
                    dataStream.write(bArr, i4, 16);
                    dataStream.flush();
                    i4 += 16;
                }
                if (uShort == 61466 || uShort == 61467 || uShort == 61468) {
                    dataStream.write(bArr, i4, 34);
                    i3 = i4 + 34;
                    dataStream.flush();
                } else {
                    dataStream.write(bArr, i4, 1);
                    i3 = i4 + 1;
                    dataStream.flush();
                }
                dataStream.write(bArr, i3, uInt - i3);
                dataStream.flush();
                IOUtils.closeQuietly(dataStream);
                IOUtils.closeQuietly(littleEndianByteArrayOutputStream);
            } catch (Exception e2) {
                throw new EncryptedPowerPointFileException(e2);
            } catch (Throwable th) {
                IOUtils.closeQuietly(null);
                IOUtils.closeQuietly(littleEndianByteArrayOutputStream);
                throw th;
            }
        }
    }

    public OutputStream encryptRecord(OutputStream outputStream, int i2, Record record) {
        if (this.dea == null || (record instanceof UserEditAtom) || (record instanceof PersistPtrHolder) || (record instanceof DocumentEncryptionAtom)) {
            try {
                if (this.cyos != null) {
                    this.cyos.flush();
                }
                return outputStream;
            } catch (Exception e2) {
                throw new EncryptedPowerPointFileException(e2);
            }
        } else {
            if (this.cyos == null) {
                Encryptor encryptor = getEncryptionInfo().getEncryptor();
                encryptor.setChunkSize(-1);
                this.cyos = encryptor.getDataStream(outputStream, 0);
            }
            this.cyos.initCipherForBlock(i2, false);
            return this.cyos;
        }
    }

    public DocumentEncryptionAtom getDocumentEncryptionAtom() {
        return this.dea;
    }

    public EncryptionInfo getEncryptionInfo() {
        DocumentEncryptionAtom documentEncryptionAtom = this.dea;
        if (documentEncryptionAtom != null) {
            return documentEncryptionAtom.getEncryptionInfo();
        }
        return null;
    }

    public Record[] updateEncryptionRecord(Record[] recordArr) {
        String currentUserPassword = Biff8EncryptionKey.getCurrentUserPassword();
        if (currentUserPassword != null) {
            if (this.dea == null) {
                this.dea = new DocumentEncryptionAtom();
            }
            EncryptionInfo encryptionInfo = this.dea.getEncryptionInfo();
            byte[] salt = encryptionInfo.getVerifier().getSalt();
            Encryptor encryptor = getEncryptionInfo().getEncryptor();
            if (salt == null) {
                encryptor.confirmPassword(currentUserPassword);
            } else {
                encryptor.confirmPassword(currentUserPassword, null, null, encryptionInfo.getDecryptor().getVerifier(), salt, null);
            }
            return addEncryptionRecord(normalizeRecords(recordArr), this.dea);
        } else if (this.dea == null) {
            return recordArr;
        } else {
            this.dea = null;
            return removeEncryptionRecord(recordArr);
        }
    }

    public HSLFSlideShowEncrypted(byte[] bArr, NavigableMap<Integer, Record> navigableMap) {
        UserEditAtom userEditAtom;
        Iterator<Map.Entry<Integer, Record>> it = navigableMap.descendingMap().entrySet().iterator();
        while (true) {
            if (!it.hasNext()) {
                userEditAtom = null;
                break;
            }
            Record value = it.next().getValue();
            if (value instanceof UserEditAtom) {
                userEditAtom = (UserEditAtom) value;
                if (userEditAtom.getEncryptSessionPersistIdRef() != -1) {
                    break;
                }
            }
        }
        if (userEditAtom == null) {
            this.dea = null;
            return;
        }
        Integer num = ((PersistPtrHolder) ((Record) navigableMap.get(Integer.valueOf(userEditAtom.getPersistPointersOffset())))).getSlideLocationsLookup().get(Integer.valueOf(userEditAtom.getEncryptSessionPersistIdRef()));
        if (num == null) {
            this.dea = null;
            return;
        }
        Record record = (Record) navigableMap.get(num);
        if (record == null) {
            record = Record.buildRecordAtOffset(bArr, num.intValue());
            navigableMap.put(num, record);
        }
        this.dea = (DocumentEncryptionAtom) record;
        String currentUserPassword = Biff8EncryptionKey.getCurrentUserPassword();
        try {
            Decryptor decryptor = getEncryptionInfo().getDecryptor();
            if (currentUserPassword == null) {
                currentUserPassword = Decryptor.DEFAULT_PASSWORD;
            }
            if (!decryptor.verifyPassword(currentUserPassword)) {
                throw new EncryptedPowerPointFileException("PowerPoint file is encrypted. The correct password needs to be set via Biff8EncryptionKey.setCurrentUserPassword()");
            }
        } catch (GeneralSecurityException e2) {
            throw new EncryptedPowerPointFileException(e2);
        }
    }
}
