package org.apache.poi.hslf.usermodel;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.NavigableMap;
import java.util.TreeMap;
import org.apache.poi.POIDocument;
import org.apache.poi.hslf.dev.PPTXMLDump;
import org.apache.poi.hslf.exceptions.CorruptPowerPointFileException;
import org.apache.poi.hslf.exceptions.HSLFException;
import org.apache.poi.hslf.record.CurrentUserAtom;
import org.apache.poi.hslf.record.DocumentEncryptionAtom;
import org.apache.poi.hslf.record.ExOleObjStg;
import org.apache.poi.hslf.record.PersistPtrHolder;
import org.apache.poi.hslf.record.PersistRecord;
import org.apache.poi.hslf.record.PositionDependentRecord;
import org.apache.poi.hslf.record.Record;
import org.apache.poi.hslf.record.RecordTypes;
import org.apache.poi.hslf.record.UserEditAtom;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentEntry;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.EntryUtils;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.sl.usermodel.PictureData;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Removal;

public final class HSLFSlideShowImpl extends POIDocument implements Closeable {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int UNSET_OFFSET = -1;
    public byte[] _docstream;
    public HSLFObjectData[] _objects;
    public List<HSLFPictureData> _pictures;
    public Record[] _records;
    public CurrentUserAtom currentUser;
    public POILogger logger;

    public static class BufAccessBAOS extends ByteArrayOutputStream {
        public BufAccessBAOS() {
        }

        public byte[] getBuf() {
            return ((ByteArrayOutputStream) this).buf;
        }
    }

    public static class CountingOS extends OutputStream {
        public int count;

        public CountingOS() {
            this.count = 0;
        }

        public int size() {
            return this.count;
        }

        @Override // java.io.OutputStream
        public void write(int i2) {
            this.count++;
        }

        @Override // java.io.OutputStream
        public void write(byte[] bArr) {
            this.count += bArr.length;
        }

        @Override // java.io.OutputStream
        public void write(byte[] bArr, int i2, int i3) {
            this.count += i3;
        }
    }

    public HSLFSlideShowImpl(String str) {
        this(new POIFSFileSystem(new File(str)));
    }

    private void buildRecords() {
        this._records = read(this._docstream, (int) this.currentUser.getCurrentEditOffset());
    }

    public static final HSLFSlideShowImpl create() {
        InputStream resourceAsStream = HSLFSlideShowImpl.class.getResourceAsStream("/org/apache/poi/hslf/data/empty.ppt");
        if (resourceAsStream != null) {
            try {
                HSLFSlideShowImpl hSLFSlideShowImpl = new HSLFSlideShowImpl(resourceAsStream);
                resourceAsStream.close();
                return hSLFSlideShowImpl;
            } catch (IOException e2) {
                throw new HSLFException(e2);
            } catch (Throwable th) {
                resourceAsStream.close();
                throw th;
            }
        } else {
            throw new HSLFException("Missing resource 'empty.ppt'");
        }
    }

    public static DirectoryNode handleDualStorage(DirectoryNode directoryNode) {
        if (!directoryNode.hasEntry("PP97_DUALSTORAGE")) {
            return directoryNode;
        }
        return (DirectoryNode) directoryNode.getEntry("PP97_DUALSTORAGE");
    }

    private void initRecordOffsets(byte[] bArr, int i2, NavigableMap<Integer, Record> navigableMap, Map<Integer, Integer> map) {
        while (i2 != 0) {
            UserEditAtom userEditAtom = (UserEditAtom) Record.buildRecordAtOffset(bArr, i2);
            navigableMap.put(Integer.valueOf(i2), userEditAtom);
            int persistPointersOffset = userEditAtom.getPersistPointersOffset();
            PersistPtrHolder persistPtrHolder = (PersistPtrHolder) Record.buildRecordAtOffset(bArr, persistPointersOffset);
            navigableMap.put(Integer.valueOf(persistPointersOffset), persistPtrHolder);
            for (Map.Entry<Integer, Integer> entry : persistPtrHolder.getSlideLocationsLookup().entrySet()) {
                Integer value = entry.getValue();
                navigableMap.put(value, null);
                map.put(value, entry.getKey());
            }
            i2 = userEditAtom.getLastUserEditAtomOffset();
            if (i2 > 0 && navigableMap.containsKey(Integer.valueOf(i2))) {
                i2 = navigableMap.firstKey().intValue() - 36;
                int uShort = LittleEndian.getUShort(bArr, i2);
                int uShort2 = LittleEndian.getUShort(bArr, i2 + 2);
                int i3 = LittleEndian.getInt(bArr, i2 + 4);
                if (uShort == 0 && uShort2 == 4085 && (i3 == 28 || i3 == 32)) {
                    this.logger.log(5, "Repairing invalid user edit atom");
                    userEditAtom.setLastUserEditAtomOffset(i2);
                } else {
                    throw new CorruptPowerPointFileException("Powerpoint document contains invalid user edit atom");
                }
            }
        }
    }

    private Record[] read(byte[] bArr, int i2) {
        TreeMap treeMap = new TreeMap();
        HashMap hashMap = new HashMap();
        initRecordOffsets(bArr, i2, treeMap, hashMap);
        HSLFSlideShowEncrypted hSLFSlideShowEncrypted = new HSLFSlideShowEncrypted(bArr, treeMap);
        for (Map.Entry entry : treeMap.entrySet()) {
            Integer num = (Integer) entry.getKey();
            Record record = (Record) entry.getValue();
            Integer num2 = (Integer) hashMap.get(num);
            if (record == null) {
                hSLFSlideShowEncrypted.decryptRecord(bArr, num2.intValue(), num.intValue());
                record = Record.buildRecordAtOffset(bArr, num.intValue());
                entry.setValue(record);
            }
            if (record instanceof PersistRecord) {
                ((PersistRecord) record).setPersistId(num2.intValue());
            }
        }
        hSLFSlideShowEncrypted.close();
        return (Record[]) treeMap.values().toArray(new Record[treeMap.size()]);
    }

    private void readCurrentUserStream() {
        try {
            this.currentUser = new CurrentUserAtom(getDirectory());
        } catch (IOException e2) {
            POILogger pOILogger = this.logger;
            pOILogger.log(7, "Error finding Current User Atom:\n" + e2);
            this.currentUser = new CurrentUserAtom();
        }
    }

    private void readOtherStreams() {
    }

    private void readPictures() {
        this._pictures = new ArrayList();
        if (getDirectory().hasEntry(PPTXMLDump.PICTURES_ENTRY)) {
            DocumentEntry documentEntry = (DocumentEntry) getDirectory().getEntry(PPTXMLDump.PICTURES_ENTRY);
            DocumentInputStream createDocumentInputStream = getDirectory().createDocumentInputStream(documentEntry);
            byte[] byteArray = IOUtils.toByteArray(createDocumentInputStream, documentEntry.getSize());
            createDocumentInputStream.close();
            HSLFSlideShowEncrypted hSLFSlideShowEncrypted = new HSLFSlideShowEncrypted(getDocumentEncryptionAtom());
            int i2 = 0;
            while (true) {
                try {
                    if (i2 > byteArray.length - 8) {
                        break;
                    }
                    hSLFSlideShowEncrypted.decryptPicture(byteArray, i2);
                    int uShort = LittleEndian.getUShort(byteArray, i2);
                    int i3 = i2 + 2;
                    int uShort2 = LittleEndian.getUShort(byteArray, i3);
                    int i4 = i3 + 2;
                    int i5 = LittleEndian.getInt(byteArray, i4);
                    int i6 = i4 + 4;
                    if (uShort2 != 61447) {
                        if (uShort2 >= 61464) {
                            if (uShort2 > 61719) {
                                break;
                            }
                        } else {
                            break;
                        }
                    }
                    if (i5 >= 0) {
                        PictureData.PictureType forNativeID = PictureData.PictureType.forNativeID(uShort2 - 61464);
                        if (forNativeID == null) {
                            POILogger pOILogger = this.logger;
                            pOILogger.log(7, "Problem reading picture: Invalid image type 0, on picture with length " + i5 + ".\nYou document will probably become corrupted if you save it!");
                            POILogger pOILogger2 = this.logger;
                            pOILogger2.log(7, "" + i6);
                        } else if (i6 + i5 > byteArray.length) {
                            this.logger.log(5, "\"Pictures\" stream may have ended early. In some circumstances, this is not a problem; in others, this could indicate a corrupt file");
                            break;
                        } else {
                            try {
                                HSLFPictureData create = HSLFPictureData.create(forNativeID);
                                create.setSignature(uShort);
                                byte[] bArr = new byte[i5];
                                System.arraycopy(byteArray, i6, bArr, 0, i5);
                                create.setRawData(bArr);
                                create.setOffset(i2);
                                create.setIndex(this._pictures.size());
                                this._pictures.add(create);
                            } catch (IllegalArgumentException e2) {
                                POILogger pOILogger3 = this.logger;
                                pOILogger3.log(7, "Problem reading picture: " + e2 + "\nYou document will probably become corrupted if you save it!");
                            }
                        }
                        i2 = i6 + i5;
                    } else {
                        throw new CorruptPowerPointFileException("The file contains a picture, at position " + this._pictures.size() + ", which has a negatively sized data length, so we can't trust any of the picture data");
                    }
                } finally {
                    hSLFSlideShowEncrypted.close();
                }
            }
        }
    }

    private void readPowerPointStream() {
        int size = ((DocumentEntry) getDirectory().getEntry(HSLFSlideShow.POWERPOINT_DOCUMENT)).getSize();
        DocumentInputStream createDocumentInputStream = getDirectory().createDocumentInputStream(HSLFSlideShow.POWERPOINT_DOCUMENT);
        try {
            this._docstream = IOUtils.toByteArray(createDocumentInputStream, size);
        } finally {
            createDocumentInputStream.close();
        }
    }

    public int addPicture(HSLFPictureData hSLFPictureData) {
        if (this._pictures == null) {
            try {
                readPictures();
            } catch (IOException e2) {
                throw new CorruptPowerPointFileException(e2.getMessage());
            }
        }
        int i2 = 0;
        if (this._pictures.size() > 0) {
            List<HSLFPictureData> list = this._pictures;
            HSLFPictureData hSLFPictureData2 = list.get(list.size() - 1);
            i2 = hSLFPictureData2.getOffset() + hSLFPictureData2.getRawData().length + 8;
        }
        hSLFPictureData.setOffset(i2);
        hSLFPictureData.setIndex(this._pictures.size() + 1);
        this._pictures.add(hSLFPictureData);
        return i2;
    }

    public synchronized int appendRootLevelRecord(Record record) {
        int i2;
        Record[] recordArr = new Record[(this._records.length + 1)];
        boolean z = false;
        i2 = -1;
        for (int length = this._records.length - 1; length >= 0; length--) {
            if (z) {
                recordArr[length] = this._records[length];
            } else {
                recordArr[length + 1] = this._records[length];
                if (this._records[length] instanceof PersistPtrHolder) {
                    recordArr[length] = record;
                    i2 = length;
                    z = true;
                }
            }
        }
        this._records = recordArr;
        return i2;
    }

    @Override // java.io.Closeable, org.apache.poi.POIDocument, java.lang.AutoCloseable
    public void close() {
        NPOIFSFileSystem fileSystem = getDirectory().getFileSystem();
        if (fileSystem != null) {
            fileSystem.close();
        }
    }

    public CurrentUserAtom getCurrentUserAtom() {
        return this.currentUser;
    }

    public DocumentEncryptionAtom getDocumentEncryptionAtom() {
        Record[] recordArr = this._records;
        for (Record record : recordArr) {
            if (record instanceof DocumentEncryptionAtom) {
                return (DocumentEncryptionAtom) record;
            }
        }
        return null;
    }

    public HSLFObjectData[] getEmbeddedObjects() {
        if (this._objects == null) {
            ArrayList arrayList = new ArrayList();
            Record[] recordArr = this._records;
            for (Record record : recordArr) {
                if (record instanceof ExOleObjStg) {
                    arrayList.add(new HSLFObjectData((ExOleObjStg) record));
                }
            }
            this._objects = (HSLFObjectData[]) arrayList.toArray(new HSLFObjectData[arrayList.size()]);
        }
        return this._objects;
    }

    @Override // org.apache.poi.POIDocument
    public String getEncryptedPropertyStreamName() {
        return "EncryptedSummary";
    }

    @Override // org.apache.poi.POIDocument
    public EncryptionInfo getEncryptionInfo() {
        DocumentEncryptionAtom documentEncryptionAtom = getDocumentEncryptionAtom();
        if (documentEncryptionAtom != null) {
            return documentEncryptionAtom.getEncryptionInfo();
        }
        return null;
    }

    @Removal(version = "3.18")
    @Deprecated
    public DirectoryNode getPOIFSDirectory() {
        return getDirectory();
    }

    public List<HSLFPictureData> getPictureData() {
        if (this._pictures == null) {
            try {
                readPictures();
            } catch (IOException e2) {
                throw new CorruptPowerPointFileException(e2.getMessage());
            }
        }
        return Collections.unmodifiableList(this._pictures);
    }

    public Record[] getRecords() {
        return this._records;
    }

    public byte[] getUnderlyingBytes() {
        return this._docstream;
    }

    public void normalizeRecords() {
        try {
            updateAndWriteDependantRecords(null, null);
            this._records = HSLFSlideShowEncrypted.normalizeRecords(this._records);
        } catch (IOException e2) {
            throw new CorruptPowerPointFileException(e2);
        }
    }

    public void updateAndWriteDependantRecords(OutputStream outputStream, Map<RecordTypes, PositionDependentRecord> map) {
        HashMap hashMap = new HashMap();
        UserEditAtom userEditAtom = null;
        CountingOS countingOS = new CountingOS();
        Record[] recordArr = this._records;
        PersistPtrHolder persistPtrHolder = null;
        for (Record record : recordArr) {
            PositionDependentRecord positionDependentRecord = (PositionDependentRecord) record;
            int lastOnDiskOffset = positionDependentRecord.getLastOnDiskOffset();
            int size = countingOS.size();
            positionDependentRecord.setLastOnDiskOffset(size);
            if (lastOnDiskOffset != -1) {
                hashMap.put(Integer.valueOf(lastOnDiskOffset), Integer.valueOf(size));
            }
            int recordType = (int) record.getRecordType();
            RecordTypes recordTypes = RecordTypes.PersistPtrIncrementalBlock;
            if (recordType == recordTypes.typeID) {
                persistPtrHolder = (PersistPtrHolder) positionDependentRecord;
            } else {
                recordTypes = RecordTypes.UserEditAtom;
                if (recordType == recordTypes.typeID) {
                    userEditAtom = (UserEditAtom) positionDependentRecord;
                } else {
                    recordTypes = null;
                }
            }
            if (!(map == null || recordTypes == null)) {
                map.put(recordTypes, positionDependentRecord);
            }
            record.writeOut(countingOS);
        }
        countingOS.close();
        if (userEditAtom == null || persistPtrHolder == null) {
            throw new HSLFException("UserEditAtom or PersistPtr can't be determined.");
        }
        HashMap hashMap2 = new HashMap();
        for (Map.Entry<Integer, Integer> entry : persistPtrHolder.getSlideLocationsLookup().entrySet()) {
            hashMap2.put(hashMap.get(entry.getValue()), entry.getKey());
        }
        HSLFSlideShowEncrypted hSLFSlideShowEncrypted = new HSLFSlideShowEncrypted(getDocumentEncryptionAtom());
        Record[] recordArr2 = this._records;
        for (Record record2 : recordArr2) {
            PositionDependentRecord positionDependentRecord2 = (PositionDependentRecord) record2;
            Integer num = (Integer) hashMap2.get(Integer.valueOf(positionDependentRecord2.getLastOnDiskOffset()));
            if (num == null) {
                num = 0;
            }
            positionDependentRecord2.updateOtherRecordReferences(hashMap);
            if (outputStream != null) {
                record2.writeOut(hSLFSlideShowEncrypted.encryptRecord(outputStream, num.intValue(), record2));
            }
        }
        hSLFSlideShowEncrypted.close();
        int currentEditOffset = (int) this.currentUser.getCurrentEditOffset();
        Integer num2 = (Integer) hashMap.get(Integer.valueOf(currentEditOffset));
        if (num2 == null || userEditAtom.getLastOnDiskOffset() != num2.intValue()) {
            throw new HSLFException(a.c("Couldn't find the new location of the last UserEditAtom that used to be at ", currentEditOffset));
        }
        this.currentUser.setCurrentEditOffset((long) userEditAtom.getLastOnDiskOffset());
    }

    @Override // org.apache.poi.POIDocument
    public void write() {
        validateInPlaceWritePossible();
        write(getDirectory().getFileSystem(), false);
        getDirectory().getFileSystem().writeFilesystem();
    }

    public HSLFSlideShowImpl(InputStream inputStream) {
        this(new POIFSFileSystem(inputStream));
    }

    public HSLFSlideShowImpl(POIFSFileSystem pOIFSFileSystem) {
        this(pOIFSFileSystem.getRoot());
    }

    public HSLFSlideShowImpl(NPOIFSFileSystem nPOIFSFileSystem) {
        this(nPOIFSFileSystem.getRoot());
    }

    @Override // org.apache.poi.POIDocument
    public void write(File file) {
        write(file, false);
    }

    public HSLFSlideShowImpl(DirectoryNode directoryNode) {
        super(handleDualStorage(directoryNode));
        this.logger = POILogFactory.getLogger(HSLFSlideShowImpl.class);
        readCurrentUserStream();
        readPowerPointStream();
        buildRecords();
        readOtherStreams();
    }

    public void write(File file, boolean z) {
        POIFSFileSystem create = POIFSFileSystem.create(file);
        try {
            write(create, z);
            create.writeFilesystem();
        } finally {
            create.close();
        }
    }

    @Override // org.apache.poi.POIDocument
    public void write(OutputStream outputStream) {
        write(outputStream, false);
    }

    public void write(OutputStream outputStream, boolean z) {
        POIFSFileSystem pOIFSFileSystem = new POIFSFileSystem();
        try {
            write(pOIFSFileSystem, z);
            pOIFSFileSystem.writeFilesystem(outputStream);
        } finally {
            pOIFSFileSystem.close();
        }
    }

    private void write(NPOIFSFileSystem nPOIFSFileSystem, boolean z) {
        if (this._pictures == null) {
            readPictures();
        }
        getDocumentSummaryInformation();
        HSLFSlideShowEncrypted hSLFSlideShowEncrypted = new HSLFSlideShowEncrypted(getDocumentEncryptionAtom());
        this._records = hSLFSlideShowEncrypted.updateEncryptionRecord(this._records);
        boolean z2 = true;
        ArrayList arrayList = new ArrayList(1);
        writeProperties(nPOIFSFileSystem, arrayList);
        BufAccessBAOS bufAccessBAOS = new BufAccessBAOS();
        updateAndWriteDependantRecords(bufAccessBAOS, null);
        this._docstream = new byte[bufAccessBAOS.size()];
        System.arraycopy(bufAccessBAOS.getBuf(), 0, this._docstream, 0, bufAccessBAOS.size());
        bufAccessBAOS.close();
        nPOIFSFileSystem.createOrUpdateDocument(new ByteArrayInputStream(this._docstream), HSLFSlideShow.POWERPOINT_DOCUMENT);
        arrayList.add(HSLFSlideShow.POWERPOINT_DOCUMENT);
        CurrentUserAtom currentUserAtom = this.currentUser;
        if (hSLFSlideShowEncrypted.getDocumentEncryptionAtom() == null) {
            z2 = false;
        }
        currentUserAtom.setEncrypted(z2);
        this.currentUser.writeToFS(nPOIFSFileSystem);
        arrayList.add("Current User");
        if (this._pictures.size() > 0) {
            BufAccessBAOS bufAccessBAOS2 = new BufAccessBAOS();
            for (HSLFPictureData hSLFPictureData : this._pictures) {
                int size = bufAccessBAOS2.size();
                hSLFPictureData.write(bufAccessBAOS2);
                hSLFSlideShowEncrypted.encryptPicture(bufAccessBAOS2.getBuf(), size);
            }
            nPOIFSFileSystem.createOrUpdateDocument(new ByteArrayInputStream(bufAccessBAOS2.getBuf(), 0, bufAccessBAOS2.size()), PPTXMLDump.PICTURES_ENTRY);
            arrayList.add(PPTXMLDump.PICTURES_ENTRY);
            bufAccessBAOS2.close();
        }
        hSLFSlideShowEncrypted.close();
        if (z) {
            EntryUtils.copyNodes(getDirectory().getFileSystem(), nPOIFSFileSystem, arrayList);
        }
    }
}
