package org.apache.poi.hsmf;

import b.b.a.a.a;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.poi.POIReadOnlyDocument;
import org.apache.poi.hmef.attribute.MAPIRtfAttribute;
import org.apache.poi.hsmf.datatypes.AttachmentChunks;
import org.apache.poi.hsmf.datatypes.ByteChunk;
import org.apache.poi.hsmf.datatypes.Chunk;
import org.apache.poi.hsmf.datatypes.ChunkGroup;
import org.apache.poi.hsmf.datatypes.Chunks;
import org.apache.poi.hsmf.datatypes.MAPIProperty;
import org.apache.poi.hsmf.datatypes.NameIdChunks;
import org.apache.poi.hsmf.datatypes.PropertyValue;
import org.apache.poi.hsmf.datatypes.RecipientChunks;
import org.apache.poi.hsmf.datatypes.StringChunk;
import org.apache.poi.hsmf.datatypes.Types;
import org.apache.poi.hsmf.exceptions.ChunkNotFoundException;
import org.apache.poi.hsmf.parsers.POIFSChunkParser;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.util.CodePageUtil;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Removal;

public class MAPIMessage extends POIReadOnlyDocument {
    public AttachmentChunks[] attachmentChunks;
    public POILogger logger;
    public Chunks mainChunks;
    public NameIdChunks nameIdChunks;
    public RecipientChunks[] recipientChunks;
    public boolean returnNullOnMissingChunk;

    public enum MESSAGE_CLASS {
        APPOINTMENT,
        CONTACT,
        NOTE,
        POST,
        STICKY_NOTE,
        TASK,
        UNKNOWN,
        UNSPECIFIED
    }

    public MAPIMessage() {
        super(new NPOIFSFileSystem());
        this.logger = POILogFactory.getLogger(MAPIMessage.class);
        this.returnNullOnMissingChunk = false;
    }

    private String toSemicolonList(String[] strArr) {
        StringBuffer stringBuffer = new StringBuffer();
        boolean z = true;
        for (String str : strArr) {
            if (str != null) {
                if (z) {
                    z = false;
                } else {
                    stringBuffer.append("; ");
                }
                stringBuffer.append(str);
            }
        }
        return stringBuffer.toString();
    }

    public AttachmentChunks[] getAttachmentFiles() {
        return this.attachmentChunks;
    }

    public String getConversationTopic() {
        return getStringFromChunk(this.mainChunks.getConversationTopic());
    }

    public String getDisplayBCC() {
        return getStringFromChunk(this.mainChunks.getDisplayBCCChunk());
    }

    public String getDisplayCC() {
        return getStringFromChunk(this.mainChunks.getDisplayCCChunk());
    }

    public String getDisplayFrom() {
        return getStringFromChunk(this.mainChunks.getDisplayFromChunk());
    }

    public String getDisplayTo() {
        return getStringFromChunk(this.mainChunks.getDisplayToChunk());
    }

    public String[] getHeaders() {
        String stringFromChunk = getStringFromChunk(this.mainChunks.getMessageHeaders());
        if (stringFromChunk == null) {
            return null;
        }
        return stringFromChunk.split("\\r?\\n");
    }

    public String getHtmlBody() {
        if (this.mainChunks.getHtmlBodyChunkBinary() != null) {
            return this.mainChunks.getHtmlBodyChunkBinary().getAs7bitString();
        }
        return getStringFromChunk(this.mainChunks.getHtmlBodyChunkString());
    }

    public Chunks getMainChunks() {
        return this.mainChunks;
    }

    @Removal(version = "3.18")
    @Deprecated
    public String getMessageClass() {
        return getStringFromChunk(this.mainChunks.getMessageClass());
    }

    public MESSAGE_CLASS getMessageClassEnum() {
        String stringFromChunk = getStringFromChunk(this.mainChunks.getMessageClass());
        if (stringFromChunk == null || stringFromChunk.trim().length() == 0) {
            return MESSAGE_CLASS.UNSPECIFIED;
        }
        if (stringFromChunk.equalsIgnoreCase("IPM.Note")) {
            return MESSAGE_CLASS.NOTE;
        }
        if (stringFromChunk.equalsIgnoreCase("IPM.Contact")) {
            return MESSAGE_CLASS.CONTACT;
        }
        if (stringFromChunk.equalsIgnoreCase("IPM.Appointment")) {
            return MESSAGE_CLASS.APPOINTMENT;
        }
        if (stringFromChunk.equalsIgnoreCase("IPM.StickyNote")) {
            return MESSAGE_CLASS.STICKY_NOTE;
        }
        if (stringFromChunk.equalsIgnoreCase("IPM.Task")) {
            return MESSAGE_CLASS.TASK;
        }
        if (stringFromChunk.equalsIgnoreCase("IPM.Post")) {
            return MESSAGE_CLASS.POST;
        }
        POILogger pOILogger = this.logger;
        pOILogger.log(5, "I don't recognize message class '" + stringFromChunk + "'. " + "Please open an issue on POI's bugzilla");
        return MESSAGE_CLASS.UNKNOWN;
    }

    public Calendar getMessageDate() {
        if (this.mainChunks.getSubmissionChunk() != null) {
            return this.mainChunks.getSubmissionChunk().getAcceptedAtTime();
        }
        MAPIProperty[] mAPIPropertyArr = {MAPIProperty.CLIENT_SUBMIT_TIME, MAPIProperty.LAST_MODIFICATION_TIME, MAPIProperty.CREATION_TIME};
        for (int i2 = 0; i2 < 3; i2++) {
            List<PropertyValue> list = this.mainChunks.getProperties().get(mAPIPropertyArr[i2]);
            if (list != null && list.size() > 0) {
                return ((PropertyValue.TimePropertyValue) list.get(0)).getValue();
            }
        }
        if (this.returnNullOnMissingChunk) {
            return null;
        }
        throw new ChunkNotFoundException();
    }

    public NameIdChunks getNameIdChunks() {
        return this.nameIdChunks;
    }

    public RecipientChunks[] getRecipientDetailsChunks() {
        return this.recipientChunks;
    }

    public String getRecipientEmailAddress() {
        return toSemicolonList(getRecipientEmailAddressList());
    }

    public String[] getRecipientEmailAddressList() {
        RecipientChunks[] recipientChunksArr = this.recipientChunks;
        if (recipientChunksArr == null || recipientChunksArr.length == 0) {
            throw new ChunkNotFoundException("No recipients section present");
        }
        int length = recipientChunksArr.length;
        String[] strArr = new String[length];
        for (int i2 = 0; i2 < length; i2++) {
            String recipientEmailAddress = this.recipientChunks[i2].getRecipientEmailAddress();
            if (recipientEmailAddress != null) {
                strArr[i2] = recipientEmailAddress;
            } else if (this.returnNullOnMissingChunk) {
                strArr[i2] = null;
            } else {
                StringBuilder b2 = a.b("No email address holding chunks found for the ");
                b2.append(i2 + 1);
                b2.append("th recipient");
                throw new ChunkNotFoundException(b2.toString());
            }
        }
        return strArr;
    }

    public String getRecipientNames() {
        return toSemicolonList(getRecipientNamesList());
    }

    public String[] getRecipientNamesList() {
        RecipientChunks[] recipientChunksArr = this.recipientChunks;
        if (recipientChunksArr == null || recipientChunksArr.length == 0) {
            throw new ChunkNotFoundException("No recipients section present");
        }
        int length = recipientChunksArr.length;
        String[] strArr = new String[length];
        for (int i2 = 0; i2 < length; i2++) {
            String recipientName = this.recipientChunks[i2].getRecipientName();
            if (recipientName != null) {
                strArr[i2] = recipientName;
            } else {
                StringBuilder b2 = a.b("No display name holding chunks found for the ");
                b2.append(i2 + 1);
                b2.append("th recipient");
                throw new ChunkNotFoundException(b2.toString());
            }
        }
        return strArr;
    }

    public String getRtfBody() {
        ByteChunk rtfBodyChunk = this.mainChunks.getRtfBodyChunk();
        if (rtfBodyChunk != null) {
            try {
                return new MAPIRtfAttribute(MAPIProperty.RTF_COMPRESSED, Types.BINARY.getId(), rtfBodyChunk.getValue()).getDataString();
            } catch (IOException e2) {
                throw new RuntimeException("Shouldn't happen", e2);
            }
        } else if (this.returnNullOnMissingChunk) {
            return null;
        } else {
            throw new ChunkNotFoundException();
        }
    }

    public String getStringFromChunk(StringChunk stringChunk) {
        if (stringChunk != null) {
            return stringChunk.getValue();
        }
        if (this.returnNullOnMissingChunk) {
            return null;
        }
        throw new ChunkNotFoundException();
    }

    public String getSubject() {
        return getStringFromChunk(this.mainChunks.getSubjectChunk());
    }

    public String getTextBody() {
        return getStringFromChunk(this.mainChunks.getTextBodyChunk());
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(8:0|(3:2|(5:6|7|8|37|9)|12)|13|14|(2:18|(3:20|(2:22|(3:41|24|(2:26|44)(1:45))(1:43))(1:42)|27))|28|29|(1:49)(2:33|(2:35|46)(1:50))) */
    /* JADX WARNING: Code restructure failed: missing block: B:47:?, code lost:
        return;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:28:0x0097 */
    public void guess7BitEncoding() {
        MAPIProperty[] mAPIPropertyArr = {MAPIProperty.MESSAGE_CODEPAGE, MAPIProperty.INTERNET_CPID};
        for (int i2 = 0; i2 < 2; i2++) {
            MAPIProperty mAPIProperty = mAPIPropertyArr[i2];
            List<PropertyValue> list = this.mainChunks.getProperties().get(mAPIProperty);
            if (list != null && list.size() > 0) {
                int intValue = ((PropertyValue.LongPropertyValue) list.get(0)).getValue().intValue();
                try {
                    set7BitEncoding(CodePageUtil.codepageToEncoding(intValue, true));
                    return;
                } catch (UnsupportedEncodingException unused) {
                    this.logger.log(5, "Invalid codepage ID ", Integer.valueOf(intValue), " set for the message via ", mAPIProperty, ", ignoring");
                }
            }
        }
        String[] headers = getHeaders();
        if (headers != null && headers.length > 0) {
            Pattern compile = Pattern.compile("Content-Type:.*?charset=[\"']?([^;'\"]+)[\"']?", 2);
            for (String str : headers) {
                if (str.startsWith("Content-Type")) {
                    Matcher matcher = compile.matcher(str);
                    if (matcher.matches()) {
                        String group = matcher.group(1);
                        if (!group.equalsIgnoreCase("utf-8")) {
                            set7BitEncoding(group);
                            return;
                        }
                        return;
                    }
                }
            }
        }
        String htmlBody = getHtmlBody();
        if (htmlBody == null && htmlBody.length() > 0) {
            Matcher matcher2 = Pattern.compile("<META\\s+HTTP-EQUIV=\"Content-Type\"\\s+CONTENT=\"text/html;\\s+charset=(.*?)\"").matcher(htmlBody);
            if (matcher2.find()) {
                set7BitEncoding(matcher2.group(1));
            }
        }
    }

    public boolean has7BitEncodingStrings() {
        Chunk[] chunks = this.mainChunks.getChunks();
        for (Chunk chunk : chunks) {
            if ((chunk instanceof StringChunk) && ((StringChunk) chunk).getType() == Types.ASCII_STRING) {
                return true;
            }
        }
        NameIdChunks nameIdChunks2 = this.nameIdChunks;
        if (nameIdChunks2 != null) {
            Chunk[] chunks2 = nameIdChunks2.getChunks();
            for (Chunk chunk2 : chunks2) {
                if ((chunk2 instanceof StringChunk) && ((StringChunk) chunk2).getType() == Types.ASCII_STRING) {
                    return true;
                }
            }
        }
        for (RecipientChunks recipientChunks2 : this.recipientChunks) {
            Chunk[] all = recipientChunks2.getAll();
            for (Chunk chunk3 : all) {
                if ((chunk3 instanceof StringChunk) && ((StringChunk) chunk3).getType() == Types.ASCII_STRING) {
                    return true;
                }
            }
        }
        return false;
    }

    public boolean isReturnNullOnMissingChunk() {
        return this.returnNullOnMissingChunk;
    }

    public void set7BitEncoding(String str) {
        Chunk[] chunks = this.mainChunks.getChunks();
        for (Chunk chunk : chunks) {
            if (chunk instanceof StringChunk) {
                ((StringChunk) chunk).set7BitEncoding(str);
            }
        }
        NameIdChunks nameIdChunks2 = this.nameIdChunks;
        if (nameIdChunks2 != null) {
            Chunk[] chunks2 = nameIdChunks2.getChunks();
            for (Chunk chunk2 : chunks2) {
                if (chunk2 instanceof StringChunk) {
                    ((StringChunk) chunk2).set7BitEncoding(str);
                }
            }
        }
        for (RecipientChunks recipientChunks2 : this.recipientChunks) {
            Chunk[] all = recipientChunks2.getAll();
            for (Chunk chunk3 : all) {
                if (chunk3 instanceof StringChunk) {
                    ((StringChunk) chunk3).set7BitEncoding(str);
                }
            }
        }
    }

    public void setReturnNullOnMissingChunk(boolean z) {
        this.returnNullOnMissingChunk = z;
    }

    public MAPIMessage(String str) {
        this(new File(str));
    }

    public MAPIMessage(File file) {
        this(new NPOIFSFileSystem(file));
    }

    public MAPIMessage(InputStream inputStream) {
        this(new NPOIFSFileSystem(inputStream));
    }

    public MAPIMessage(NPOIFSFileSystem nPOIFSFileSystem) {
        this(nPOIFSFileSystem.getRoot());
    }

    public MAPIMessage(DirectoryNode directoryNode) {
        super(directoryNode);
        this.logger = POILogFactory.getLogger(MAPIMessage.class);
        this.returnNullOnMissingChunk = false;
        ChunkGroup[] parse = POIFSChunkParser.parse(directoryNode);
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        for (ChunkGroup chunkGroup : parse) {
            if (chunkGroup instanceof Chunks) {
                this.mainChunks = (Chunks) chunkGroup;
            } else if (chunkGroup instanceof NameIdChunks) {
                this.nameIdChunks = (NameIdChunks) chunkGroup;
            } else if (chunkGroup instanceof RecipientChunks) {
                arrayList2.add((RecipientChunks) chunkGroup);
            }
            if (chunkGroup instanceof AttachmentChunks) {
                arrayList.add((AttachmentChunks) chunkGroup);
            }
        }
        this.attachmentChunks = (AttachmentChunks[]) arrayList.toArray(new AttachmentChunks[arrayList.size()]);
        this.recipientChunks = (RecipientChunks[]) arrayList2.toArray(new RecipientChunks[arrayList2.size()]);
        Arrays.sort(this.attachmentChunks, new AttachmentChunks.AttachmentChunksSorter());
        Arrays.sort(this.recipientChunks, new RecipientChunks.RecipientChunksSorter());
    }
}
