package org.apache.poi.hsmf.datatypes;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class Chunks implements ChunkGroupWithProperties {
    public static final POILogger LOG = POILogFactory.getLogger(Chunks.class);
    public Map<MAPIProperty, List<Chunk>> allChunks = new HashMap();
    public StringChunk conversationTopic;
    public StringChunk displayBCCChunk;
    public StringChunk displayCCChunk;
    public StringChunk displayFromChunk;
    public StringChunk displayToChunk;
    public StringChunk emailFromChunk;
    public ByteChunk htmlBodyChunkBinary;
    public StringChunk htmlBodyChunkString;
    public StringChunk messageClass;
    public StringChunk messageHeaders;
    public StringChunk messageId;
    public MessagePropertiesChunk messageProperties;
    public ByteChunk rtfBodyChunk;
    public StringChunk sentByServerType;
    public StringChunk subjectChunk;
    public MessageSubmissionChunk submissionChunk;
    public StringChunk textBodyChunk;

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroup
    public void chunksComplete() {
        MessagePropertiesChunk messagePropertiesChunk = this.messageProperties;
        if (messagePropertiesChunk != null) {
            messagePropertiesChunk.matchVariableSizedPropertiesToChunks();
            return;
        }
        LOG.log(5, "Message didn't contain a root list of properties!");
    }

    public Map<MAPIProperty, List<Chunk>> getAll() {
        return this.allChunks;
    }

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroup
    public Chunk[] getChunks() {
        ArrayList arrayList = new ArrayList(this.allChunks.size());
        for (List<Chunk> list : this.allChunks.values()) {
            arrayList.addAll(list);
        }
        return (Chunk[]) arrayList.toArray(new Chunk[arrayList.size()]);
    }

    public StringChunk getConversationTopic() {
        return this.conversationTopic;
    }

    public StringChunk getDisplayBCCChunk() {
        return this.displayBCCChunk;
    }

    public StringChunk getDisplayCCChunk() {
        return this.displayCCChunk;
    }

    public StringChunk getDisplayFromChunk() {
        return this.displayFromChunk;
    }

    public StringChunk getDisplayToChunk() {
        return this.displayToChunk;
    }

    public StringChunk getEmailFromChunk() {
        return this.emailFromChunk;
    }

    public ByteChunk getHtmlBodyChunkBinary() {
        return this.htmlBodyChunkBinary;
    }

    public StringChunk getHtmlBodyChunkString() {
        return this.htmlBodyChunkString;
    }

    public StringChunk getMessageClass() {
        return this.messageClass;
    }

    public StringChunk getMessageHeaders() {
        return this.messageHeaders;
    }

    public StringChunk getMessageId() {
        return this.messageId;
    }

    public MessagePropertiesChunk getMessageProperties() {
        return this.messageProperties;
    }

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroupWithProperties
    public Map<MAPIProperty, List<PropertyValue>> getProperties() {
        MessagePropertiesChunk messagePropertiesChunk = this.messageProperties;
        if (messagePropertiesChunk != null) {
            return messagePropertiesChunk.getProperties();
        }
        return Collections.emptyMap();
    }

    public Map<MAPIProperty, PropertyValue> getRawProperties() {
        MessagePropertiesChunk messagePropertiesChunk = this.messageProperties;
        if (messagePropertiesChunk != null) {
            return messagePropertiesChunk.getRawProperties();
        }
        return Collections.emptyMap();
    }

    public ByteChunk getRtfBodyChunk() {
        return this.rtfBodyChunk;
    }

    public StringChunk getSentByServerType() {
        return this.sentByServerType;
    }

    public StringChunk getSubjectChunk() {
        return this.subjectChunk;
    }

    public MessageSubmissionChunk getSubmissionChunk() {
        return this.submissionChunk;
    }

    public StringChunk getTextBodyChunk() {
        return this.textBodyChunk;
    }

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroup
    public void record(Chunk chunk) {
        MAPIProperty mAPIProperty = MAPIProperty.get(chunk.getChunkId());
        if (mAPIProperty == MAPIProperty.MESSAGE_CLASS) {
            this.messageClass = (StringChunk) chunk;
        } else if (mAPIProperty == MAPIProperty.INTERNET_MESSAGE_ID) {
            this.messageId = (StringChunk) chunk;
        } else if (mAPIProperty == MAPIProperty.MESSAGE_SUBMISSION_ID) {
            this.submissionChunk = (MessageSubmissionChunk) chunk;
        } else if (mAPIProperty == MAPIProperty.RECEIVED_BY_ADDRTYPE) {
            this.sentByServerType = (StringChunk) chunk;
        } else if (mAPIProperty == MAPIProperty.TRANSPORT_MESSAGE_HEADERS) {
            this.messageHeaders = (StringChunk) chunk;
        } else if (mAPIProperty == MAPIProperty.CONVERSATION_TOPIC) {
            this.conversationTopic = (StringChunk) chunk;
        } else if (mAPIProperty == MAPIProperty.SUBJECT) {
            this.subjectChunk = (StringChunk) chunk;
        } else if (mAPIProperty != MAPIProperty.ORIGINAL_SUBJECT) {
            if (mAPIProperty == MAPIProperty.DISPLAY_TO) {
                this.displayToChunk = (StringChunk) chunk;
            } else if (mAPIProperty == MAPIProperty.DISPLAY_CC) {
                this.displayCCChunk = (StringChunk) chunk;
            } else if (mAPIProperty == MAPIProperty.DISPLAY_BCC) {
                this.displayBCCChunk = (StringChunk) chunk;
            } else if (mAPIProperty == MAPIProperty.SENDER_EMAIL_ADDRESS) {
                this.emailFromChunk = (StringChunk) chunk;
            } else if (mAPIProperty == MAPIProperty.SENDER_NAME) {
                this.displayFromChunk = (StringChunk) chunk;
            } else if (mAPIProperty == MAPIProperty.BODY) {
                this.textBodyChunk = (StringChunk) chunk;
            } else if (mAPIProperty == MAPIProperty.BODY_HTML) {
                if (chunk instanceof StringChunk) {
                    this.htmlBodyChunkString = (StringChunk) chunk;
                }
                if (chunk instanceof ByteChunk) {
                    this.htmlBodyChunkBinary = (ByteChunk) chunk;
                }
            } else if (mAPIProperty == MAPIProperty.RTF_COMPRESSED) {
                this.rtfBodyChunk = (ByteChunk) chunk;
            } else if (chunk instanceof MessagePropertiesChunk) {
                this.messageProperties = (MessagePropertiesChunk) chunk;
            }
        }
        if (this.allChunks.get(mAPIProperty) == null) {
            this.allChunks.put(mAPIProperty, new ArrayList());
        }
        this.allChunks.get(mAPIProperty).add(chunk);
    }
}
