package org.apache.poi.hsmf.datatypes;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.poi.hsmf.datatypes.PropertyValue;
import org.apache.poi.hsmf.datatypes.Types;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public abstract class PropertiesChunk extends Chunk {
    public static final String NAME = "__properties_version1.0";
    public POILogger logger = POILogFactory.getLogger(PropertiesChunk.class);
    public ChunkGroup parentGroup;
    public Map<MAPIProperty, PropertyValue> properties = new HashMap();

    public PropertiesChunk(ChunkGroup chunkGroup) {
        super(NAME, -1, Types.UNKNOWN);
        this.parentGroup = chunkGroup;
    }

    @Override // org.apache.poi.hsmf.datatypes.Chunk
    public String getEntryName() {
        return NAME;
    }

    public Map<MAPIProperty, List<PropertyValue>> getProperties() {
        HashMap hashMap = new HashMap(this.properties.size());
        for (MAPIProperty mAPIProperty : this.properties.keySet()) {
            hashMap.put(mAPIProperty, getValues(mAPIProperty));
        }
        return hashMap;
    }

    public Map<MAPIProperty, PropertyValue> getRawProperties() {
        return this.properties;
    }

    public PropertyValue getRawValue(MAPIProperty mAPIProperty) {
        return this.properties.get(mAPIProperty);
    }

    public List<PropertyValue> getValues(MAPIProperty mAPIProperty) {
        PropertyValue propertyValue = this.properties.get(mAPIProperty);
        if (propertyValue == null) {
            return null;
        }
        if (propertyValue instanceof ChunkBasedPropertyValue) {
            return Collections.emptyList();
        }
        return Collections.singletonList(propertyValue);
    }

    public void matchVariableSizedPropertiesToChunks() {
        HashMap hashMap = new HashMap();
        Chunk[] chunks = this.parentGroup.getChunks();
        for (Chunk chunk : chunks) {
            hashMap.put(Integer.valueOf(chunk.getChunkId()), chunk);
        }
        for (PropertyValue propertyValue : this.properties.values()) {
            if (propertyValue instanceof ChunkBasedPropertyValue) {
                ChunkBasedPropertyValue chunkBasedPropertyValue = (ChunkBasedPropertyValue) propertyValue;
                Chunk chunk2 = (Chunk) hashMap.get(Integer.valueOf(chunkBasedPropertyValue.getProperty().id));
                if (chunk2 != null) {
                    chunkBasedPropertyValue.setValue(chunk2);
                } else {
                    this.logger.log(5, "No chunk found matching Property " + chunkBasedPropertyValue);
                }
            }
        }
    }

    public void readProperties(InputStream inputStream) {
        boolean z;
        PropertyValue propertyValue;
        boolean z2 = true;
        while (z2) {
            try {
                int readUShort = LittleEndian.readUShort(inputStream);
                int readUShort2 = LittleEndian.readUShort(inputStream);
                long readUInt = LittleEndian.readUInt(inputStream);
                Types.MAPIType byId = Types.getById(readUShort);
                MAPIProperty mAPIProperty = MAPIProperty.get(readUShort2);
                if (mAPIProperty == MAPIProperty.UNKNOWN) {
                    mAPIProperty = MAPIProperty.createCustom(readUShort2, byId, "Unknown " + readUShort2);
                }
                if (byId == null) {
                    this.logger.log(5, "Invalid type found, expected ", mAPIProperty.usualType, " but got ", Integer.valueOf(readUShort), " for property ", mAPIProperty);
                    return;
                }
                if (!(mAPIProperty.usualType == byId || ((byId == Types.ASCII_STRING && mAPIProperty.usualType == Types.UNICODE_STRING) || (byId == Types.UNICODE_STRING && mAPIProperty.usualType == Types.ASCII_STRING)))) {
                    if (mAPIProperty.usualType == Types.UNKNOWN) {
                        this.logger.log(3, "Property definition for ", mAPIProperty, " is missing a type definition, found a value with type ", byId);
                    } else {
                        this.logger.log(5, "Type mismatch, expected ", mAPIProperty.usualType, " but got ", byId, " for property ", mAPIProperty);
                        return;
                    }
                }
                int length = byId.getLength();
                if (!byId.isFixedLength()) {
                    length = 8;
                    z = true;
                } else {
                    z = false;
                }
                byte[] bArr = new byte[length];
                IOUtils.readFully(inputStream, bArr);
                if (length < 8) {
                    IOUtils.readFully(inputStream, new byte[(8 - length)]);
                }
                if (z) {
                    propertyValue = new ChunkBasedPropertyValue(mAPIProperty, readUInt, bArr);
                } else if (byId == Types.NULL) {
                    propertyValue = new PropertyValue.NullPropertyValue(mAPIProperty, readUInt, bArr);
                } else if (byId == Types.BOOLEAN) {
                    propertyValue = new PropertyValue.BooleanPropertyValue(mAPIProperty, readUInt, bArr);
                } else if (byId == Types.SHORT) {
                    propertyValue = new PropertyValue.ShortPropertyValue(mAPIProperty, readUInt, bArr);
                } else if (byId == Types.LONG) {
                    propertyValue = new PropertyValue.LongPropertyValue(mAPIProperty, readUInt, bArr);
                } else if (byId == Types.LONG_LONG) {
                    propertyValue = new PropertyValue.LongLongPropertyValue(mAPIProperty, readUInt, bArr);
                } else if (byId == Types.FLOAT) {
                    propertyValue = new PropertyValue.FloatPropertyValue(mAPIProperty, readUInt, bArr);
                } else if (byId == Types.DOUBLE) {
                    propertyValue = new PropertyValue.DoublePropertyValue(mAPIProperty, readUInt, bArr);
                } else if (byId == Types.CURRENCY) {
                    propertyValue = new PropertyValue.CurrencyPropertyValue(mAPIProperty, readUInt, bArr);
                } else if (byId == Types.TIME) {
                    propertyValue = new PropertyValue.TimePropertyValue(mAPIProperty, readUInt, bArr);
                } else {
                    propertyValue = new PropertyValue(mAPIProperty, readUInt, bArr);
                }
                if (this.properties.get(mAPIProperty) != null) {
                    POILogger pOILogger = this.logger;
                    pOILogger.log(5, "Duplicate values found for " + mAPIProperty);
                }
                this.properties.put(mAPIProperty, propertyValue);
            } catch (LittleEndian.BufferUnderrunException unused) {
                z2 = false;
            }
        }
    }

    public void writeProperties(OutputStream outputStream) {
    }
}
