package org.apache.poi.hsmf.datatypes;

import b.b.a.a.a;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.Map;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class RecipientChunks implements ChunkGroupWithProperties {
    public static final MAPIProperty DELIVERY_TYPE = MAPIProperty.ADDRTYPE;
    public static final POILogger LOG = POILogFactory.getLogger(RecipientChunks.class);
    public static final String PREFIX = "__recip_version1.0_#";
    public static final MAPIProperty RECIPIENT_DISPLAY_NAME = MAPIProperty.RECIPIENT_DISPLAY_NAME;
    public static final MAPIProperty RECIPIENT_EMAIL_ADDRESS = MAPIProperty.EMAIL_ADDRESS;
    public static final MAPIProperty RECIPIENT_NAME = MAPIProperty.DISPLAY_NAME;
    public static final MAPIProperty RECIPIENT_SEARCH = MAPIProperty.SEARCH_KEY;
    public static final MAPIProperty RECIPIENT_SMTP_ADDRESS = MAPIProperty.SMTP_ADDRESS;
    public List<Chunk> allChunks = new ArrayList();
    public StringChunk deliveryTypeChunk;
    public StringChunk recipientDisplayNameChunk;
    public StringChunk recipientEmailChunk;
    public StringChunk recipientNameChunk;
    public int recipientNumber = -1;
    public PropertiesChunk recipientProperties;
    public StringChunk recipientSMTPChunk;
    public ByteChunk recipientSearchChunk;

    public static class RecipientChunksSorter implements Comparator<RecipientChunks>, Serializable {
        public int compare(RecipientChunks recipientChunks, RecipientChunks recipientChunks2) {
            int i2 = recipientChunks.recipientNumber;
            int i3 = recipientChunks2.recipientNumber;
            if (i2 < i3) {
                return -1;
            }
            return i2 > i3 ? 1 : 0;
        }
    }

    public RecipientChunks(String str) {
        int lastIndexOf = str.lastIndexOf(35);
        if (lastIndexOf > -1) {
            try {
                this.recipientNumber = Integer.parseInt(str.substring(lastIndexOf + 1), 16);
            } catch (NumberFormatException unused) {
                LOG.log(7, a.b("Invalid recipient number in name ", str));
            }
        }
    }

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroup
    public void chunksComplete() {
        PropertiesChunk propertiesChunk = this.recipientProperties;
        if (propertiesChunk != null) {
            propertiesChunk.matchVariableSizedPropertiesToChunks();
            return;
        }
        LOG.log(5, "Recipeints Chunk didn't contain a list of properties!");
    }

    public Chunk[] getAll() {
        List<Chunk> list = this.allChunks;
        return (Chunk[]) list.toArray(new Chunk[list.size()]);
    }

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroup
    public Chunk[] getChunks() {
        return getAll();
    }

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroupWithProperties
    public Map<MAPIProperty, List<PropertyValue>> getProperties() {
        PropertiesChunk propertiesChunk = this.recipientProperties;
        if (propertiesChunk != null) {
            return propertiesChunk.getProperties();
        }
        return Collections.emptyMap();
    }

    public String getRecipientEmailAddress() {
        String as7bitString;
        int indexOf;
        StringChunk stringChunk = this.recipientSMTPChunk;
        if (stringChunk != null) {
            return stringChunk.getValue();
        }
        StringChunk stringChunk2 = this.recipientEmailChunk;
        if (stringChunk2 != null) {
            String value = stringChunk2.getValue();
            int indexOf2 = value.indexOf("/CN=");
            if (indexOf2 < 0) {
                return value;
            }
            return value.substring(indexOf2 + 4);
        }
        StringChunk stringChunk3 = this.recipientNameChunk;
        if (stringChunk3 != null) {
            String value2 = stringChunk3.getValue();
            if (value2.contains("@")) {
                return (!value2.startsWith("'") || !value2.endsWith("'")) ? value2 : value2.substring(1, value2.length() - 1);
            }
        }
        ByteChunk byteChunk = this.recipientSearchChunk;
        if (byteChunk == null || (indexOf = (as7bitString = byteChunk.getAs7bitString()).indexOf("SMTP:")) < 0) {
            return null;
        }
        return as7bitString.substring(indexOf + 5);
    }

    public String getRecipientName() {
        StringChunk stringChunk = this.recipientNameChunk;
        if (stringChunk != null) {
            return stringChunk.getValue();
        }
        StringChunk stringChunk2 = this.recipientDisplayNameChunk;
        if (stringChunk2 != null) {
            return stringChunk2.getValue();
        }
        return null;
    }

    @Override // org.apache.poi.hsmf.datatypes.ChunkGroup
    public void record(Chunk chunk) {
        if (chunk.getChunkId() == RECIPIENT_SEARCH.id) {
            this.recipientSearchChunk = (ByteChunk) chunk;
        } else if (chunk.getChunkId() == RECIPIENT_NAME.id) {
            this.recipientDisplayNameChunk = (StringChunk) chunk;
        } else if (chunk.getChunkId() == RECIPIENT_DISPLAY_NAME.id) {
            this.recipientNameChunk = (StringChunk) chunk;
        } else if (chunk.getChunkId() == RECIPIENT_EMAIL_ADDRESS.id) {
            this.recipientEmailChunk = (StringChunk) chunk;
        } else if (chunk.getChunkId() == RECIPIENT_SMTP_ADDRESS.id) {
            this.recipientSMTPChunk = (StringChunk) chunk;
        } else if (chunk.getChunkId() == DELIVERY_TYPE.id) {
            this.deliveryTypeChunk = (StringChunk) chunk;
        } else if (chunk instanceof PropertiesChunk) {
            this.recipientProperties = (PropertiesChunk) chunk;
        }
        this.allChunks.add(chunk);
    }
}
