package org.apache.poi.hssf.extractor;

import b.b.a.a.a;
import java.io.BufferedInputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.hssf.OldExcelFormatException;
import org.apache.poi.hssf.model.InternalWorkbook;
import org.apache.poi.hssf.record.BOFRecord;
import org.apache.poi.hssf.record.CodepageRecord;
import org.apache.poi.hssf.record.FormulaRecord;
import org.apache.poi.hssf.record.NumberRecord;
import org.apache.poi.hssf.record.OldFormulaRecord;
import org.apache.poi.hssf.record.OldLabelRecord;
import org.apache.poi.hssf.record.OldSheetRecord;
import org.apache.poi.hssf.record.OldStringRecord;
import org.apache.poi.hssf.record.RKRecord;
import org.apache.poi.hssf.record.RecordInputStream;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentNode;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.NotOLE2FileException;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.util.IOUtils;

public class OldExcelExtractor implements Closeable {
    public static final int FILE_PASS_RECORD_SID = 47;
    public int biffVersion;
    public int fileType;
    public RecordInputStream ris;
    public Closeable toClose;

    public OldExcelExtractor(InputStream inputStream) {
        open(inputStream);
    }

    public static void main(String[] strArr) {
        if (strArr.length < 1) {
            System.err.println("Use:");
            System.err.println("   OldExcelExtractor <filename>");
            System.exit(1);
        }
        OldExcelExtractor oldExcelExtractor = new OldExcelExtractor(new File(strArr[0]));
        System.out.println(oldExcelExtractor.getText());
        oldExcelExtractor.close();
    }

    private void open(InputStream inputStream) {
        BufferedInputStream bufferedInputStream = inputStream instanceof BufferedInputStream ? (BufferedInputStream) inputStream : new BufferedInputStream(inputStream, 8);
        if (NPOIFSFileSystem.hasPOIFSHeader(bufferedInputStream)) {
            NPOIFSFileSystem nPOIFSFileSystem = new NPOIFSFileSystem(bufferedInputStream);
            try {
                open(nPOIFSFileSystem);
            } finally {
                nPOIFSFileSystem.close();
            }
        } else {
            this.ris = new RecordInputStream(bufferedInputStream);
            this.toClose = bufferedInputStream;
            prepare();
        }
    }

    private void prepare() {
        if (this.ris.hasNextRecord()) {
            this.ris.nextRecord();
            short sid = this.ris.getSid();
            if (sid == 9) {
                this.biffVersion = 2;
            } else if (sid == 521) {
                this.biffVersion = 3;
            } else if (sid == 1033) {
                this.biffVersion = 4;
            } else if (sid == 2057) {
                this.biffVersion = 5;
            } else {
                throw new IllegalArgumentException(a.c("File does not begin with a BOF, found sid of ", sid));
            }
            this.fileType = new BOFRecord(this.ris).getType();
            return;
        }
        throw new IllegalArgumentException("File contains no records!");
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        Closeable closeable = this.toClose;
        if (closeable != null) {
            IOUtils.closeQuietly(closeable);
            this.toClose = null;
        }
    }

    public int getBiffVersion() {
        return this.biffVersion;
    }

    public int getFileType() {
        return this.fileType;
    }

    public String getText() {
        StringBuffer stringBuffer = new StringBuffer();
        CodepageRecord codepageRecord = null;
        while (this.ris.hasNextRecord()) {
            int nextSid = this.ris.getNextSid();
            this.ris.nextRecord();
            if (nextSid != 4) {
                if (nextSid == 47) {
                    throw new EncryptedDocumentException("Encryption not supported for Old Excel files");
                } else if (nextSid == 66) {
                    codepageRecord = new CodepageRecord(this.ris);
                } else if (nextSid == 133) {
                    OldSheetRecord oldSheetRecord = new OldSheetRecord(this.ris);
                    oldSheetRecord.setCodePage(codepageRecord);
                    stringBuffer.append("Sheet: ");
                    stringBuffer.append(oldSheetRecord.getSheetname());
                    stringBuffer.append('\n');
                } else if (nextSid != 638) {
                    if (!(nextSid == 1030 || nextSid == 6)) {
                        if (nextSid != 7) {
                            if (nextSid == 515) {
                                handleNumericCell(stringBuffer, new NumberRecord(this.ris).getValue());
                            } else if (nextSid != 516) {
                                if (nextSid != 518) {
                                    if (nextSid != 519) {
                                        RecordInputStream recordInputStream = this.ris;
                                        recordInputStream.readFully(new byte[recordInputStream.remaining()]);
                                    }
                                }
                            }
                        }
                        OldStringRecord oldStringRecord = new OldStringRecord(this.ris);
                        oldStringRecord.setCodePage(codepageRecord);
                        stringBuffer.append(oldStringRecord.getString());
                        stringBuffer.append('\n');
                    }
                    if (this.biffVersion == 5) {
                        FormulaRecord formulaRecord = new FormulaRecord(this.ris);
                        if (formulaRecord.getCachedResultType() == CellType.NUMERIC.getCode()) {
                            handleNumericCell(stringBuffer, formulaRecord.getValue());
                        }
                    } else {
                        OldFormulaRecord oldFormulaRecord = new OldFormulaRecord(this.ris);
                        if (oldFormulaRecord.getCachedResultType() == CellType.NUMERIC.getCode()) {
                            handleNumericCell(stringBuffer, oldFormulaRecord.getValue());
                        }
                    }
                } else {
                    handleNumericCell(stringBuffer, new RKRecord(this.ris).getRKNumber());
                }
            }
            OldLabelRecord oldLabelRecord = new OldLabelRecord(this.ris);
            oldLabelRecord.setCodePage(codepageRecord);
            stringBuffer.append(oldLabelRecord.getValue());
            stringBuffer.append('\n');
        }
        close();
        this.ris = null;
        return stringBuffer.toString();
    }

    public void handleNumericCell(StringBuffer stringBuffer, double d2) {
        stringBuffer.append(d2);
        stringBuffer.append('\n');
    }

    /* JADX WARNING: Code restructure failed: missing block: B:28:0x0032, code lost:
        if (r2.toClose == null) goto L_0x003a;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:31:0x0038, code lost:
        if (r2.toClose == null) goto L_0x003a;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:32:0x003a, code lost:
        org.apache.poi.util.IOUtils.closeQuietly(r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:33:0x003d, code lost:
        r0 = new java.io.FileInputStream(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:35:?, code lost:
        open(r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:36:0x0045, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:37:0x0046, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:38:0x0047, code lost:
        r0.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:39:0x004a, code lost:
        throw r3;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:40:0x004b, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:41:0x004c, code lost:
        r0.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:0x004f, code lost:
        throw r3;
     */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x002b  */
    public OldExcelExtractor(File file) {
        Throwable th;
        RuntimeException e2;
        NPOIFSFileSystem nPOIFSFileSystem;
        NPOIFSFileSystem nPOIFSFileSystem2 = null;
        try {
            nPOIFSFileSystem = new NPOIFSFileSystem(file);
            open(nPOIFSFileSystem);
            this.toClose = nPOIFSFileSystem;
            if (nPOIFSFileSystem == null) {
                IOUtils.closeQuietly(nPOIFSFileSystem);
            }
        } catch (OldExcelFormatException unused) {
        } catch (NotOLE2FileException unused2) {
        } catch (IOException e3) {
            throw e3;
        } catch (RuntimeException e4) {
            e2 = e4;
            throw e2;
        } catch (OldExcelFormatException unused3) {
            nPOIFSFileSystem2 = nPOIFSFileSystem;
        } catch (NotOLE2FileException unused4) {
            nPOIFSFileSystem2 = nPOIFSFileSystem;
        } catch (IOException e5) {
            throw e5;
        } catch (RuntimeException e6) {
            e2 = e6;
            nPOIFSFileSystem2 = nPOIFSFileSystem;
            throw e2;
        } catch (Throwable th2) {
            th = th2;
            if (this.toClose == null) {
            }
            throw th;
        }
    }

    private void open(NPOIFSFileSystem nPOIFSFileSystem) {
        open(nPOIFSFileSystem.getRoot());
    }

    private void open(DirectoryNode directoryNode) {
        DocumentNode documentNode;
        try {
            documentNode = (DocumentNode) directoryNode.getEntry(InternalWorkbook.OLD_WORKBOOK_DIR_ENTRY_NAME);
        } catch (FileNotFoundException unused) {
            documentNode = (DocumentNode) directoryNode.getEntry(InternalWorkbook.WORKBOOK_DIR_ENTRY_NAMES[0]);
        }
        if (documentNode != null) {
            this.ris = new RecordInputStream(directoryNode.createDocumentInputStream(documentNode));
            prepare();
            return;
        }
        throw new IOException("No Excel 5/95 Book stream found");
    }

    public OldExcelExtractor(NPOIFSFileSystem nPOIFSFileSystem) {
        open(nPOIFSFileSystem);
    }

    public OldExcelExtractor(DirectoryNode directoryNode) {
        open(directoryNode);
    }
}
