package org.apache.poi.hssf.record;

import org.apache.poi.hssf.model.HSSFFormulaParser;
import org.apache.poi.hssf.record.cf.BorderFormatting;
import org.apache.poi.hssf.record.cf.FontFormatting;
import org.apache.poi.hssf.record.cf.PatternFormatting;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.ss.formula.Formula;
import org.apache.poi.ss.formula.FormulaType;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.xmlbeans.impl.common.ConcurrentReaderHashMap;

public abstract class CFRuleBase extends StandardRecord implements Cloneable {
    public static final byte CONDITION_TYPE_CELL_VALUE_IS = 1;
    public static final byte CONDITION_TYPE_COLOR_SCALE = 3;
    public static final byte CONDITION_TYPE_DATA_BAR = 4;
    public static final byte CONDITION_TYPE_FILTER = 5;
    public static final byte CONDITION_TYPE_FORMULA = 2;
    public static final byte CONDITION_TYPE_ICON_SET = 6;
    public static final int TEMPLATE_ABOVE_AVERAGE = 25;
    public static final int TEMPLATE_ABOVE_OR_EQUAL_TO_AVERAGE = 29;
    public static final int TEMPLATE_BELOW_AVERAGE = 26;
    public static final int TEMPLATE_BELOW_OR_EQUAL_TO_AVERAGE = 30;
    public static final int TEMPLATE_CELL_VALUE = 0;
    public static final int TEMPLATE_COLOR_SCALE_FORMATTING = 2;
    public static final int TEMPLATE_CONTAINS_BLANKS = 9;
    public static final int TEMPLATE_CONTAINS_ERRORS = 11;
    public static final int TEMPLATE_CONTAINS_NO_BLANKS = 10;
    public static final int TEMPLATE_CONTAINS_NO_ERRORS = 12;
    public static final int TEMPLATE_CONTAINS_TEXT = 8;
    public static final int TEMPLATE_DATA_BAR_FORMATTING = 3;
    public static final int TEMPLATE_DUPLICATE_VALUES = 27;
    public static final int TEMPLATE_FILTER = 5;
    public static final int TEMPLATE_FORMULA = 1;
    public static final int TEMPLATE_ICON_SET_FORMATTING = 4;
    public static final int TEMPLATE_LAST_7_DAYS = 18;
    public static final int TEMPLATE_LAST_MONTH = 19;
    public static final int TEMPLATE_LAST_WEEK = 23;
    public static final int TEMPLATE_NEXT_MONTH = 20;
    public static final int TEMPLATE_NEXT_WEEK = 22;
    public static final int TEMPLATE_THIS_MONTH = 24;
    public static final int TEMPLATE_THIS_WEEK = 21;
    public static final int TEMPLATE_TODAY = 15;
    public static final int TEMPLATE_TOMORROW = 16;
    public static final int TEMPLATE_UNIQUE_VALUES = 7;
    public static final int TEMPLATE_YESTERDAY = 17;
    public static final BitField align = bf(134217728);
    public static final BitField alignHor = bf(1);
    public static final BitField alignIndent = bf(32);
    public static final BitField alignJustLast = bf(16);
    public static final BitField alignRot = bf(8);
    public static final BitField alignShrin = bf(64);
    public static final BitField alignTextDir = bf(Integer.MIN_VALUE);
    public static final BitField alignVer = bf(2);
    public static final BitField alignWrap = bf(4);
    public static final BitField bord = bf(268435456);
    public static final BitField bordBlTr = bf(32768);
    public static final BitField bordBot = bf(8192);
    public static final BitField bordLeft = bf(1024);
    public static final BitField bordRight = bf(2048);
    public static final BitField bordTlBr = bf(16384);
    public static final BitField bordTop = bf(4096);
    public static final BitField fmtBlockBits = bf(2080374784);
    public static final BitField font = bf(67108864);
    public static final POILogger logger = POILogFactory.getLogger(CFRuleBase.class);
    public static final BitField mergeCell = bf(128);
    public static final BitField modificationBits = bf(4194303);
    public static final BitField notUsed2 = bf(3670016);
    public static final BitField patt = bf(536870912);
    public static final BitField pattBgCol = bf(262144);
    public static final BitField pattCol = bf(131072);
    public static final BitField pattStyle = bf(65536);
    public static final BitField prot = bf(ConcurrentReaderHashMap.MAXIMUM_CAPACITY);
    public static final BitField protHidden = bf(512);
    public static final BitField protLocked = bf(256);
    public static final BitField undocumented = bf(62914560);
    public BorderFormatting _borderFormatting;
    public FontFormatting _fontFormatting;
    public PatternFormatting _patternFormatting;
    public byte comparison_operator;
    public byte condition_type;
    public short formatting_not_used;
    public int formatting_options;
    public Formula formula1;
    public Formula formula2;

    public static final class ComparisonOperator {
        public static final byte BETWEEN = 1;
        public static final byte EQUAL = 3;
        public static final byte GE = 7;
        public static final byte GT = 5;
        public static final byte LE = 8;
        public static final byte LT = 6;
        public static final byte NOT_BETWEEN = 2;
        public static final byte NOT_EQUAL = 4;
        public static final byte NO_COMPARISON = 0;
        public static final byte max_operator = 8;
    }

    public CFRuleBase(byte b2, byte b3) {
        setConditionType(b2);
        setComparisonOperation(b3);
        this.formula1 = Formula.create(Ptg.EMPTY_PTG_ARRAY);
        this.formula2 = Formula.create(Ptg.EMPTY_PTG_ARRAY);
    }

    public static BitField bf(int i2) {
        return BitFieldFactory.getInstance(i2);
    }

    public static int getFormulaSize(Formula formula) {
        return formula.getEncodedTokenSize();
    }

    private boolean getOptionFlag(BitField bitField) {
        return bitField.isSet(this.formatting_options);
    }

    private boolean isModified(BitField bitField) {
        return !bitField.isSet(this.formatting_options);
    }

    public static Ptg[] parseFormula(String str, HSSFSheet hSSFSheet) {
        if (str == null) {
            return null;
        }
        return HSSFFormulaParser.parse(str, hSSFSheet.getWorkbook(), FormulaType.CELL, hSSFSheet.getWorkbook().getSheetIndex(hSSFSheet));
    }

    private void setModified(boolean z, BitField bitField) {
        this.formatting_options = bitField.setBoolean(this.formatting_options, !z);
    }

    private void setOptionFlag(boolean z, BitField bitField) {
        this.formatting_options = bitField.setBoolean(this.formatting_options, z);
    }

    @Override // org.apache.poi.hssf.record.Record, java.lang.Object
    public abstract CFRuleBase clone();

    public boolean containsAlignFormattingBlock() {
        return getOptionFlag(align);
    }

    public boolean containsBorderFormattingBlock() {
        return getOptionFlag(bord);
    }

    public boolean containsFontFormattingBlock() {
        return getOptionFlag(font);
    }

    public boolean containsPatternFormattingBlock() {
        return getOptionFlag(patt);
    }

    public boolean containsProtectionFormattingBlock() {
        return getOptionFlag(prot);
    }

    public void copyTo(CFRuleBase cFRuleBase) {
        cFRuleBase.condition_type = this.condition_type;
        cFRuleBase.comparison_operator = this.comparison_operator;
        cFRuleBase.formatting_options = this.formatting_options;
        cFRuleBase.formatting_not_used = this.formatting_not_used;
        if (containsFontFormattingBlock()) {
            cFRuleBase._fontFormatting = this._fontFormatting.clone();
        }
        if (containsBorderFormattingBlock()) {
            cFRuleBase._borderFormatting = this._borderFormatting.clone();
        }
        if (containsPatternFormattingBlock()) {
            cFRuleBase._patternFormatting = (PatternFormatting) this._patternFormatting.clone();
        }
        cFRuleBase.setFormula1(getFormula1().copy());
        cFRuleBase.setFormula2(getFormula2().copy());
    }

    public BorderFormatting getBorderFormatting() {
        if (containsBorderFormattingBlock()) {
            return this._borderFormatting;
        }
        return null;
    }

    public byte getComparisonOperation() {
        return this.comparison_operator;
    }

    public byte getConditionType() {
        return this.condition_type;
    }

    public FontFormatting getFontFormatting() {
        if (containsFontFormattingBlock()) {
            return this._fontFormatting;
        }
        return null;
    }

    public int getFormattingBlockSize() {
        int i2 = 0;
        int length = (containsFontFormattingBlock() ? this._fontFormatting.getRawRecord().length : 0) + 6 + (containsBorderFormattingBlock() ? 8 : 0);
        if (containsPatternFormattingBlock()) {
            i2 = 4;
        }
        return length + i2;
    }

    public Formula getFormula1() {
        return this.formula1;
    }

    public Formula getFormula2() {
        return this.formula2;
    }

    public int getOptions() {
        return this.formatting_options;
    }

    public Ptg[] getParsedExpression1() {
        return this.formula1.getTokens();
    }

    public Ptg[] getParsedExpression2() {
        return Formula.getTokens(this.formula2);
    }

    public PatternFormatting getPatternFormatting() {
        if (containsPatternFormattingBlock()) {
            return this._patternFormatting;
        }
        return null;
    }

    public boolean isBottomBorderModified() {
        return isModified(bordBot);
    }

    public boolean isBottomLeftTopRightBorderModified() {
        return isModified(bordBlTr);
    }

    public boolean isLeftBorderModified() {
        return isModified(bordLeft);
    }

    public boolean isPatternBackgroundColorModified() {
        return isModified(pattBgCol);
    }

    public boolean isPatternColorModified() {
        return isModified(pattCol);
    }

    public boolean isPatternStyleModified() {
        return isModified(pattStyle);
    }

    public boolean isRightBorderModified() {
        return isModified(bordRight);
    }

    public boolean isTopBorderModified() {
        return isModified(bordTop);
    }

    public boolean isTopLeftBottomRightBorderModified() {
        return isModified(bordTlBr);
    }

    public int readFormatOptions(RecordInputStream recordInputStream) {
        this.formatting_options = recordInputStream.readInt();
        this.formatting_not_used = recordInputStream.readShort();
        int i2 = 6;
        if (containsFontFormattingBlock()) {
            FontFormatting fontFormatting = new FontFormatting(recordInputStream);
            this._fontFormatting = fontFormatting;
            i2 = 6 + fontFormatting.getDataLength();
        }
        if (containsBorderFormattingBlock()) {
            BorderFormatting borderFormatting = new BorderFormatting(recordInputStream);
            this._borderFormatting = borderFormatting;
            i2 += borderFormatting.getDataLength();
        }
        if (!containsPatternFormattingBlock()) {
            return i2;
        }
        PatternFormatting patternFormatting = new PatternFormatting(recordInputStream);
        this._patternFormatting = patternFormatting;
        return i2 + patternFormatting.getDataLength();
    }

    public void serializeFormattingBlock(LittleEndianOutput littleEndianOutput) {
        littleEndianOutput.writeInt(this.formatting_options);
        littleEndianOutput.writeShort(this.formatting_not_used);
        if (containsFontFormattingBlock()) {
            littleEndianOutput.write(this._fontFormatting.getRawRecord());
        }
        if (containsBorderFormattingBlock()) {
            this._borderFormatting.serialize(littleEndianOutput);
        }
        if (containsPatternFormattingBlock()) {
            this._patternFormatting.serialize(littleEndianOutput);
        }
    }

    public void setAlignFormattingUnchanged() {
        setOptionFlag(false, align);
    }

    public void setBorderFormatting(BorderFormatting borderFormatting) {
        this._borderFormatting = borderFormatting;
        setOptionFlag(borderFormatting != null, bord);
    }

    public void setBottomBorderModified(boolean z) {
        setModified(z, bordBot);
    }

    public void setBottomLeftTopRightBorderModified(boolean z) {
        setModified(z, bordBlTr);
    }

    public void setComparisonOperation(byte b2) {
        if (b2 < 0 || b2 > 8) {
            throw new IllegalArgumentException("Valid operators are only in the range 0 to 8");
        }
        this.comparison_operator = b2;
    }

    public void setConditionType(byte b2) {
        if (!(this instanceof CFRuleRecord) || b2 == 1 || b2 == 2) {
            this.condition_type = b2;
            return;
        }
        throw new IllegalArgumentException("CFRuleRecord only accepts Value-Is and Formula types");
    }

    public void setFontFormatting(FontFormatting fontFormatting) {
        this._fontFormatting = fontFormatting;
        setOptionFlag(fontFormatting != null, font);
    }

    public void setFormula1(Formula formula) {
        this.formula1 = formula;
    }

    public void setFormula2(Formula formula) {
        this.formula2 = formula;
    }

    public void setLeftBorderModified(boolean z) {
        setModified(z, bordLeft);
    }

    public void setParsedExpression1(Ptg[] ptgArr) {
        this.formula1 = Formula.create(ptgArr);
    }

    public void setParsedExpression2(Ptg[] ptgArr) {
        this.formula2 = Formula.create(ptgArr);
    }

    public void setPatternBackgroundColorModified(boolean z) {
        setModified(z, pattBgCol);
    }

    public void setPatternColorModified(boolean z) {
        setModified(z, pattCol);
    }

    public void setPatternFormatting(PatternFormatting patternFormatting) {
        this._patternFormatting = patternFormatting;
        setOptionFlag(patternFormatting != null, patt);
    }

    public void setPatternStyleModified(boolean z) {
        setModified(z, pattStyle);
    }

    public void setProtectionFormattingUnchanged() {
        setOptionFlag(false, prot);
    }

    public void setRightBorderModified(boolean z) {
        setModified(z, bordRight);
    }

    public void setTopBorderModified(boolean z) {
        setModified(z, bordTop);
    }

    public void setTopLeftBottomRightBorderModified(boolean z) {
        setModified(z, bordTlBr);
    }

    public CFRuleBase(byte b2, byte b3, Ptg[] ptgArr, Ptg[] ptgArr2) {
        this(b2, b3);
        this.formula1 = Formula.create(ptgArr);
        this.formula2 = Formula.create(ptgArr2);
    }

    public CFRuleBase() {
    }
}
