package org.apache.poi.hssf.record;

import java.io.ByteArrayOutputStream;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.LittleEndianOutputStream;

public abstract class SubRecord {

    public static final class UnknownSubRecord extends SubRecord {
        public final byte[] _data;
        public final int _sid;

        public UnknownSubRecord(LittleEndianInput littleEndianInput, int i2, int i3) {
            this._sid = i2;
            byte[] bArr = new byte[i3];
            littleEndianInput.readFully(bArr);
            this._data = bArr;
        }

        @Override // org.apache.poi.hssf.record.SubRecord, org.apache.poi.hssf.record.SubRecord
        public UnknownSubRecord clone() {
            return this;
        }

        @Override // org.apache.poi.hssf.record.SubRecord
        public int getDataSize() {
            return this._data.length;
        }

        @Override // org.apache.poi.hssf.record.SubRecord
        public void serialize(LittleEndianOutput littleEndianOutput) {
            littleEndianOutput.writeShort(this._sid);
            littleEndianOutput.writeShort(this._data.length);
            littleEndianOutput.write(this._data);
        }

        public String toString() {
            StringBuilder sb = new StringBuilder(64);
            sb.append(UnknownSubRecord.class.getName());
            sb.append(" [");
            sb.append("sid=");
            sb.append(HexDump.shortToHex(this._sid));
            sb.append(" size=");
            sb.append(this._data.length);
            sb.append(" : ");
            sb.append(HexDump.toHex(this._data));
            sb.append("]\n");
            return sb.toString();
        }
    }

    public static SubRecord createSubRecord(LittleEndianInput littleEndianInput, int i2) {
        int readUShort = littleEndianInput.readUShort();
        int readUShort2 = littleEndianInput.readUShort();
        if (readUShort == 0) {
            return new EndSubRecord(littleEndianInput, readUShort2);
        }
        if (readUShort == 19) {
            return new LbsDataSubRecord(littleEndianInput, readUShort2, i2);
        }
        if (readUShort == 21) {
            return new CommonObjectDataSubRecord(littleEndianInput, readUShort2);
        }
        if (readUShort == 12) {
            return new FtCblsSubRecord(littleEndianInput, readUShort2);
        }
        if (readUShort == 13) {
            return new NoteStructureSubRecord(littleEndianInput, readUShort2);
        }
        switch (readUShort) {
            case 6:
                return new GroupMarkerSubRecord(littleEndianInput, readUShort2);
            case 7:
                return new FtCfSubRecord(littleEndianInput, readUShort2);
            case 8:
                return new FtPioGrbitSubRecord(littleEndianInput, readUShort2);
            case 9:
                return new EmbeddedObjectRefSubRecord(littleEndianInput, readUShort2);
            default:
                return new UnknownSubRecord(littleEndianInput, readUShort, readUShort2);
        }
    }

    public abstract SubRecord clone();

    public abstract int getDataSize();

    public boolean isTerminating() {
        return false;
    }

    public abstract void serialize(LittleEndianOutput littleEndianOutput);

    public byte[] serialize() {
        int dataSize = getDataSize() + 4;
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(dataSize);
        serialize(new LittleEndianOutputStream(byteArrayOutputStream));
        if (byteArrayOutputStream.size() == dataSize) {
            return byteArrayOutputStream.toByteArray();
        }
        throw new RuntimeException("write size mismatch");
    }
}
