package org.apache.poi.hssf.record.aggregates;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hssf.model.RecordStream;
import org.apache.poi.hssf.record.CFHeader12Record;
import org.apache.poi.hssf.record.CFHeaderBase;
import org.apache.poi.hssf.record.CFHeaderRecord;
import org.apache.poi.hssf.record.CFRule12Record;
import org.apache.poi.hssf.record.CFRuleBase;
import org.apache.poi.hssf.record.CFRuleRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.aggregates.RecordAggregate;
import org.apache.poi.ss.formula.FormulaShifter;
import org.apache.poi.ss.formula.ptg.AreaErrPtg;
import org.apache.poi.ss.formula.ptg.AreaPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.RecordFormatException;

public final class CFRecordsAggregate extends RecordAggregate {
    public static final int MAX_97_2003_CONDTIONAL_FORMAT_RULES = 3;
    public static final POILogger logger = POILogFactory.getLogger(CFRecordsAggregate.class);
    public final CFHeaderBase header;
    public final List<CFRuleBase> rules;

    public CFRecordsAggregate(CFHeaderBase cFHeaderBase, CFRuleBase[] cFRuleBaseArr) {
        if (cFHeaderBase == null) {
            throw new IllegalArgumentException("header must not be null");
        } else if (cFRuleBaseArr != null) {
            if (cFRuleBaseArr.length > 3) {
                POILogger pOILogger = logger;
                StringBuilder b2 = a.b("Excel versions before 2007 require that No more than 3 rules may be specified, ");
                b2.append(cFRuleBaseArr.length);
                b2.append(" were found,");
                b2.append(" this file will cause problems with old Excel versions");
                pOILogger.log(5, b2.toString());
            }
            if (cFRuleBaseArr.length == cFHeaderBase.getNumberOfConditionalFormats()) {
                this.header = cFHeaderBase;
                this.rules = new ArrayList(cFRuleBaseArr.length);
                for (CFRuleBase cFRuleBase : cFRuleBaseArr) {
                    checkRuleType(cFRuleBase);
                    this.rules.add(cFRuleBase);
                }
                return;
            }
            throw new RecordFormatException("Mismatch number of rules");
        } else {
            throw new IllegalArgumentException("rules must not be null");
        }
    }

    private void checkRuleIndex(int i2) {
        if (i2 < 0 || i2 >= this.rules.size()) {
            StringBuilder a = a.a("Bad rule record index (", i2, ") nRules=");
            a.append(this.rules.size());
            throw new IllegalArgumentException(a.toString());
        }
    }

    private void checkRuleType(CFRuleBase cFRuleBase) {
        if ((this.header instanceof CFHeaderRecord) && (cFRuleBase instanceof CFRuleRecord)) {
            return;
        }
        if (!(this.header instanceof CFHeader12Record) || !(cFRuleBase instanceof CFRule12Record)) {
            throw new IllegalArgumentException("Header and Rule must both be CF or both be CF12, can't mix");
        }
    }

    public static CFRecordsAggregate createCFAggregate(RecordStream recordStream) {
        Record next = recordStream.getNext();
        if (next.getSid() == 432 || next.getSid() == 2169) {
            CFHeaderBase cFHeaderBase = (CFHeaderBase) next;
            int numberOfConditionalFormats = cFHeaderBase.getNumberOfConditionalFormats();
            CFRuleBase[] cFRuleBaseArr = new CFRuleBase[numberOfConditionalFormats];
            for (int i2 = 0; i2 < numberOfConditionalFormats; i2++) {
                cFRuleBaseArr[i2] = (CFRuleBase) recordStream.getNext();
            }
            return new CFRecordsAggregate(cFHeaderBase, cFRuleBaseArr);
        }
        StringBuilder b2 = a.b("next record sid was ");
        b2.append((int) next.getSid());
        b2.append(" instead of ");
        b2.append(432);
        b2.append(" or ");
        throw new IllegalStateException(a.a(b2, 2169, " as expected"));
    }

    public static CFHeaderBase createHeader(CellRangeAddress[] cellRangeAddressArr, CFRuleBase[] cFRuleBaseArr) {
        CFHeaderBase cFHeaderBase;
        if (cFRuleBaseArr.length == 0 || (cFRuleBaseArr[0] instanceof CFRuleRecord)) {
            cFHeaderBase = new CFHeaderRecord(cellRangeAddressArr, cFRuleBaseArr.length);
        } else {
            cFHeaderBase = new CFHeader12Record(cellRangeAddressArr, cFRuleBaseArr.length);
        }
        cFHeaderBase.setNeedRecalculation(true);
        return cFHeaderBase;
    }

    public static CellRangeAddress shiftRange(FormulaShifter formulaShifter, CellRangeAddress cellRangeAddress, int i2) {
        Ptg[] ptgArr = {new AreaPtg(cellRangeAddress.getFirstRow(), cellRangeAddress.getLastRow(), cellRangeAddress.getFirstColumn(), cellRangeAddress.getLastColumn(), false, false, false, false)};
        if (!formulaShifter.adjustFormula(ptgArr, i2)) {
            return cellRangeAddress;
        }
        Ptg ptg = ptgArr[0];
        if (ptg instanceof AreaPtg) {
            AreaPtg areaPtg = (AreaPtg) ptg;
            return new CellRangeAddress(areaPtg.getFirstRow(), areaPtg.getLastRow(), areaPtg.getFirstColumn(), areaPtg.getLastColumn());
        } else if (ptg instanceof AreaErrPtg) {
            return null;
        } else {
            StringBuilder b2 = a.b("Unexpected shifted ptg class (");
            b2.append(ptg.getClass().getName());
            b2.append(")");
            throw new IllegalStateException(b2.toString());
        }
    }

    public void addRule(CFRuleBase cFRuleBase) {
        if (cFRuleBase != null) {
            if (this.rules.size() >= 3) {
                logger.log(5, "Excel versions before 2007 cannot cope with any more than 3 - this file will cause problems with old Excel versions");
            }
            checkRuleType(cFRuleBase);
            this.rules.add(cFRuleBase);
            this.header.setNumberOfConditionalFormats(this.rules.size());
            return;
        }
        throw new IllegalArgumentException("r must not be null");
    }

    public CFRecordsAggregate cloneCFAggregate() {
        int size = this.rules.size();
        CFRuleBase[] cFRuleBaseArr = new CFRuleBase[size];
        for (int i2 = 0; i2 < size; i2++) {
            cFRuleBaseArr[i2] = getRule(i2).clone();
        }
        return new CFRecordsAggregate(this.header.clone(), cFRuleBaseArr);
    }

    public CFHeaderBase getHeader() {
        return this.header;
    }

    public int getNumberOfRules() {
        return this.rules.size();
    }

    public CFRuleBase getRule(int i2) {
        checkRuleIndex(i2);
        return this.rules.get(i2);
    }

    public void setRule(int i2, CFRuleBase cFRuleBase) {
        if (cFRuleBase != null) {
            checkRuleIndex(i2);
            checkRuleType(cFRuleBase);
            this.rules.set(i2, cFRuleBase);
            return;
        }
        throw new IllegalArgumentException("r must not be null");
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        String str = this.header instanceof CFHeader12Record ? "CF12" : "CF";
        sb.append("[");
        sb.append(str);
        sb.append("]\n");
        CFHeaderBase cFHeaderBase = this.header;
        if (cFHeaderBase != null) {
            sb.append(cFHeaderBase);
        }
        for (CFRuleBase cFRuleBase : this.rules) {
            sb.append(cFRuleBase);
        }
        sb.append("[/");
        sb.append(str);
        sb.append("]\n");
        return sb.toString();
    }

    public boolean updateFormulasAfterCellShift(FormulaShifter formulaShifter, int i2) {
        CFRule12Record cFRule12Record;
        Ptg[] parsedExpressionScale;
        CellRangeAddress[] cellRanges = this.header.getCellRanges();
        ArrayList arrayList = new ArrayList();
        boolean z = false;
        for (CellRangeAddress cellRangeAddress : cellRanges) {
            CellRangeAddress shiftRange = shiftRange(formulaShifter, cellRangeAddress, i2);
            if (shiftRange != null) {
                arrayList.add(shiftRange);
                if (shiftRange == cellRangeAddress) {
                }
            }
            z = true;
        }
        if (z) {
            int size = arrayList.size();
            if (size == 0) {
                return false;
            }
            CellRangeAddress[] cellRangeAddressArr = new CellRangeAddress[size];
            arrayList.toArray(cellRangeAddressArr);
            this.header.setCellRanges(cellRangeAddressArr);
        }
        for (CFRuleBase cFRuleBase : this.rules) {
            Ptg[] parsedExpression1 = cFRuleBase.getParsedExpression1();
            if (parsedExpression1 != null && formulaShifter.adjustFormula(parsedExpression1, i2)) {
                cFRuleBase.setParsedExpression1(parsedExpression1);
            }
            Ptg[] parsedExpression2 = cFRuleBase.getParsedExpression2();
            if (parsedExpression2 != null && formulaShifter.adjustFormula(parsedExpression2, i2)) {
                cFRuleBase.setParsedExpression2(parsedExpression2);
            }
            if ((cFRuleBase instanceof CFRule12Record) && (parsedExpressionScale = (cFRule12Record = (CFRule12Record) cFRuleBase).getParsedExpressionScale()) != null && formulaShifter.adjustFormula(parsedExpressionScale, i2)) {
                cFRule12Record.setParsedExpressionScale(parsedExpressionScale);
            }
        }
        return true;
    }

    @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate
    public void visitContainedRecords(RecordAggregate.RecordVisitor recordVisitor) {
        recordVisitor.visitRecord(this.header);
        for (CFRuleBase cFRuleBase : this.rules) {
            recordVisitor.visitRecord(cFRuleBase);
        }
    }

    public CFRecordsAggregate(CellRangeAddress[] cellRangeAddressArr, CFRuleBase[] cFRuleBaseArr) {
        this(createHeader(cellRangeAddressArr, cFRuleBaseArr), cFRuleBaseArr);
    }
}
