package org.apache.poi.hssf.usermodel;

import b.b.a.a.a;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.regex.Pattern;
import org.apache.poi.hssf.model.HSSFFormulaParser;
import org.apache.poi.hssf.record.DVRecord;
import org.apache.poi.ss.formula.FormulaRenderer;
import org.apache.poi.ss.formula.FormulaRenderingWorkbook;
import org.apache.poi.ss.formula.FormulaType;
import org.apache.poi.ss.formula.ptg.NumberPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.formula.ptg.StringPtg;
import org.apache.poi.ss.usermodel.DataValidationConstraint;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.util.LocaleUtil;

public class DVConstraint implements DataValidationConstraint {
    public String[] _explicitListValues;
    public String _formula1;
    public String _formula2;
    public int _operator;
    public final int _validationType;
    public Double _value1;
    public Double _value2;

    public static final class FormulaPair {
        public final Ptg[] _formula1;
        public final Ptg[] _formula2;

        public FormulaPair(Ptg[] ptgArr, Ptg[] ptgArr2) {
            Ptg[] ptgArr3;
            Ptg[] ptgArr4 = null;
            if (ptgArr == null) {
                ptgArr3 = null;
            } else {
                ptgArr3 = (Ptg[]) ptgArr.clone();
            }
            this._formula1 = ptgArr3;
            this._formula2 = ptgArr2 != null ? (Ptg[]) ptgArr2.clone() : ptgArr4;
        }

        public Ptg[] getFormula1() {
            return this._formula1;
        }

        public Ptg[] getFormula2() {
            return this._formula2;
        }
    }

    public static class FormulaValuePair {
        public String _formula;
        public String _value;

        public FormulaValuePair() {
        }

        public String formula() {
            return this._formula;
        }

        public String string() {
            String str = this._formula;
            if (str != null) {
                return str;
            }
            String str2 = this._value;
            if (str2 != null) {
                return str2;
            }
            return null;
        }

        public Double value() {
            if (this._value == null) {
                return null;
            }
            return new Double(this._value);
        }
    }

    public DVConstraint(int i2, int i3, String str, String str2, Double d2, Double d3, String[] strArr) {
        String[] strArr2;
        this._validationType = i2;
        this._operator = i3;
        this._formula1 = str;
        this._formula2 = str2;
        this._value1 = d2;
        this._value2 = d3;
        if (strArr == null) {
            strArr2 = null;
        } else {
            strArr2 = (String[]) strArr.clone();
        }
        this._explicitListValues = strArr2;
    }

    public static Double convertDate(String str, SimpleDateFormat simpleDateFormat) {
        Date date;
        if (str == null) {
            return null;
        }
        if (simpleDateFormat == null) {
            date = DateUtil.parseYYYYMMDDDate(str);
        } else {
            try {
                date = simpleDateFormat.parse(str);
            } catch (ParseException e2) {
                throw new RuntimeException("Failed to parse date '" + str + "' using specified format '" + simpleDateFormat + "'", e2);
            }
        }
        return new Double(DateUtil.getExcelDate(date));
    }

    public static Ptg[] convertDoubleFormula(String str, Double d2, HSSFSheet hSSFSheet) {
        if (str == null) {
            if (d2 == null) {
                return Ptg.EMPTY_PTG_ARRAY;
            }
            return new Ptg[]{new NumberPtg(d2.doubleValue())};
        } else if (d2 == null) {
            HSSFWorkbook workbook = hSSFSheet.getWorkbook();
            return HSSFFormulaParser.parse(str, workbook, FormulaType.CELL, workbook.getSheetIndex(hSSFSheet));
        } else {
            throw new IllegalStateException("Both formula and value cannot be present");
        }
    }

    public static Double convertNumber(String str) {
        if (str == null) {
            return null;
        }
        try {
            return new Double(str);
        } catch (NumberFormatException unused) {
            throw new RuntimeException(a.b("The supplied text '", str, "' could not be parsed as a number"));
        }
    }

    public static Double convertTime(String str) {
        if (str == null) {
            return null;
        }
        return new Double(DateUtil.convertTime(str));
    }

    public static DVConstraint createCustomFormulaConstraint(String str) {
        if (str != null) {
            return new DVConstraint(7, 0, str, null, null, null, null);
        }
        throw new IllegalArgumentException("formula must be supplied");
    }

    public static DVConstraint createDVConstraint(DVRecord dVRecord, FormulaRenderingWorkbook formulaRenderingWorkbook) {
        switch (dVRecord.getDataType()) {
            case 0:
                return new DVConstraint(0, dVRecord.getConditionOperator(), null, null, null, null, null);
            case 1:
            case 2:
            case 4:
            case 5:
            case 6:
                FormulaValuePair formulaString = toFormulaString(dVRecord.getFormula1(), formulaRenderingWorkbook);
                FormulaValuePair formulaString2 = toFormulaString(dVRecord.getFormula2(), formulaRenderingWorkbook);
                return new DVConstraint(dVRecord.getDataType(), dVRecord.getConditionOperator(), formulaString.formula(), formulaString2.formula(), formulaString.value(), formulaString2.value(), null);
            case 3:
                if (!dVRecord.getListExplicitFormula()) {
                    return createFormulaListConstraint(toFormulaString(dVRecord.getFormula1(), formulaRenderingWorkbook).string());
                }
                String string = toFormulaString(dVRecord.getFormula1(), formulaRenderingWorkbook).string();
                if (string.startsWith("\"")) {
                    string = string.substring(1);
                }
                if (string.endsWith("\"")) {
                    string = string.substring(0, string.length() - 1);
                }
                return createExplicitListConstraint(string.split(Pattern.quote("\u0000")));
            case 7:
                return createCustomFormulaConstraint(toFormulaString(dVRecord.getFormula1(), formulaRenderingWorkbook).string());
            default:
                StringBuilder b2 = a.b("validationType=");
                b2.append(dVRecord.getDataType());
                throw new UnsupportedOperationException(b2.toString());
        }
    }

    public static DVConstraint createDateConstraint(int i2, String str, String str2, String str3) {
        SimpleDateFormat simpleDateFormat;
        if (str != null) {
            DataValidationConstraint.OperatorType.validateSecondArg(i2, str2);
            Double d2 = null;
            if (str3 != null) {
                simpleDateFormat = new SimpleDateFormat(str3, LocaleUtil.getUserLocale());
                simpleDateFormat.setTimeZone(LocaleUtil.getUserTimeZone());
            } else {
                simpleDateFormat = null;
            }
            String formulaFromTextExpression = getFormulaFromTextExpression(str);
            Double convertDate = formulaFromTextExpression == null ? convertDate(str, simpleDateFormat) : null;
            String formulaFromTextExpression2 = getFormulaFromTextExpression(str2);
            if (formulaFromTextExpression2 == null) {
                d2 = convertDate(str2, simpleDateFormat);
            }
            return new DVConstraint(4, i2, formulaFromTextExpression, formulaFromTextExpression2, convertDate, d2, null);
        }
        throw new IllegalArgumentException("expr1 must be supplied");
    }

    public static DVConstraint createExplicitListConstraint(String[] strArr) {
        return new DVConstraint(null, strArr);
    }

    public static DVConstraint createFormulaListConstraint(String str) {
        return new DVConstraint(str, null);
    }

    private Ptg[] createListFormula(HSSFSheet hSSFSheet) {
        String[] strArr = this._explicitListValues;
        if (strArr == null) {
            HSSFWorkbook workbook = hSSFSheet.getWorkbook();
            return HSSFFormulaParser.parse(this._formula1, workbook, FormulaType.DATAVALIDATION_LIST, workbook.getSheetIndex(hSSFSheet));
        }
        StringBuffer stringBuffer = new StringBuffer(strArr.length * 16);
        for (int i2 = 0; i2 < this._explicitListValues.length; i2++) {
            if (i2 > 0) {
                stringBuffer.append((char) 0);
            }
            stringBuffer.append(this._explicitListValues[i2]);
        }
        return new Ptg[]{new StringPtg(stringBuffer.toString())};
    }

    public static DVConstraint createNumericConstraint(int i2, int i3, String str, String str2) {
        if (i2 != 0) {
            if (i2 != 1 && i2 != 2 && i2 != 6) {
                throw new IllegalArgumentException(a.b("Validation Type (", i2, ") not supported with this method"));
            } else if (str != null) {
                DataValidationConstraint.OperatorType.validateSecondArg(i3, str2);
            } else {
                throw new IllegalArgumentException("expr1 must be supplied");
            }
        } else if (!(str == null && str2 == null)) {
            throw new IllegalArgumentException("expr1 and expr2 must be null for validation type 'any'");
        }
        String formulaFromTextExpression = getFormulaFromTextExpression(str);
        Double convertNumber = formulaFromTextExpression == null ? convertNumber(str) : null;
        String formulaFromTextExpression2 = getFormulaFromTextExpression(str2);
        return new DVConstraint(i2, i3, formulaFromTextExpression, formulaFromTextExpression2, convertNumber, formulaFromTextExpression2 == null ? convertNumber(str2) : null, null);
    }

    public static DVConstraint createTimeConstraint(int i2, String str, String str2) {
        if (str != null) {
            DataValidationConstraint.OperatorType.validateSecondArg(i2, str);
            String formulaFromTextExpression = getFormulaFromTextExpression(str);
            Double convertTime = formulaFromTextExpression == null ? convertTime(str) : null;
            String formulaFromTextExpression2 = getFormulaFromTextExpression(str2);
            return new DVConstraint(5, i2, formulaFromTextExpression, formulaFromTextExpression2, convertTime, formulaFromTextExpression2 == null ? convertTime(str2) : null, null);
        }
        throw new IllegalArgumentException("expr1 must be supplied");
    }

    public static String getFormulaFromTextExpression(String str) {
        if (str == null) {
            return null;
        }
        if (str.length() < 1) {
            throw new IllegalArgumentException("Empty string is not a valid formula/value expression");
        } else if (str.charAt(0) == '=') {
            return str.substring(1);
        } else {
            return null;
        }
    }

    public static FormulaValuePair toFormulaString(Ptg[] ptgArr, FormulaRenderingWorkbook formulaRenderingWorkbook) {
        FormulaValuePair formulaValuePair = new FormulaValuePair();
        if (ptgArr != null && ptgArr.length > 0) {
            String formulaString = FormulaRenderer.toFormulaString(formulaRenderingWorkbook, ptgArr);
            if (ptgArr.length == 1 && ptgArr[0].getClass() == NumberPtg.class) {
                formulaValuePair._value = formulaString;
            } else {
                formulaValuePair._formula = formulaString;
            }
        }
        return formulaValuePair;
    }

    public FormulaPair createFormulas(HSSFSheet hSSFSheet) {
        Ptg[] ptgArr;
        Ptg[] ptgArr2;
        if (isListValidationType()) {
            ptgArr = createListFormula(hSSFSheet);
            ptgArr2 = Ptg.EMPTY_PTG_ARRAY;
        } else {
            Ptg[] convertDoubleFormula = convertDoubleFormula(this._formula1, this._value1, hSSFSheet);
            ptgArr2 = convertDoubleFormula(this._formula2, this._value2, hSSFSheet);
            ptgArr = convertDoubleFormula;
        }
        return new FormulaPair(ptgArr, ptgArr2);
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public String[] getExplicitListValues() {
        return this._explicitListValues;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public String getFormula1() {
        return this._formula1;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public String getFormula2() {
        return this._formula2;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public int getOperator() {
        return this._operator;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public int getValidationType() {
        return this._validationType;
    }

    public Double getValue1() {
        return this._value1;
    }

    public Double getValue2() {
        return this._value2;
    }

    public boolean isExplicitList() {
        return this._validationType == 3 && this._explicitListValues != null;
    }

    public boolean isListValidationType() {
        return this._validationType == 3;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public void setExplicitListValues(String[] strArr) {
        if (this._validationType == 3) {
            this._formula1 = null;
            this._explicitListValues = strArr;
            return;
        }
        throw new RuntimeException("Cannot setExplicitListValues on non-list constraint");
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public void setFormula1(String str) {
        this._value1 = null;
        this._explicitListValues = null;
        this._formula1 = str;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public void setFormula2(String str) {
        this._value2 = null;
        this._formula2 = str;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public void setOperator(int i2) {
        this._operator = i2;
    }

    public void setValue1(double d2) {
        this._formula1 = null;
        this._value1 = new Double(d2);
    }

    public void setValue2(double d2) {
        this._formula2 = null;
        this._value2 = new Double(d2);
    }

    public DVConstraint(String str, String[] strArr) {
        this(3, 0, str, null, null, null, strArr);
    }
}
