package org.apache.poi.hssf.usermodel;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Composite;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.GraphicsConfiguration;
import java.awt.Image;
import java.awt.Paint;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import java.awt.Shape;
import java.awt.Stroke;
import java.awt.font.FontRenderContext;
import java.awt.font.GlyphVector;
import java.awt.font.TextLayout;
import java.awt.geom.AffineTransform;
import java.awt.geom.Arc2D;
import java.awt.geom.Area;
import java.awt.geom.GeneralPath;
import java.awt.geom.Line2D;
import java.awt.geom.RoundRectangle2D;
import java.awt.image.BufferedImage;
import java.awt.image.BufferedImageOp;
import java.awt.image.ImageObserver;
import java.awt.image.RenderedImage;
import java.awt.image.renderable.RenderableImage;
import java.text.AttributedCharacterIterator;
import java.util.Hashtable;
import java.util.Map;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class EscherGraphics2d extends Graphics2D {
    public Shape _deviceclip;
    public EscherGraphics _escherGraphics;
    public BufferedImage _img;
    public Paint _paint;
    public Stroke _stroke;
    public AffineTransform _trans;
    public POILogger logger = POILogFactory.getLogger(EscherGraphics2d.class);

    public EscherGraphics2d(EscherGraphics escherGraphics) {
        this._escherGraphics = escherGraphics;
        setImg(new BufferedImage(1, 1, 2));
        setColor(Color.black);
    }

    private Shape getDeviceclip() {
        return this._deviceclip;
    }

    private EscherGraphics getEscherGraphics() {
        return this._escherGraphics;
    }

    private Graphics2D getG2D() {
        return this._img.getGraphics();
    }

    private BufferedImage getImg() {
        return this._img;
    }

    private AffineTransform getTrans() {
        return this._trans;
    }

    private void setDeviceclip(Shape shape) {
        this._deviceclip = shape;
    }

    private void setImg(BufferedImage bufferedImage) {
        this._img = bufferedImage;
    }

    private void setTrans(AffineTransform affineTransform) {
        this._trans = affineTransform;
    }

    public void addRenderingHints(Map<?, ?> map) {
        getG2D().addRenderingHints(map);
    }

    public void clearRect(int i2, int i3, int i4, int i5) {
        Paint paint = getPaint();
        setColor(getBackground());
        fillRect(i2, i3, i4, i5);
        setPaint(paint);
    }

    public void clip(Shape shape) {
        if (getDeviceclip() != null) {
            Shape area = new Area(getClip());
            if (shape != null) {
                area.intersect(new Area(shape));
            }
            shape = area;
        }
        setClip(shape);
    }

    public void clipRect(int i2, int i3, int i4, int i5) {
        clip(new Rectangle(i2, i3, i4, i5));
    }

    public void copyArea(int i2, int i3, int i4, int i5, int i6, int i7) {
        getG2D().copyArea(i2, i3, i4, i5, i6, i7);
    }

    public Graphics create() {
        return new EscherGraphics2d(this._escherGraphics);
    }

    public void dispose() {
        getEscherGraphics().dispose();
        getG2D().dispose();
        getImg().flush();
    }

    public void draw(Shape shape) {
        if (shape instanceof Line2D) {
            Line2D line2D = (Line2D) shape;
            BasicStroke basicStroke = this._stroke;
            drawLine((int) line2D.getX1(), (int) line2D.getY1(), (int) line2D.getX2(), (int) line2D.getY2(), (basicStroke == null || !(basicStroke instanceof BasicStroke)) ? 0 : ((int) basicStroke.getLineWidth()) * 12700);
        } else if (this.logger.check(5)) {
            this.logger.log(5, "draw not fully supported");
        }
    }

    public void drawArc(int i2, int i3, int i4, int i5, int i6, int i7) {
        draw(new Arc2D.Float((float) i2, (float) i3, (float) i4, (float) i5, (float) i6, (float) i7, 0));
    }

    public void drawGlyphVector(GlyphVector glyphVector, float f2, float f3) {
        fill(glyphVector.getOutline(f2, f3));
    }

    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9, Color color, ImageObserver imageObserver) {
        if (this.logger.check(5)) {
            this.logger.log(5, "drawImage() not supported");
        }
        return true;
    }

    public void drawLine(int i2, int i3, int i4, int i5, int i6) {
        getEscherGraphics().drawLine(i2, i3, i4, i5, i6);
    }

    public void drawOval(int i2, int i3, int i4, int i5) {
        getEscherGraphics().drawOval(i2, i3, i4, i5);
    }

    public void drawPolygon(int[] iArr, int[] iArr2, int i2) {
        getEscherGraphics().drawPolygon(iArr, iArr2, i2);
    }

    public void drawPolyline(int[] iArr, int[] iArr2, int i2) {
        if (i2 > 0) {
            GeneralPath generalPath = new GeneralPath();
            generalPath.moveTo((float) iArr[0], (float) iArr2[0]);
            for (int i3 = 1; i3 < i2; i3++) {
                generalPath.lineTo((float) iArr[i3], (float) iArr2[i3]);
            }
            draw(generalPath);
        }
    }

    public void drawRect(int i2, int i3, int i4, int i5) {
        this._escherGraphics.drawRect(i2, i3, i4, i5);
    }

    public void drawRenderableImage(RenderableImage renderableImage, AffineTransform affineTransform) {
        drawRenderedImage(renderableImage.createDefaultRendering(), affineTransform);
    }

    public void drawRenderedImage(RenderedImage renderedImage, AffineTransform affineTransform) {
        BufferedImage bufferedImage = new BufferedImage(renderedImage.getColorModel(), renderedImage.getData().createCompatibleWritableRaster(), false, (Hashtable) null);
        bufferedImage.setData(renderedImage.getData());
        drawImage(bufferedImage, affineTransform, null);
    }

    public void drawRoundRect(int i2, int i3, int i4, int i5, int i6, int i7) {
        draw(new RoundRectangle2D.Float((float) i2, (float) i3, (float) i4, (float) i5, (float) i6, (float) i7));
    }

    public void drawString(String str, float f2, float f3) {
        getEscherGraphics().drawString(str, (int) f2, (int) f3);
    }

    public void fill(Shape shape) {
        if (this.logger.check(5)) {
            this.logger.log(5, "fill(Shape) not supported");
        }
    }

    public void fillArc(int i2, int i3, int i4, int i5, int i6, int i7) {
        fill(new Arc2D.Float((float) i2, (float) i3, (float) i4, (float) i5, (float) i6, (float) i7, 2));
    }

    public void fillOval(int i2, int i3, int i4, int i5) {
        this._escherGraphics.fillOval(i2, i3, i4, i5);
    }

    public void fillPolygon(int[] iArr, int[] iArr2, int i2) {
        this._escherGraphics.fillPolygon(iArr, iArr2, i2);
    }

    public void fillRect(int i2, int i3, int i4, int i5) {
        getEscherGraphics().fillRect(i2, i3, i4, i5);
    }

    public void fillRoundRect(int i2, int i3, int i4, int i5, int i6, int i7) {
        fill(new RoundRectangle2D.Float((float) i2, (float) i3, (float) i4, (float) i5, (float) i6, (float) i7));
    }

    public Color getBackground() {
        return getEscherGraphics().getBackground();
    }

    public Shape getClip() {
        try {
            return getTrans().createInverse().createTransformedShape(getDeviceclip());
        } catch (Exception unused) {
            return null;
        }
    }

    public Rectangle getClipBounds() {
        if (getDeviceclip() != null) {
            return getClip().getBounds();
        }
        return null;
    }

    public Color getColor() {
        return this._escherGraphics.getColor();
    }

    public Composite getComposite() {
        return getG2D().getComposite();
    }

    public GraphicsConfiguration getDeviceConfiguration() {
        return getG2D().getDeviceConfiguration();
    }

    public Font getFont() {
        return getEscherGraphics().getFont();
    }

    public FontMetrics getFontMetrics(Font font) {
        return getEscherGraphics().getFontMetrics(font);
    }

    public FontRenderContext getFontRenderContext() {
        getG2D().setTransform(getTrans());
        return getG2D().getFontRenderContext();
    }

    public Paint getPaint() {
        return this._paint;
    }

    public Object getRenderingHint(RenderingHints.Key key) {
        return getG2D().getRenderingHint(key);
    }

    public RenderingHints getRenderingHints() {
        return getG2D().getRenderingHints();
    }

    public Stroke getStroke() {
        return this._stroke;
    }

    public AffineTransform getTransform() {
        return (AffineTransform) getTrans().clone();
    }

    public boolean hit(Rectangle rectangle, Shape shape, boolean z) {
        getG2D().setTransform(getTrans());
        getG2D().setStroke(getStroke());
        getG2D().setClip(getClip());
        return getG2D().hit(rectangle, shape, z);
    }

    public void rotate(double d2) {
        getTrans().rotate(d2);
    }

    public void scale(double d2, double d3) {
        getTrans().scale(d2, d3);
    }

    public void setBackground(Color color) {
        getEscherGraphics().setBackground(color);
    }

    public void setClip(int i2, int i3, int i4, int i5) {
        setClip(new Rectangle(i2, i3, i4, i5));
    }

    public void setColor(Color color) {
        this._escherGraphics.setColor(color);
    }

    public void setComposite(Composite composite) {
        getG2D().setComposite(composite);
    }

    public void setFont(Font font) {
        getEscherGraphics().setFont(font);
    }

    public void setPaint(Paint paint) {
        if (paint != null) {
            this._paint = paint;
            if (paint instanceof Color) {
                setColor((Color) paint);
            }
        }
    }

    public void setPaintMode() {
        getEscherGraphics().setPaintMode();
    }

    public void setRenderingHint(RenderingHints.Key key, Object obj) {
        getG2D().setRenderingHint(key, obj);
    }

    public void setRenderingHints(Map<?, ?> map) {
        getG2D().setRenderingHints(map);
    }

    public void setStroke(Stroke stroke) {
        this._stroke = stroke;
    }

    public void setTransform(AffineTransform affineTransform) {
        setTrans((AffineTransform) affineTransform.clone());
    }

    public void setXORMode(Color color) {
        getEscherGraphics().setXORMode(color);
    }

    public void shear(double d2, double d3) {
        getTrans().shear(d2, d3);
    }

    public void transform(AffineTransform affineTransform) {
        getTrans().concatenate(affineTransform);
    }

    public void translate(double d2, double d3) {
        getTrans().translate(d2, d3);
    }

    public void drawLine(int i2, int i3, int i4, int i5) {
        BasicStroke basicStroke = this._stroke;
        getEscherGraphics().drawLine(i2, i3, i4, i5, (basicStroke == null || !(basicStroke instanceof BasicStroke)) ? 0 : ((int) basicStroke.getLineWidth()) * 12700);
    }

    public void drawString(String str, int i2, int i3) {
        getEscherGraphics().drawString(str, i2, i3);
    }

    public void rotate(double d2, double d3, double d4) {
        getTrans().rotate(d2, d3, d4);
    }

    public void setClip(Shape shape) {
        setDeviceclip(getTrans().createTransformedShape(shape));
    }

    public void translate(int i2, int i3) {
        getTrans().translate((double) i2, (double) i3);
    }

    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9, ImageObserver imageObserver) {
        if (this.logger.check(5)) {
            this.logger.log(5, "drawImage() not supported");
        }
        return drawImage(image, i2, i3, i4, i5, i6, i7, i8, i9, null, imageObserver);
    }

    public void drawString(AttributedCharacterIterator attributedCharacterIterator, float f2, float f3) {
        TextLayout textLayout = new TextLayout(attributedCharacterIterator, getFontRenderContext());
        Paint paint = getPaint();
        setColor(getColor());
        fill(textLayout.getOutline(AffineTransform.getTranslateInstance((double) f2, (double) f3)));
        setPaint(paint);
    }

    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, Color color, ImageObserver imageObserver) {
        if (this.logger.check(5)) {
            this.logger.log(5, "drawImage() not supported");
        }
        return true;
    }

    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, ImageObserver imageObserver) {
        return drawImage(image, i2, i3, i4, i5, null, imageObserver);
    }

    public void drawString(AttributedCharacterIterator attributedCharacterIterator, int i2, int i3) {
        getEscherGraphics().drawString(attributedCharacterIterator, i2, i3);
    }

    public boolean drawImage(Image image, int i2, int i3, Color color, ImageObserver imageObserver) {
        return drawImage(image, i2, i3, image.getWidth(imageObserver), image.getHeight(imageObserver), color, imageObserver);
    }

    public boolean drawImage(Image image, int i2, int i3, ImageObserver imageObserver) {
        return drawImage(image, i2, i3, image.getWidth(imageObserver), image.getHeight(imageObserver), imageObserver);
    }

    public boolean drawImage(Image image, AffineTransform affineTransform, ImageObserver imageObserver) {
        getTrans().concatenate(affineTransform);
        drawImage(image, 0, 0, imageObserver);
        setTrans((AffineTransform) getTrans().clone());
        return true;
    }

    public void drawImage(BufferedImage bufferedImage, BufferedImageOp bufferedImageOp, int i2, int i3) {
        drawImage(bufferedImageOp.filter(bufferedImage, (BufferedImage) null), new AffineTransform(1.0f, 0.0f, 0.0f, 1.0f, (float) i2, (float) i3), null);
    }
}
