package org.apache.poi.hssf.usermodel;

import b.b.a.a.a;
import org.apache.poi.hssf.model.HSSFFormulaParser;
import org.apache.poi.hssf.model.InternalWorkbook;
import org.apache.poi.hssf.record.NameCommentRecord;
import org.apache.poi.hssf.record.NameRecord;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.FormulaType;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.usermodel.Name;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.xssf.eventusermodel.XSSFReader;

public final class HSSFName implements Name {
    public HSSFWorkbook _book;
    public NameCommentRecord _commentRec;
    public NameRecord _definedNameRec;

    public HSSFName(HSSFWorkbook hSSFWorkbook, NameRecord nameRecord) {
        this(hSSFWorkbook, nameRecord, null);
    }

    public static void validateName(String str) {
        if (str.length() == 0) {
            throw new IllegalArgumentException("Name cannot be blank");
        } else if (str.length() > 255) {
            throw new IllegalArgumentException(a.b("Invalid name: '", str, "': cannot exceed 255 characters in length"));
        } else if (str.equalsIgnoreCase("R") || str.equalsIgnoreCase("C")) {
            throw new IllegalArgumentException(a.b("Invalid name: '", str, "': cannot be special shorthand R or C"));
        } else {
            char charAt = str.charAt(0);
            if (Character.isLetter(charAt) || "_\\".indexOf(charAt) != -1) {
                char[] charArray = str.toCharArray();
                for (char c : charArray) {
                    if (!(Character.isLetterOrDigit(c) || "_.\\".indexOf(c) != -1)) {
                        throw new IllegalArgumentException(a.b("Invalid name: '", str, "': name must be letter, digit, period, or underscore"));
                    }
                }
                if (str.matches("[A-Za-z]+\\d+") && CellReference.cellReferenceIsWithinRange(str.replaceAll("\\d", ""), str.replaceAll("[A-Za-z]", ""), SpreadsheetVersion.EXCEL97)) {
                    throw new IllegalArgumentException(a.b("Invalid name: '", str, "': cannot be $A$1-style cell reference"));
                } else if (str.matches("[Rr]\\d+[Cc]\\d+")) {
                    throw new IllegalArgumentException(a.b("Invalid name: '", str, "': cannot be R1C1-style cell reference"));
                }
            } else {
                throw new IllegalArgumentException(a.b("Invalid name: '", str, "': first character must be underscore or a letter"));
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public String getComment() {
        NameCommentRecord nameCommentRecord = this._commentRec;
        if (nameCommentRecord == null || nameCommentRecord.getCommentText() == null || this._commentRec.getCommentText().length() <= 0) {
            return this._definedNameRec.getDescriptionText();
        }
        return this._commentRec.getCommentText();
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public String getNameName() {
        return this._definedNameRec.getNameText();
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public String getRefersToFormula() {
        if (!this._definedNameRec.isFunctionName()) {
            Ptg[] nameDefinition = this._definedNameRec.getNameDefinition();
            if (nameDefinition.length < 1) {
                return null;
            }
            return HSSFFormulaParser.toFormulaString(this._book, nameDefinition);
        }
        throw new IllegalStateException("Only applicable to named ranges");
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public int getSheetIndex() {
        return this._definedNameRec.getSheetNumber() - 1;
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public String getSheetName() {
        return this._book.getWorkbook().findSheetFirstNameFromExternSheet(this._definedNameRec.getExternSheetNumber());
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public boolean isDeleted() {
        return Ptg.doesFormulaReferToDeletedCell(this._definedNameRec.getNameDefinition());
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public boolean isFunctionName() {
        return this._definedNameRec.isFunctionName();
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public void setComment(String str) {
        this._definedNameRec.setDescriptionText(str);
        NameCommentRecord nameCommentRecord = this._commentRec;
        if (nameCommentRecord != null) {
            nameCommentRecord.setCommentText(str);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public void setFunction(boolean z) {
        this._definedNameRec.setFunction(z);
    }

    public void setNameDefinition(Ptg[] ptgArr) {
        this._definedNameRec.setNameDefinition(ptgArr);
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public void setNameName(String str) {
        validateName(str);
        InternalWorkbook workbook = this._book.getWorkbook();
        this._definedNameRec.setNameText(str);
        int sheetNumber = this._definedNameRec.getSheetNumber();
        int numNames = workbook.getNumNames();
        while (true) {
            numNames--;
            if (numNames >= 0) {
                NameRecord nameRecord = workbook.getNameRecord(numNames);
                if (nameRecord != this._definedNameRec && nameRecord.getNameText().equalsIgnoreCase(str) && sheetNumber == nameRecord.getSheetNumber()) {
                    StringBuilder b2 = a.b("The ");
                    b2.append(sheetNumber == 0 ? "workbook" : XSSFReader.XMLSheetRefReader.SHEET);
                    b2.append(" already contains this name: ");
                    b2.append(str);
                    String sb = b2.toString();
                    this._definedNameRec.setNameText(str + "(2)");
                    throw new IllegalArgumentException(sb);
                }
            } else {
                NameCommentRecord nameCommentRecord = this._commentRec;
                if (nameCommentRecord != null) {
                    nameCommentRecord.setNameText(str);
                    this._book.getWorkbook().updateNameCommentRecordCache(this._commentRec);
                    return;
                }
                return;
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public void setRefersToFormula(String str) {
        this._definedNameRec.setNameDefinition(HSSFFormulaParser.parse(str, this._book, FormulaType.NAMEDRANGE, getSheetIndex()));
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public void setSheetIndex(int i2) {
        int numberOfSheets = this._book.getNumberOfSheets() - 1;
        if (i2 < -1 || i2 > numberOfSheets) {
            StringBuilder a = a.a("Sheet index (", i2, ") is out of range");
            a.append(numberOfSheets == -1 ? "" : a.b(" (0..", numberOfSheets, ")"));
            throw new IllegalArgumentException(a.toString());
        }
        this._definedNameRec.setSheetNumber(i2 + 1);
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer(64);
        a.a(HSSFName.class, stringBuffer, " [");
        stringBuffer.append(this._definedNameRec.getNameText());
        stringBuffer.append("]");
        return stringBuffer.toString();
    }

    public HSSFName(HSSFWorkbook hSSFWorkbook, NameRecord nameRecord, NameCommentRecord nameCommentRecord) {
        this._book = hSSFWorkbook;
        this._definedNameRec = nameRecord;
        this._commentRec = nameCommentRecord;
    }
}
