package org.apache.poi.hssf.usermodel;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import org.apache.poi.ddf.EscherBoolProperty;
import org.apache.poi.ddf.EscherChildAnchorRecord;
import org.apache.poi.ddf.EscherClientAnchorRecord;
import org.apache.poi.ddf.EscherComplexProperty;
import org.apache.poi.ddf.EscherContainerRecord;
import org.apache.poi.ddf.EscherOptRecord;
import org.apache.poi.ddf.EscherProperties;
import org.apache.poi.ddf.EscherProperty;
import org.apache.poi.ddf.EscherRGBProperty;
import org.apache.poi.ddf.EscherSimpleProperty;
import org.apache.poi.ddf.EscherSpRecord;
import org.apache.poi.hssf.record.CommonObjectDataSubRecord;
import org.apache.poi.hssf.record.ObjRecord;
import org.apache.poi.ss.usermodel.Shape;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;

public abstract class HSSFShape implements Shape {
    public static final int FILL__FILLCOLOR_DEFAULT = 134217737;
    public static final int LINESTYLE_DASHDOTDOTSYS = 4;
    public static final int LINESTYLE_DASHDOTGEL = 8;
    public static final int LINESTYLE_DASHDOTSYS = 3;
    public static final int LINESTYLE_DASHGEL = 6;
    public static final int LINESTYLE_DASHSYS = 1;
    public static final int LINESTYLE_DEFAULT = -1;
    public static final int LINESTYLE_DOTGEL = 5;
    public static final int LINESTYLE_DOTSYS = 2;
    public static final int LINESTYLE_LONGDASHDOTDOTGEL = 10;
    public static final int LINESTYLE_LONGDASHDOTGEL = 9;
    public static final int LINESTYLE_LONGDASHGEL = 7;
    public static final int LINESTYLE_NONE = -1;
    public static final int LINESTYLE_SOLID = 0;
    public static final int LINESTYLE__COLOR_DEFAULT = 134217792;
    public static final int LINEWIDTH_DEFAULT = 9525;
    public static final int LINEWIDTH_ONE_PT = 12700;
    public static final POILogger LOG = POILogFactory.getLogger(HSSFShape.class);
    public static final int NO_FILLHITTEST_FALSE = 65536;
    public static final int NO_FILLHITTEST_TRUE = 1114112;
    public static final boolean NO_FILL_DEFAULT = true;
    public final EscherContainerRecord _escherContainer;
    public final ObjRecord _objRecord;
    public final EscherOptRecord _optRecord;
    public HSSFPatriarch _patriarch;
    public HSSFAnchor anchor;
    public HSSFShape parent;

    public HSSFShape(EscherContainerRecord escherContainerRecord, ObjRecord objRecord) {
        this._escherContainer = escherContainerRecord;
        this._objRecord = objRecord;
        this._optRecord = (EscherOptRecord) escherContainerRecord.getChildById(EscherOptRecord.RECORD_ID);
        this.anchor = HSSFAnchor.createAnchorFromEscher(escherContainerRecord);
    }

    public abstract void afterInsert(HSSFPatriarch hSSFPatriarch);

    public abstract void afterRemove(HSSFPatriarch hSSFPatriarch);

    public abstract HSSFShape cloneShape();

    public int countOfAllChildren() {
        return 1;
    }

    public abstract ObjRecord createObjRecord();

    public abstract EscherContainerRecord createSpContainer();

    public EscherContainerRecord getEscherContainer() {
        return this._escherContainer;
    }

    public int getFillColor() {
        EscherRGBProperty escherRGBProperty = (EscherRGBProperty) this._optRecord.lookup(385);
        if (escherRGBProperty == null) {
            return FILL__FILLCOLOR_DEFAULT;
        }
        return escherRGBProperty.getRgbColor();
    }

    public int getLineStyle() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) this._optRecord.lookup(462);
        if (escherSimpleProperty == null) {
            return -1;
        }
        return escherSimpleProperty.getPropertyValue();
    }

    public int getLineStyleColor() {
        EscherRGBProperty escherRGBProperty = (EscherRGBProperty) this._optRecord.lookup(448);
        if (escherRGBProperty == null) {
            return LINESTYLE__COLOR_DEFAULT;
        }
        return escherRGBProperty.getRgbColor();
    }

    public int getLineWidth() {
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) this._optRecord.lookup(459);
        if (escherSimpleProperty == null) {
            return 9525;
        }
        return escherSimpleProperty.getPropertyValue();
    }

    public ObjRecord getObjRecord() {
        return this._objRecord;
    }

    public EscherOptRecord getOptRecord() {
        return this._optRecord;
    }

    public HSSFPatriarch getPatriarch() {
        return this._patriarch;
    }

    public int getRotationDegree() {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        EscherSimpleProperty escherSimpleProperty = (EscherSimpleProperty) getOptRecord().lookup(4);
        if (escherSimpleProperty == null) {
            return 0;
        }
        try {
            LittleEndian.putInt(escherSimpleProperty.getPropertyValue(), byteArrayOutputStream);
            return LittleEndian.getShort(byteArrayOutputStream.toByteArray(), 2);
        } catch (IOException e2) {
            LOG.log(7, "can't determine rotation degree", e2);
            return 0;
        }
    }

    public int getShapeId() {
        return ((EscherSpRecord) this._escherContainer.getChildById(EscherSpRecord.RECORD_ID)).getShapeId();
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public String getShapeName() {
        EscherOptRecord optRecord = getOptRecord();
        if (optRecord == null) {
            return null;
        }
        EscherProperty lookup = optRecord.lookup(896);
        if (lookup instanceof EscherComplexProperty) {
            return StringUtil.getFromUnicodeLE(((EscherComplexProperty) lookup).getComplexData());
        }
        return null;
    }

    public boolean isFlipHorizontal() {
        return (((EscherSpRecord) getEscherContainer().getChildById(EscherSpRecord.RECORD_ID)).getFlags() & 64) != 0;
    }

    public boolean isFlipVertical() {
        return (((EscherSpRecord) getEscherContainer().getChildById(EscherSpRecord.RECORD_ID)).getFlags() & 128) != 0;
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public boolean isNoFill() {
        EscherBoolProperty escherBoolProperty = (EscherBoolProperty) this._optRecord.lookup(447);
        if (escherBoolProperty == null || escherBoolProperty.getPropertyValue() == 1114112) {
            return true;
        }
        return false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:34:0x00a9  */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x00b3  */
    public void setAnchor(HSSFAnchor hSSFAnchor) {
        short s;
        int i2 = 0;
        if (this.parent == null) {
            if (!(hSSFAnchor instanceof HSSFChildAnchor)) {
                EscherClientAnchorRecord escherClientAnchorRecord = (EscherClientAnchorRecord) this._escherContainer.getChildById(EscherClientAnchorRecord.RECORD_ID);
                if (escherClientAnchorRecord != null) {
                    s = -1;
                    while (i2 < this._escherContainer.getChildRecords().size()) {
                        if (this._escherContainer.getChild(i2).getRecordId() == -4080 && i2 != this._escherContainer.getChildRecords().size() - 1) {
                            s = this._escherContainer.getChild(i2 + 1).getRecordId();
                        }
                        i2++;
                    }
                    this._escherContainer.removeChildRecord(escherClientAnchorRecord);
                    if (-1 == s) {
                        this._escherContainer.addChildRecord(hSSFAnchor.getEscherAnchor());
                    } else {
                        this._escherContainer.addChildBefore(hSSFAnchor.getEscherAnchor(), s);
                    }
                    this.anchor = hSSFAnchor;
                }
            } else {
                throw new IllegalArgumentException("Must use client anchors for shapes directly attached to sheet.");
            }
        } else if (!(hSSFAnchor instanceof HSSFClientAnchor)) {
            EscherChildAnchorRecord escherChildAnchorRecord = (EscherChildAnchorRecord) this._escherContainer.getChildById(EscherChildAnchorRecord.RECORD_ID);
            if (escherChildAnchorRecord != null) {
                s = -1;
                while (i2 < this._escherContainer.getChildRecords().size()) {
                    if (this._escherContainer.getChild(i2).getRecordId() == -4081 && i2 != this._escherContainer.getChildRecords().size() - 1) {
                        s = this._escherContainer.getChild(i2 + 1).getRecordId();
                    }
                    i2++;
                }
                this._escherContainer.removeChildRecord(escherChildAnchorRecord);
                if (-1 == s) {
                }
                this.anchor = hSSFAnchor;
            }
        } else {
            throw new IllegalArgumentException("Must use child anchors for shapes attached to groups.");
        }
        s = -1;
        if (-1 == s) {
        }
        this.anchor = hSSFAnchor;
    }

    public void setFillColor(int i2) {
        setPropertyValue(new EscherRGBProperty(EscherProperties.FILL__FILLCOLOR, i2));
    }

    public void setFlipHorizontal(boolean z) {
        EscherSpRecord escherSpRecord = (EscherSpRecord) getEscherContainer().getChildById(EscherSpRecord.RECORD_ID);
        if (z) {
            escherSpRecord.setFlags(escherSpRecord.getFlags() | 64);
        } else {
            escherSpRecord.setFlags(escherSpRecord.getFlags() & 2147483583);
        }
    }

    public void setFlipVertical(boolean z) {
        EscherSpRecord escherSpRecord = (EscherSpRecord) getEscherContainer().getChildById(EscherSpRecord.RECORD_ID);
        if (z) {
            escherSpRecord.setFlags(escherSpRecord.getFlags() | 128);
        } else {
            escherSpRecord.setFlags(escherSpRecord.getFlags() & 2147483519);
        }
    }

    public void setLineStyle(int i2) {
        setPropertyValue(new EscherSimpleProperty(EscherProperties.LINESTYLE__LINEDASHING, i2));
        if (getLineStyle() != 0) {
            setPropertyValue(new EscherSimpleProperty(EscherProperties.LINESTYLE__LINEENDCAPSTYLE, 0));
            if (getLineStyle() == -1) {
                setPropertyValue(new EscherBoolProperty(EscherProperties.LINESTYLE__NOLINEDRAWDASH, 524288));
            } else {
                setPropertyValue(new EscherBoolProperty(EscherProperties.LINESTYLE__NOLINEDRAWDASH, 524296));
            }
        }
    }

    public void setLineStyleColor(int i2) {
        setPropertyValue(new EscherRGBProperty(EscherProperties.LINESTYLE__COLOR, i2));
    }

    public void setLineWidth(int i2) {
        setPropertyValue(new EscherSimpleProperty(EscherProperties.LINESTYLE__LINEWIDTH, i2));
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public void setNoFill(boolean z) {
        setPropertyValue(new EscherBoolProperty(EscherProperties.FILL__NOFILLHITTEST, z ? NO_FILLHITTEST_TRUE : 65536));
    }

    public void setParent(HSSFShape hSSFShape) {
        this.parent = hSSFShape;
    }

    public void setPatriarch(HSSFPatriarch hSSFPatriarch) {
        this._patriarch = hSSFPatriarch;
    }

    public void setPropertyValue(EscherProperty escherProperty) {
        this._optRecord.setEscherProperty(escherProperty);
    }

    public void setRotationDegree(short s) {
        setPropertyValue(new EscherSimpleProperty(4, s << 16));
    }

    public void setShapeId(int i2) {
        ((EscherSpRecord) this._escherContainer.getChildById(EscherSpRecord.RECORD_ID)).setShapeId(i2);
        ((CommonObjectDataSubRecord) this._objRecord.getSubRecords().get(0)).setObjectId((short) (i2 % 1024));
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public HSSFAnchor getAnchor() {
        return this.anchor;
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public HSSFShape getParent() {
        return this.parent;
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public void setFillColor(int i2, int i3, int i4) {
        setPropertyValue(new EscherRGBProperty(EscherProperties.FILL__FILLCOLOR, i2 | (i3 << 8) | (i4 << 16)));
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public void setLineStyleColor(int i2, int i3, int i4) {
        setPropertyValue(new EscherRGBProperty(EscherProperties.LINESTYLE__COLOR, i2 | (i3 << 8) | (i4 << 16)));
    }

    public HSSFShape(HSSFShape hSSFShape, HSSFAnchor hSSFAnchor) {
        this.parent = hSSFShape;
        this.anchor = hSSFAnchor;
        EscherContainerRecord createSpContainer = createSpContainer();
        this._escherContainer = createSpContainer;
        this._optRecord = (EscherOptRecord) createSpContainer.getChildById(EscherOptRecord.RECORD_ID);
        this._objRecord = createObjRecord();
    }
}
