package org.apache.poi.hssf.usermodel;

import b.b.a.a.a;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import java.util.TreeSet;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.hssf.model.DrawingManager2;
import org.apache.poi.hssf.model.HSSFFormulaParser;
import org.apache.poi.hssf.model.InternalSheet;
import org.apache.poi.hssf.model.InternalWorkbook;
import org.apache.poi.hssf.record.AutoFilterInfoRecord;
import org.apache.poi.hssf.record.CellValueRecordInterface;
import org.apache.poi.hssf.record.DVRecord;
import org.apache.poi.hssf.record.DrawingRecord;
import org.apache.poi.hssf.record.EscherAggregate;
import org.apache.poi.hssf.record.HyperlinkRecord;
import org.apache.poi.hssf.record.NameRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordBase;
import org.apache.poi.hssf.record.RowRecord;
import org.apache.poi.hssf.record.SCLRecord;
import org.apache.poi.hssf.record.WSBoolRecord;
import org.apache.poi.hssf.record.aggregates.DataValidityTable;
import org.apache.poi.hssf.record.aggregates.FormulaRecordAggregate;
import org.apache.poi.hssf.record.aggregates.RecordAggregate;
import org.apache.poi.hssf.record.aggregates.WorksheetProtectionBlock;
import org.apache.poi.hssf.usermodel.helpers.HSSFRowShifter;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.FormulaShifter;
import org.apache.poi.ss.formula.FormulaType;
import org.apache.poi.ss.formula.ptg.Area3DPtg;
import org.apache.poi.ss.formula.ptg.MemFuncPtg;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.formula.ptg.UnionPtg;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellRange;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.DataValidation;
import org.apache.poi.ss.usermodel.DataValidationHelper;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.util.CellAddress;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.ss.util.PaneInformation;
import org.apache.poi.ss.util.SSCellRange;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.poi.util.Configurator;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public final class HSSFSheet implements Sheet {
    public static final int DEBUG = 1;
    public static final int INITIAL_CAPACITY = Configurator.getIntValue("HSSFSheet.RowInitialCapacity", 20);
    public static final float PX_DEFAULT = 32.0f;
    public static final float PX_MODIFIED = 36.56f;
    public static final POILogger log = POILogFactory.getLogger(HSSFSheet.class);
    public final InternalWorkbook _book;
    public int _firstrow;
    public int _lastrow;
    public HSSFPatriarch _patriarch;
    public final TreeMap<Integer, HSSFRow> _rows;
    public final InternalSheet _sheet;
    public final HSSFWorkbook _workbook;

    public HSSFSheet(HSSFWorkbook hSSFWorkbook) {
        this._sheet = InternalSheet.createSheet();
        this._rows = new TreeMap<>();
        this._workbook = hSSFWorkbook;
        this._book = hSSFWorkbook.getWorkbook();
    }

    private void addRow(HSSFRow hSSFRow, boolean z) {
        this._rows.put(Integer.valueOf(hSSFRow.getRowNum()), hSSFRow);
        if (z) {
            this._sheet.addRow(hSSFRow.getRowRecord());
        }
        boolean z2 = true;
        if (this._rows.size() != 1) {
            z2 = false;
        }
        if (hSSFRow.getRowNum() > getLastRowNum() || z2) {
            this._lastrow = hSSFRow.getRowNum();
        }
        if (hSSFRow.getRowNum() < getFirstRowNum() || z2) {
            this._firstrow = hSSFRow.getRowNum();
        }
    }

    private void checkForIntersectingMergedRegions() {
        List<CellRangeAddress> mergedRegions = getMergedRegions();
        int size = mergedRegions.size();
        int i2 = 0;
        while (i2 < size) {
            CellRangeAddress cellRangeAddress = mergedRegions.get(i2);
            i2++;
            Iterator<CellRangeAddress> it = mergedRegions.subList(i2, mergedRegions.size()).iterator();
            while (true) {
                if (it.hasNext()) {
                    CellRangeAddress next = it.next();
                    if (cellRangeAddress.intersects(next)) {
                        StringBuilder b2 = a.b("The range ");
                        b2.append(cellRangeAddress.formatAsString());
                        b2.append(" intersects with another merged region ");
                        b2.append(next.formatAsString());
                        b2.append(" in this sheet");
                        throw new IllegalStateException(b2.toString());
                    }
                }
            }
        }
    }

    private void checkForMergedRegionsIntersectingArrayFormulas() {
        for (CellRangeAddress cellRangeAddress : getMergedRegions()) {
            validateArrayFormulas(cellRangeAddress);
        }
    }

    public static int clip(int i2) {
        return Math.min(Math.max(0, i2), SpreadsheetVersion.EXCEL97.getLastRowIndex());
    }

    private HSSFRow createRowFromRecord(RowRecord rowRecord) {
        HSSFRow hSSFRow = new HSSFRow(this._workbook, this, rowRecord);
        addRow(hSSFRow, false);
        return hSSFRow;
    }

    private void findCellCommentLocations(HSSFShapeContainer hSSFShapeContainer, Map<CellAddress, HSSFComment> map) {
        for (HSSFShape hSSFShape : hSSFShapeContainer.getChildren()) {
            if (hSSFShape instanceof HSSFShapeGroup) {
                findCellCommentLocations((HSSFShapeGroup) hSSFShape, map);
            } else if (hSSFShape instanceof HSSFComment) {
                HSSFComment hSSFComment = (HSSFComment) hSSFShape;
                if (hSSFComment.hasPosition()) {
                    map.put(new CellAddress(hSSFComment.getRow(), hSSFComment.getColumn()), hSSFComment);
                }
            }
        }
    }

    private int findFirstRow(int i2) {
        int i3 = i2 + 1;
        HSSFRow row = getRow(i3);
        while (row == null && i3 <= getLastRowNum()) {
            i3++;
            row = getRow(i3);
        }
        if (i3 > getLastRowNum()) {
            return 0;
        }
        return i3;
    }

    private int findLastRow(int i2) {
        if (i2 < 1) {
            return 0;
        }
        int i3 = i2 - 1;
        HSSFRow row = getRow(i3);
        while (row == null && i3 > 0) {
            i3--;
            row = getRow(i3);
        }
        if (row == null) {
            return 0;
        }
        return i3;
    }

    private NameRecord getBuiltinNameRecord(byte b2) {
        int findExistingBuiltinNameRecordIdx = this._workbook.findExistingBuiltinNameRecordIdx(this._workbook.getSheetIndex(this), b2);
        if (findExistingBuiltinNameRecordIdx == -1) {
            return null;
        }
        return this._workbook.getNameRecord(findExistingBuiltinNameRecordIdx);
    }

    private CellRange<HSSFCell> getCellRange(CellRangeAddress cellRangeAddress) {
        int firstRow = cellRangeAddress.getFirstRow();
        int firstColumn = cellRangeAddress.getFirstColumn();
        int lastRow = cellRangeAddress.getLastRow();
        int lastColumn = cellRangeAddress.getLastColumn();
        int i2 = (lastRow - firstRow) + 1;
        int i3 = (lastColumn - firstColumn) + 1;
        ArrayList arrayList = new ArrayList(i2 * i3);
        for (int i4 = firstRow; i4 <= lastRow; i4++) {
            for (int i5 = firstColumn; i5 <= lastColumn; i5++) {
                HSSFRow row = getRow(i4);
                if (row == null) {
                    row = createRow(i4);
                }
                HSSFCell cell = row.getCell(i5);
                if (cell == null) {
                    cell = row.createCell(i5);
                }
                arrayList.add(cell);
            }
        }
        return SSCellRange.create(firstRow, firstColumn, i2, i3, arrayList, HSSFCell.class);
    }

    private HSSFPatriarch getPatriarch(boolean z) {
        HSSFPatriarch hSSFPatriarch = this._patriarch;
        if (hSSFPatriarch != null) {
            return hSSFPatriarch;
        }
        DrawingManager2 findDrawingGroup = this._book.findDrawingGroup();
        if (findDrawingGroup == null) {
            if (!z) {
                return null;
            }
            this._book.createDrawingGroup();
            findDrawingGroup = this._book.getDrawingManager();
        }
        EscherAggregate escherAggregate = (EscherAggregate) this._sheet.findFirstRecordBySid(EscherAggregate.sid);
        if (escherAggregate == null) {
            int aggregateDrawingRecords = this._sheet.aggregateDrawingRecords(findDrawingGroup, false);
            if (-1 != aggregateDrawingRecords) {
                escherAggregate = (EscherAggregate) this._sheet.getRecords().get(aggregateDrawingRecords);
            } else if (!z) {
                return null;
            } else {
                HSSFPatriarch hSSFPatriarch2 = new HSSFPatriarch(this, (EscherAggregate) this._sheet.getRecords().get(this._sheet.aggregateDrawingRecords(findDrawingGroup, true)));
                hSSFPatriarch2.afterCreate();
                return hSSFPatriarch2;
            }
        }
        return new HSSFPatriarch(this, escherAggregate);
    }

    private WorksheetProtectionBlock getProtectionBlock() {
        return this._sheet.getProtectionBlock();
    }

    private CellRangeAddress getRepeatingRowsOrColums(boolean z) {
        Ptg[] nameDefinition;
        NameRecord builtinNameRecord = getBuiltinNameRecord((byte) 7);
        if (builtinNameRecord == null || (nameDefinition = builtinNameRecord.getNameDefinition()) == null) {
            return null;
        }
        int lastRowIndex = SpreadsheetVersion.EXCEL97.getLastRowIndex();
        int lastColumnIndex = SpreadsheetVersion.EXCEL97.getLastColumnIndex();
        for (Ptg ptg : nameDefinition) {
            if (ptg instanceof Area3DPtg) {
                Area3DPtg area3DPtg = (Area3DPtg) ptg;
                if (area3DPtg.getFirstColumn() == 0 && area3DPtg.getLastColumn() == lastColumnIndex) {
                    if (z) {
                        return new CellRangeAddress(area3DPtg.getFirstRow(), area3DPtg.getLastRow(), -1, -1);
                    }
                } else if (area3DPtg.getFirstRow() == 0 && area3DPtg.getLastRow() == lastRowIndex && !z) {
                    return new CellRangeAddress(-1, -1, area3DPtg.getFirstColumn(), area3DPtg.getLastColumn());
                }
            }
        }
        return null;
    }

    private HSSFComment lookForComment(HSSFShapeContainer hSSFShapeContainer, int i2, int i3) {
        for (HSSFShape hSSFShape : hSSFShapeContainer.getChildren()) {
            if (hSSFShape instanceof HSSFShapeGroup) {
                HSSFComment lookForComment = lookForComment((HSSFShapeContainer) hSSFShape, i2, i3);
                if (lookForComment != null) {
                    return lookForComment;
                }
            } else if (hSSFShape instanceof HSSFComment) {
                HSSFComment hSSFComment = (HSSFComment) hSSFShape;
                if (hSSFComment.hasPosition() && hSSFComment.getColumn() == i3 && hSSFComment.getRow() == i2) {
                    return hSSFComment;
                }
            } else {
                continue;
            }
        }
        return null;
    }

    private void notifyRowShifting(HSSFRow hSSFRow) {
        StringBuilder b2 = a.b("Row[rownum=");
        b2.append(hSSFRow.getRowNum());
        b2.append("] contains cell(s) included in a multi-cell array formula. ");
        b2.append("You cannot change part of an array.");
        String sb = b2.toString();
        Iterator<Cell> it = hSSFRow.iterator();
        while (it.hasNext()) {
            HSSFCell hSSFCell = (HSSFCell) it.next();
            if (hSSFCell.isPartOfArrayFormulaGroup()) {
                hSSFCell.notifyArrayFormulaChanging(sb);
            }
        }
    }

    private void setPropertiesFromSheet(InternalSheet internalSheet) {
        HSSFRow hSSFRow;
        RowRecord nextRow = internalSheet.getNextRow();
        while (nextRow != null) {
            createRowFromRecord(nextRow);
            nextRow = internalSheet.getNextRow();
        }
        Iterator<CellValueRecordInterface> cellValueIterator = internalSheet.getCellValueIterator();
        long currentTimeMillis = System.currentTimeMillis();
        if (log.check(1)) {
            log.log(1, "Time at start of cell creating in HSSF sheet = ", Long.valueOf(currentTimeMillis));
        }
        HSSFRow hSSFRow2 = null;
        while (cellValueIterator.hasNext()) {
            CellValueRecordInterface next = cellValueIterator.next();
            long currentTimeMillis2 = System.currentTimeMillis();
            if ((hSSFRow2 == null || hSSFRow2.getRowNum() != next.getRow()) && (hSSFRow2 = getRow(next.getRow())) == null) {
                RowRecord rowRecord = new RowRecord(next.getRow());
                internalSheet.addRow(rowRecord);
                hSSFRow = createRowFromRecord(rowRecord);
            } else {
                hSSFRow = hSSFRow2;
            }
            if (log.check(1)) {
                if (next instanceof Record) {
                    POILogger pOILogger = log;
                    StringBuilder b2 = a.b("record id = ");
                    b2.append(Integer.toHexString(((Record) next).getSid()));
                    pOILogger.log(1, b2.toString());
                } else {
                    POILogger pOILogger2 = log;
                    pOILogger2.log(1, "record = " + next);
                }
            }
            hSSFRow.createCellFromRecord(next);
            if (log.check(1)) {
                log.log(1, "record took ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis2));
            }
        }
        if (log.check(1)) {
            log.log(1, "total sheet cell creation took ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis));
        }
    }

    private void setRepeatingRowsAndColumns(CellRangeAddress cellRangeAddress, CellRangeAddress cellRangeAddress2) {
        int i2;
        int i3;
        int i4;
        int i5;
        ArrayList arrayList;
        int sheetIndex = this._workbook.getSheetIndex(this);
        int lastRowIndex = SpreadsheetVersion.EXCEL97.getLastRowIndex();
        int lastColumnIndex = SpreadsheetVersion.EXCEL97.getLastColumnIndex();
        if (cellRangeAddress != null) {
            int firstRow = cellRangeAddress.getFirstRow();
            int lastRow = cellRangeAddress.getLastRow();
            if ((firstRow != -1 || lastRow == -1) && firstRow <= lastRow && firstRow >= 0 && firstRow <= lastRowIndex && lastRow >= 0 && lastRow <= lastRowIndex) {
                i3 = firstRow;
                i2 = lastRow;
            } else {
                throw new IllegalArgumentException("Invalid row range specification");
            }
        } else {
            i3 = -1;
            i2 = -1;
        }
        if (cellRangeAddress2 != null) {
            int firstColumn = cellRangeAddress2.getFirstColumn();
            int lastColumn = cellRangeAddress2.getLastColumn();
            if ((firstColumn != -1 || lastColumn == -1) && firstColumn <= lastColumn && firstColumn >= 0 && firstColumn <= lastColumnIndex && lastColumn >= 0 && lastColumn <= lastColumnIndex) {
                i4 = lastColumn;
                i5 = firstColumn;
            } else {
                throw new IllegalArgumentException("Invalid column range specification");
            }
        } else {
            i5 = -1;
            i4 = -1;
        }
        short checkExternSheet = this._workbook.getWorkbook().checkExternSheet(sheetIndex);
        boolean z = (cellRangeAddress == null || cellRangeAddress2 == null) ? false : true;
        boolean z2 = cellRangeAddress == null && cellRangeAddress2 == null;
        HSSFName builtInName = this._workbook.getBuiltInName((byte) 7, sheetIndex);
        if (!z2) {
            if (builtInName == null) {
                builtInName = this._workbook.createBuiltInName((byte) 7, sheetIndex);
            }
            ArrayList arrayList2 = new ArrayList();
            if (z) {
                arrayList2.add(new MemFuncPtg(23));
            }
            if (cellRangeAddress2 != null) {
                arrayList = arrayList2;
                arrayList.add(new Area3DPtg(0, lastRowIndex, i5, i4, false, false, false, false, checkExternSheet));
            } else {
                arrayList = arrayList2;
            }
            if (cellRangeAddress != null) {
                arrayList.add(new Area3DPtg(i3, i2, 0, lastColumnIndex, false, false, false, false, checkExternSheet));
            }
            if (z) {
                arrayList.add(UnionPtg.instance);
            }
            Ptg[] ptgArr = new Ptg[arrayList.size()];
            arrayList.toArray(ptgArr);
            builtInName.setNameDefinition(ptgArr);
            getPrintSetup().setValidSettings(false);
            setActive(true);
        } else if (builtInName != null) {
            this._workbook.removeName(builtInName);
        }
    }

    private void validateArrayFormulas(CellRangeAddress cellRangeAddress) {
        int firstColumn = cellRangeAddress.getFirstColumn();
        int lastRow = cellRangeAddress.getLastRow();
        int lastColumn = cellRangeAddress.getLastColumn();
        for (int firstRow = cellRangeAddress.getFirstRow(); firstRow <= lastRow; firstRow++) {
            HSSFRow row = getRow(firstRow);
            if (row != null) {
                for (int i2 = firstColumn; i2 <= lastColumn; i2++) {
                    HSSFCell cell = row.getCell(i2);
                    if (cell != null && cell.isPartOfArrayFormulaGroup()) {
                        CellRangeAddress arrayFormulaRange = cell.getArrayFormulaRange();
                        if (arrayFormulaRange.getNumberOfCells() > 1 && cellRangeAddress.intersects(arrayFormulaRange)) {
                            StringBuilder b2 = a.b("The range ");
                            b2.append(cellRangeAddress.formatAsString());
                            b2.append(" intersects with a multi-cell array formula. ");
                            b2.append("You cannot merge cells of an array.");
                            throw new IllegalStateException(b2.toString());
                        }
                    }
                }
                continue;
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int addMergedRegion(CellRangeAddress cellRangeAddress) {
        return addMergedRegion(cellRangeAddress, true);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int addMergedRegionUnsafe(CellRangeAddress cellRangeAddress) {
        return addMergedRegion(cellRangeAddress, false);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void addValidationData(DataValidation dataValidation) {
        if (dataValidation != null) {
            this._sheet.getOrCreateDataValidityTable().addDataValidation(((HSSFDataValidation) dataValidation).createDVRecord(this));
            return;
        }
        throw new IllegalArgumentException("objValidation must not be null");
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void autoSizeColumn(int i2) {
        autoSizeColumn(i2, false);
    }

    public HSSFSheet cloneSheet(HSSFWorkbook hSSFWorkbook) {
        getDrawingPatriarch();
        HSSFSheet hSSFSheet = new HSSFSheet(hSSFWorkbook, this._sheet.cloneSheet());
        int findFirstRecordLocBySid = hSSFSheet._sheet.findFirstRecordLocBySid(236);
        DrawingRecord drawingRecord = (DrawingRecord) hSSFSheet._sheet.findFirstRecordBySid(236);
        if (drawingRecord != null) {
            hSSFSheet._sheet.getRecords().remove(drawingRecord);
        }
        if (getDrawingPatriarch() != null) {
            HSSFPatriarch createPatriarch = HSSFPatriarch.createPatriarch(getDrawingPatriarch(), hSSFSheet);
            hSSFSheet._sheet.getRecords().add(findFirstRecordLocBySid, createPatriarch.getBoundAggregate());
            hSSFSheet._patriarch = createPatriarch;
        }
        return hSSFSheet;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void createFreezePane(int i2, int i3, int i4, int i5) {
        validateColumn(i2);
        validateRow(i3);
        if (i4 < i2) {
            throw new IllegalArgumentException("leftmostColumn parameter must not be less than colSplit parameter");
        } else if (i5 >= i3) {
            getSheet().createFreezePane(i2, i3, i5, i4);
        } else {
            throw new IllegalArgumentException("topRow parameter must not be less than leftmostColumn parameter");
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void createSplitPane(int i2, int i3, int i4, int i5, int i6) {
        getSheet().createSplitPane(i2, i3, i5, i4, i6);
    }

    public void dumpDrawingRecords(boolean z, PrintWriter printWriter) {
        this._sheet.aggregateDrawingRecords(this._book.getDrawingManager(), false);
        for (EscherRecord escherRecord : ((EscherAggregate) getSheet().findFirstRecordBySid(EscherAggregate.sid)).getEscherRecords()) {
            if (z) {
                printWriter.println(escherRecord);
            } else {
                escherRecord.display(printWriter, 0);
            }
        }
        printWriter.flush();
    }

    public HSSFComment findCellComment(int i2, int i3) {
        HSSFPatriarch drawingPatriarch = getDrawingPatriarch();
        if (drawingPatriarch == null) {
            drawingPatriarch = createDrawingPatriarch();
        }
        return lookForComment(drawingPatriarch, i2, i3);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellAddress getActiveCell() {
        return new CellAddress(this._sheet.getActiveCellRow(), this._sheet.getActiveCellCol());
    }

    public boolean getAlternateExpression() {
        return ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).getAlternateExpression();
    }

    public boolean getAlternateFormula() {
        return ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).getAlternateFormula();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getAutobreaks() {
        return ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).getAutobreaks();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public Map<CellAddress, HSSFComment> getCellComments() {
        HSSFPatriarch drawingPatriarch = getDrawingPatriarch();
        if (drawingPatriarch == null) {
            drawingPatriarch = createDrawingPatriarch();
        }
        TreeMap treeMap = new TreeMap();
        findCellCommentLocations(drawingPatriarch, treeMap);
        return treeMap;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int[] getColumnBreaks() {
        return this._sheet.getPageSettings().getColumnBreaks();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getColumnOutlineLevel(int i2) {
        return this._sheet.getColumnOutlineLevel(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getColumnWidth(int i2) {
        return this._sheet.getColumnWidth(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public float getColumnWidthInPixels(int i2) {
        int columnWidth = getColumnWidth(i2);
        return ((float) columnWidth) / (columnWidth == getDefaultColumnWidth() * 256 ? 32.0f : 36.56f);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public DataValidationHelper getDataValidationHelper() {
        return new HSSFDataValidationHelper(this);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public List<HSSFDataValidation> getDataValidations() {
        DataValidityTable orCreateDataValidityTable = this._sheet.getOrCreateDataValidityTable();
        final ArrayList arrayList = new ArrayList();
        orCreateDataValidityTable.visitContainedRecords(new RecordAggregate.RecordVisitor() {
            /* class org.apache.poi.hssf.usermodel.HSSFSheet.AnonymousClass1 */
            public HSSFEvaluationWorkbook book = HSSFEvaluationWorkbook.create(HSSFSheet.this.getWorkbook());

            @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate.RecordVisitor
            public void visitRecord(Record record) {
                if (record instanceof DVRecord) {
                    DVRecord dVRecord = (DVRecord) record;
                    HSSFDataValidation hSSFDataValidation = new HSSFDataValidation(dVRecord.getCellRangeAddress().copy(), DVConstraint.createDVConstraint(dVRecord, this.book));
                    hSSFDataValidation.setErrorStyle(dVRecord.getErrorStyle());
                    hSSFDataValidation.setEmptyCellAllowed(dVRecord.getEmptyCellAllowed());
                    hSSFDataValidation.setSuppressDropDownArrow(dVRecord.getSuppressDropdownArrow());
                    hSSFDataValidation.createPromptBox(dVRecord.getPromptTitle(), dVRecord.getPromptText());
                    hSSFDataValidation.setShowPromptBox(dVRecord.getShowPromptOnCellSelected());
                    hSSFDataValidation.createErrorBox(dVRecord.getErrorTitle(), dVRecord.getErrorText());
                    hSSFDataValidation.setShowErrorBox(dVRecord.getShowErrorOnInvalidValue());
                    arrayList.add(hSSFDataValidation);
                }
            }
        });
        return arrayList;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getDefaultColumnWidth() {
        return this._sheet.getDefaultColumnWidth();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public short getDefaultRowHeight() {
        return this._sheet.getDefaultRowHeight();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public float getDefaultRowHeightInPoints() {
        return ((float) this._sheet.getDefaultRowHeight()) / 20.0f;
    }

    public boolean getDialog() {
        return ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).getDialog();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getDisplayGuts() {
        return ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).getDisplayGuts();
    }

    public EscherAggregate getDrawingEscherAggregate() {
        this._book.findDrawingGroup();
        if (this._book.getDrawingManager() == null || this._sheet.aggregateDrawingRecords(this._book.getDrawingManager(), false) == -1) {
            return null;
        }
        return (EscherAggregate) this._sheet.findFirstRecordBySid(EscherAggregate.sid);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getFirstRowNum() {
        return this._firstrow;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getFitToPage() {
        return ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).getFitToPage();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getForceFormulaRecalculation() {
        return this._sheet.getUncalced();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getHorizontallyCenter() {
        return this._sheet.getPageSettings().getHCenter().getHCenter();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public List<HSSFHyperlink> getHyperlinkList() {
        ArrayList arrayList = new ArrayList();
        for (RecordBase recordBase : this._sheet.getRecords()) {
            if (recordBase instanceof HyperlinkRecord) {
                arrayList.add(new HSSFHyperlink((HyperlinkRecord) recordBase));
            }
        }
        return arrayList;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getLastRowNum() {
        return this._lastrow;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public short getLeftCol() {
        return this._sheet.getLeftCol();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public double getMargin(short s) {
        if (s == 4) {
            return this._sheet.getPageSettings().getPrintSetup().getHeaderMargin();
        }
        if (s != 5) {
            return this._sheet.getPageSettings().getMargin(s);
        }
        return this._sheet.getPageSettings().getPrintSetup().getFooterMargin();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellRangeAddress getMergedRegion(int i2) {
        return this._sheet.getMergedRegionAt(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public List<CellRangeAddress> getMergedRegions() {
        ArrayList arrayList = new ArrayList();
        int numMergedRegions = this._sheet.getNumMergedRegions();
        for (int i2 = 0; i2 < numMergedRegions; i2++) {
            arrayList.add(this._sheet.getMergedRegionAt(i2));
        }
        return arrayList;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getNumMergedRegions() {
        return this._sheet.getNumMergedRegions();
    }

    public boolean getObjectProtect() {
        return getProtectionBlock().isObjectProtected();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public PaneInformation getPaneInformation() {
        return getSheet().getPaneInformation();
    }

    public short getPassword() {
        return (short) getProtectionBlock().getPasswordHash();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int getPhysicalNumberOfRows() {
        return this._rows.size();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getProtect() {
        return getProtectionBlock().isSheetProtected();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellRangeAddress getRepeatingColumns() {
        return getRepeatingRowsOrColums(false);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellRangeAddress getRepeatingRows() {
        return getRepeatingRowsOrColums(true);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public int[] getRowBreaks() {
        return this._sheet.getPageSettings().getRowBreaks();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getRowSumsBelow() {
        return ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).getRowSumsBelow();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getRowSumsRight() {
        return ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).getRowSumsRight();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getScenarioProtect() {
        return getProtectionBlock().isScenarioProtected();
    }

    public InternalSheet getSheet() {
        return this._sheet;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public String getSheetName() {
        HSSFWorkbook workbook = getWorkbook();
        return workbook.getSheetName(workbook.getSheetIndex(this));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public short getTopRow() {
        return this._sheet.getTopRow();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean getVerticallyCenter() {
        return this._sheet.getPageSettings().getVCenter().getVCenter();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void groupColumn(int i2, int i3) {
        this._sheet.groupColumnRange(i2, i3, true);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void groupRow(int i2, int i3) {
        this._sheet.groupRowRange(i2, i3, true);
    }

    public void insertChartRecords(List<Record> list) {
        this._sheet.getRecords().addAll(this._sheet.findFirstRecordLocBySid(574), list);
    }

    public boolean isActive() {
        return getSheet().getWindowTwo().isActive();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isColumnBroken(int i2) {
        return this._sheet.getPageSettings().isColumnBroken(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isColumnHidden(int i2) {
        return this._sheet.isColumnHidden(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isDisplayFormulas() {
        return this._sheet.isDisplayFormulas();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isDisplayGridlines() {
        return this._sheet.isDisplayGridlines();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isDisplayRowColHeadings() {
        return this._sheet.isDisplayRowColHeadings();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isDisplayZeros() {
        return this._sheet.getWindowTwo().getDisplayZeros();
    }

    public boolean isGridsPrinted() {
        return this._sheet.isGridsPrinted();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isPrintGridlines() {
        return getSheet().getPrintGridlines().getPrintGridlines();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isPrintRowAndColumnHeadings() {
        return getSheet().getPrintHeaders().getPrintHeaders();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isRightToLeft() {
        return this._sheet.getWindowTwo().getArabic();
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isRowBroken(int i2) {
        return this._sheet.getPageSettings().isRowBroken(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public boolean isSelected() {
        return getSheet().getWindowTwo().getSelected();
    }

    @Override // java.lang.Iterable
    public Iterator<Row> iterator() {
        return rowIterator();
    }

    public void preSerialize() {
        HSSFPatriarch hSSFPatriarch = this._patriarch;
        if (hSSFPatriarch != null) {
            hSSFPatriarch.preSerialize();
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void protectSheet(String str) {
        getProtectionBlock().protectSheet(str, true, true);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellRange<HSSFCell> removeArrayFormula(Cell cell) {
        if (cell.getSheet() == this) {
            CellValueRecordInterface cellValueRecord = ((HSSFCell) cell).getCellValueRecord();
            if (cellValueRecord instanceof FormulaRecordAggregate) {
                CellRange<HSSFCell> cellRange = getCellRange(((FormulaRecordAggregate) cellValueRecord).removeArrayFormula(cell.getRowIndex(), cell.getColumnIndex()));
                for (HSSFCell hSSFCell : cellRange) {
                    hSSFCell.setCellType(CellType.BLANK);
                }
                return cellRange;
            }
            throw new IllegalArgumentException(a.b("Cell ", new CellReference(cell).formatAsString(), " is not part of an array formula."));
        }
        throw new IllegalArgumentException("Specified cell does not belong to this sheet.");
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void removeColumnBreak(int i2) {
        this._sheet.getPageSettings().removeColumnBreak(i2);
    }

    public void removeHyperlink(HSSFHyperlink hSSFHyperlink) {
        removeHyperlink(hSSFHyperlink.record);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void removeMergedRegion(int i2) {
        this._sheet.removeMergedRegion(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void removeMergedRegions(Collection<Integer> collection) {
        for (Integer num : new TreeSet(collection).descendingSet()) {
            this._sheet.removeMergedRegion(num.intValue());
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void removeRow(Row row) {
        HSSFRow hSSFRow = (HSSFRow) row;
        if (row.getSheet() == this) {
            Iterator it = row.iterator();
            while (it.hasNext()) {
                HSSFCell hSSFCell = (HSSFCell) ((Cell) it.next());
                if (hSSFCell.isPartOfArrayFormulaGroup()) {
                    StringBuilder b2 = a.b("Row[rownum=");
                    b2.append(row.getRowNum());
                    b2.append("] contains cell(s) included in a multi-cell array formula. You cannot change part of an array.");
                    hSSFCell.notifyArrayFormulaChanging(b2.toString());
                }
            }
            if (this._rows.size() > 0) {
                if (this._rows.remove(Integer.valueOf(row.getRowNum())) == row) {
                    if (hSSFRow.getRowNum() == getLastRowNum()) {
                        this._lastrow = findLastRow(this._lastrow);
                    }
                    if (hSSFRow.getRowNum() == getFirstRowNum()) {
                        this._firstrow = findFirstRow(this._firstrow);
                    }
                    this._sheet.removeRow(hSSFRow.getRowRecord());
                    return;
                }
                throw new IllegalArgumentException("Specified row does not belong to this sheet");
            }
            return;
        }
        throw new IllegalArgumentException("Specified row does not belong to this sheet");
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void removeRowBreak(int i2) {
        this._sheet.getPageSettings().removeRowBreak(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public Iterator<Row> rowIterator() {
        return this._rows.values().iterator();
    }

    public void setActive(boolean z) {
        getSheet().getWindowTwo().setActive(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setActiveCell(CellAddress cellAddress) {
        this._sheet.setActiveCellRow(cellAddress.getRow());
        this._sheet.setActiveCellCol((short) cellAddress.getColumn());
    }

    public void setAlternativeExpression(boolean z) {
        ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).setAlternateExpression(z);
    }

    public void setAlternativeFormula(boolean z) {
        ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).setAlternateFormula(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public CellRange<HSSFCell> setArrayFormula(String str, CellRangeAddress cellRangeAddress) {
        Ptg[] parse = HSSFFormulaParser.parse(str, this._workbook, FormulaType.ARRAY, this._workbook.getSheetIndex(this));
        CellRange<HSSFCell> cellRange = getCellRange(cellRangeAddress);
        for (HSSFCell hSSFCell : cellRange) {
            hSSFCell.setCellArrayFormula(cellRangeAddress);
        }
        ((FormulaRecordAggregate) cellRange.getTopLeftCell().getCellValueRecord()).setArrayFormula(cellRangeAddress, parse);
        return cellRange;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setAutobreaks(boolean z) {
        ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).setAutobreaks(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setColumnBreak(int i2) {
        short s = (short) i2;
        validateColumn(s);
        this._sheet.getPageSettings().setColumnBreak(s, 0, (short) SpreadsheetVersion.EXCEL97.getLastRowIndex());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setColumnGroupCollapsed(int i2, boolean z) {
        this._sheet.setColumnGroupCollapsed(i2, z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setColumnHidden(int i2, boolean z) {
        this._sheet.setColumnHidden(i2, z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setColumnWidth(int i2, int i3) {
        this._sheet.setColumnWidth(i2, i3);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDefaultColumnStyle(int i2, CellStyle cellStyle) {
        this._sheet.setDefaultColumnStyle(i2, ((HSSFCellStyle) cellStyle).getIndex());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDefaultColumnWidth(int i2) {
        this._sheet.setDefaultColumnWidth(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDefaultRowHeight(short s) {
        this._sheet.setDefaultRowHeight(s);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDefaultRowHeightInPoints(float f2) {
        this._sheet.setDefaultRowHeight((short) ((int) (f2 * 20.0f)));
    }

    public void setDialog(boolean z) {
        ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).setDialog(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDisplayFormulas(boolean z) {
        this._sheet.setDisplayFormulas(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDisplayGridlines(boolean z) {
        this._sheet.setDisplayGridlines(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDisplayGuts(boolean z) {
        ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).setDisplayGuts(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDisplayRowColHeadings(boolean z) {
        this._sheet.setDisplayRowColHeadings(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setDisplayZeros(boolean z) {
        this._sheet.getWindowTwo().setDisplayZeros(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setFitToPage(boolean z) {
        ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).setFitToPage(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setForceFormulaRecalculation(boolean z) {
        this._sheet.setUncalced(z);
    }

    public void setGridsPrinted(boolean z) {
        this._sheet.setGridsPrinted(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setHorizontallyCenter(boolean z) {
        this._sheet.getPageSettings().getHCenter().setHCenter(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setMargin(short s, double d2) {
        if (s == 4) {
            this._sheet.getPageSettings().getPrintSetup().setHeaderMargin(d2);
        } else if (s != 5) {
            this._sheet.getPageSettings().setMargin(s, d2);
        } else {
            this._sheet.getPageSettings().getPrintSetup().setFooterMargin(d2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setPrintGridlines(boolean z) {
        getSheet().getPrintGridlines().setPrintGridlines(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setPrintRowAndColumnHeadings(boolean z) {
        getSheet().getPrintHeaders().setPrintHeaders(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRepeatingColumns(CellRangeAddress cellRangeAddress) {
        setRepeatingRowsAndColumns(getRepeatingRows(), cellRangeAddress);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRepeatingRows(CellRangeAddress cellRangeAddress) {
        setRepeatingRowsAndColumns(cellRangeAddress, getRepeatingColumns());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRightToLeft(boolean z) {
        this._sheet.getWindowTwo().setArabic(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRowBreak(int i2) {
        validateRow(i2);
        this._sheet.getPageSettings().setRowBreak(i2, 0, 255);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRowGroupCollapsed(int i2, boolean z) {
        if (z) {
            this._sheet.getRowsAggregate().collapseRow(i2);
        } else {
            this._sheet.getRowsAggregate().expandRow(i2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRowSumsBelow(boolean z) {
        WSBoolRecord wSBoolRecord = (WSBoolRecord) this._sheet.findFirstRecordBySid(129);
        wSBoolRecord.setRowSumsBelow(z);
        wSBoolRecord.setAlternateExpression(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setRowSumsRight(boolean z) {
        ((WSBoolRecord) this._sheet.findFirstRecordBySid(129)).setRowSumsRight(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setSelected(boolean z) {
        getSheet().getWindowTwo().setSelected(z);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setVerticallyCenter(boolean z) {
        this._sheet.getPageSettings().getVCenter().setVCenter(z);
    }

    public void setZoom(int i2, int i3) {
        if (i2 < 1 || i2 > 65535) {
            throw new IllegalArgumentException("Numerator must be greater than 0 and less than 65536");
        } else if (i3 < 1 || i3 > 65535) {
            throw new IllegalArgumentException("Denominator must be greater than 0 and less than 65536");
        } else {
            SCLRecord sCLRecord = new SCLRecord();
            sCLRecord.setNumerator((short) i2);
            sCLRecord.setDenominator((short) i3);
            getSheet().setSCLRecord(sCLRecord);
        }
    }

    public void shiftMerged(int i2, int i3, int i4, boolean z) {
        new HSSFRowShifter(this).shiftMergedRegions(i2, i3, i4);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void shiftRows(int i2, int i3, int i4) {
        shiftRows(i2, i3, i4, false, false);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void showInPane(int i2, int i3) {
        int lastRowIndex = SpreadsheetVersion.EXCEL97.getLastRowIndex();
        if (i2 <= lastRowIndex) {
            showInPane((short) i2, (short) i3);
            return;
        }
        throw new IllegalArgumentException(a.c("Maximum row number is ", lastRowIndex));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void ungroupColumn(int i2, int i3) {
        this._sheet.groupColumnRange(i2, i3, false);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void ungroupRow(int i2, int i3) {
        this._sheet.groupRowRange(i2, i3, false);
    }

    public void validateColumn(int i2) {
        int lastColumnIndex = SpreadsheetVersion.EXCEL97.getLastColumnIndex();
        if (i2 > lastColumnIndex) {
            throw new IllegalArgumentException(a.c("Maximum column number is ", lastColumnIndex));
        } else if (i2 < 0) {
            throw new IllegalArgumentException("Minimum column number is 0");
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void validateMergedRegions() {
        checkForMergedRegionsIntersectingArrayFormulas();
        checkForIntersectingMergedRegions();
    }

    public void validateRow(int i2) {
        int lastRowIndex = SpreadsheetVersion.EXCEL97.getLastRowIndex();
        if (i2 > lastRowIndex) {
            throw new IllegalArgumentException(a.c("Maximum row number is ", lastRowIndex));
        } else if (i2 < 0) {
            throw new IllegalArgumentException("Minumum row number is 0");
        }
    }

    private int addMergedRegion(CellRangeAddress cellRangeAddress, boolean z) {
        if (cellRangeAddress.getNumberOfCells() >= 2) {
            cellRangeAddress.validate(SpreadsheetVersion.EXCEL97);
            if (z) {
                validateArrayFormulas(cellRangeAddress);
                validateMergedRegions(cellRangeAddress);
            }
            return this._sheet.addMergedRegion(cellRangeAddress.getFirstRow(), cellRangeAddress.getFirstColumn(), cellRangeAddress.getLastRow(), cellRangeAddress.getLastColumn());
        }
        StringBuilder b2 = a.b("Merged region ");
        b2.append(cellRangeAddress.formatAsString());
        b2.append(" must contain 2 or more cells");
        throw new IllegalArgumentException(b2.toString());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void autoSizeColumn(int i2, boolean z) {
        double columnWidth = SheetUtil.getColumnWidth(this, i2, z);
        if (columnWidth != -1.0d) {
            double d2 = columnWidth * 256.0d;
            double d3 = (double) 65280;
            if (d2 > d3) {
                d2 = d3;
            }
            setColumnWidth(i2, (int) d2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFPatriarch createDrawingPatriarch() {
        HSSFPatriarch patriarch = getPatriarch(true);
        this._patriarch = patriarch;
        return patriarch;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFRow createRow(int i2) {
        HSSFRow hSSFRow = new HSSFRow(this._workbook, this, i2);
        hSSFRow.setHeight(getDefaultRowHeight());
        hSSFRow.getRowRecord().setBadFontHeight(false);
        addRow(hSSFRow, true);
        return hSSFRow;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFComment getCellComment(CellAddress cellAddress) {
        return findCellComment(cellAddress.getRow(), cellAddress.getColumn());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFCellStyle getColumnStyle(int i2) {
        short xFIndexForColAt = this._sheet.getXFIndexForColAt((short) i2);
        if (xFIndexForColAt == 15) {
            return null;
        }
        return new HSSFCellStyle(xFIndexForColAt, this._book.getExFormatAt(xFIndexForColAt), this._book);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFPatriarch getDrawingPatriarch() {
        HSSFPatriarch patriarch = getPatriarch(false);
        this._patriarch = patriarch;
        return patriarch;
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFFooter getFooter() {
        return new HSSFFooter(this._sheet.getPageSettings());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFHeader getHeader() {
        return new HSSFHeader(this._sheet.getPageSettings());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFPrintSetup getPrintSetup() {
        return new HSSFPrintSetup(this._sheet.getPageSettings().getPrintSetup());
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFRow getRow(int i2) {
        return this._rows.get(Integer.valueOf(i2));
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFSheetConditionalFormatting getSheetConditionalFormatting() {
        return new HSSFSheetConditionalFormatting(this);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFWorkbook getWorkbook() {
        return this._workbook;
    }

    public void removeHyperlink(HyperlinkRecord hyperlinkRecord) {
        Iterator<RecordBase> it = this._sheet.getRecords().iterator();
        while (it.hasNext()) {
            RecordBase next = it.next();
            if ((next instanceof HyperlinkRecord) && hyperlinkRecord == ((HyperlinkRecord) next)) {
                it.remove();
                return;
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFAutoFilter setAutoFilter(CellRangeAddress cellRangeAddress) {
        InternalWorkbook workbook = this._workbook.getWorkbook();
        int sheetIndex = this._workbook.getSheetIndex(this);
        int i2 = sheetIndex + 1;
        NameRecord specificBuiltinRecord = workbook.getSpecificBuiltinRecord((byte) 13, i2);
        if (specificBuiltinRecord == null) {
            specificBuiltinRecord = workbook.createBuiltInName((byte) 13, i2);
        }
        int firstRow = cellRangeAddress.getFirstRow();
        if (firstRow == -1) {
            firstRow = 0;
        }
        specificBuiltinRecord.setNameDefinition(new Ptg[]{new Area3DPtg(firstRow, cellRangeAddress.getLastRow(), cellRangeAddress.getFirstColumn(), cellRangeAddress.getLastColumn(), false, false, false, false, sheetIndex)});
        AutoFilterInfoRecord autoFilterInfoRecord = new AutoFilterInfoRecord();
        autoFilterInfoRecord.setNumEntries((short) ((cellRangeAddress.getLastColumn() + 1) - cellRangeAddress.getFirstColumn()));
        this._sheet.getRecords().add(this._sheet.findFirstRecordLocBySid(512), autoFilterInfoRecord);
        HSSFPatriarch createDrawingPatriarch = createDrawingPatriarch();
        int firstColumn = cellRangeAddress.getFirstColumn();
        int lastColumn = cellRangeAddress.getLastColumn();
        while (firstColumn <= lastColumn) {
            short s = (short) firstColumn;
            firstColumn++;
            createDrawingPatriarch.createComboBox(new HSSFClientAnchor(0, 0, 0, 0, s, firstRow, (short) firstColumn, firstRow + 1));
        }
        return new HSSFAutoFilter(this);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void shiftRows(int i2, int i3, int i4, boolean z, boolean z2) {
        shiftRows(i2, i3, i4, z, z2, true);
    }

    private void validateMergedRegions(CellRangeAddress cellRangeAddress) {
        for (CellRangeAddress cellRangeAddress2 : getMergedRegions()) {
            if (cellRangeAddress2.intersects(cellRangeAddress)) {
                StringBuilder b2 = a.b("Cannot add merged region ");
                b2.append(cellRangeAddress.formatAsString());
                b2.append(" to sheet because it overlaps with an existing merged region (");
                b2.append(cellRangeAddress2.formatAsString());
                b2.append(").");
                throw new IllegalStateException(b2.toString());
            }
        }
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFHyperlink getHyperlink(int i2, int i3) {
        for (RecordBase recordBase : this._sheet.getRecords()) {
            if (recordBase instanceof HyperlinkRecord) {
                HyperlinkRecord hyperlinkRecord = (HyperlinkRecord) recordBase;
                if (hyperlinkRecord.getFirstColumn() == i3 && hyperlinkRecord.getFirstRow() == i2) {
                    return new HSSFHyperlink(hyperlinkRecord);
                }
            }
        }
        return null;
    }

    public void shiftRows(int i2, int i3, int i4, boolean z, boolean z2, boolean z3) {
        int i5;
        int i6;
        HSSFComment hSSFComment;
        int row;
        if (i3 >= i2) {
            if (i4 < 0) {
                i6 = 1;
                i5 = i2;
            } else if (i4 > 0) {
                i6 = -1;
                i5 = i3;
            } else {
                return;
            }
            HSSFRowShifter hSSFRowShifter = new HSSFRowShifter(this);
            if (z3) {
                for (HSSFShape hSSFShape : createDrawingPatriarch().getChildren()) {
                    if ((hSSFShape instanceof HSSFComment) && i2 <= (row = (hSSFComment = (HSSFComment) hSSFShape).getRow()) && row <= i3) {
                        hSSFComment.setRow(clip(row + i4));
                    }
                }
            }
            hSSFRowShifter.shiftMergedRegions(i2, i3, i4);
            this._sheet.getPageSettings().shiftRowBreaks(i2, i3, i4);
            int i7 = i2 + i4;
            int i8 = i3 + i4;
            for (HSSFHyperlink hSSFHyperlink : getHyperlinkList()) {
                int firstRow = hSSFHyperlink.getFirstRow();
                int lastRow = hSSFHyperlink.getLastRow();
                if (i7 <= firstRow && firstRow <= i8 && i8 <= lastRow && lastRow <= i8) {
                    removeHyperlink(hSSFHyperlink);
                }
            }
            while (i5 >= i2 && i5 <= i3 && i5 >= 0 && i5 < 65536) {
                HSSFRow row2 = getRow(i5);
                if (row2 != null) {
                    notifyRowShifting(row2);
                }
                int i9 = i5 + i4;
                HSSFRow row3 = getRow(i9);
                if (row3 == null) {
                    row3 = createRow(i9);
                }
                row3.removeAllCells();
                if (row2 != null) {
                    if (z) {
                        row3.setHeight(row2.getHeight());
                    }
                    if (z2) {
                        row2.setHeight(255);
                    }
                    Iterator<Cell> cellIterator = row2.cellIterator();
                    while (cellIterator.hasNext()) {
                        HSSFCell hSSFCell = (HSSFCell) cellIterator.next();
                        HSSFHyperlink hyperlink = hSSFCell.getHyperlink();
                        row2.removeCell(hSSFCell);
                        CellValueRecordInterface cellValueRecord = hSSFCell.getCellValueRecord();
                        cellValueRecord.setRow(i9);
                        row3.createCellFromRecord(cellValueRecord);
                        this._sheet.addValueRecord(i9, cellValueRecord);
                        if (hyperlink != null) {
                            hyperlink.setFirstRow(hyperlink.getFirstRow() + i4);
                            hyperlink.setLastRow(hyperlink.getLastRow() + i4);
                        }
                    }
                    row2.removeAllCells();
                }
                i5 += i6;
            }
            if (i4 > 0) {
                if (i2 == this._firstrow) {
                    this._firstrow = Math.max(i7, 0);
                    int i10 = i2 + 1;
                    while (true) {
                        if (i10 >= i7) {
                            break;
                        } else if (getRow(i10) != null) {
                            this._firstrow = i10;
                            break;
                        } else {
                            i10++;
                        }
                    }
                }
                if (i8 > this._lastrow) {
                    this._lastrow = Math.min(i8, SpreadsheetVersion.EXCEL97.getLastRowIndex());
                }
            } else {
                if (i7 < this._firstrow) {
                    this._firstrow = Math.max(i7, 0);
                }
                if (i3 == this._lastrow) {
                    this._lastrow = Math.min(i8, SpreadsheetVersion.EXCEL97.getLastRowIndex());
                    int i11 = i3 - 1;
                    while (true) {
                        if (i11 <= i8) {
                            break;
                        } else if (getRow(i11) != null) {
                            this._lastrow = i11;
                            break;
                        } else {
                            i11--;
                        }
                    }
                }
            }
            int sheetIndex = this._workbook.getSheetIndex(this);
            String sheetName = this._workbook.getSheetName(sheetIndex);
            short checkExternSheet = this._book.checkExternSheet(sheetIndex);
            FormulaShifter createForRowShift = FormulaShifter.createForRowShift(checkExternSheet, sheetName, i2, i3, i4, SpreadsheetVersion.EXCEL97);
            this._sheet.updateFormulasAfterCellShift(createForRowShift, checkExternSheet);
            int numberOfSheets = this._workbook.getNumberOfSheets();
            for (int i12 = 0; i12 < numberOfSheets; i12++) {
                InternalSheet sheet = this._workbook.getSheetAt(i12).getSheet();
                if (sheet != this._sheet) {
                    sheet.updateFormulasAfterCellShift(createForRowShift, this._book.checkExternSheet(i12));
                }
            }
            this._workbook.getWorkbook().updateNamesAfterCellShift(createForRowShift);
            return;
        }
        throw new IllegalArgumentException("startRow must be less than or equal to endRow. To shift rows up, use n<0.");
    }

    private void showInPane(short s, short s2) {
        this._sheet.setTopRow(s);
        this._sheet.setLeftCol(s2);
    }

    public HSSFSheet(HSSFWorkbook hSSFWorkbook, InternalSheet internalSheet) {
        this._sheet = internalSheet;
        this._rows = new TreeMap<>();
        this._workbook = hSSFWorkbook;
        this._book = hSSFWorkbook.getWorkbook();
        setPropertiesFromSheet(internalSheet);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void createFreezePane(int i2, int i3) {
        createFreezePane(i2, i3, i2, i3);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public void setZoom(int i2) {
        setZoom(i2, 100);
    }

    @Override // org.apache.poi.ss.usermodel.Sheet
    public HSSFHyperlink getHyperlink(CellAddress cellAddress) {
        return getHyperlink(cellAddress.getRow(), cellAddress.getColumn());
    }
}
