package org.apache.poi.hssf.usermodel;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.nio.charset.Charset;
import java.security.GeneralSecurityException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;
import org.apache.lucene.codecs.lucene3x.Lucene3xFields;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.POIDocument;
import org.apache.poi.ddf.EscherBSERecord;
import org.apache.poi.ddf.EscherBitmapBlip;
import org.apache.poi.ddf.EscherBlipRecord;
import org.apache.poi.ddf.EscherMetafileBlip;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.hpsf.ClassID;
import org.apache.poi.hpsf.DocumentSummaryInformation;
import org.apache.poi.hpsf.SummaryInformation;
import org.apache.poi.hslf.usermodel.HSLFSlideShow;
import org.apache.poi.hssf.OldExcelFormatException;
import org.apache.poi.hssf.model.HSSFFormulaParser;
import org.apache.poi.hssf.model.InternalSheet;
import org.apache.poi.hssf.model.InternalWorkbook;
import org.apache.poi.hssf.model.RecordStream;
import org.apache.poi.hssf.model.WorkbookRecordList;
import org.apache.poi.hssf.record.AbstractEscherHolderRecord;
import org.apache.poi.hssf.record.DrawingGroupRecord;
import org.apache.poi.hssf.record.FilePassRecord;
import org.apache.poi.hssf.record.LabelRecord;
import org.apache.poi.hssf.record.LabelSSTRecord;
import org.apache.poi.hssf.record.NameRecord;
import org.apache.poi.hssf.record.RecalcIdRecord;
import org.apache.poi.hssf.record.Record;
import org.apache.poi.hssf.record.RecordFactory;
import org.apache.poi.hssf.record.UnknownRecord;
import org.apache.poi.hssf.record.aggregates.RecordAggregate;
import org.apache.poi.hssf.record.common.UnicodeString;
import org.apache.poi.hssf.record.crypto.Biff8DecryptingStream;
import org.apache.poi.hssf.record.crypto.Biff8EncryptionKey;
import org.apache.poi.hssf.util.CellReference;
import org.apache.poi.poifs.crypt.ChunkedCipherOutputStream;
import org.apache.poi.poifs.crypt.Decryptor;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.crypt.EncryptionMode;
import org.apache.poi.poifs.crypt.EncryptionVerifier;
import org.apache.poi.poifs.crypt.Encryptor;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentNode;
import org.apache.poi.poifs.filesystem.EntryUtils;
import org.apache.poi.poifs.filesystem.FilteringDirectoryNode;
import org.apache.poi.poifs.filesystem.NPOIFSDocument;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.Ole10Native;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.FormulaShifter;
import org.apache.poi.ss.formula.FormulaType;
import org.apache.poi.ss.formula.SheetNameFormatter;
import org.apache.poi.ss.formula.ptg.IntPtg;
import org.apache.poi.ss.formula.udf.AggregatingUDFFinder;
import org.apache.poi.ss.formula.udf.IndexedUDFFinder;
import org.apache.poi.ss.formula.udf.UDFFinder;
import org.apache.poi.ss.usermodel.Name;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.SheetVisibility;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.util.Configurator;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianByteArrayInputStream;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Removal;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.apache.xerces.impl.xpath.XPath;

public final class HSSFWorkbook extends POIDocument implements Workbook {
    public static final Pattern COMMA_PATTERN = Pattern.compile(XSSFDataValidationConstraint.LIST_SEPARATOR);
    public static final int DEBUG = 1;
    public static final int INITIAL_CAPACITY = Configurator.getIntValue("HSSFWorkbook.SheetInitialCapacity", 3);
    public static final int MAX_STYLES = 4030;
    public static final POILogger log = POILogFactory.getLogger(HSSFWorkbook.class);
    public List<HSSFSheet> _sheets;
    public UDFFinder _udfFinder;
    public Map<Short, HSSFFont> fonts;
    public HSSFDataFormat formatter;
    public Row.MissingCellPolicy missingCellPolicy;
    public ArrayList<HSSFName> names;
    public boolean preserveNodes;
    public InternalWorkbook workbook;

    public final class SheetIterator<T extends Sheet> implements Iterator<T> {
        public T cursor = null;
        public final Iterator<T> it;

        public SheetIterator() {
            this.it = HSSFWorkbook.this._sheets.iterator();
        }

        public boolean hasNext() {
            return this.it.hasNext();
        }

        public void remove() {
            throw new UnsupportedOperationException("remove method not supported on HSSFWorkbook.iterator(). Use Sheet.removeSheetAt(int) instead.");
        }

        @Override // java.util.Iterator
        public T next() {
            T next = this.it.next();
            this.cursor = next;
            return next;
        }
    }

    public static final class SheetRecordCollector implements RecordAggregate.RecordVisitor {
        public List<Record> _list = new ArrayList(128);
        public int _totalSize = 0;

        public int getTotalSize() {
            return this._totalSize;
        }

        public int serialize(int i2, byte[] bArr) {
            int i3 = 0;
            for (Record record : this._list) {
                i3 += record.serialize(i2 + i3, bArr);
            }
            return i3;
        }

        @Override // org.apache.poi.hssf.record.aggregates.RecordAggregate.RecordVisitor
        public void visitRecord(Record record) {
            this._list.add(record);
            this._totalSize = record.getRecordSize() + this._totalSize;
        }
    }

    public HSSFWorkbook() {
        this(InternalWorkbook.createWorkbook());
    }

    private void convertLabelRecords(List<Record> list, int i2) {
        if (log.check(1)) {
            log.log(1, "convertLabelRecords called");
        }
        while (i2 < list.size()) {
            Record record = list.get(i2);
            if (record.getSid() == 516) {
                LabelRecord labelRecord = (LabelRecord) record;
                list.remove(i2);
                LabelSSTRecord labelSSTRecord = new LabelSSTRecord();
                int addSSTString = this.workbook.addSSTString(new UnicodeString(labelRecord.getValue()));
                labelSSTRecord.setRow(labelRecord.getRow());
                labelSSTRecord.setColumn(labelRecord.getColumn());
                labelSSTRecord.setXFIndex(labelRecord.getXFIndex());
                labelSSTRecord.setSSTIndex(addSSTString);
                list.add(i2, labelSSTRecord);
            }
            i2++;
        }
        if (log.check(1)) {
            log.log(1, "convertLabelRecords exit");
        }
    }

    public static HSSFWorkbook create(InternalWorkbook internalWorkbook) {
        return new HSSFWorkbook(internalWorkbook);
    }

    public static Map<String, ClassID> getOleMap() {
        HashMap hashMap = new HashMap();
        hashMap.put(HSLFSlideShow.POWERPOINT_DOCUMENT, ClassID.PPT_SHOW);
        for (String str : InternalWorkbook.WORKBOOK_DIR_ENTRY_NAMES) {
            hashMap.put(str, ClassID.XLS_WORKBOOK);
        }
        return hashMap;
    }

    private HSSFSheet[] getSheets() {
        HSSFSheet[] hSSFSheetArr = new HSSFSheet[this._sheets.size()];
        this._sheets.toArray(hSSFSheetArr);
        return hSSFSheetArr;
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x0048  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0060  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x0086 A[LOOP:0: B:13:0x0033->B:20:0x0086, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x0085 A[SYNTHETIC] */
    private String getUniqueSheetName(String str) {
        int i2;
        String num;
        String str2;
        int lastIndexOf = str.lastIndexOf(40);
        if (lastIndexOf > 0 && str.endsWith(")")) {
            try {
                i2 = Integer.parseInt(str.substring(lastIndexOf + 1, str.length() - 1).trim()) + 1;
                try {
                    str = str.substring(0, lastIndexOf).trim();
                } catch (NumberFormatException unused) {
                }
            } catch (NumberFormatException unused2) {
            }
            while (true) {
                int i3 = i2 + 1;
                num = Integer.toString(i2);
                if (num.length() + str.length() + 2 >= 31) {
                    str2 = str + " (" + num + ")";
                } else {
                    StringBuilder sb = new StringBuilder();
                    sb.append(str.substring(0, (31 - num.length()) - 2));
                    sb.append("(");
                    str2 = a.a(sb, num, ")");
                }
                if (this.workbook.getSheetIndex(str2) != -1) {
                    return str2;
                }
                i2 = i3;
            }
        }
        i2 = 2;
        while (true) {
            int i32 = i2 + 1;
            num = Integer.toString(i2);
            if (num.length() + str.length() + 2 >= 31) {
            }
            if (this.workbook.getSheetIndex(str2) != -1) {
            }
            i2 = i32;
        }
    }

    public static String getWorkbookDirEntryName(DirectoryNode directoryNode) {
        String[] strArr = InternalWorkbook.WORKBOOK_DIR_ENTRY_NAMES;
        for (String str : strArr) {
            try {
                directoryNode.getEntry(str);
                return str;
            } catch (FileNotFoundException unused) {
            }
        }
        try {
            directoryNode.getEntry("EncryptedPackage");
            throw new EncryptedDocumentException("The supplied spreadsheet seems to be an Encrypted .xlsx file. It must be decrypted before use by XSSF, it cannot be used by HSSF");
        } catch (FileNotFoundException unused2) {
            directoryNode.getEntry(InternalWorkbook.OLD_WORKBOOK_DIR_ENTRY_NAME);
            throw new OldExcelFormatException("The supplied spreadsheet seems to be Excel 5.0/7.0 (BIFF5) format. POI only supports BIFF8 format (from Excel versions 97/2000/XP/2003)");
        } catch (FileNotFoundException unused3) {
            StringBuilder b2 = a.b("The supplied POIFSFileSystem does not contain a BIFF8 'Workbook' entry. Is it really an excel file? Had: ");
            b2.append(directoryNode.getEntryNames());
            throw new IllegalArgumentException(b2.toString());
        }
    }

    private void searchForPictures(List<EscherRecord> list, List<HSSFPictureData> list2) {
        EscherBlipRecord blipRecord;
        for (EscherRecord escherRecord : list) {
            if ((escherRecord instanceof EscherBSERecord) && (blipRecord = ((EscherBSERecord) escherRecord).getBlipRecord()) != null) {
                list2.add(new HSSFPictureData(blipRecord));
            }
            searchForPictures(escherRecord.getChildRecords(), list2);
        }
    }

    private void setPropertiesFromWorkbook(InternalWorkbook internalWorkbook) {
        this.workbook = internalWorkbook;
    }

    private void updateActiveSheetAfterSheetReorder(int i2, int i3) {
        int activeSheetIndex = getActiveSheetIndex();
        if (activeSheetIndex == i2) {
            setActiveSheet(i3);
        } else if (activeSheetIndex < i2 && activeSheetIndex < i3) {
        } else {
            if (activeSheetIndex > i2 && activeSheetIndex > i3) {
                return;
            }
            if (i3 > i2) {
                setActiveSheet(activeSheetIndex - 1);
            } else {
                setActiveSheet(activeSheetIndex + 1);
            }
        }
    }

    private void updateEncryptionInfo() {
        readProperties();
        FilePassRecord filePassRecord = (FilePassRecord) this.workbook.findFirstRecordBySid(47);
        String currentUserPassword = Biff8EncryptionKey.getCurrentUserPassword();
        WorkbookRecordList workbookRecordList = this.workbook.getWorkbookRecordList();
        if (currentUserPassword != null) {
            if (filePassRecord == null) {
                filePassRecord = new FilePassRecord(EncryptionMode.cryptoAPI);
                workbookRecordList.add(1, filePassRecord);
            }
            EncryptionInfo encryptionInfo = filePassRecord.getEncryptionInfo();
            EncryptionVerifier verifier = encryptionInfo.getVerifier();
            byte[] encryptedVerifier = verifier.getEncryptedVerifier();
            Decryptor decryptor = encryptionInfo.getDecryptor();
            Encryptor encryptor = encryptionInfo.getEncryptor();
            if (encryptedVerifier != null) {
                try {
                    if (decryptor.verifyPassword(currentUserPassword)) {
                        encryptor.confirmPassword(currentUserPassword, null, null, decryptor.getVerifier(), verifier.getSalt(), null);
                        return;
                    }
                } catch (GeneralSecurityException e2) {
                    throw new EncryptedDocumentException("can't validate/update encryption setting", e2);
                }
            }
            encryptor.confirmPassword(currentUserPassword);
        } else if (filePassRecord != null) {
            workbookRecordList.remove(filePassRecord);
        }
    }

    private void updateNamedRangesAfterSheetReorder(int i2, int i3) {
        Iterator<HSSFName> it = this.names.iterator();
        while (it.hasNext()) {
            HSSFName next = it.next();
            int sheetIndex = next.getSheetIndex();
            if (sheetIndex != -1) {
                if (sheetIndex == i2) {
                    next.setSheetIndex(i3);
                } else if (i3 <= sheetIndex && sheetIndex < i2) {
                    next.setSheetIndex(sheetIndex + 1);
                } else if (i2 < sheetIndex && sheetIndex <= i3) {
                    next.setSheetIndex(sheetIndex - 1);
                }
            }
        }
    }

    private void validateSheetIndex(int i2) {
        int size = this._sheets.size() - 1;
        if (i2 < 0 || i2 > size) {
            String b2 = a.b("(0..", size, ")");
            if (size == -1) {
                b2 = "(no sheets)";
            }
            throw new IllegalArgumentException("Sheet index (" + i2 + ") is out of range " + b2);
        }
    }

    public int addOlePackage(POIFSFileSystem pOIFSFileSystem, String str, String str2, String str3) {
        DirectoryNode root = pOIFSFileSystem.getRoot();
        Iterator<Map.Entry<String, ClassID>> it = getOleMap().entrySet().iterator();
        while (true) {
            if (!it.hasNext()) {
                break;
            }
            Map.Entry<String, ClassID> next = it.next();
            if (root.hasEntry(next.getKey())) {
                root.setStorageClsid(next.getValue());
                break;
            }
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        pOIFSFileSystem.writeFilesystem(byteArrayOutputStream);
        return addOlePackage(byteArrayOutputStream.toByteArray(), str, str2, str3);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v7, resolved type: org.apache.poi.ddf.EscherBitmapBlip */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x005d  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0069  */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x006f  */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x0075  */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x007b  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x0081  */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x0087  */
    @Override // org.apache.poi.ss.usermodel.Workbook
    public int addPicture(byte[] bArr, int i2) {
        int i3;
        short s;
        EscherMetafileBlip escherMetafileBlip;
        initDrawings();
        try {
            byte[] digest = MessageDigest.getInstance("MD5").digest(bArr);
            if (i2 != 2) {
                if (i2 != 3) {
                    EscherBitmapBlip escherBitmapBlip = new EscherBitmapBlip();
                    escherBitmapBlip.setUID(digest);
                    escherBitmapBlip.setMarker((byte) -1);
                    escherBitmapBlip.setPictureData(bArr);
                    i3 = bArr.length + 25;
                    s = 255;
                    escherMetafileBlip = escherBitmapBlip;
                    escherMetafileBlip.setRecordId((short) (i2 - 4072));
                    switch (i2) {
                        case 2:
                            escherMetafileBlip.setOptions(HSSFPictureData.MSOBI_EMF);
                            break;
                        case 3:
                            escherMetafileBlip.setOptions(HSSFPictureData.MSOBI_WMF);
                            break;
                        case 4:
                            escherMetafileBlip.setOptions(HSSFPictureData.MSOBI_PICT);
                            break;
                        case 5:
                            escherMetafileBlip.setOptions(HSSFPictureData.MSOBI_JPEG);
                            break;
                        case 6:
                            escherMetafileBlip.setOptions(HSSFPictureData.MSOBI_PNG);
                            break;
                        case 7:
                            escherMetafileBlip.setOptions(HSSFPictureData.MSOBI_DIB);
                            break;
                        default:
                            throw new IllegalStateException(a.c("Unexpected picture format: ", i2));
                    }
                    EscherBSERecord escherBSERecord = new EscherBSERecord();
                    escherBSERecord.setRecordId(EscherBSERecord.RECORD_ID);
                    escherBSERecord.setOptions((short) (2 | (i2 << 4)));
                    byte b2 = (byte) i2;
                    escherBSERecord.setBlipTypeMacOS(b2);
                    escherBSERecord.setBlipTypeWin32(b2);
                    escherBSERecord.setUid(digest);
                    escherBSERecord.setTag(s);
                    escherBSERecord.setSize(i3);
                    escherBSERecord.setRef(0);
                    escherBSERecord.setOffset(0);
                    escherBSERecord.setBlipRecord(escherMetafileBlip);
                    return this.workbook.addBSERecord(escherBSERecord);
                } else if (LittleEndian.getInt(bArr) == -1698247209) {
                    byte[] bArr2 = new byte[(bArr.length - 22)];
                    System.arraycopy(bArr, 22, bArr2, 0, bArr.length - 22);
                    bArr = bArr2;
                }
            }
            EscherMetafileBlip escherMetafileBlip2 = new EscherMetafileBlip();
            escherMetafileBlip2.setUID(digest);
            escherMetafileBlip2.setPictureData(bArr);
            escherMetafileBlip2.setFilter((byte) -2);
            i3 = escherMetafileBlip2.getCompressedSize() + 58;
            s = 0;
            escherMetafileBlip = escherMetafileBlip2;
            escherMetafileBlip.setRecordId((short) (i2 - 4072));
            switch (i2) {
            }
            EscherBSERecord escherBSERecord2 = new EscherBSERecord();
            escherBSERecord2.setRecordId(EscherBSERecord.RECORD_ID);
            escherBSERecord2.setOptions((short) (2 | (i2 << 4)));
            byte b22 = (byte) i2;
            escherBSERecord2.setBlipTypeMacOS(b22);
            escherBSERecord2.setBlipTypeWin32(b22);
            escherBSERecord2.setUid(digest);
            escherBSERecord2.setTag(s);
            escherBSERecord2.setSize(i3);
            escherBSERecord2.setRef(0);
            escherBSERecord2.setOffset(0);
            escherBSERecord2.setBlipRecord(escherMetafileBlip);
            return this.workbook.addBSERecord(escherBSERecord2);
        } catch (NoSuchAlgorithmException e2) {
            throw new IllegalArgumentException(e2);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void addToolPack(UDFFinder uDFFinder) {
        ((AggregatingUDFFinder) this._udfFinder).add(uDFFinder);
    }

    public boolean changeExternalReference(String str, String str2) {
        return this.workbook.changeExternalReference(str, str2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook, java.io.Closeable, org.apache.poi.POIDocument, java.lang.AutoCloseable
    public void close() {
        super.close();
    }

    public HSSFName createBuiltInName(byte b2, int i2) {
        HSSFName hSSFName = new HSSFName(this, this.workbook.createBuiltInName(b2, i2 + 1), null);
        this.names.add(hSSFName);
        return hSSFName;
    }

    public void dumpDrawingGroupRecords(boolean z) {
        DrawingGroupRecord drawingGroupRecord = (DrawingGroupRecord) this.workbook.findFirstRecordBySid(DrawingGroupRecord.sid);
        drawingGroupRecord.decode();
        List<EscherRecord> escherRecords = drawingGroupRecord.getEscherRecords();
        PrintWriter printWriter = new PrintWriter(new OutputStreamWriter(System.out, Charset.defaultCharset()));
        for (EscherRecord escherRecord : escherRecords) {
            if (z) {
                System.out.println(escherRecord);
            } else {
                escherRecord.display(printWriter, 0);
            }
        }
        printWriter.flush();
    }

    public void encryptBytes(byte[] bArr) {
        EncryptionInfo encryptionInfo = getEncryptionInfo();
        if (encryptionInfo != null) {
            Encryptor encryptor = encryptionInfo.getEncryptor();
            LittleEndianByteArrayInputStream littleEndianByteArrayInputStream = new LittleEndianByteArrayInputStream(bArr, 0);
            LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream = new LittleEndianByteArrayOutputStream(bArr, 0);
            encryptor.setChunkSize(1024);
            byte[] bArr2 = new byte[1024];
            try {
                ChunkedCipherOutputStream dataStream = encryptor.getDataStream(littleEndianByteArrayOutputStream, 0);
                int i2 = 0;
                while (i2 < bArr.length) {
                    littleEndianByteArrayInputStream.read(bArr2, 0, 4);
                    int uShort = LittleEndian.getUShort(bArr2, 0);
                    int uShort2 = LittleEndian.getUShort(bArr2, 2);
                    boolean isNeverEncryptedRecord = Biff8DecryptingStream.isNeverEncryptedRecord(uShort);
                    dataStream.setNextRecordSize(uShort2, isNeverEncryptedRecord);
                    dataStream.writePlain(bArr2, 0, 4);
                    if (uShort == 133) {
                        byte[] bArr3 = new byte[uShort2];
                        littleEndianByteArrayInputStream.readFully(bArr3);
                        dataStream.writePlain(bArr3, 0, 4);
                        dataStream.write(bArr3, 4, uShort2 - 4);
                    } else {
                        int i3 = uShort2;
                        while (i3 > 0) {
                            int min = Math.min(i3, 1024);
                            littleEndianByteArrayInputStream.readFully(bArr2, 0, min);
                            if (isNeverEncryptedRecord) {
                                dataStream.writePlain(bArr2, 0, min);
                            } else {
                                dataStream.write(bArr2, 0, min);
                            }
                            i3 -= min;
                        }
                    }
                    i2 += uShort2 + 4;
                }
                dataStream.close();
            } catch (Exception e2) {
                throw new EncryptedDocumentException(e2);
            }
        }
    }

    public int findExistingBuiltinNameRecordIdx(int i2, byte b2) {
        for (int i3 = 0; i3 < this.names.size(); i3++) {
            NameRecord nameRecord = this.workbook.getNameRecord(i3);
            if (nameRecord == null) {
                throw new RuntimeException("Unable to find all defined names to iterate over");
            } else if (nameRecord.isBuiltInName() && nameRecord.getBuiltInName() == b2 && nameRecord.getSheetNumber() - 1 == i2) {
                return i3;
            }
        }
        return -1;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getActiveSheetIndex() {
        return this.workbook.getWindowOne().getActiveSheetIndex();
    }

    public List<HSSFObjectData> getAllEmbeddedObjects() {
        ArrayList arrayList = new ArrayList();
        for (HSSFSheet hSSFSheet : this._sheets) {
            getAllEmbeddedObjects(hSSFSheet, arrayList);
        }
        return Collections.unmodifiableList(arrayList);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public List<HSSFName> getAllNames() {
        return Collections.unmodifiableList(this.names);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public List<HSSFPictureData> getAllPictures() {
        ArrayList arrayList = new ArrayList();
        for (Record record : this.workbook.getRecords()) {
            if (record instanceof AbstractEscherHolderRecord) {
                AbstractEscherHolderRecord abstractEscherHolderRecord = (AbstractEscherHolderRecord) record;
                abstractEscherHolderRecord.decode();
                searchForPictures(abstractEscherHolderRecord.getEscherRecords(), arrayList);
            }
        }
        return Collections.unmodifiableList(arrayList);
    }

    public boolean getBackupFlag() {
        return this.workbook.getBackupRecord().getBackup() != 0;
    }

    public HSSFName getBuiltInName(byte b2, int i2) {
        int findExistingBuiltinNameRecordIdx = findExistingBuiltinNameRecordIdx(i2, b2);
        if (findExistingBuiltinNameRecordIdx < 0) {
            return null;
        }
        return this.names.get(findExistingBuiltinNameRecordIdx);
    }

    public byte[] getBytes() {
        if (log.check(1)) {
            log.log(1, "HSSFWorkbook.getBytes()");
        }
        HSSFSheet[] sheets = getSheets();
        int length = sheets.length;
        updateEncryptionInfo();
        this.workbook.preSerialize();
        for (HSSFSheet hSSFSheet : sheets) {
            hSSFSheet.getSheet().preSerialize();
            hSSFSheet.preSerialize();
        }
        int size = this.workbook.getSize();
        SheetRecordCollector[] sheetRecordCollectorArr = new SheetRecordCollector[length];
        for (int i2 = 0; i2 < length; i2++) {
            this.workbook.setSheetBof(i2, size);
            SheetRecordCollector sheetRecordCollector = new SheetRecordCollector();
            sheets[i2].getSheet().visitContainedRecords(sheetRecordCollector, size);
            size += sheetRecordCollector.getTotalSize();
            sheetRecordCollectorArr[i2] = sheetRecordCollector;
        }
        byte[] bArr = new byte[size];
        int serialize = this.workbook.serialize(0, bArr);
        for (int i3 = 0; i3 < length; i3++) {
            SheetRecordCollector sheetRecordCollector2 = sheetRecordCollectorArr[i3];
            int serialize2 = sheetRecordCollector2.serialize(serialize, bArr);
            if (serialize2 == sheetRecordCollector2.getTotalSize()) {
                serialize += serialize2;
            } else {
                StringBuilder a = a.a("Actual serialized sheet size (", serialize2, ") differs from pre-calculated size (");
                a.append(sheetRecordCollector2.getTotalSize());
                a.append(") for sheet (");
                a.append(i3);
                a.append(")");
                throw new IllegalStateException(a.toString());
            }
        }
        encryptBytes(bArr);
        return bArr;
    }

    public HSSFPalette getCustomPalette() {
        return new HSSFPalette(this.workbook.getCustomPalette());
    }

    @Override // org.apache.poi.POIDocument
    public EncryptionInfo getEncryptionInfo() {
        FilePassRecord filePassRecord = (FilePassRecord) this.workbook.findFirstRecordBySid(47);
        if (filePassRecord != null) {
            return filePassRecord.getEncryptionInfo();
        }
        return null;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getFirstVisibleTab() {
        return this.workbook.getWindowOne().getFirstVisibleTab();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public boolean getForceFormulaRecalculation() {
        RecalcIdRecord recalcIdRecord = (RecalcIdRecord) getWorkbook().findFirstRecordBySid(449);
        return (recalcIdRecord == null || recalcIdRecord.getEngineId() == 0) ? false : true;
    }

    @Internal
    public InternalWorkbook getInternalWorkbook() {
        return this.workbook;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Row.MissingCellPolicy getMissingCellPolicy() {
        return this.missingCellPolicy;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getNameIndex(String str) {
        for (int i2 = 0; i2 < this.names.size(); i2++) {
            if (getNameName(i2).equalsIgnoreCase(str)) {
                return i2;
            }
        }
        return -1;
    }

    public String getNameName(int i2) {
        return getNameAt(i2).getNameName();
    }

    public NameRecord getNameRecord(int i2) {
        return getWorkbook().getNameRecord(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public List<HSSFName> getNames(String str) {
        ArrayList arrayList = new ArrayList();
        Iterator<HSSFName> it = this.names.iterator();
        while (it.hasNext()) {
            HSSFName next = it.next();
            if (next.getNameName().equals(str)) {
                arrayList.add(next);
            }
        }
        return Collections.unmodifiableList(arrayList);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getNumCellStyles() {
        return this.workbook.getNumExFormats();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public short getNumberOfFonts() {
        return (short) this.workbook.getNumberOfFontRecords();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getNumberOfNames() {
        return this.names.size();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getNumberOfSheets() {
        return this._sheets.size();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public String getPrintArea(int i2) {
        NameRecord specificBuiltinRecord = this.workbook.getSpecificBuiltinRecord((byte) 6, i2 + 1);
        if (specificBuiltinRecord == null) {
            return null;
        }
        return HSSFFormulaParser.toFormulaString(this, specificBuiltinRecord.getNameDefinition());
    }

    @Removal(version = "3.18")
    @Deprecated
    public DirectoryNode getRootDirectory() {
        return getDirectory();
    }

    public Collection<Integer> getSelectedTabs() {
        ArrayList arrayList = new ArrayList();
        int size = this._sheets.size();
        for (int i2 = 0; i2 < size; i2++) {
            if (getSheetAt(i2).isSelected()) {
                arrayList.add(Integer.valueOf(i2));
            }
        }
        return Collections.unmodifiableCollection(arrayList);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getSheetIndex(String str) {
        return this.workbook.getSheetIndex(str);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public String getSheetName(int i2) {
        validateSheetIndex(i2);
        return this.workbook.getSheetName(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public SheetVisibility getSheetVisibility(int i2) {
        return this.workbook.getSheetVisibility(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public SpreadsheetVersion getSpreadsheetVersion() {
        return SpreadsheetVersion.EXCEL97;
    }

    public UDFFinder getUDFFinder() {
        return this._udfFinder;
    }

    public InternalWorkbook getWorkbook() {
        return this.workbook;
    }

    public void initDrawings() {
        if (this.workbook.findDrawingGroup() != null) {
            for (HSSFSheet hSSFSheet : this._sheets) {
                hSSFSheet.getDrawingPatriarch();
            }
            return;
        }
        this.workbook.createDrawingGroup();
    }

    public void insertChartRecord() {
        this.workbook.getRecords().add(this.workbook.findFirstRecordLocBySid(252), new UnknownRecord(235, new byte[]{15, 0, 0, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 82, 0, 0, 0, 0, 0, 6, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, XPath.Scanner.CHARTYPE_UNION, 0, 0, 0, 1, 8, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 3, 0, 0, 0, 51, 0, 11, Lucene3xFields.PreTermsEnum.UTF8_NON_BMP_LEAD, 18, 0, 0, 0, -65, 0, 8, 0, 8, 0, -127, 1, 9, 0, 0, 8, -64, 1, 64, 0, 0, 8, 64, 0, IntPtg.sid, -15, 16, 0, 0, 0, 13, 0, 0, 8, 12, 0, 0, 8, 23, 0, 0, 8, -9, 0, 0, 16}));
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public boolean isHidden() {
        return this.workbook.getWindowOne().getHidden();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public boolean isSheetHidden(int i2) {
        validateSheetIndex(i2);
        return this.workbook.isSheetHidden(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public boolean isSheetVeryHidden(int i2) {
        validateSheetIndex(i2);
        return this.workbook.isSheetVeryHidden(i2);
    }

    public boolean isWriteProtected() {
        return this.workbook.isWriteProtected();
    }

    @Override // java.lang.Iterable
    public Iterator<Sheet> iterator() {
        return sheetIterator();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int linkExternalWorkbook(String str, Workbook workbook2) {
        return this.workbook.linkExternalWorkbook(str, workbook2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removeName(int i2) {
        this.names.remove(i2);
        this.workbook.removeName(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removePrintArea(int i2) {
        getWorkbook().removeBuiltinRecord((byte) 6, i2 + 1);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removeSheetAt(int i2) {
        validateSheetIndex(i2);
        boolean isSelected = getSheetAt(i2).isSelected();
        this._sheets.remove(i2);
        this.workbook.removeSheet(i2);
        int size = this._sheets.size();
        if (size >= 1) {
            int i3 = i2 >= size ? size - 1 : i2;
            if (isSelected) {
                boolean z = false;
                int i4 = 0;
                while (true) {
                    if (i4 >= size) {
                        break;
                    } else if (getSheetAt(i4).isSelected()) {
                        z = true;
                        break;
                    } else {
                        i4++;
                    }
                }
                if (!z) {
                    setSelectedTab(i3);
                }
            }
            int activeSheetIndex = getActiveSheetIndex();
            if (activeSheetIndex == i2) {
                setActiveSheet(i3);
            } else if (activeSheetIndex > i2) {
                setActiveSheet(activeSheetIndex - 1);
            }
        }
    }

    public void resetFontCache() {
        this.fonts = new HashMap();
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setActiveSheet(int i2) {
        validateSheetIndex(i2);
        int size = this._sheets.size();
        int i3 = 0;
        while (i3 < size) {
            getSheetAt(i3).setActive(i3 == i2);
            i3++;
        }
        this.workbook.getWindowOne().setActiveSheetIndex(i2);
    }

    public void setBackupFlag(boolean z) {
        this.workbook.getBackupRecord().setBackup(z ? (short) 1 : 0);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setFirstVisibleTab(int i2) {
        this.workbook.getWindowOne().setFirstVisibleTab(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setForceFormulaRecalculation(boolean z) {
        getWorkbook().getRecalcId().setEngineId(0);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setHidden(boolean z) {
        this.workbook.getWindowOne().setHidden(z);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setMissingCellPolicy(Row.MissingCellPolicy missingCellPolicy2) {
        this.missingCellPolicy = missingCellPolicy2;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setPrintArea(int i2, String str) {
        int i3 = i2 + 1;
        NameRecord specificBuiltinRecord = this.workbook.getSpecificBuiltinRecord((byte) 6, i3);
        if (specificBuiltinRecord == null) {
            specificBuiltinRecord = this.workbook.createBuiltInName((byte) 6, i3);
        }
        String[] split = COMMA_PATTERN.split(str);
        StringBuffer stringBuffer = new StringBuffer(32);
        for (int i4 = 0; i4 < split.length; i4++) {
            if (i4 > 0) {
                stringBuffer.append(XSSFDataValidationConstraint.LIST_SEPARATOR);
            }
            SheetNameFormatter.appendFormat(stringBuffer, getSheetName(i2));
            stringBuffer.append("!");
            stringBuffer.append(split[i4]);
        }
        specificBuiltinRecord.setNameDefinition(HSSFFormulaParser.parse(stringBuffer.toString(), this, FormulaType.NAMEDRANGE, i2));
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSelectedTab(int i2) {
        validateSheetIndex(i2);
        int size = this._sheets.size();
        int i3 = 0;
        while (true) {
            boolean z = true;
            if (i3 < size) {
                HSSFSheet sheetAt = getSheetAt(i3);
                if (i3 != i2) {
                    z = false;
                }
                sheetAt.setSelected(z);
                i3++;
            } else {
                this.workbook.getWindowOne().setNumSelectedTabs(1);
                return;
            }
        }
    }

    public void setSelectedTabs(int[] iArr) {
        ArrayList arrayList = new ArrayList(iArr.length);
        for (int i2 : iArr) {
            arrayList.add(Integer.valueOf(i2));
        }
        setSelectedTabs(arrayList);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetHidden(int i2, boolean z) {
        setSheetVisibility(i2, z ? SheetVisibility.HIDDEN : SheetVisibility.VISIBLE);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetName(int i2, String str) {
        if (str == null) {
            throw new IllegalArgumentException("sheetName must not be null");
        } else if (!this.workbook.doesContainsSheetName(str, i2)) {
            validateSheetIndex(i2);
            this.workbook.setSheetName(i2, str);
        } else {
            throw new IllegalArgumentException(a.b("The workbook already contains a sheet named '", str, "'"));
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetOrder(String str, int i2) {
        int sheetIndex = getSheetIndex(str);
        List<HSSFSheet> list = this._sheets;
        list.add(i2, list.remove(sheetIndex));
        this.workbook.setSheetOrder(str, i2);
        FormulaShifter createForSheetShift = FormulaShifter.createForSheetShift(sheetIndex, i2);
        for (HSSFSheet hSSFSheet : this._sheets) {
            hSSFSheet.getSheet().updateFormulasAfterCellShift(createForSheetShift, -1);
        }
        this.workbook.updateNamesAfterCellShift(createForSheetShift);
        updateNamedRangesAfterSheetReorder(sheetIndex, i2);
        updateActiveSheetAfterSheetReorder(sheetIndex, i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setSheetVisibility(int i2, SheetVisibility sheetVisibility) {
        validateSheetIndex(i2);
        this.workbook.setSheetHidden(i2, sheetVisibility);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public Iterator<Sheet> sheetIterator() {
        return new SheetIterator();
    }

    public void unwriteProtectWorkbook() {
        this.workbook.unwriteProtectWorkbook();
    }

    @Override // org.apache.poi.POIDocument
    public void write() {
        validateInPlaceWritePossible();
        DirectoryNode directory = getDirectory();
        new NPOIFSDocument((DocumentNode) directory.getEntry(getWorkbookDirEntryName(directory))).replaceContents(new ByteArrayInputStream(getBytes()));
        writeProperties();
        directory.getFileSystem().writeFilesystem();
    }

    public void writeProtectWorkbook(String str, String str2) {
        this.workbook.writeProtectWorkbook(str, str2);
    }

    public HSSFWorkbook(InternalWorkbook internalWorkbook) {
        super((DirectoryNode) null);
        this.missingCellPolicy = Row.MissingCellPolicy.RETURN_NULL_AND_BLANK;
        this._udfFinder = new IndexedUDFFinder(AggregatingUDFFinder.DEFAULT);
        this.workbook = internalWorkbook;
        this._sheets = new ArrayList(INITIAL_CAPACITY);
        this.names = new ArrayList<>(INITIAL_CAPACITY);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFSheet cloneSheet(int i2) {
        validateSheetIndex(i2);
        String sheetName = this.workbook.getSheetName(i2);
        HSSFSheet cloneSheet = this._sheets.get(i2).cloneSheet(this);
        cloneSheet.setSelected(false);
        cloneSheet.setActive(false);
        String uniqueSheetName = getUniqueSheetName(sheetName);
        int size = this._sheets.size();
        this._sheets.add(cloneSheet);
        this.workbook.setSheetName(size, uniqueSheetName);
        int findExistingBuiltinNameRecordIdx = findExistingBuiltinNameRecordIdx(i2, (byte) 13);
        if (findExistingBuiltinNameRecordIdx != -1) {
            this.names.add(new HSSFName(this, this.workbook.cloneFilter(findExistingBuiltinNameRecordIdx, size)));
        }
        return cloneSheet;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFCellStyle createCellStyle() {
        if (this.workbook.getNumExFormats() != 4030) {
            return new HSSFCellStyle((short) (getNumCellStyles() - 1), this.workbook.createCellXF(), this);
        }
        throw new IllegalStateException("The maximum number of cell styles was exceeded. You can define up to 4000 styles in a .xls workbook");
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFDataFormat createDataFormat() {
        if (this.formatter == null) {
            this.formatter = new HSSFDataFormat(this.workbook);
        }
        return this.formatter;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFFont createFont() {
        this.workbook.createNewFont();
        short numberOfFonts = (short) (getNumberOfFonts() - 1);
        if (numberOfFonts > 3) {
            numberOfFonts = (short) (numberOfFonts + 1);
        }
        if (numberOfFonts != Short.MAX_VALUE) {
            return getFontAt(numberOfFonts);
        }
        throw new IllegalArgumentException("Maximum number of fonts was exceeded");
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFName createName() {
        HSSFName hSSFName = new HSSFName(this, this.workbook.createName());
        this.names.add(hSSFName);
        return hSSFName;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFFont findFont(boolean z, short s, short s2, String str, boolean z2, boolean z3, short s3, byte b2) {
        short numberOfFonts = getNumberOfFonts();
        for (short s4 = 0; s4 <= numberOfFonts; s4 = (short) (s4 + 1)) {
            if (s4 != 4) {
                HSSFFont fontAt = getFontAt(s4);
                if (fontAt.getBold() == z && fontAt.getColor() == s && fontAt.getFontHeight() == s2 && fontAt.getFontName().equals(str) && fontAt.getItalic() == z2 && fontAt.getStrikeout() == z3 && fontAt.getTypeOffset() == s3 && fontAt.getUnderline() == b2) {
                    return fontAt;
                }
            }
        }
        return null;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFCellStyle getCellStyleAt(int i2) {
        return new HSSFCellStyle((short) i2, this.workbook.getExFormatAt(i2), this);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFCreationHelper getCreationHelper() {
        return new HSSFCreationHelper(this);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFFont getFontAt(short s) {
        if (this.fonts == null) {
            this.fonts = new HashMap();
        }
        Short valueOf = Short.valueOf(s);
        if (this.fonts.containsKey(valueOf)) {
            return this.fonts.get(valueOf);
        }
        HSSFFont hSSFFont = new HSSFFont(s, this.workbook.getFontRecordAt(s));
        this.fonts.put(valueOf, hSSFFont);
        return hSSFFont;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFName getName(String str) {
        int nameIndex = getNameIndex(str);
        if (nameIndex < 0) {
            return null;
        }
        return this.names.get(nameIndex);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFName getNameAt(int i2) {
        int size = this.names.size();
        if (size < 1) {
            throw new IllegalStateException("There are no defined names in this workbook");
        } else if (i2 >= 0 && i2 <= size) {
            return this.names.get(i2);
        } else {
            StringBuilder a = a.a("Specified name index ", i2, " is outside the allowable range (0..");
            a.append(size - 1);
            a.append(").");
            throw new IllegalArgumentException(a.toString());
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFSheet getSheet(String str) {
        HSSFSheet hSSFSheet = null;
        for (int i2 = 0; i2 < this._sheets.size(); i2++) {
            if (this.workbook.getSheetName(i2).equalsIgnoreCase(str)) {
                hSSFSheet = this._sheets.get(i2);
            }
        }
        return hSSFSheet;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFSheet getSheetAt(int i2) {
        validateSheetIndex(i2);
        return this._sheets.get(i2);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int getSheetIndex(Sheet sheet) {
        return this._sheets.indexOf(sheet);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    @Removal(version = "3.18")
    @Deprecated
    public void setSheetHidden(int i2, int i3) {
        if (i3 == 0) {
            setSheetVisibility(i2, SheetVisibility.VISIBLE);
        } else if (i3 == 1) {
            setSheetVisibility(i2, SheetVisibility.HIDDEN);
        } else if (i3 == 2) {
            setSheetVisibility(i2, SheetVisibility.VERY_HIDDEN);
        } else {
            throw new IllegalArgumentException("Invalid sheet state : " + i3 + "\n" + "Sheet state must beone of the Workbook.SHEET_STATE_* constants");
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFSheet createSheet() {
        HSSFSheet hSSFSheet = new HSSFSheet(this);
        this._sheets.add(hSSFSheet);
        boolean z = true;
        StringBuilder b2 = a.b("Sheet");
        b2.append(this._sheets.size() - 1);
        this.workbook.setSheetName(this._sheets.size() - 1, b2.toString());
        if (this._sheets.size() != 1) {
            z = false;
        }
        hSSFSheet.setSelected(z);
        hSSFSheet.setActive(z);
        return hSSFSheet;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removeName(String str) {
        removeName(getNameIndex(str));
    }

    public int getNameIndex(HSSFName hSSFName) {
        for (int i2 = 0; i2 < this.names.size(); i2++) {
            if (hSSFName == this.names.get(i2)) {
                return i2;
            }
        }
        return -1;
    }

    private void getAllEmbeddedObjects(HSSFSheet hSSFSheet, List<HSSFObjectData> list) {
        HSSFPatriarch drawingPatriarch = hSSFSheet.getDrawingPatriarch();
        if (drawingPatriarch != null) {
            getAllEmbeddedObjects(drawingPatriarch, list);
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void removeName(Name name) {
        removeName(getNameIndex((HSSFName) name));
    }

    public void setSelectedTabs(Collection<Integer> collection) {
        for (Integer num : collection) {
            validateSheetIndex(num.intValue());
        }
        HashSet hashSet = new HashSet(collection);
        int size = this._sheets.size();
        for (int i2 = 0; i2 < size; i2++) {
            getSheetAt(i2).setSelected(hashSet.contains(Integer.valueOf(i2)));
        }
        this.workbook.getWindowOne().setNumSelectedTabs((short) hashSet.size());
    }

    private void getAllEmbeddedObjects(HSSFShapeContainer hSSFShapeContainer, List<HSSFObjectData> list) {
        for (HSSFShape hSSFShape : hSSFShapeContainer.getChildren()) {
            if (hSSFShape instanceof HSSFObjectData) {
                list.add((HSSFObjectData) hSSFShape);
            } else if (hSSFShape instanceof HSSFShapeContainer) {
                getAllEmbeddedObjects((HSSFShapeContainer) hSSFShape, list);
            }
        }
    }

    public HSSFWorkbook(POIFSFileSystem pOIFSFileSystem) {
        this(pOIFSFileSystem, true);
    }

    @Override // org.apache.poi.POIDocument
    public void write(File file) {
        POIFSFileSystem create = POIFSFileSystem.create(file);
        try {
            write(create);
            create.writeFilesystem();
        } finally {
            create.close();
        }
    }

    public HSSFWorkbook(NPOIFSFileSystem nPOIFSFileSystem) {
        this(nPOIFSFileSystem.getRoot(), true);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public int addOlePackage(byte[] bArr, String str, String str2, String str3) {
        if (initDirectory()) {
            this.preserveNodes = true;
        }
        int i2 = 0;
        DirectoryEntry directoryEntry = null;
        do {
            StringBuilder b2 = a.b("MBD");
            i2++;
            b2.append(HexDump.toHex(i2));
            String sb = b2.toString();
            if (!getDirectory().hasEntry(sb)) {
                directoryEntry = getDirectory().createDirectory(sb);
                directoryEntry.setStorageClsid(ClassID.OLE10_PACKAGE);
                continue;
            }
        } while (directoryEntry == null);
        directoryEntry.createDocument("\u0001Ole", new ByteArrayInputStream(new byte[]{1, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}));
        Ole10Native ole10Native = new Ole10Native(str, str2, str3, bArr);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        ole10Native.writeOut(byteArrayOutputStream);
        directoryEntry.createDocument(Ole10Native.OLE10_NATIVE, new ByteArrayInputStream(byteArrayOutputStream.toByteArray()));
        return i2;
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public HSSFSheet createSheet(String str) {
        if (str == null) {
            throw new IllegalArgumentException("sheetName must not be null");
        } else if (!this.workbook.doesContainsSheetName(str, this._sheets.size())) {
            HSSFSheet hSSFSheet = new HSSFSheet(this);
            this.workbook.setSheetName(this._sheets.size(), str);
            this._sheets.add(hSSFSheet);
            boolean z = true;
            if (this._sheets.size() != 1) {
                z = false;
            }
            hSSFSheet.setSelected(z);
            hSSFSheet.setActive(z);
            return hSSFSheet;
        } else {
            throw new IllegalArgumentException(a.b("The workbook already contains a sheet named '", str, "'"));
        }
    }

    public HSSFWorkbook(POIFSFileSystem pOIFSFileSystem, boolean z) {
        this(pOIFSFileSystem.getRoot(), pOIFSFileSystem, z);
    }

    public HSSFWorkbook(DirectoryNode directoryNode, POIFSFileSystem pOIFSFileSystem, boolean z) {
        this(directoryNode, z);
    }

    @Override // org.apache.poi.ss.usermodel.Workbook
    public void setPrintArea(int i2, int i3, int i4, int i5, int i6) {
        String formatAsString = new CellReference(i5, i3, true, true).formatAsString();
        CellReference cellReference = new CellReference(i6, i4, true, true);
        StringBuilder d2 = a.d(formatAsString, ":");
        d2.append(cellReference.formatAsString());
        setPrintArea(i2, d2.toString());
    }

    public HSSFWorkbook(DirectoryNode directoryNode, boolean z) {
        super(directoryNode);
        this.missingCellPolicy = Row.MissingCellPolicy.RETURN_NULL_AND_BLANK;
        this._udfFinder = new IndexedUDFFinder(AggregatingUDFFinder.DEFAULT);
        String workbookDirEntryName = getWorkbookDirEntryName(directoryNode);
        this.preserveNodes = z;
        if (!z) {
            clearDirectory();
        }
        this._sheets = new ArrayList(INITIAL_CAPACITY);
        this.names = new ArrayList<>(INITIAL_CAPACITY);
        List<Record> createRecords = RecordFactory.createRecords(directoryNode.createDocumentInputStream(workbookDirEntryName));
        InternalWorkbook createWorkbook = InternalWorkbook.createWorkbook(createRecords);
        this.workbook = createWorkbook;
        setPropertiesFromWorkbook(createWorkbook);
        int numRecords = this.workbook.getNumRecords();
        convertLabelRecords(createRecords, numRecords);
        RecordStream recordStream = new RecordStream(createRecords, numRecords);
        while (recordStream.hasNext()) {
            try {
                this._sheets.add(new HSSFSheet(this, InternalSheet.createSheet(recordStream)));
            } catch (InternalSheet.UnsupportedBOFType e2) {
                POILogger pOILogger = log;
                StringBuilder b2 = a.b("Unsupported BOF found of type ");
                b2.append(e2.getType());
                pOILogger.log(5, b2.toString());
            }
        }
        for (int i2 = 0; i2 < this.workbook.getNumNames(); i2++) {
            NameRecord nameRecord = this.workbook.getNameRecord(i2);
            this.names.add(new HSSFName(this, nameRecord, this.workbook.getNameCommentRecord(nameRecord)));
        }
    }

    @Override // org.apache.poi.ss.usermodel.Workbook, org.apache.poi.POIDocument
    public void write(OutputStream outputStream) {
        NPOIFSFileSystem nPOIFSFileSystem = new NPOIFSFileSystem();
        try {
            write(nPOIFSFileSystem);
            nPOIFSFileSystem.writeFilesystem(outputStream);
        } finally {
            nPOIFSFileSystem.close();
        }
    }

    private void write(NPOIFSFileSystem nPOIFSFileSystem) {
        ArrayList arrayList = new ArrayList(1);
        nPOIFSFileSystem.createDocument(new ByteArrayInputStream(getBytes()), "Workbook");
        writeProperties(nPOIFSFileSystem, arrayList);
        if (this.preserveNodes) {
            arrayList.addAll(Arrays.asList(InternalWorkbook.WORKBOOK_DIR_ENTRY_NAMES));
            arrayList.addAll(Arrays.asList(DocumentSummaryInformation.DEFAULT_STREAM_NAME, SummaryInformation.DEFAULT_STREAM_NAME, getEncryptedPropertyStreamName()));
            EntryUtils.copyNodes(new FilteringDirectoryNode(getDirectory(), arrayList), new FilteringDirectoryNode(nPOIFSFileSystem.getRoot(), arrayList));
            nPOIFSFileSystem.getRoot().setStorageClsid(getDirectory().getStorageClsid());
        }
    }

    public HSSFWorkbook(InputStream inputStream) {
        this(inputStream, true);
    }

    public HSSFWorkbook(InputStream inputStream, boolean z) {
        this(new NPOIFSFileSystem(inputStream).getRoot(), z);
    }
}
