package org.apache.poi.hwmf.record;

import java.io.IOException;
import java.nio.charset.Charset;
import org.apache.poi.common.usermodel.fonts.FontCharset;
import org.apache.poi.common.usermodel.fonts.FontFamily;
import org.apache.poi.common.usermodel.fonts.FontInfo;
import org.apache.poi.common.usermodel.fonts.FontPitch;
import org.apache.poi.poifs.filesystem.Ole10Native;
import org.apache.poi.util.LittleEndianInputStream;

public class HwmfFont implements FontInfo {
    public FontCharset charSet;
    public WmfClipPrecision clipPrecision;
    public int escapement;
    public String facename;
    public FontFamily family;
    public int height;
    public boolean italic;
    public int orientation;
    public WmfOutPrecision outPrecision;
    public FontPitch pitch;
    public int pitchAndFamily;
    public WmfFontQuality quality;
    public boolean strikeOut;
    public boolean underline;
    public int weight;
    public int width;

    public enum WmfClipPrecision {
        CLIP_DEFAULT_PRECIS(0),
        CLIP_CHARACTER_PRECIS(1),
        CLIP_STROKE_PRECIS(2),
        CLIP_LH_ANGLES(16),
        CLIP_TT_ALWAYS(32),
        CLIP_DFA_DISABLE(64),
        CLIP_EMBEDDED(128);
        
        public int flag;

        /* access modifiers changed from: public */
        WmfClipPrecision(int i2) {
            this.flag = i2;
        }

        public static WmfClipPrecision valueOf(int i2) {
            WmfClipPrecision[] values = values();
            for (WmfClipPrecision wmfClipPrecision : values) {
                if (wmfClipPrecision.flag == i2) {
                    return wmfClipPrecision;
                }
            }
            return null;
        }
    }

    public enum WmfFontQuality {
        DEFAULT_QUALITY(0),
        DRAFT_QUALITY(1),
        PROOF_QUALITY(2),
        NONANTIALIASED_QUALITY(3),
        ANTIALIASED_QUALITY(4),
        CLEARTYPE_QUALITY(5);
        
        public int flag;

        /* access modifiers changed from: public */
        WmfFontQuality(int i2) {
            this.flag = i2;
        }

        public static WmfFontQuality valueOf(int i2) {
            WmfFontQuality[] values = values();
            for (WmfFontQuality wmfFontQuality : values) {
                if (wmfFontQuality.flag == i2) {
                    return wmfFontQuality;
                }
            }
            return null;
        }
    }

    public enum WmfOutPrecision {
        OUT_DEFAULT_PRECIS(0),
        OUT_STRING_PRECIS(1),
        OUT_STROKE_PRECIS(3),
        OUT_TT_PRECIS(4),
        OUT_DEVICE_PRECIS(5),
        OUT_RASTER_PRECIS(6),
        OUT_TT_ONLY_PRECIS(7),
        OUT_OUTLINE_PRECIS(8),
        OUT_SCREEN_OUTLINE_PRECIS(9),
        OUT_PS_ONLY_PRECIS(10);
        
        public int flag;

        /* access modifiers changed from: public */
        WmfOutPrecision(int i2) {
            this.flag = i2;
        }

        public static WmfOutPrecision valueOf(int i2) {
            WmfOutPrecision[] values = values();
            for (WmfOutPrecision wmfOutPrecision : values) {
                if (wmfOutPrecision.flag == i2) {
                    return wmfOutPrecision;
                }
            }
            return null;
        }
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public FontCharset getCharset() {
        return this.charSet;
    }

    public WmfClipPrecision getClipPrecision() {
        return this.clipPrecision;
    }

    public int getEscapement() {
        return this.escapement;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public FontFamily getFamily() {
        return FontFamily.valueOf(this.pitchAndFamily & 15);
    }

    public int getHeight() {
        return this.height;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public Integer getIndex() {
        return null;
    }

    public int getOrientation() {
        return this.orientation;
    }

    public WmfOutPrecision getOutPrecision() {
        return this.outPrecision;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public FontPitch getPitch() {
        return FontPitch.valueOf((this.pitchAndFamily >>> 6) & 3);
    }

    public int getPitchAndFamily() {
        return this.pitchAndFamily;
    }

    public WmfFontQuality getQuality() {
        return this.quality;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public String getTypeface() {
        return this.facename;
    }

    public int getWeight() {
        return this.weight;
    }

    public int getWidth() {
        return this.width;
    }

    public int init(LittleEndianInputStream littleEndianInputStream) {
        this.height = littleEndianInputStream.readShort();
        this.width = littleEndianInputStream.readShort();
        this.escapement = littleEndianInputStream.readShort();
        this.orientation = littleEndianInputStream.readShort();
        this.weight = littleEndianInputStream.readShort();
        boolean z = true;
        this.italic = littleEndianInputStream.readByte() != 0;
        this.underline = littleEndianInputStream.readByte() != 0;
        if (littleEndianInputStream.readByte() == 0) {
            z = false;
        }
        this.strikeOut = z;
        this.charSet = FontCharset.valueOf(littleEndianInputStream.readUByte());
        this.outPrecision = WmfOutPrecision.valueOf(littleEndianInputStream.readUByte());
        this.clipPrecision = WmfClipPrecision.valueOf(littleEndianInputStream.readUByte());
        this.quality = WmfFontQuality.valueOf(littleEndianInputStream.readUByte());
        this.pitchAndFamily = littleEndianInputStream.readUByte();
        byte[] bArr = new byte[32];
        byte b2 = 0;
        while (b2 != 32) {
            byte b3 = (byte) (b2 + 1);
            byte readByte = littleEndianInputStream.readByte();
            bArr[b2] = readByte;
            if (readByte == 0 || readByte == -1 || b3 > 32) {
                this.facename = new String(bArr, 0, b3 - 1, Charset.forName(Ole10Native.ISO1));
                return b3 + 18;
            }
            b2 = b3;
        }
        throw new IOException("Font facename can't be determined.");
    }

    public boolean isItalic() {
        return this.italic;
    }

    public boolean isStrikeOut() {
        return this.strikeOut;
    }

    public boolean isUnderline() {
        return this.underline;
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public void setCharset(FontCharset fontCharset) {
        throw new UnsupportedOperationException("setCharset not supported by HwmfFont.");
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public void setFamily(FontFamily fontFamily) {
        throw new UnsupportedOperationException("setCharset not supported by HwmfFont.");
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public void setIndex(int i2) {
        throw new UnsupportedOperationException("setIndex not supported by HwmfFont.");
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public void setPitch(FontPitch fontPitch) {
        throw new UnsupportedOperationException("setPitch not supported by HwmfFont.");
    }

    @Override // org.apache.poi.common.usermodel.fonts.FontInfo
    public void setTypeface(String str) {
        throw new UnsupportedOperationException("setTypeface not supported by HwmfFont.");
    }
}
