package org.apache.poi.hwmf.record;

import java.awt.Color;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.hwmf.draw.HwmfDrawProperties;
import org.apache.poi.hwmf.draw.HwmfGraphics;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.LittleEndianInputStream;

public class HwmfPalette {

    public static class WmfAnimatePalette extends WmfPaletteParent {
        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
            HwmfDrawProperties properties = hwmfGraphics.getProperties();
            List<PaletteEntry> palette = properties.getPalette();
            List<PaletteEntry> paletteCopy = getPaletteCopy();
            int paletteStart = getPaletteStart();
            if (palette == null) {
                palette = new ArrayList<>();
            }
            for (int size = palette.size(); size < paletteStart; size++) {
                palette.add(new PaletteEntry());
            }
            for (int i2 = 0; i2 < paletteCopy.size(); i2++) {
                PaletteEntry paletteEntry = paletteCopy.get(i2);
                int i3 = paletteStart + i2;
                if (palette.size() <= i3) {
                    palette.add(paletteEntry);
                } else if (palette.get(i3).isReserved()) {
                    palette.set(i3, paletteEntry);
                }
            }
            properties.setPalette(palette);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.animatePalette;
        }
    }

    public static class WmfCreatePalette extends WmfPaletteParent implements HwmfObjectTableEntry {
        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.getProperties().setPalette(getPaletteCopy());
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.createPalette;
        }
    }

    public static abstract class WmfPaletteParent implements HwmfRecord, HwmfObjectTableEntry {
        public List<PaletteEntry> palette = new ArrayList();
        public int start;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public final void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        public List<PaletteEntry> getPaletteCopy() {
            ArrayList arrayList = new ArrayList();
            for (PaletteEntry paletteEntry : this.palette) {
                arrayList.add(new PaletteEntry(paletteEntry));
            }
            return arrayList;
        }

        public int getPaletteStart() {
            return this.start;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.start = littleEndianInputStream.readUShort();
            int readUShort = littleEndianInputStream.readUShort();
            int i3 = 4;
            for (int i4 = 0; i4 < readUShort; i4++) {
                PaletteEntry paletteEntry = new PaletteEntry();
                i3 += paletteEntry.init(littleEndianInputStream);
                this.palette.add(paletteEntry);
            }
            return i3;
        }
    }

    public static class WmfRealizePalette implements HwmfRecord {
        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.realizePalette;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            return 0;
        }
    }

    public static class WmfResizePalette implements HwmfRecord, HwmfObjectTableEntry {
        public int numberOfEntries;

        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
            HwmfDrawProperties properties = hwmfGraphics.getProperties();
            List<PaletteEntry> palette = properties.getPalette();
            if (palette == null) {
                palette = new ArrayList<>();
            }
            int size = palette.size();
            while (true) {
                int i2 = this.numberOfEntries;
                if (size < i2) {
                    palette.add(new PaletteEntry());
                    size++;
                } else {
                    properties.setPalette(palette.subList(0, i2));
                    return;
                }
            }
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.resizePalette;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.numberOfEntries = littleEndianInputStream.readUShort();
            return 2;
        }
    }

    public static class WmfSelectPalette implements HwmfRecord {
        public int paletteIndex;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.applyObjectTableEntry(this.paletteIndex);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.selectPalette;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.paletteIndex = littleEndianInputStream.readUShort();
            return 2;
        }
    }

    public static class WmfSetPaletteEntries extends WmfPaletteParent {
        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
            HwmfDrawProperties properties = hwmfGraphics.getProperties();
            List<PaletteEntry> palette = properties.getPalette();
            if (palette == null) {
                palette = new ArrayList<>();
            }
            int paletteStart = getPaletteStart();
            for (int size = palette.size(); size < paletteStart; size++) {
                palette.add(new PaletteEntry());
            }
            for (PaletteEntry paletteEntry : getPaletteCopy()) {
                if (palette.size() <= paletteStart) {
                    palette.add(paletteEntry);
                } else {
                    palette.set(paletteStart, paletteEntry);
                }
                paletteStart++;
            }
            properties.setPalette(palette);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setPalEntries;
        }
    }

    public static class PaletteEntry {
        public static final BitField PC_EXPLICIT = BitFieldFactory.getInstance(2);
        public static final BitField PC_NOCOLLAPSE = BitFieldFactory.getInstance(4);
        public static final BitField PC_RESERVED = BitFieldFactory.getInstance(1);
        public Color colorRef;
        public int values;

        public int init(LittleEndianInputStream littleEndianInputStream) {
            this.values = littleEndianInputStream.readUByte();
            int readUByte = littleEndianInputStream.readUByte();
            this.colorRef = new Color(littleEndianInputStream.readUByte(), littleEndianInputStream.readUByte(), readUByte);
            return 4;
        }

        public boolean isExplicit() {
            return PC_EXPLICIT.isSet(this.values);
        }

        public boolean isNoCollapse() {
            return PC_NOCOLLAPSE.isSet(this.values);
        }

        public boolean isReserved() {
            return PC_RESERVED.isSet(this.values);
        }

        public PaletteEntry() {
            this.values = PC_RESERVED.set(0);
            this.colorRef = Color.BLACK;
        }

        public PaletteEntry(PaletteEntry paletteEntry) {
            this.values = paletteEntry.values;
            this.colorRef = paletteEntry.colorRef;
        }
    }
}
