package org.apache.poi.hwmf.usermodel;

import b.b.a.a.a;
import java.awt.Dimension;
import java.awt.Graphics2D;
import java.awt.geom.AffineTransform;
import java.awt.geom.Rectangle2D;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.poi.hwmf.draw.HwmfGraphics;
import org.apache.poi.hwmf.record.HwmfHeader;
import org.apache.poi.hwmf.record.HwmfPlaceableHeader;
import org.apache.poi.hwmf.record.HwmfRecord;
import org.apache.poi.hwmf.record.HwmfRecordType;
import org.apache.poi.hwmf.record.HwmfWindowing;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndianInputStream;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.RecordFormatException;
import org.apache.poi.util.Units;

public class HwmfPicture {
    public static final POILogger logger = POILogFactory.getLogger(HwmfPicture.class);
    public final HwmfHeader header;
    public final HwmfPlaceableHeader placeableHeader;
    public final List<HwmfRecord> records = new ArrayList();

    public HwmfPicture(InputStream inputStream) {
        LittleEndianInputStream littleEndianInputStream = new LittleEndianInputStream(new BufferedInputStream(inputStream, 10000));
        this.placeableHeader = HwmfPlaceableHeader.readHeader(littleEndianInputStream);
        this.header = new HwmfHeader(littleEndianInputStream);
        while (littleEndianInputStream.available() >= 6) {
            long readUInt = littleEndianInputStream.readUInt() * 2;
            if (readUInt > 2147483647L) {
                throw new RecordFormatException("record size can't be > 2147483647");
            } else if (readUInt >= 0) {
                int i2 = (int) readUInt;
                short readShort = littleEndianInputStream.readShort();
                HwmfRecordType byId = HwmfRecordType.getById(readShort);
                if (byId == null) {
                    throw new IOException(a.c("unexpected record type: ", readShort));
                } else if (byId != HwmfRecordType.eof) {
                    Class<? extends HwmfRecord> cls = byId.clazz;
                    if (cls != null) {
                        try {
                            HwmfRecord hwmfRecord = (HwmfRecord) cls.newInstance();
                            this.records.add(hwmfRecord);
                            int init = hwmfRecord.init(littleEndianInputStream, (long) i2, readShort) + 6;
                            int i3 = i2 - init;
                            if (i3 < 0) {
                                throw new RecordFormatException(a.a("read too many bytes. record size: ", i2, "; comsumed size: ", init));
                            } else if (i3 > 0) {
                                long j = (long) i3;
                                long skipFully = IOUtils.skipFully(littleEndianInputStream, j);
                                if (skipFully != j) {
                                    throw new RecordFormatException("Tried to skip " + i3 + " but skipped: " + skipFully);
                                }
                            }
                        } catch (Exception e2) {
                            throw ((IOException) new IOException("can't create wmf record").initCause(e2));
                        }
                    } else {
                        throw new IOException(a.c("unsupported record type: ", readShort));
                    }
                } else {
                    return;
                }
            } else {
                throw new RecordFormatException("record size can't be < 0");
            }
        }
        logger.log(7, "unexpected eof - wmf file was truncated");
    }

    public void draw(Graphics2D graphics2D) {
        Dimension size = getSize();
        draw(graphics2D, new Rectangle2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e, (double) Units.pointsToPixel(size.getWidth()), (double) Units.pointsToPixel(size.getHeight())));
    }

    public Rectangle2D getBounds() {
        HwmfPlaceableHeader hwmfPlaceableHeader = this.placeableHeader;
        if (hwmfPlaceableHeader != null) {
            return hwmfPlaceableHeader.getBounds();
        }
        HwmfWindowing.WmfSetWindowOrg wmfSetWindowOrg = null;
        HwmfWindowing.WmfSetWindowExt wmfSetWindowExt = null;
        for (HwmfRecord hwmfRecord : getRecords()) {
            if (wmfSetWindowOrg != null && wmfSetWindowExt != null) {
                break;
            } else if (hwmfRecord instanceof HwmfWindowing.WmfSetWindowOrg) {
                wmfSetWindowOrg = (HwmfWindowing.WmfSetWindowOrg) hwmfRecord;
            } else if (hwmfRecord instanceof HwmfWindowing.WmfSetWindowExt) {
                wmfSetWindowExt = (HwmfWindowing.WmfSetWindowExt) hwmfRecord;
            }
        }
        if (!(wmfSetWindowOrg == null || wmfSetWindowExt == null)) {
            return new Rectangle2D.Double((double) wmfSetWindowOrg.getX(), (double) wmfSetWindowOrg.getY(), (double) wmfSetWindowExt.getWidth(), (double) wmfSetWindowExt.getHeight());
        }
        throw new RuntimeException("invalid wmf file - window records are incomplete.");
    }

    public HwmfHeader getHeader() {
        return this.header;
    }

    public HwmfPlaceableHeader getPlaceableHeader() {
        return this.placeableHeader;
    }

    public List<HwmfRecord> getRecords() {
        return Collections.unmodifiableList(this.records);
    }

    public Dimension getSize() {
        HwmfPlaceableHeader hwmfPlaceableHeader = this.placeableHeader;
        double unitsPerInch = hwmfPlaceableHeader == null ? 1440.0d : (double) hwmfPlaceableHeader.getUnitsPerInch();
        Rectangle2D bounds = getBounds();
        double d2 = 72.0d / unitsPerInch;
        return new Dimension((int) Math.round(bounds.getWidth() * d2), (int) Math.round(bounds.getHeight() * d2));
    }

    public void draw(Graphics2D graphics2D, Rectangle2D rectangle2D) {
        AffineTransform transform = graphics2D.getTransform();
        try {
            Rectangle2D bounds = getBounds();
            graphics2D.translate(rectangle2D.getX(), rectangle2D.getY());
            graphics2D.scale(rectangle2D.getWidth() / bounds.getWidth(), rectangle2D.getHeight() / bounds.getHeight());
            HwmfGraphics hwmfGraphics = new HwmfGraphics(graphics2D, bounds);
            for (HwmfRecord hwmfRecord : this.records) {
                hwmfRecord.draw(hwmfGraphics);
            }
        } finally {
            graphics2D.setTransform(transform);
        }
    }
}
