package org.apache.poi.hwpf;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.security.GeneralSecurityException;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.POIDocument;
import org.apache.poi.hssf.record.crypto.Biff8EncryptionKey;
import org.apache.poi.hwpf.model.CHPBinTable;
import org.apache.poi.hwpf.model.FibBase;
import org.apache.poi.hwpf.model.FileInformationBlock;
import org.apache.poi.hwpf.model.FontTable;
import org.apache.poi.hwpf.model.ListTables;
import org.apache.poi.hwpf.model.PAPBinTable;
import org.apache.poi.hwpf.model.SectionTable;
import org.apache.poi.hwpf.model.StyleSheet;
import org.apache.poi.hwpf.model.TextPieceTable;
import org.apache.poi.hwpf.usermodel.ObjectPoolImpl;
import org.apache.poi.hwpf.usermodel.ObjectsPool;
import org.apache.poi.hwpf.usermodel.Range;
import org.apache.poi.poifs.crypt.ChunkedCipherInputStream;
import org.apache.poi.poifs.crypt.Decryptor;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.crypt.EncryptionMode;
import org.apache.poi.poifs.crypt.Encryptor;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentEntry;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.FileMagic;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.util.BoundedInputStream;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndianByteArrayInputStream;

public abstract class HWPFDocumentCore extends POIDocument {
    public static final int FIB_BASE_LEN = 68;
    public static final int RC4_REKEYING_INTERVAL = 512;
    public static final String STREAM_OBJECT_POOL = "ObjectPool";
    public static final String STREAM_TABLE_0 = "0Table";
    public static final String STREAM_TABLE_1 = "1Table";
    public static final String STREAM_WORD_DOCUMENT = "WordDocument";
    public CHPBinTable _cbt;
    public EncryptionInfo _encryptionInfo;
    public FileInformationBlock _fib;
    public FontTable _ft;
    public ListTables _lt;
    public byte[] _mainStream;
    public ObjectPoolImpl _objectPool;
    public PAPBinTable _pbt;
    public StyleSheet _ss;
    public SectionTable _st;

    public HWPFDocumentCore() {
        super((DirectoryNode) null);
    }

    public static POIFSFileSystem verifyAndBuildPOIFS(InputStream inputStream) {
        InputStream prepareToCheckMagic = FileMagic.prepareToCheckMagic(inputStream);
        FileMagic valueOf = FileMagic.valueOf(prepareToCheckMagic);
        if (valueOf == FileMagic.OLE2) {
            return new POIFSFileSystem(prepareToCheckMagic);
        }
        throw new IllegalArgumentException("The document is really a " + valueOf + " file");
    }

    public CHPBinTable getCharacterTable() {
        return this._cbt;
    }

    public byte[] getDocumentEntryBytes(String str, int i2, int i3) {
        BoundedInputStream boundedInputStream;
        Throwable th;
        GeneralSecurityException e2;
        DirectoryNode directory = getDirectory();
        DocumentEntry documentEntry = (DocumentEntry) directory.getEntry(str);
        DocumentInputStream createDocumentInputStream = directory.createDocumentInputStream(documentEntry);
        EncryptionInfo encryptionInfo = i2 > -1 ? getEncryptionInfo() : null;
        int size = documentEntry.getSize();
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(Math.min(size, i3));
        if (encryptionInfo != null) {
            try {
                boundedInputStream = encryptionInfo.getDecryptor().getDataStream(createDocumentInputStream, size, 0);
                if (i2 > 0) {
                    try {
                        byte[] bArr = new byte[i2];
                        ((ChunkedCipherInputStream) boundedInputStream).readPlain(bArr, 0, i2);
                        byteArrayOutputStream.write(bArr);
                    } catch (GeneralSecurityException e3) {
                        e2 = e3;
                    }
                }
            } catch (GeneralSecurityException e4) {
                e2 = e4;
                boundedInputStream = createDocumentInputStream;
                try {
                    throw new IOException(e2.getMessage(), e2);
                } catch (Throwable th2) {
                    th = th2;
                    IOUtils.closeQuietly(boundedInputStream);
                    IOUtils.closeQuietly(createDocumentInputStream);
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                boundedInputStream = createDocumentInputStream;
                IOUtils.closeQuietly(boundedInputStream);
                IOUtils.closeQuietly(createDocumentInputStream);
                throw th;
            }
        } else {
            boundedInputStream = createDocumentInputStream;
        }
        if (i3 < Integer.MAX_VALUE) {
            boundedInputStream = new BoundedInputStream(boundedInputStream, (long) i3);
        }
        IOUtils.copy(boundedInputStream, byteArrayOutputStream);
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        IOUtils.closeQuietly(boundedInputStream);
        IOUtils.closeQuietly(createDocumentInputStream);
        return byteArray;
    }

    public String getDocumentText() {
        return getText().toString();
    }

    @Override // org.apache.poi.POIDocument
    public EncryptionInfo getEncryptionInfo() {
        FibBase fibBase;
        EncryptionInfo encryptionInfo = this._encryptionInfo;
        if (encryptionInfo != null) {
            return encryptionInfo;
        }
        FileInformationBlock fileInformationBlock = this._fib;
        if (fileInformationBlock == null || fileInformationBlock.getFibBase() == null) {
            byte[] bArr = this._mainStream;
            if (bArr == null) {
                bArr = getDocumentEntryBytes(STREAM_WORD_DOCUMENT, -1, 68);
            }
            fibBase = new FibBase(bArr, 0);
        } else {
            fibBase = this._fib.getFibBase();
        }
        EncryptionMode encryptionMode = null;
        if (!fibBase.isFEncrypted()) {
            return null;
        }
        LittleEndianByteArrayInputStream littleEndianByteArrayInputStream = new LittleEndianByteArrayInputStream(getDocumentEntryBytes(fibBase.isFWhichTblStm() ? STREAM_TABLE_1 : STREAM_TABLE_0, -1, fibBase.getLKey()));
        if (fibBase.isFObfuscated()) {
            encryptionMode = EncryptionMode.xor;
        }
        EncryptionInfo encryptionInfo2 = new EncryptionInfo(littleEndianByteArrayInputStream, encryptionMode);
        Decryptor decryptor = encryptionInfo2.getDecryptor();
        decryptor.setChunkSize(512);
        try {
            String currentUserPassword = Biff8EncryptionKey.getCurrentUserPassword();
            if (currentUserPassword == null) {
                currentUserPassword = Decryptor.DEFAULT_PASSWORD;
            }
            if (decryptor.verifyPassword(currentUserPassword)) {
                this._encryptionInfo = encryptionInfo2;
                return encryptionInfo2;
            }
            throw new EncryptedDocumentException("document is encrypted, password is invalid - use Biff8EncryptionKey.setCurrentUserPasswort() to set password before opening");
        } catch (GeneralSecurityException e2) {
            throw new IOException(e2.getMessage(), e2);
        }
    }

    public FileInformationBlock getFileInformationBlock() {
        return this._fib;
    }

    public FontTable getFontTable() {
        return this._ft;
    }

    public ListTables getListTables() {
        return this._lt;
    }

    @Internal
    public byte[] getMainStream() {
        return this._mainStream;
    }

    public ObjectsPool getObjectsPool() {
        return this._objectPool;
    }

    public abstract Range getOverallRange();

    public PAPBinTable getParagraphTable() {
        return this._pbt;
    }

    public abstract Range getRange();

    public SectionTable getSectionTable() {
        return this._st;
    }

    public StyleSheet getStyleSheet() {
        return this._ss;
    }

    @Internal
    public abstract StringBuilder getText();

    public abstract TextPieceTable getTextTable();

    public void updateEncryptionInfo() {
        readProperties();
        String currentUserPassword = Biff8EncryptionKey.getCurrentUserPassword();
        FibBase fibBase = this._fib.getFibBase();
        if (currentUserPassword == null) {
            fibBase.setLKey(0);
            fibBase.setFEncrypted(false);
            fibBase.setFObfuscated(false);
            this._encryptionInfo = null;
            return;
        }
        if (this._encryptionInfo == null) {
            this._encryptionInfo = new EncryptionInfo(EncryptionMode.cryptoAPI);
            fibBase.setFEncrypted(true);
            fibBase.setFObfuscated(false);
        }
        Encryptor encryptor = this._encryptionInfo.getEncryptor();
        byte[] salt = this._encryptionInfo.getVerifier().getSalt();
        if (salt == null) {
            encryptor.confirmPassword(currentUserPassword);
        } else {
            encryptor.confirmPassword(currentUserPassword, null, null, this._encryptionInfo.getDecryptor().getVerifier(), salt, null);
        }
    }

    public HWPFDocumentCore(InputStream inputStream) {
        this(verifyAndBuildPOIFS(inputStream));
    }

    public HWPFDocumentCore(POIFSFileSystem pOIFSFileSystem) {
        this(pOIFSFileSystem.getRoot());
    }

    public HWPFDocumentCore(DirectoryNode directoryNode) {
        super(directoryNode);
        this._mainStream = getDocumentEntryBytes(STREAM_WORD_DOCUMENT, 68, Integer.MAX_VALUE);
        this._fib = new FileInformationBlock(this._mainStream);
        this._objectPool = new ObjectPoolImpl(directoryNode.hasEntry(STREAM_OBJECT_POOL) ? (DirectoryEntry) directoryNode.getEntry(STREAM_OBJECT_POOL) : null);
    }
}
