package org.apache.poi.hwpf;

import b.b.a.a.a;
import java.io.File;
import java.io.OutputStream;
import java.nio.charset.Charset;
import org.apache.poi.common.usermodel.fonts.FontCharset;
import org.apache.poi.hssf.usermodel.HSSFShapeTypes;
import org.apache.poi.hwpf.model.FontTable;
import org.apache.poi.hwpf.model.OldCHPBinTable;
import org.apache.poi.hwpf.model.OldComplexFileTable;
import org.apache.poi.hwpf.model.OldFfn;
import org.apache.poi.hwpf.model.OldFontTable;
import org.apache.poi.hwpf.model.OldPAPBinTable;
import org.apache.poi.hwpf.model.OldSectionTable;
import org.apache.poi.hwpf.model.OldTextPieceTable;
import org.apache.poi.hwpf.model.PieceDescriptor;
import org.apache.poi.hwpf.model.TextPiece;
import org.apache.poi.hwpf.model.TextPieceTable;
import org.apache.poi.hwpf.usermodel.Range;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.util.CodePageUtil;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.NotImplemented;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.StringUtil;

public class HWPFOldDocument extends HWPFDocumentCore {
    public static final Charset DEFAULT_CHARSET = StringUtil.WIN_1252;
    public static final POILogger logger = POILogFactory.getLogger(HWPFOldDocument.class);
    public StringBuilder _text;
    public final OldFontTable fontTable;
    public final Charset guessedCharset;
    public OldTextPieceTable tpt;

    public HWPFOldDocument(POIFSFileSystem pOIFSFileSystem) {
        this(pOIFSFileSystem.getRoot());
    }

    private TextPiece buildTextPiece(Charset charset) {
        PieceDescriptor pieceDescriptor = new PieceDescriptor(new byte[]{0, 0, 0, 0, 0, Byte.MAX_VALUE, 0, 0}, 0, charset);
        pieceDescriptor.setFilePosition(this._fib.getFibBase().getFcMin());
        this.tpt = new OldTextPieceTable();
        int fcMac = this._fib.getFibBase().getFcMac() - this._fib.getFibBase().getFcMin();
        byte[] bArr = new byte[fcMac];
        System.arraycopy(this._mainStream, this._fib.getFibBase().getFcMin(), bArr, 0, fcMac);
        if (CodePageUtil.DOUBLE_BYTE_CHARSETS.contains(charset)) {
            fcMac /= 2;
        }
        return new TextPiece(0, fcMac, bArr, pieceDescriptor);
    }

    private Charset guessCodePage(OldFontTable oldFontTable) {
        for (OldFfn oldFfn : oldFontTable.getFontNames()) {
            FontCharset valueOf = FontCharset.valueOf(oldFfn.getChs() & 255);
            if (!(valueOf == null || valueOf == FontCharset.ANSI || valueOf == FontCharset.DEFAULT || valueOf == FontCharset.SYMBOL)) {
                return valueOf.getCharset();
            }
        }
        logger.log(5, "Couldn't find a defined charset; backing off to cp1252");
        return DEFAULT_CHARSET;
    }

    @Override // org.apache.poi.hwpf.HWPFDocumentCore
    @NotImplemented
    public FontTable getFontTable() {
        throw new UnsupportedOperationException("Use getOldFontTable instead.");
    }

    public Charset getGuessedCharset() {
        return this.guessedCharset;
    }

    public OldFontTable getOldFontTable() {
        return this.fontTable;
    }

    @Override // org.apache.poi.hwpf.HWPFDocumentCore
    public Range getOverallRange() {
        return new Range(0, this._fib.getFibBase().getFcMac() - this._fib.getFibBase().getFcMin(), this);
    }

    @Override // org.apache.poi.hwpf.HWPFDocumentCore
    public Range getRange() {
        return getOverallRange();
    }

    @Override // org.apache.poi.hwpf.HWPFDocumentCore
    public StringBuilder getText() {
        return this._text;
    }

    @Override // org.apache.poi.hwpf.HWPFDocumentCore
    public TextPieceTable getTextTable() {
        return this.tpt;
    }

    @Override // org.apache.poi.POIDocument
    public void write() {
        throw new IllegalStateException("Writing is not available for the older file formats");
    }

    public HWPFOldDocument(DirectoryNode directoryNode) {
        super(directoryNode);
        OldComplexFileTable oldComplexFileTable;
        TextPiece textPiece;
        int i2 = LittleEndian.getInt(this._mainStream, 136);
        int i3 = LittleEndian.getInt(this._mainStream, 140);
        int i4 = LittleEndian.getInt(this._mainStream, 184);
        int i5 = LittleEndian.getInt(this._mainStream, 188);
        int i6 = LittleEndian.getInt(this._mainStream, HSSFShapeTypes.ActionButtonInformation);
        int i7 = LittleEndian.getInt(this._mainStream, HSSFShapeTypes.ActionButtonBeginning);
        OldFontTable oldFontTable = new OldFontTable(this._mainStream, LittleEndian.getInt(this._mainStream, 208), LittleEndian.getInt(this._mainStream, 212));
        this.fontTable = oldFontTable;
        this.guessedCharset = guessCodePage(oldFontTable);
        int i8 = LittleEndian.getInt(this._mainStream, 352);
        boolean z = false;
        if (this._fib.getFibBase().isFComplex()) {
            byte[] bArr = this._mainStream;
            oldComplexFileTable = new OldComplexFileTable(bArr, bArr, i8, this._fib.getFibBase().getFcMin(), this.guessedCharset);
            this.tpt = (OldTextPieceTable) oldComplexFileTable.getTextPieceTable();
        } else {
            try {
                textPiece = buildTextPiece(this.guessedCharset);
            } catch (IllegalStateException unused) {
                textPiece = buildTextPiece(StringUtil.WIN_1252);
                POILogger pOILogger = logger;
                StringBuilder b2 = a.b("Error with ");
                b2.append(this.guessedCharset);
                b2.append(". Backing off to Windows-1252");
                pOILogger.log(5, b2.toString());
            }
            this.tpt.add(textPiece);
            oldComplexFileTable = null;
        }
        this._text = this.tpt.getText();
        this._cbt = new OldCHPBinTable(this._mainStream, i4, i5, this._fib.getFibBase().getFcMin(), this.tpt);
        this._pbt = new OldPAPBinTable(this._mainStream, i6, i7, this._fib.getFibBase().getFcMin(), this.tpt);
        this._st = new OldSectionTable(this._mainStream, i2, i3, this._fib.getFibBase().getFcMin(), this.tpt);
        try {
            z = Boolean.parseBoolean(System.getProperty(HWPFDocument.PROPERTY_PRESERVE_BIN_TABLES));
        } catch (Exception unused2) {
        }
        if (!z) {
            this._cbt.rebuild(oldComplexFileTable);
            this._pbt.rebuild(this._text, oldComplexFileTable);
        }
    }

    @Override // org.apache.poi.POIDocument
    public void write(File file) {
        throw new IllegalStateException("Writing is not available for the older file formats");
    }

    @Override // org.apache.poi.POIDocument
    public void write(OutputStream outputStream) {
        throw new IllegalStateException("Writing is not available for the older file formats");
    }
}
