package org.apache.poi.hwpf.converter;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.lucene.codecs.lucene3x.Lucene3xNormsProducer;
import org.apache.poi.hpsf.SummaryInformation;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.converter.AbstractWordUtils;
import org.apache.poi.hwpf.converter.FontReplacer;
import org.apache.poi.hwpf.model.FieldsDocumentPart;
import org.apache.poi.hwpf.usermodel.Bookmark;
import org.apache.poi.hwpf.usermodel.Bookmarks;
import org.apache.poi.hwpf.usermodel.CharacterRun;
import org.apache.poi.hwpf.usermodel.Field;
import org.apache.poi.hwpf.usermodel.Notes;
import org.apache.poi.hwpf.usermodel.ObjectsPool;
import org.apache.poi.hwpf.usermodel.OfficeDrawing;
import org.apache.poi.hwpf.usermodel.Paragraph;
import org.apache.poi.hwpf.usermodel.Picture;
import org.apache.poi.hwpf.usermodel.PictureType;
import org.apache.poi.hwpf.usermodel.Range;
import org.apache.poi.hwpf.usermodel.Section;
import org.apache.poi.hwpf.usermodel.Table;
import org.apache.poi.hwpf.usermodel.TableCell;
import org.apache.poi.hwpf.usermodel.TableRow;
import org.apache.poi.poifs.filesystem.Entry;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public abstract class AbstractWordConverter {
    public static final byte BEL_MARK = 7;
    public static final byte FIELD_BEGIN_MARK = 19;
    public static final byte FIELD_END_MARK = 21;
    public static final byte FIELD_SEPARATOR_MARK = 20;
    public static final Pattern PATTERN_HYPERLINK_EXTERNAL = Pattern.compile("^[ \\t\\r\\n]*HYPERLINK \"(.*)\".*$");
    public static final Pattern PATTERN_HYPERLINK_LOCAL = Pattern.compile("^[ \\t\\r\\n]*HYPERLINK \\\\l \"(.*)\"[ ](.*)$");
    public static final Pattern PATTERN_PAGEREF = Pattern.compile("^[ \\t\\r\\n]*PAGEREF ([^ ]*)[ \\t\\r\\n]*\\\\h.*$");
    public static final byte SPECCHAR_AUTONUMBERED_FOOTNOTE_REFERENCE = 2;
    public static final byte SPECCHAR_DRAWN_OBJECT = 8;
    public static final char UNICODECHAR_NONBREAKING_HYPHEN = 8209;
    public static final char UNICODECHAR_NO_BREAK_SPACE = 160;
    public static final char UNICODECHAR_ZERO_WIDTH_SPACE = 8203;
    public static final POILogger logger = POILogFactory.getLogger(AbstractWordConverter.class);
    public final Set<Bookmark> bookmarkStack = new LinkedHashSet();
    public FontReplacer fontReplacer = new DefaultFontReplacer();
    public POILogger log = POILogFactory.getLogger(getClass());
    public AbstractWordUtils.NumberingState numberingState = new AbstractWordUtils.NumberingState();
    public PicturesManager picturesManager;

    public static class DeadFieldBoundaries {
        public final int beginMark;
        public final int endMark;
        public final int separatorMark;

        public DeadFieldBoundaries(int i2, int i3, int i4) {
            this.beginMark = i2;
            this.separatorMark = i3;
            this.endMark = i4;
        }
    }

    public static final class Structure implements Comparable<Structure> {
        public final int end;
        public final int start;
        public final Object structure;

        public Structure(Bookmark bookmark) {
            this.start = bookmark.getStart();
            this.end = bookmark.getEnd();
            this.structure = bookmark;
        }

        public String toString() {
            StringBuilder b2 = a.b("Structure [");
            b2.append(this.start);
            b2.append("; ");
            b2.append(this.end);
            b2.append("): ");
            b2.append(this.structure);
            return b2.toString();
        }

        public int compareTo(Structure structure2) {
            int i2 = this.start;
            int i3 = structure2.start;
            if (i2 < i3) {
                return -1;
            }
            return i2 == i3 ? 0 : 1;
        }

        public Structure(DeadFieldBoundaries deadFieldBoundaries, int i2, int i3) {
            this.start = i2;
            this.end = i3;
            this.structure = deadFieldBoundaries;
        }

        public Structure(Field field) {
            this.start = field.getFieldStartOffset();
            this.end = field.getFieldEndOffset();
            this.structure = field;
        }
    }

    public static void addToStructures(List<Structure> list, Structure structure) {
        Iterator<Structure> it = list.iterator();
        while (it.hasNext()) {
            Structure next = it.next();
            int i2 = next.start;
            int i3 = structure.start;
            if (i2 > i3 || next.end < i3) {
                int i4 = structure.start;
                int i5 = next.start;
                if ((i4 < i5 && i5 < structure.end) || ((structure.start < next.start && next.end <= structure.end) || (structure.start <= next.start && next.end < structure.end))) {
                    it.remove();
                }
            } else {
                return;
            }
        }
        list.add(structure);
    }

    private boolean processOle2(HWPFDocument hWPFDocument, CharacterRun characterRun, Element element) {
        ObjectsPool objectsPool = hWPFDocument.getObjectsPool();
        StringBuilder b2 = a.b("_");
        b2.append(characterRun.getPicOffset());
        Entry objectById = objectsPool.getObjectById(b2.toString());
        if (objectById == null) {
            logger.log(5, "Referenced OLE2 object '", Integer.valueOf(characterRun.getPicOffset()), "' not found in ObjectPool");
            return false;
        }
        try {
            return processOle2(hWPFDocument, element, objectById);
        } catch (Exception e2) {
            logger.log(5, "Unable to convert internal OLE2 object '", Integer.valueOf(characterRun.getPicOffset()), "': ", e2, e2);
            return false;
        }
    }

    private int[] tryDeadField_lookupFieldSeparatorEnd(HWPFDocumentCore hWPFDocumentCore, Range range, int i2) {
        int i3 = i2 + 1;
        int i4 = -1;
        while (true) {
            if (i3 >= range.numCharacterRuns()) {
                i3 = -1;
                break;
            }
            String text = range.getCharacterRun(i3).text();
            if (!text.isEmpty()) {
                char charAt = text.charAt(0);
                if (charAt == 19) {
                    int[] tryDeadField_lookupFieldSeparatorEnd = tryDeadField_lookupFieldSeparatorEnd(hWPFDocumentCore, range, i3);
                    if (tryDeadField_lookupFieldSeparatorEnd != null) {
                        i3 = tryDeadField_lookupFieldSeparatorEnd[1];
                    }
                } else if (charAt == 20) {
                    if (i4 != -1) {
                        return null;
                    }
                    i4 = i3;
                } else if (charAt == 21) {
                    break;
                }
            }
            i3++;
        }
        if (i4 == -1 || i3 == -1) {
            return null;
        }
        return new int[]{i4, i3};
    }

    public void afterProcess() {
    }

    public FontReplacer.Triplet getCharacterRunTriplet(CharacterRun characterRun) {
        FontReplacer.Triplet triplet = new FontReplacer.Triplet();
        triplet.bold = characterRun.isBold();
        triplet.italic = characterRun.isItalic();
        triplet.fontName = characterRun.getFontName();
        return getFontReplacer().update(triplet);
    }

    public abstract Document getDocument();

    public FontReplacer getFontReplacer() {
        return this.fontReplacer;
    }

    public int getNumberColumnsSpanned(int[] iArr, int i2, TableCell tableCell) {
        int i3 = 0;
        while (iArr[i2] < tableCell.getWidth() + tableCell.getLeftEdge()) {
            i3++;
            i2++;
        }
        return i3;
    }

    public int getNumberRowsSpanned(Table table, int[] iArr, int i2, int i3, TableCell tableCell) {
        if (!tableCell.isFirstVerticallyMerged()) {
            return 1;
        }
        int numRows = table.numRows();
        int i4 = 1;
        for (int i5 = i2 + 1; i5 < numRows; i5++) {
            TableRow row = table.getRow(i5);
            if (i3 >= row.numCells()) {
                break;
            }
            boolean z = false;
            int i6 = 0;
            int i7 = 0;
            while (true) {
                if (i6 >= row.numCells()) {
                    break;
                }
                TableCell cell = row.getCell(i6);
                if (!cell.isVerticallyMerged() || cell.isFirstVerticallyMerged()) {
                    int numberColumnsSpanned = getNumberColumnsSpanned(iArr, i7, cell);
                    i7 += numberColumnsSpanned;
                    if (numberColumnsSpanned != 0) {
                        z = true;
                        break;
                    }
                } else {
                    i7 = getNumberColumnsSpanned(iArr, i7, cell) + i7;
                }
                i6++;
            }
            if (z) {
                TableCell cell2 = row.getCell(i3);
                if (!cell2.isVerticallyMerged() || cell2.isFirstVerticallyMerged()) {
                    break;
                }
                i4++;
            }
        }
        return i4;
    }

    public PicturesManager getPicturesManager() {
        return this.picturesManager;
    }

    public abstract void outputCharacters(Element element, CharacterRun characterRun, String str);

    public abstract void processBookmarks(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, List<Bookmark> list);

    /* JADX WARN: Type inference failed for: r1v3 */
    /* JADX WARN: Type inference failed for: r1v4, types: [boolean, int] */
    /* JADX WARN: Type inference failed for: r1v5 */
    /* JADX WARNING: Unknown variable types count: 1 */
    public boolean processCharacters(HWPFDocumentCore hWPFDocumentCore, int i2, Range range, Element element) {
        String text;
        int i3 = 0;
        if (range == null) {
            return false;
        }
        LinkedList linkedList = new LinkedList();
        boolean z = hWPFDocumentCore instanceof HWPFDocument;
        char c = 19;
        if (z) {
            HWPFDocument hWPFDocument = (HWPFDocument) hWPFDocumentCore;
            Map<Integer, List<Bookmark>> bookmarksStartedBetween = hWPFDocument.getBookmarks().getBookmarksStartedBetween(range.getStartOffset(), range.getEndOffset());
            if (bookmarksStartedBetween != null) {
                for (List<Bookmark> list : bookmarksStartedBetween.values()) {
                    for (Bookmark bookmark : list) {
                        if (!this.bookmarkStack.contains(bookmark)) {
                            addToStructures(linkedList, new Structure(bookmark));
                        }
                    }
                }
            }
            int i4 = 0;
            while (i4 < range.numCharacterRuns()) {
                CharacterRun characterRun = range.getCharacterRun(i4);
                if (characterRun != null) {
                    if (characterRun.getStartOffset() >= -1 && (text = characterRun.text()) != null && text.length() != 0 && text.charAt(i3) == c) {
                        Field fieldByStartOffset = hWPFDocument.getFields().getFieldByStartOffset(FieldsDocumentPart.MAIN, characterRun.getStartOffset());
                        if (fieldByStartOffset != null) {
                            addToStructures(linkedList, new Structure(fieldByStartOffset));
                        } else {
                            int[] tryDeadField_lookupFieldSeparatorEnd = tryDeadField_lookupFieldSeparatorEnd(hWPFDocumentCore, range, i4);
                            if (tryDeadField_lookupFieldSeparatorEnd != null) {
                                addToStructures(linkedList, new Structure(new DeadFieldBoundaries(i4, tryDeadField_lookupFieldSeparatorEnd[i3], tryDeadField_lookupFieldSeparatorEnd[1]), characterRun.getStartOffset(), range.getCharacterRun(tryDeadField_lookupFieldSeparatorEnd[1]).getEndOffset()));
                                i4 = tryDeadField_lookupFieldSeparatorEnd[1];
                            }
                        }
                    }
                    i4++;
                    i3 = 0;
                    c = 19;
                } else {
                    throw new AssertionError();
                }
            }
        }
        ArrayList arrayList = new ArrayList(linkedList);
        Collections.sort(arrayList);
        int startOffset = range.getStartOffset();
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            Structure structure = (Structure) it.next();
            int i5 = structure.start;
            if (i5 != startOffset) {
                processCharacters(hWPFDocumentCore, i2, new Range(startOffset, i5, range) {
                    /* class org.apache.poi.hwpf.converter.AbstractWordConverter.AnonymousClass1 */

                    @Override // org.apache.poi.hwpf.usermodel.Range
                    public String toString() {
                        StringBuilder b2 = a.b("BetweenStructuresSubrange ");
                        b2.append(super.toString());
                        return b2.toString();
                    }
                }, element);
            }
            Object obj = structure.structure;
            if (obj instanceof Bookmark) {
                LinkedList linkedList2 = new LinkedList();
                Bookmarks bookmarks = ((HWPFDocument) hWPFDocumentCore).getBookmarks();
                int i6 = structure.start;
                for (Bookmark bookmark2 : bookmarks.getBookmarksStartedBetween(i6, i6 + 1).values().iterator().next()) {
                    if (bookmark2.getStart() == structure.start && bookmark2.getEnd() == structure.end) {
                        linkedList2.add(bookmark2);
                    }
                }
                this.bookmarkStack.addAll(linkedList2);
                try {
                    processBookmarks(hWPFDocumentCore, element, new Range(structure.start, Math.min(range.getEndOffset(), structure.end), range) {
                        /* class org.apache.poi.hwpf.converter.AbstractWordConverter.AnonymousClass2 */

                        @Override // org.apache.poi.hwpf.usermodel.Range
                        public String toString() {
                            StringBuilder b2 = a.b("BookmarksSubrange ");
                            b2.append(super.toString());
                            return b2.toString();
                        }
                    }, i2, linkedList2);
                } finally {
                    this.bookmarkStack.removeAll(linkedList2);
                }
            } else if (obj instanceof Field) {
                processField((HWPFDocument) hWPFDocumentCore, range, i2, (Field) obj, element);
            } else if (obj instanceof DeadFieldBoundaries) {
                DeadFieldBoundaries deadFieldBoundaries = (DeadFieldBoundaries) obj;
                processDeadField(hWPFDocumentCore, element, range, i2, deadFieldBoundaries.beginMark, deadFieldBoundaries.separatorMark, deadFieldBoundaries.endMark);
            } else {
                StringBuilder b2 = a.b("NYI: ");
                b2.append(structure.structure.getClass());
                throw new UnsupportedOperationException(b2.toString());
            }
            startOffset = Math.min(range.getEndOffset(), structure.end);
        }
        ?? r1 = 1;
        char c2 = 2;
        if (startOffset == range.getStartOffset()) {
            int i7 = 0;
            boolean z2 = false;
            while (i7 < range.numCharacterRuns()) {
                CharacterRun characterRun2 = range.getCharacterRun(i7);
                if (characterRun2 != null) {
                    if (z) {
                        HWPFDocument hWPFDocument2 = (HWPFDocument) hWPFDocumentCore;
                        if (hWPFDocument2.getPicturesTable().hasPicture(characterRun2)) {
                            processImage(element, characterRun2.text().charAt(0) == r1, hWPFDocument2.getPicturesTable().extractPicture(characterRun2, r1));
                            i7++;
                            c2 = 2;
                            r1 = 1;
                        }
                    }
                    String text2 = characterRun2.text();
                    if (!text2.isEmpty()) {
                        if (characterRun2.isSpecialCharacter()) {
                            if (text2.charAt(0) == c2 && z) {
                                processNoteAnchor((HWPFDocument) hWPFDocumentCore, characterRun2, element);
                            } else if (text2.charAt(0) == '\b' && z) {
                                processDrawnObject((HWPFDocument) hWPFDocumentCore, characterRun2, element);
                            } else if (characterRun2.isOle2() && z) {
                                processOle2((HWPFDocument) hWPFDocumentCore, characterRun2, element);
                            } else if (characterRun2.isSymbol() && z) {
                                processSymbol((HWPFDocument) hWPFDocumentCore, characterRun2, element);
                            }
                        }
                        if (text2.charAt(0) == 19) {
                            if (z) {
                                HWPFDocument hWPFDocument3 = (HWPFDocument) hWPFDocumentCore;
                                Field fieldByStartOffset2 = hWPFDocument3.getFields().getFieldByStartOffset(FieldsDocumentPart.MAIN, characterRun2.getStartOffset());
                                if (fieldByStartOffset2 != null) {
                                    processField(hWPFDocument3, range, i2, fieldByStartOffset2, element);
                                    int fieldEndOffset = fieldByStartOffset2.getFieldEndOffset();
                                    while (i7 < range.numCharacterRuns() && range.getCharacterRun(i7).getEndOffset() <= fieldEndOffset) {
                                        i7++;
                                    }
                                    if (i7 < range.numCharacterRuns()) {
                                        i7--;
                                    }
                                }
                            }
                            int tryDeadField = tryDeadField(hWPFDocumentCore, range, i2, i7, element);
                            if (tryDeadField != i7) {
                                i7 = tryDeadField;
                            }
                        } else if (text2.charAt(0) != 20 && text2.charAt(0) != 21 && !characterRun2.isSpecialCharacter() && !characterRun2.isObj() && !characterRun2.isOle2()) {
                            if (text2.endsWith("\r") || (a.a(text2, (int) r1) == 7 && i2 != Integer.MIN_VALUE)) {
                                int length = text2.length();
                                int i8 = r1 == true ? 1 : 0;
                                int i9 = r1 == true ? 1 : 0;
                                int i10 = r1 == true ? 1 : 0;
                                text2 = text2.substring(0, length - i8);
                            }
                            StringBuilder sb = new StringBuilder();
                            char[] charArray = text2.toCharArray();
                            for (char c3 : charArray) {
                                if (c3 == 11) {
                                    if (sb.length() > 0) {
                                        outputCharacters(element, characterRun2, sb.toString());
                                        sb.setLength(0);
                                    }
                                    processLineBreak(element, characterRun2);
                                } else if (c3 == 30) {
                                    sb.append(UNICODECHAR_NONBREAKING_HYPHEN);
                                } else if (c3 == 31) {
                                    sb.append(UNICODECHAR_ZERO_WIDTH_SPACE);
                                } else if (c3 >= ' ' || c3 == '\t' || c3 == '\n' || c3 == '\r') {
                                    sb.append(c3);
                                }
                            }
                            if (sb.length() > 0) {
                                outputCharacters(element, characterRun2, sb.toString());
                                sb.setLength(0);
                            }
                            z2 = (text2.trim().length() != 0) | z2;
                        }
                    }
                    i7++;
                    c2 = 2;
                    r1 = 1;
                } else {
                    throw new AssertionError();
                }
            }
            return z2;
        } else if (startOffset > range.getEndOffset()) {
            logger.log(5, "Latest structure in ", range, a.c(" ended at #", startOffset), " after range boundaries [", range.getStartOffset() + "; " + range.getEndOffset(), ")");
            return true;
        } else {
            if (startOffset < range.getEndOffset()) {
                processCharacters(hWPFDocumentCore, i2, new Range(startOffset, range.getEndOffset(), range) {
                    /* class org.apache.poi.hwpf.converter.AbstractWordConverter.AnonymousClass3 */

                    @Override // org.apache.poi.hwpf.usermodel.Range
                    public String toString() {
                        StringBuilder b2 = a.b("AfterStructureSubrange ");
                        b2.append(super.toString());
                        return b2.toString();
                    }
                }, element);
            }
            return true;
        }
    }

    public void processDeadField(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, int i3, int i4, int i5) {
        int i6;
        int i7 = i3 + 1;
        if (i7 < i4 && (i6 = i4 + 1) < i5) {
            AnonymousClass4 r7 = new Range(range.getCharacterRun(i7).getStartOffset(), range.getCharacterRun(i4 - 1).getEndOffset(), range) {
                /* class org.apache.poi.hwpf.converter.AbstractWordConverter.AnonymousClass4 */

                @Override // org.apache.poi.hwpf.usermodel.Range
                public String toString() {
                    StringBuilder b2 = a.b("Dead field formula subrange: ");
                    b2.append(super.toString());
                    return b2.toString();
                }
            };
            AnonymousClass5 r3 = new Range(range.getCharacterRun(i6).getStartOffset(), range.getCharacterRun(i5 - 1).getEndOffset(), range) {
                /* class org.apache.poi.hwpf.converter.AbstractWordConverter.AnonymousClass5 */

                @Override // org.apache.poi.hwpf.usermodel.Range
                public String toString() {
                    StringBuilder b2 = a.b("Dead field value subrange: ");
                    b2.append(super.toString());
                    return b2.toString();
                }
            };
            Matcher matcher = PATTERN_HYPERLINK_LOCAL.matcher(r7.text());
            if (matcher.matches()) {
                processPageref(hWPFDocumentCore, element, r3, i2, matcher.group(1));
                return;
            }
        }
        StringBuilder sb = new StringBuilder("Unsupported field type: \n");
        for (int i8 = i3; i8 <= i5; i8++) {
            sb.append("\t");
            sb.append(range.getCharacterRun(i8));
            sb.append("\n");
        }
        logger.log(5, sb);
        AnonymousClass6 r32 = new Range(range.getCharacterRun(i4).getStartOffset() + 1, range.getCharacterRun(i5).getStartOffset(), range) {
            /* class org.apache.poi.hwpf.converter.AbstractWordConverter.AnonymousClass6 */

            @Override // org.apache.poi.hwpf.usermodel.Range
            public String toString() {
                return a.a(a.b("DeadFieldValueSubrange ("), super.toString(), ")");
            }
        };
        if (i4 + 1 < i5) {
            processCharacters(hWPFDocumentCore, i2, r32, element);
        }
    }

    public void processDocument(HWPFDocumentCore hWPFDocumentCore) {
        try {
            SummaryInformation summaryInformation = hWPFDocumentCore.getSummaryInformation();
            if (summaryInformation != null) {
                processDocumentInformation(summaryInformation);
            }
        } catch (Exception e2) {
            logger.log(5, "Unable to process document summary information: ", e2, e2);
        }
        Range range = hWPFDocumentCore.getRange();
        if (range.numSections() == 1) {
            processSingleSection(hWPFDocumentCore, range.getSection(0));
            afterProcess();
            return;
        }
        processDocumentPart(hWPFDocumentCore, range);
        afterProcess();
    }

    public abstract void processDocumentInformation(SummaryInformation summaryInformation);

    public void processDocumentPart(HWPFDocumentCore hWPFDocumentCore, Range range) {
        for (int i2 = 0; i2 < range.numSections(); i2++) {
            processSection(hWPFDocumentCore, range.getSection(i2), i2);
        }
    }

    public abstract void processDrawnObject(HWPFDocument hWPFDocument, CharacterRun characterRun, OfficeDrawing officeDrawing, String str, Element element);

    public void processDrawnObject(HWPFDocument hWPFDocument, CharacterRun characterRun, Element element) {
        if (getPicturesManager() != null) {
            OfficeDrawing officeDrawingAt = hWPFDocument.getOfficeDrawingsMain().getOfficeDrawingAt(characterRun.getStartOffset());
            if (officeDrawingAt == null) {
                POILogger pOILogger = logger;
                pOILogger.log(5, "Characters #" + characterRun + " references missing drawn object");
                return;
            }
            byte[] pictureData = officeDrawingAt.getPictureData();
            if (pictureData != null) {
                float rectangleRight = ((float) (officeDrawingAt.getRectangleRight() - officeDrawingAt.getRectangleLeft())) / 1440.0f;
                float rectangleBottom = ((float) (officeDrawingAt.getRectangleBottom() - officeDrawingAt.getRectangleTop())) / 1440.0f;
                PictureType findMatchingType = PictureType.findMatchingType(pictureData);
                PicturesManager picturesManager2 = getPicturesManager();
                StringBuilder b2 = a.b(Lucene3xNormsProducer.SEPARATE_NORMS_EXTENSION);
                b2.append(characterRun.getStartOffset());
                b2.append(".");
                b2.append(findMatchingType);
                processDrawnObject(hWPFDocument, characterRun, officeDrawingAt, picturesManager2.savePicture(pictureData, findMatchingType, b2.toString(), rectangleRight, rectangleBottom), element);
            }
        }
    }

    public void processDropDownList(Element element, CharacterRun characterRun, String[] strArr, int i2) {
        outputCharacters(element, characterRun, strArr[i2]);
    }

    public abstract void processEndnoteAutonumbered(HWPFDocument hWPFDocument, int i2, Element element, Range range);

    public void processField(HWPFDocument hWPFDocument, Range range, int i2, Field field, Element element) {
        int i3;
        Range firstSubrange;
        int type = field.getType();
        if (type == 37) {
            Range firstSubrange2 = field.firstSubrange(range);
            if (firstSubrange2 != null) {
                Matcher matcher = PATTERN_PAGEREF.matcher(firstSubrange2.text());
                if (matcher.find()) {
                    processPageref(hWPFDocument, element, field.secondSubrange(range), i2, matcher.group(1));
                    return;
                }
            }
        } else if (type != 58) {
            if (type == 83) {
                Range firstSubrange3 = field.firstSubrange(range);
                CharacterRun characterRun = firstSubrange3.getCharacterRun(firstSubrange3.numCharacterRuns() - 1);
                String[] dropDownListValues = characterRun.getDropDownListValues();
                Integer dropDownListDefaultItemIndex = characterRun.getDropDownListDefaultItemIndex();
                if (dropDownListValues != null && dropDownListValues.length > 0) {
                    if (dropDownListDefaultItemIndex == null) {
                        i3 = -1;
                    } else {
                        i3 = dropDownListDefaultItemIndex.intValue();
                    }
                    processDropDownList(element, characterRun, dropDownListValues, i3);
                    return;
                }
            } else if (type == 88 && (firstSubrange = field.firstSubrange(range)) != null) {
                Matcher matcher2 = PATTERN_HYPERLINK_EXTERNAL.matcher(firstSubrange.text());
                if (matcher2.matches()) {
                    processHyperlink(hWPFDocument, element, field.secondSubrange(range), i2, matcher2.group(1));
                    return;
                }
                matcher2.usePattern(PATTERN_HYPERLINK_LOCAL);
                if (matcher2.matches()) {
                    String group = matcher2.group(1);
                    AnonymousClass7 r0 = null;
                    if (AbstractWordUtils.isNotEmpty(matcher2.group(2))) {
                        r0 = new Range(matcher2.start(2) + firstSubrange.getStartOffset(), matcher2.end(2) + firstSubrange.getStartOffset(), firstSubrange) {
                            /* class org.apache.poi.hwpf.converter.AbstractWordConverter.AnonymousClass7 */

                            @Override // org.apache.poi.hwpf.usermodel.Range
                            public String toString() {
                                return "Local hyperlink text";
                            }
                        };
                    }
                    processPageref(hWPFDocument, element, r0, i2, group);
                    return;
                }
            }
        } else if (!field.hasSeparator()) {
            POILogger pOILogger = logger;
            pOILogger.log(5, range + " contains " + field + " with 'Embedded Object' but without separator mark");
            return;
        } else {
            CharacterRun markSeparatorCharacterRun = field.getMarkSeparatorCharacterRun(range);
            if (markSeparatorCharacterRun.isOle2()) {
                if (!processOle2(hWPFDocument, markSeparatorCharacterRun, element)) {
                    processCharacters(hWPFDocument, i2, field.secondSubrange(range), element);
                    return;
                }
                return;
            }
        }
        POILogger pOILogger2 = logger;
        pOILogger2.log(5, range + " contains " + field + " with unsupported type or format");
        processCharacters(hWPFDocument, i2, field.secondSubrange(range), element);
    }

    public abstract void processFootnoteAutonumbered(HWPFDocument hWPFDocument, int i2, Element element, Range range);

    public abstract void processHyperlink(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, String str);

    public void processImage(Element element, boolean z, Picture picture) {
        PicturesManager picturesManager2 = getPicturesManager();
        if (picturesManager2 != null) {
            float horizontalScalingFactor = (float) picture.getHorizontalScalingFactor();
            float verticalScalingFactor = (float) picture.getVerticalScalingFactor();
            float dxaGoal = (float) picture.getDxaGoal();
            if (horizontalScalingFactor > 0.0f) {
                dxaGoal *= horizontalScalingFactor / 1000.0f;
            }
            float f2 = dxaGoal / 1440.0f;
            float dyaGoal = (float) picture.getDyaGoal();
            if (verticalScalingFactor > 0.0f) {
                dyaGoal *= verticalScalingFactor / 1000.0f;
            }
            String savePicture = picturesManager2.savePicture(picture.getContent(), picture.suggestPictureType(), picture.suggestFullFileName(), f2, dyaGoal / 1440.0f);
            if (AbstractWordUtils.isNotEmpty(savePicture)) {
                processImage(element, z, picture, savePicture);
                return;
            }
        }
        processImageWithoutPicturesManager(element, z, picture);
    }

    public abstract void processImage(Element element, boolean z, Picture picture, String str);

    @Internal
    public abstract void processImageWithoutPicturesManager(Element element, boolean z, Picture picture);

    public abstract void processLineBreak(Element element, CharacterRun characterRun);

    public void processNoteAnchor(HWPFDocument hWPFDocument, CharacterRun characterRun, Element element) {
        Notes footnotes = hWPFDocument.getFootnotes();
        int noteIndexByAnchorPosition = footnotes.getNoteIndexByAnchorPosition(characterRun.getStartOffset());
        if (noteIndexByAnchorPosition != -1) {
            int startOffset = hWPFDocument.getFootnoteRange().getStartOffset();
            processFootnoteAutonumbered(hWPFDocument, noteIndexByAnchorPosition, element, new Range(footnotes.getNoteTextStartOffset(noteIndexByAnchorPosition) + startOffset, startOffset + footnotes.getNoteTextEndOffset(noteIndexByAnchorPosition), hWPFDocument));
            return;
        }
        Notes endnotes = hWPFDocument.getEndnotes();
        int noteIndexByAnchorPosition2 = endnotes.getNoteIndexByAnchorPosition(characterRun.getStartOffset());
        if (noteIndexByAnchorPosition2 != -1) {
            int startOffset2 = hWPFDocument.getEndnoteRange().getStartOffset();
            processEndnoteAutonumbered(hWPFDocument, noteIndexByAnchorPosition2, element, new Range(endnotes.getNoteTextStartOffset(noteIndexByAnchorPosition2) + startOffset2, startOffset2 + endnotes.getNoteTextEndOffset(noteIndexByAnchorPosition2), hWPFDocument));
        }
    }

    public boolean processOle2(HWPFDocument hWPFDocument, Element element, Entry entry) {
        return false;
    }

    public abstract void processPageBreak(HWPFDocumentCore hWPFDocumentCore, Element element);

    public abstract void processPageref(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2, String str);

    public abstract void processParagraph(HWPFDocumentCore hWPFDocumentCore, Element element, int i2, Paragraph paragraph, String str);

    /* JADX WARNING: Removed duplicated region for block: B:23:0x0094  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x009e A[SYNTHETIC] */
    public void processParagraphes(HWPFDocumentCore hWPFDocumentCore, Element element, Range range, int i2) {
        boolean z;
        int numParagraphs = range.numParagraphs();
        int i3 = 0;
        while (i3 < numParagraphs) {
            Paragraph paragraph = range.getParagraph(i3);
            if (!paragraph.isInTable() || paragraph.getTableLevel() == i2) {
                if (paragraph.text().equals("\f")) {
                    processPageBreak(hWPFDocumentCore, element);
                }
                if (paragraph.isInList()) {
                    try {
                        processParagraph(hWPFDocumentCore, element, i2, paragraph, AbstractWordUtils.getBulletText(this.numberingState, paragraph.getList(), (char) paragraph.getIlvl()));
                        z = true;
                    } catch (Exception e2) {
                        this.log.log(5, "Can't process paragraph as list entry, will be processed without list information", e2);
                    }
                    if (z) {
                        processParagraph(hWPFDocumentCore, element, i2, paragraph, "");
                    }
                }
                z = false;
                if (z) {
                }
            } else if (paragraph.getTableLevel() >= i2) {
                Table table = range.getTable(paragraph);
                processTable(hWPFDocumentCore, element, table);
                i3 = (table.numParagraphs() + i3) - 1;
            } else {
                StringBuilder b2 = a.b("Trying to process table cell with higher level (");
                b2.append(paragraph.getTableLevel());
                b2.append(") than current table level (");
                b2.append(i2);
                b2.append(") as inner table part");
                throw new IllegalStateException(b2.toString());
            }
            i3++;
        }
    }

    public abstract void processSection(HWPFDocumentCore hWPFDocumentCore, Section section, int i2);

    public void processSingleSection(HWPFDocumentCore hWPFDocumentCore, Section section) {
        processSection(hWPFDocumentCore, section, 0);
    }

    public void processSymbol(HWPFDocument hWPFDocument, CharacterRun characterRun, Element element) {
    }

    public abstract void processTable(HWPFDocumentCore hWPFDocumentCore, Element element, Table table);

    public void setFontReplacer(FontReplacer fontReplacer2) {
        this.fontReplacer = fontReplacer2;
    }

    public void setPicturesManager(PicturesManager picturesManager2) {
        this.picturesManager = picturesManager2;
    }

    public int tryDeadField(HWPFDocumentCore hWPFDocumentCore, Range range, int i2, int i3, Element element) {
        int[] tryDeadField_lookupFieldSeparatorEnd = tryDeadField_lookupFieldSeparatorEnd(hWPFDocumentCore, range, i3);
        if (tryDeadField_lookupFieldSeparatorEnd == null) {
            return i3;
        }
        processDeadField(hWPFDocumentCore, element, range, i2, i3, tryDeadField_lookupFieldSeparatorEnd[0], tryDeadField_lookupFieldSeparatorEnd[1]);
        return tryDeadField_lookupFieldSeparatorEnd[1];
    }
}
