package org.apache.poi.hwpf.model;

import java.io.ByteArrayOutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashSet;
import java.util.IdentityHashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import org.apache.poi.hwpf.HWPFDocumentCore;
import org.apache.poi.hwpf.model.PropertyNode;
import org.apache.poi.hwpf.model.io.HWPFFileSystem;
import org.apache.poi.hwpf.sprm.SprmBuffer;
import org.apache.poi.hwpf.sprm.SprmIterator;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public class CHPBinTable {
    public static final POILogger logger = POILogFactory.getLogger(CHPBinTable.class);
    public List<CHPX> _textRuns;

    public CHPBinTable() {
        this._textRuns = new ArrayList();
    }

    public static int binarySearch(List<CHPX> list, int i2) {
        int size = list.size() - 1;
        int i3 = 0;
        while (i3 <= size) {
            int i4 = (i3 + size) >>> 1;
            int start = list.get(i4).getStart();
            if (start < i2) {
                i3 = i4 + 1;
            } else if (start <= i2) {
                return i4;
            } else {
                size = i4 - 1;
            }
        }
        return -(i3 + 1);
    }

    public void adjustForDelete(int i2, int i3, int i4) {
        int size = this._textRuns.size();
        int i5 = i3 + i4;
        CHPX chpx = this._textRuns.get(i2);
        int i6 = i2;
        while (chpx.getEnd() < i5) {
            i6++;
            chpx = this._textRuns.get(i6);
        }
        if (i2 == i6) {
            CHPX chpx2 = this._textRuns.get(i6);
            chpx2.setEnd((chpx2.getEnd() - i5) + i3);
        } else {
            this._textRuns.get(i2).setEnd(i3);
            while (true) {
                i2++;
                if (i2 >= i6) {
                    break;
                }
                CHPX chpx3 = this._textRuns.get(i2);
                chpx3.setStart(i3);
                chpx3.setEnd(i3);
            }
            CHPX chpx4 = this._textRuns.get(i6);
            chpx4.setEnd((chpx4.getEnd() - i5) + i3);
        }
        while (true) {
            i6++;
            if (i6 < size) {
                CHPX chpx5 = this._textRuns.get(i6);
                chpx5.setStart(chpx5.getStart() - i4);
                chpx5.setEnd(chpx5.getEnd() - i4);
            } else {
                return;
            }
        }
    }

    public void adjustForInsert(int i2, int i3) {
        int size = this._textRuns.size();
        CHPX chpx = this._textRuns.get(i2);
        chpx.setEnd(chpx.getEnd() + i3);
        while (true) {
            i2++;
            if (i2 < size) {
                CHPX chpx2 = this._textRuns.get(i2);
                chpx2.setStart(chpx2.getStart() + i3);
                chpx2.setEnd(chpx2.getEnd() + i3);
            } else {
                return;
            }
        }
    }

    public List<CHPX> getTextRuns() {
        return this._textRuns;
    }

    public void insert(int i2, int i3, SprmBuffer sprmBuffer) {
        CHPX chpx = new CHPX(0, 0, sprmBuffer);
        chpx.setStart(i3);
        chpx.setEnd(i3);
        if (i2 == this._textRuns.size()) {
            this._textRuns.add(chpx);
            return;
        }
        CHPX chpx2 = this._textRuns.get(i2);
        if (chpx2.getStart() < i3) {
            CHPX chpx3 = new CHPX(0, 0, chpx2.getSprmBuf());
            chpx3.setStart(i3);
            chpx3.setEnd(chpx2.getEnd());
            chpx2.setEnd(i3);
            this._textRuns.add(i2 + 1, chpx);
            this._textRuns.add(i2 + 2, chpx3);
            return;
        }
        this._textRuns.add(i2, chpx);
    }

    public void rebuild(ComplexFileTable complexFileTable) {
        boolean z;
        long currentTimeMillis = System.currentTimeMillis();
        if (complexFileTable != null) {
            SprmBuffer[] grpprls = complexFileTable.getGrpprls();
            for (TextPiece textPiece : complexFileTable.getTextPieceTable().getTextPieces()) {
                PropertyModifier prm = textPiece.getPieceDescriptor().getPrm();
                if (prm.isComplex()) {
                    short igrpprl = prm.getIgrpprl();
                    if (igrpprl < 0 || igrpprl >= grpprls.length) {
                        logger.log(5, textPiece + "'s PRM references to unknown grpprl");
                    } else {
                        SprmBuffer sprmBuffer = grpprls[igrpprl];
                        SprmIterator it = sprmBuffer.iterator();
                        while (true) {
                            if (it.hasNext()) {
                                if (it.next().getType() == 2) {
                                    z = true;
                                    break;
                                }
                            } else {
                                z = false;
                                break;
                            }
                        }
                        if (z) {
                            this._textRuns.add(new CHPX(textPiece.getStart(), textPiece.getEnd(), sprmBuffer.clone()));
                        }
                    }
                }
            }
            logger.log(1, "Merged with CHPX from complex file table in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis), " ms (", Integer.valueOf(this._textRuns.size()), " elements in total)");
            currentTimeMillis = System.currentTimeMillis();
        }
        ArrayList arrayList = new ArrayList(this._textRuns);
        Collections.sort(arrayList, PropertyNode.StartComparator.instance);
        logger.log(1, "CHPX sorted by start position in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis), " ms");
        long currentTimeMillis2 = System.currentTimeMillis();
        final IdentityHashMap identityHashMap = new IdentityHashMap();
        int i2 = 0;
        for (CHPX chpx : this._textRuns) {
            identityHashMap.put(chpx, Integer.valueOf(i2));
            i2++;
        }
        AnonymousClass1 r13 = new Comparator<CHPX>() {
            /* class org.apache.poi.hwpf.model.CHPBinTable.AnonymousClass1 */

            public int compare(CHPX chpx, CHPX chpx2) {
                return ((Integer) identityHashMap.get(chpx)).compareTo((Integer) identityHashMap.get(chpx2));
            }
        };
        logger.log(1, "CHPX's order map created in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis2), " ms");
        long currentTimeMillis3 = System.currentTimeMillis();
        HashSet hashSet = new HashSet();
        for (CHPX chpx2 : this._textRuns) {
            hashSet.add(Integer.valueOf(chpx2.getStart()));
            hashSet.add(Integer.valueOf(chpx2.getEnd()));
        }
        hashSet.remove(0);
        ArrayList arrayList2 = new ArrayList(hashSet);
        Collections.sort(arrayList2);
        logger.log(1, "Texts CHPX boundaries collected in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis3), " ms");
        long currentTimeMillis4 = System.currentTimeMillis();
        LinkedList linkedList = new LinkedList();
        Iterator it2 = arrayList2.iterator();
        int i3 = 0;
        while (it2.hasNext()) {
            int intValue = ((Integer) it2.next()).intValue();
            int abs = Math.abs(binarySearch(arrayList, intValue));
            while (abs >= arrayList.size()) {
                abs--;
            }
            while (abs > 0 && ((CHPX) arrayList.get(abs)).getStart() >= intValue) {
                abs--;
            }
            LinkedList linkedList2 = new LinkedList();
            while (abs < arrayList.size()) {
                CHPX chpx3 = (CHPX) arrayList.get(abs);
                if (intValue < chpx3.getStart()) {
                    break;
                }
                if (Math.max(i3, chpx3.getStart()) < Math.min(intValue, chpx3.getEnd())) {
                    linkedList2.add(chpx3);
                }
                abs++;
            }
            if (linkedList2.size() == 0) {
                logger.log(5, "Text piece [", Integer.valueOf(i3), "; ", Integer.valueOf(intValue), ") has no CHPX. Creating new one.");
                linkedList.add(new CHPX(i3, intValue, new SprmBuffer(0)));
            } else {
                if (linkedList2.size() == 1) {
                    CHPX chpx4 = (CHPX) linkedList2.get(0);
                    if (chpx4.getStart() == i3 && chpx4.getEnd() == intValue) {
                        linkedList.add(chpx4);
                    }
                }
                Collections.sort(linkedList2, r13);
                SprmBuffer sprmBuffer2 = new SprmBuffer(0);
                Iterator it3 = linkedList2.iterator();
                while (it3.hasNext()) {
                    sprmBuffer2.append(((CHPX) it3.next()).getGrpprl(), 0);
                }
                linkedList.add(new CHPX(i3, intValue, sprmBuffer2));
            }
            i3 = intValue;
        }
        this._textRuns = new ArrayList(linkedList);
        logger.log(1, "CHPX rebuilded in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis4), " ms (", Integer.valueOf(this._textRuns.size()), " elements)");
        long currentTimeMillis5 = System.currentTimeMillis();
        CHPX chpx5 = null;
        Iterator<CHPX> it4 = this._textRuns.iterator();
        while (it4.hasNext()) {
            CHPX next = it4.next();
            if (chpx5 != null && chpx5.getEnd() == next.getStart() && Arrays.equals(chpx5.getGrpprl(), next.getGrpprl())) {
                chpx5.setEnd(next.getEnd());
                it4.remove();
            } else {
                chpx5 = next;
            }
        }
        logger.log(1, "CHPX compacted in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis5), " ms (", Integer.valueOf(this._textRuns.size()), " elements)");
    }

    @Deprecated
    public void writeTo(HWPFFileSystem hWPFFileSystem, int i2, CharIndexTranslator charIndexTranslator) {
        writeTo(hWPFFileSystem.getStream(HWPFDocumentCore.STREAM_WORD_DOCUMENT), hWPFFileSystem.getStream(HWPFDocumentCore.STREAM_TABLE_1), i2, charIndexTranslator);
    }

    public CHPBinTable(byte[] bArr, byte[] bArr2, int i2, int i3, int i4, TextPieceTable textPieceTable) {
        this(bArr, bArr2, i2, i3, textPieceTable);
    }

    public CHPBinTable(byte[] bArr, byte[] bArr2, int i2, int i3, CharIndexTranslator charIndexTranslator) {
        this._textRuns = new ArrayList();
        long currentTimeMillis = System.currentTimeMillis();
        PlexOfCps plexOfCps = new PlexOfCps(bArr2, i2, i3, 4);
        int length = plexOfCps.length();
        for (int i4 = 0; i4 < length; i4++) {
            for (CHPX chpx : new CHPFormattedDiskPage(bArr, LittleEndian.getInt(plexOfCps.getProperty(i4).getBytes()) * 512, charIndexTranslator).getCHPXs()) {
                if (chpx != null) {
                    this._textRuns.add(chpx);
                }
            }
        }
        logger.log(1, "CHPX FKPs loaded in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis), " ms (", Integer.valueOf(this._textRuns.size()), " elements)");
        if (this._textRuns.isEmpty()) {
            logger.log(5, "CHPX FKPs are empty");
            this._textRuns.add(new CHPX(0, 0, new SprmBuffer(0)));
        }
    }

    public void writeTo(ByteArrayOutputStream byteArrayOutputStream, ByteArrayOutputStream byteArrayOutputStream2, int i2, CharIndexTranslator charIndexTranslator) {
        PlexOfCps plexOfCps = new PlexOfCps(4);
        int size = byteArrayOutputStream.size() % 512;
        if (size != 0) {
            byteArrayOutputStream.write(new byte[(512 - size)]);
        }
        int size2 = byteArrayOutputStream.size() / 512;
        List<CHPX> list = this._textRuns;
        int byteIndex = charIndexTranslator.getByteIndex(list.get(list.size() - 1).getEnd());
        List<CHPX> list2 = this._textRuns;
        while (true) {
            int byteIndex2 = charIndexTranslator.getByteIndex(list2.get(0).getStart());
            CHPFormattedDiskPage cHPFormattedDiskPage = new CHPFormattedDiskPage();
            cHPFormattedDiskPage.fill(list2);
            byteArrayOutputStream.write(cHPFormattedDiskPage.toByteArray(charIndexTranslator));
            list2 = cHPFormattedDiskPage.getOverflow();
            int byteIndex3 = list2 != null ? charIndexTranslator.getByteIndex(list2.get(0).getStart()) : byteIndex;
            byte[] bArr = new byte[4];
            int i3 = size2 + 1;
            LittleEndian.putInt(bArr, 0, size2);
            plexOfCps.addProperty(new GenericPropertyNode(byteIndex2, byteIndex3, bArr));
            if (list2 == null) {
                byteArrayOutputStream2.write(plexOfCps.toByteArray());
                return;
            }
            size2 = i3;
        }
    }
}
