package org.apache.poi.hwpf.model;

import java.util.ArrayList;
import java.util.List;
import org.apache.poi.ddf.DefaultEscherRecordFactory;
import org.apache.poi.ddf.EscherBSERecord;
import org.apache.poi.ddf.EscherBlipRecord;
import org.apache.poi.ddf.EscherRecord;
import org.apache.poi.ddf.EscherRecordFactory;
import org.apache.poi.hwpf.HWPFDocument;
import org.apache.poi.hwpf.usermodel.CharacterRun;
import org.apache.poi.hwpf.usermodel.Picture;
import org.apache.poi.hwpf.usermodel.Range;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public final class PicturesTable {
    public static final int BLOCK_TYPE_OFFSET = 14;
    public static final int MM_MODE_TYPE_OFFSET = 6;
    public static final int TYPE_HORIZONTAL_LINE = 14;
    public static final int TYPE_IMAGE = 8;
    public static final int TYPE_IMAGE_PASTED_FROM_CLIPBOARD = 10;
    public static final int TYPE_IMAGE_PASTED_FROM_CLIPBOARD_WORD2000 = 2;
    public static final int TYPE_IMAGE_WORD2000 = 0;
    public static final POILogger logger = POILogFactory.getLogger(PicturesTable.class);
    public byte[] _dataStream;
    @Deprecated
    public EscherRecordHolder _dgg;
    public HWPFDocument _document;
    @Deprecated
    public FSPATable _fspa;
    public byte[] _mainStream;

    @Deprecated
    public PicturesTable(HWPFDocument hWPFDocument, byte[] bArr, byte[] bArr2, FSPATable fSPATable, EscherRecordHolder escherRecordHolder) {
        this._document = hWPFDocument;
        this._dataStream = bArr;
        this._mainStream = bArr2;
        this._fspa = fSPATable;
        this._dgg = escherRecordHolder;
    }

    public static short getBlockType(byte[] bArr, int i2) {
        return LittleEndian.getShort(bArr, i2 + 14);
    }

    public static short getMmMode(byte[] bArr, int i2) {
        return LittleEndian.getShort(bArr, i2 + 6);
    }

    private boolean isBlockContainsHorizontalLine(int i2) {
        return getBlockType(this._dataStream, i2) == 14 && getMmMode(this._dataStream, i2) == 100;
    }

    private boolean isBlockContainsImage(int i2) {
        return isPictureRecognized(getBlockType(this._dataStream, i2), getMmMode(this._dataStream, i2));
    }

    private boolean isPictureRecognized(short s, short s2) {
        return s == 8 || s == 10 || (s == 0 && s2 == 100) || (s == 2 && s2 == 100);
    }

    private void searchForPictures(List<EscherRecord> list, List<Picture> list2) {
        for (EscherRecord escherRecord : list) {
            if (escherRecord instanceof EscherBSERecord) {
                EscherBSERecord escherBSERecord = (EscherBSERecord) escherRecord;
                EscherBlipRecord blipRecord = escherBSERecord.getBlipRecord();
                if (blipRecord != null) {
                    list2.add(new Picture(blipRecord));
                } else if (escherBSERecord.getOffset() > 0) {
                    try {
                        EscherRecordFactory defaultEscherRecordFactory = new DefaultEscherRecordFactory();
                        EscherRecord createRecord = defaultEscherRecordFactory.createRecord(this._mainStream, escherBSERecord.getOffset());
                        if (createRecord instanceof EscherBlipRecord) {
                            createRecord.fillFields(this._mainStream, escherBSERecord.getOffset(), defaultEscherRecordFactory);
                            list2.add(new Picture((EscherBlipRecord) createRecord));
                        }
                    } catch (Exception e2) {
                        logger.log(5, "Unable to load picture from BLIB record at offset #", Integer.valueOf(escherBSERecord.getOffset()), e2);
                    }
                }
            }
            searchForPictures(escherRecord.getChildRecords(), list2);
        }
    }

    public Picture extractPicture(CharacterRun characterRun, boolean z) {
        if (hasPicture(characterRun)) {
            return new Picture(characterRun.getPicOffset(), this._dataStream, z);
        }
        return null;
    }

    public List<Picture> getAllPictures() {
        Picture extractPicture;
        ArrayList arrayList = new ArrayList();
        Range overallRange = this._document.getOverallRange();
        for (int i2 = 0; i2 < overallRange.numCharacterRuns(); i2++) {
            CharacterRun characterRun = overallRange.getCharacterRun(i2);
            if (!(characterRun == null || (extractPicture = extractPicture(characterRun, false)) == null)) {
                arrayList.add(extractPicture);
            }
        }
        searchForPictures(this._dgg.getEscherRecords(), arrayList);
        return arrayList;
    }

    public boolean hasEscherPicture(CharacterRun characterRun) {
        return characterRun.isSpecialCharacter() && !characterRun.isObj() && !characterRun.isOle2() && !characterRun.isData() && characterRun.text().startsWith("\b");
    }

    public boolean hasHorizontalLine(CharacterRun characterRun) {
        if (!characterRun.isSpecialCharacter() || !"\u0001".equals(characterRun.text())) {
            return false;
        }
        return isBlockContainsHorizontalLine(characterRun.getPicOffset());
    }

    public boolean hasPicture(CharacterRun characterRun) {
        if (characterRun != null && characterRun.isSpecialCharacter() && !characterRun.isObj() && !characterRun.isOle2() && !characterRun.isData() && ("\u0001".equals(characterRun.text()) || "\u0001\u0015".equals(characterRun.text()))) {
            return isBlockContainsImage(characterRun.getPicOffset());
        }
        return false;
    }

    public PicturesTable(HWPFDocument hWPFDocument, byte[] bArr, byte[] bArr2) {
        this._document = hWPFDocument;
        this._dataStream = bArr;
        this._mainStream = bArr2;
    }
}
