package org.apache.poi.hwpf.model;

import java.io.ByteArrayOutputStream;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

@Internal
public class TextPieceTable implements CharIndexTranslator {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final POILogger logger = POILogFactory.getLogger(TextPieceTable.class);
    public int _cpMin;
    public ArrayList<TextPiece> _textPieces = new ArrayList<>();
    public ArrayList<TextPiece> _textPiecesFCOrder = new ArrayList<>();

    public static class FCComparator implements Comparator<TextPiece>, Serializable {
        public int compare(TextPiece textPiece, TextPiece textPiece2) {
            if (textPiece.getPieceDescriptor().fc > textPiece2.getPieceDescriptor().fc) {
                return 1;
            }
            return textPiece.getPieceDescriptor().fc < textPiece2.getPieceDescriptor().fc ? -1 : 0;
        }
    }

    public TextPieceTable() {
    }

    public void add(TextPiece textPiece) {
        this._textPieces.add(textPiece);
        this._textPiecesFCOrder.add(textPiece);
        Collections.sort(this._textPieces);
        Collections.sort(this._textPiecesFCOrder, new FCComparator());
    }

    public int adjustForInsert(int i2, int i3) {
        int size = this._textPieces.size();
        TextPiece textPiece = this._textPieces.get(i2);
        textPiece.setEnd(textPiece.getEnd() + i3);
        while (true) {
            i2++;
            if (i2 >= size) {
                return i3;
            }
            TextPiece textPiece2 = this._textPieces.get(i2);
            textPiece2.setStart(textPiece2.getStart() + i3);
            textPiece2.setEnd(textPiece2.getEnd() + i3);
        }
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof TextPieceTable)) {
            return false;
        }
        TextPieceTable textPieceTable = (TextPieceTable) obj;
        int size = textPieceTable._textPieces.size();
        if (size != this._textPieces.size()) {
            return false;
        }
        for (int i2 = 0; i2 < size; i2++) {
            if (!textPieceTable._textPieces.get(i2).equals(this._textPieces.get(i2))) {
                return false;
            }
        }
        return true;
    }

    @Override // org.apache.poi.hwpf.model.CharIndexTranslator
    public int getByteIndex(int i2) {
        Iterator<TextPiece> it = this._textPieces.iterator();
        int i3 = 0;
        while (it.hasNext()) {
            TextPiece next = it.next();
            int i4 = 2;
            if (i2 >= next.getEnd()) {
                int filePosition = next.getPieceDescriptor().getFilePosition();
                int end = next.getEnd() - next.getStart();
                if (!next.isUnicode()) {
                    i4 = 1;
                }
                i3 = filePosition + (end * i4);
                if (i2 == next.getEnd()) {
                    return i3;
                }
            } else if (i2 < next.getEnd()) {
                int start = i2 - next.getStart();
                int filePosition2 = next.getPieceDescriptor().getFilePosition();
                if (!next.isUnicode()) {
                    i4 = 1;
                }
                return (start * i4) + filePosition2;
            }
        }
        return i3;
    }

    @Override // org.apache.poi.hwpf.model.CharIndexTranslator
    @Deprecated
    public int getCharIndex(int i2) {
        return getCharIndex(i2, 0);
    }

    @Override // org.apache.poi.hwpf.model.CharIndexTranslator
    public int[][] getCharIndexRanges(int i2, int i3) {
        LinkedList linkedList = new LinkedList();
        Iterator<TextPiece> it = this._textPiecesFCOrder.iterator();
        while (it.hasNext()) {
            TextPiece next = it.next();
            int filePosition = next.getPieceDescriptor().getFilePosition();
            int bytesLength = next.bytesLength() + next.getPieceDescriptor().getFilePosition();
            if (i2 <= bytesLength) {
                if (i3 <= filePosition) {
                    break;
                }
                int max = Math.max(filePosition, i2);
                int min = Math.min(bytesLength, i3);
                int i4 = min - max;
                if (max <= min) {
                    int encodingMultiplier = getEncodingMultiplier(next);
                    int start = ((max - filePosition) / encodingMultiplier) + next.getStart();
                    linkedList.add(new int[]{start, (i4 / encodingMultiplier) + start});
                }
            }
        }
        return (int[][]) linkedList.toArray(new int[linkedList.size()][]);
    }

    public int getCpMin() {
        return this._cpMin;
    }

    public int getEncodingMultiplier(TextPiece textPiece) {
        return textPiece.isUnicode() ? 2 : 1;
    }

    public StringBuilder getText() {
        long currentTimeMillis = System.currentTimeMillis();
        StringBuilder sb = new StringBuilder();
        Iterator<TextPiece> it = this._textPieces.iterator();
        while (it.hasNext()) {
            TextPiece next = it.next();
            String sb2 = next.getStringBuilder().toString();
            int length = sb2.length();
            if (length != next.getEnd() - next.getStart()) {
                logger.log(5, "Text piece has boundaries [", Integer.valueOf(next.getStart()), "; ", Integer.valueOf(next.getEnd()), ") but length ", Integer.valueOf(next.getEnd() - next.getStart()));
            }
            sb.replace(next.getStart(), next.getStart() + length, sb2);
        }
        logger.log(1, "Document text were rebuilded in ", Long.valueOf(System.currentTimeMillis() - currentTimeMillis), " ms (", Integer.valueOf(sb.length()), " chars)");
        return sb;
    }

    public List<TextPiece> getTextPieces() {
        return this._textPieces;
    }

    public int hashCode() {
        return this._textPieces.size();
    }

    @Override // org.apache.poi.hwpf.model.CharIndexTranslator
    public boolean isIndexInTable(int i2) {
        Iterator<TextPiece> it = this._textPiecesFCOrder.iterator();
        while (it.hasNext()) {
            TextPiece next = it.next();
            int filePosition = next.getPieceDescriptor().getFilePosition();
            if (i2 <= next.bytesLength() + filePosition) {
                if (filePosition > i2) {
                    return false;
                }
                return true;
            }
        }
        return false;
    }

    @Override // org.apache.poi.hwpf.model.CharIndexTranslator
    public int lookIndexBackward(int i2) {
        Iterator<TextPiece> it = this._textPiecesFCOrder.iterator();
        int i3 = 0;
        while (it.hasNext()) {
            TextPiece next = it.next();
            int filePosition = next.getPieceDescriptor().getFilePosition();
            if (i2 <= next.bytesLength() + filePosition) {
                return filePosition > i2 ? i3 : i2;
            }
            i3 = next.bytesLength() + filePosition;
        }
        return i2;
    }

    @Override // org.apache.poi.hwpf.model.CharIndexTranslator
    public int lookIndexForward(int i2) {
        if (!this._textPiecesFCOrder.isEmpty()) {
            int i3 = 0;
            if (this._textPiecesFCOrder.get(0).getPieceDescriptor().getFilePosition() > i2) {
                return this._textPiecesFCOrder.get(0).getPieceDescriptor().getFilePosition();
            }
            ArrayList<TextPiece> arrayList = this._textPiecesFCOrder;
            if (arrayList.get(arrayList.size() - 1).getPieceDescriptor().getFilePosition() <= i2) {
                return i2;
            }
            int size = this._textPiecesFCOrder.size() - 1;
            while (i3 <= size) {
                int i4 = (i3 + size) >>> 1;
                TextPiece textPiece = this._textPiecesFCOrder.get(i4);
                int filePosition = textPiece.getPieceDescriptor().getFilePosition();
                if (filePosition < i2) {
                    i3 = i4 + 1;
                } else if (filePosition <= i2) {
                    return textPiece.getPieceDescriptor().getFilePosition();
                } else {
                    size = i4 - 1;
                }
            }
            return this._textPiecesFCOrder.get(i3 + 1).getPieceDescriptor().getFilePosition();
        }
        throw new IllegalStateException("Text pieces table is empty");
    }

    public TextPiece newTextPiece(int i2, int i3, byte[] bArr, PieceDescriptor pieceDescriptor) {
        return new TextPiece(i2, i3, bArr, pieceDescriptor);
    }

    public byte[] writeTo(ByteArrayOutputStream byteArrayOutputStream) {
        PlexOfCps plexOfCps = new PlexOfCps(PieceDescriptor.getSizeInBytes());
        Iterator<TextPiece> it = this._textPieces.iterator();
        while (it.hasNext()) {
            TextPiece next = it.next();
            PieceDescriptor pieceDescriptor = next.getPieceDescriptor();
            int size = byteArrayOutputStream.size() % 512;
            if (size != 0) {
                byteArrayOutputStream.write(new byte[(512 - size)]);
            }
            pieceDescriptor.setFilePosition(byteArrayOutputStream.size());
            byteArrayOutputStream.write(next.getRawBytes());
            plexOfCps.addProperty(new GenericPropertyNode(next.getStart(), next.getEnd(), pieceDescriptor.toByteArray()));
        }
        return plexOfCps.toByteArray();
    }

    @Override // org.apache.poi.hwpf.model.CharIndexTranslator
    @Deprecated
    public int getCharIndex(int i2, int i3) {
        int lookIndexForward = lookIndexForward(i2);
        Iterator<TextPiece> it = this._textPieces.iterator();
        int i4 = 0;
        while (it.hasNext()) {
            TextPiece next = it.next();
            int filePosition = next.getPieceDescriptor().getFilePosition();
            int bytesLength = next.bytesLength();
            int i5 = filePosition + bytesLength;
            if (lookIndexForward >= filePosition && lookIndexForward <= i5) {
                bytesLength = (lookIndexForward <= filePosition || lookIndexForward >= i5) ? bytesLength - (i5 - lookIndexForward) : lookIndexForward - filePosition;
            }
            i4 = next.isUnicode() ? (bytesLength / 2) + i4 : i4 + bytesLength;
            if (lookIndexForward >= filePosition && lookIndexForward <= i5 && i4 >= i3) {
                break;
            }
        }
        return i4;
    }

    public TextPieceTable(byte[] bArr, byte[] bArr2, int i2, int i3, int i4) {
        PlexOfCps plexOfCps = new PlexOfCps(bArr2, i2, i3, PieceDescriptor.getSizeInBytes());
        int length = plexOfCps.length();
        PieceDescriptor[] pieceDescriptorArr = new PieceDescriptor[length];
        for (int i5 = 0; i5 < length; i5++) {
            pieceDescriptorArr[i5] = new PieceDescriptor(plexOfCps.getProperty(i5).getBytes(), 0);
        }
        this._cpMin = pieceDescriptorArr[0].getFilePosition() - i4;
        for (int i6 = 0; i6 < length; i6++) {
            int filePosition = pieceDescriptorArr[i6].getFilePosition() - i4;
            if (filePosition < this._cpMin) {
                this._cpMin = filePosition;
            }
        }
        for (int i7 = 0; i7 < length; i7++) {
            int filePosition2 = pieceDescriptorArr[i7].getFilePosition();
            GenericPropertyNode property = plexOfCps.getProperty(i7);
            int start = property.getStart();
            int end = property.getEnd();
            int i8 = (end - start) * (pieceDescriptorArr[i7].isUnicode() ? 2 : 1);
            byte[] bArr3 = new byte[i8];
            System.arraycopy(bArr, filePosition2, bArr3, 0, i8);
            this._textPieces.add(newTextPiece(start, end, bArr3, pieceDescriptorArr[i7]));
        }
        Collections.sort(this._textPieces);
        ArrayList<TextPiece> arrayList = new ArrayList<>(this._textPieces);
        this._textPiecesFCOrder = arrayList;
        Collections.sort(arrayList, new FCComparator());
    }

    public boolean isIndexInTable(int i2, int i3) {
        Iterator<TextPiece> it = this._textPiecesFCOrder.iterator();
        while (it.hasNext()) {
            TextPiece next = it.next();
            int filePosition = next.getPieceDescriptor().getFilePosition();
            if (i2 < next.bytesLength() + filePosition) {
                if (Math.max(i2, filePosition) >= Math.min(i3, next.bytesLength() + filePosition)) {
                    return false;
                }
                return true;
            }
        }
        return false;
    }
}
