package org.apache.poi.hwpf.usermodel;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.hwpf.model.FieldsDocumentPart;
import org.apache.poi.hwpf.model.FieldsTables;
import org.apache.poi.hwpf.model.PlexOfField;
import org.apache.poi.util.Internal;

@Internal
public class FieldsImpl implements Fields {
    public Map<FieldsDocumentPart, Map<Integer, FieldImpl>> _fieldsByOffset = new HashMap(FieldsDocumentPart.values().length);
    public PlexOfFieldComparator comparator = new PlexOfFieldComparator();

    public static final class PlexOfFieldComparator implements Comparator<PlexOfField>, Serializable {
        public PlexOfFieldComparator() {
        }

        public int compare(PlexOfField plexOfField, PlexOfField plexOfField2) {
            int fcStart = plexOfField.getFcStart();
            int fcStart2 = plexOfField2.getFcStart();
            if (fcStart < fcStart2) {
                return -1;
            }
            return fcStart == fcStart2 ? 0 : 1;
        }
    }

    public FieldsImpl(FieldsTables fieldsTables) {
        FieldsDocumentPart[] values = FieldsDocumentPart.values();
        for (FieldsDocumentPart fieldsDocumentPart : values) {
            this._fieldsByOffset.put(fieldsDocumentPart, parseFieldStructure(fieldsTables.getFieldsPLCF(fieldsDocumentPart)));
        }
    }

    public static <T> int binarySearch(List<PlexOfField> list, int i2, int i3, int i4) {
        checkIndexForBinarySearch(list.size(), i2, i3);
        int i5 = i3 - 1;
        int i6 = -1;
        int i7 = i2;
        while (i7 <= i5) {
            i6 = (i7 + i5) >>> 1;
            int fcStart = list.get(i6).getFcStart();
            if (fcStart == i4) {
                return i6;
            }
            if (fcStart < i4) {
                i7 = i6 + 1;
            } else {
                i5 = i6 - 1;
            }
        }
        if (i6 >= 0) {
            return (-i6) - 1;
        }
        int i8 = i3;
        while (i2 < i3) {
            if (i4 < list.get(i2).getFcStart()) {
                i8 = i2;
            }
            i2++;
        }
        return (-i8) - 1;
    }

    public static void checkIndexForBinarySearch(int i2, int i3, int i4) {
        if (i3 > i4) {
            throw new IllegalArgumentException();
        } else if (i2 < i4 || i3 < 0) {
            throw new ArrayIndexOutOfBoundsException();
        }
    }

    private Map<Integer, FieldImpl> parseFieldStructure(List<PlexOfField> list) {
        if (list == null || list.isEmpty()) {
            return new HashMap();
        }
        Collections.sort(list, this.comparator);
        ArrayList arrayList = new ArrayList((list.size() / 3) + 1);
        parseFieldStructureImpl(list, 0, list.size(), arrayList);
        HashMap hashMap = new HashMap(arrayList.size());
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            FieldImpl fieldImpl = (FieldImpl) it.next();
            hashMap.put(Integer.valueOf(fieldImpl.getFieldStartOffset()), fieldImpl);
        }
        return hashMap;
    }

    private void parseFieldStructureImpl(List<PlexOfField> list, int i2, int i3, List<FieldImpl> list2) {
        while (i2 < i3) {
            PlexOfField plexOfField = list.get(i2);
            if (plexOfField.getFld().getBoundaryType() != 19) {
                i2++;
            } else {
                i2++;
                int binarySearch = binarySearch(list, i2, i3, plexOfField.getFcEnd());
                if (binarySearch >= 0) {
                    PlexOfField plexOfField2 = list.get(binarySearch);
                    int boundaryType = plexOfField2.getFld().getBoundaryType();
                    if (boundaryType == 20) {
                        int binarySearch2 = binarySearch(list, binarySearch, i3, plexOfField2.getFcEnd());
                        if (binarySearch2 >= 0) {
                            PlexOfField plexOfField3 = list.get(binarySearch2);
                            if (plexOfField3.getFld().getBoundaryType() == 21) {
                                list2.add(new FieldImpl(plexOfField, plexOfField2, plexOfField3));
                                if (plexOfField.getFcStart() + 1 < plexOfField2.getFcStart() - 1) {
                                    parseFieldStructureImpl(list, i2, binarySearch, list2);
                                }
                                if (plexOfField2.getFcStart() + 1 < plexOfField3.getFcStart() - 1) {
                                    parseFieldStructureImpl(list, binarySearch + 1, binarySearch2, list2);
                                }
                                i2 = binarySearch2 + 1;
                            }
                        }
                    } else if (boundaryType == 21) {
                        list2.add(new FieldImpl(plexOfField, null, plexOfField2));
                        if (plexOfField.getFcStart() + 1 < plexOfField2.getFcStart() - 1) {
                            parseFieldStructureImpl(list, i2, binarySearch, list2);
                        }
                        i2 = binarySearch + 1;
                    }
                }
            }
        }
    }

    @Override // org.apache.poi.hwpf.usermodel.Fields
    public Collection<Field> getFields(FieldsDocumentPart fieldsDocumentPart) {
        Map<Integer, FieldImpl> map = this._fieldsByOffset.get(fieldsDocumentPart);
        if (map == null || map.isEmpty()) {
            return Collections.emptySet();
        }
        return Collections.unmodifiableCollection(map.values());
    }

    @Override // org.apache.poi.hwpf.usermodel.Fields
    public FieldImpl getFieldByStartOffset(FieldsDocumentPart fieldsDocumentPart, int i2) {
        Map<Integer, FieldImpl> map = this._fieldsByOffset.get(fieldsDocumentPart);
        if (map == null || map.isEmpty()) {
            return null;
        }
        return map.get(Integer.valueOf(i2));
    }
}
