package org.apache.poi.openxml4j.opc;

import b.b.a.a.a;
import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.exceptions.InvalidOperationException;
import org.apache.poi.openxml4j.exceptions.OpenXML4JRuntimeException;
import org.apache.poi.openxml4j.exceptions.PartAlreadyExistsException;
import org.apache.poi.openxml4j.opc.internal.ContentType;
import org.apache.poi.openxml4j.opc.internal.ContentTypeManager;
import org.apache.poi.openxml4j.opc.internal.PackagePropertiesPart;
import org.apache.poi.openxml4j.opc.internal.PartMarshaller;
import org.apache.poi.openxml4j.opc.internal.PartUnmarshaller;
import org.apache.poi.openxml4j.opc.internal.ZipContentTypeManager;
import org.apache.poi.openxml4j.opc.internal.marshallers.DefaultMarshaller;
import org.apache.poi.openxml4j.opc.internal.marshallers.ZipPackagePropertiesMarshaller;
import org.apache.poi.openxml4j.opc.internal.unmarshallers.PackagePropertiesUnmarshaller;
import org.apache.poi.openxml4j.opc.internal.unmarshallers.UnmarshallContext;
import org.apache.poi.openxml4j.util.Nullable;
import org.apache.poi.openxml4j.util.ZipEntrySource;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.NotImplemented;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public abstract class OPCPackage implements RelationshipSource, Closeable {
    public static final PackageAccess defaultPackageAccess = PackageAccess.READ_WRITE;
    public static final POILogger logger = POILogFactory.getLogger(OPCPackage.class);
    public ContentTypeManager contentTypeManager;
    public PartMarshaller defaultPartMarshaller;
    public boolean isDirty = false;
    public String originalPackagePath;
    public OutputStream output;
    public PackageAccess packageAccess;
    public PackagePropertiesPart packageProperties;
    public PackagePartCollection partList;
    public Map<ContentType, PartMarshaller> partMarshallers;
    public Map<ContentType, PartUnmarshaller> partUnmarshallers;
    public PackageRelationshipCollection relationships;

    public OPCPackage(PackageAccess packageAccess2) {
        if (getClass() == ZipPackage.class) {
            init();
            this.packageAccess = packageAccess2;
            return;
        }
        throw new IllegalArgumentException("PackageBase may not be subclassed");
    }

    public static void configurePackage(OPCPackage oPCPackage) {
        try {
            ZipContentTypeManager zipContentTypeManager = new ZipContentTypeManager(null, oPCPackage);
            oPCPackage.contentTypeManager = zipContentTypeManager;
            zipContentTypeManager.addContentType(PackagingURIHelper.createPartName(PackagingURIHelper.PACKAGE_RELATIONSHIPS_ROOT_URI), ContentTypes.RELATIONSHIPS_PART);
            oPCPackage.contentTypeManager.addContentType(PackagingURIHelper.createPartName("/default.xml"), ContentTypes.PLAIN_OLD_XML);
            PackagePropertiesPart packagePropertiesPart = new PackagePropertiesPart(oPCPackage, PackagingURIHelper.CORE_PROPERTIES_PART_NAME);
            oPCPackage.packageProperties = packagePropertiesPart;
            packagePropertiesPart.setCreatorProperty("Generated by Apache POI OpenXML4J");
            oPCPackage.packageProperties.setCreatedProperty(new Nullable<>(new Date()));
        } catch (InvalidFormatException e2) {
            throw new IllegalStateException(e2);
        }
    }

    public static OPCPackage create(String str) {
        return create(new File(str));
    }

    private PackageRelationshipCollection getRelationshipsHelper(String str) {
        throwExceptionIfWriteOnly();
        ensureRelationships();
        return this.relationships.getRelationships(str);
    }

    private void init() {
        this.partMarshallers = new HashMap(5);
        HashMap hashMap = new HashMap(2);
        this.partUnmarshallers = hashMap;
        try {
            hashMap.put(new ContentType(ContentTypes.CORE_PROPERTIES_PART), new PackagePropertiesUnmarshaller());
            this.defaultPartMarshaller = new DefaultMarshaller();
            this.partMarshallers.put(new ContentType(ContentTypes.CORE_PROPERTIES_PART), new ZipPackagePropertiesMarshaller());
        } catch (InvalidFormatException e2) {
            StringBuilder b2 = a.b("Package.init() : this exception should never happen, if you read this message please send a mail to the developers team. : ");
            b2.append(e2.getMessage());
            throw new OpenXML4JRuntimeException(b2.toString(), e2);
        }
    }

    public static OPCPackage open(String str) {
        return open(str, defaultPackageAccess);
    }

    public static OPCPackage openOrCreate(File file) {
        if (file.exists()) {
            return open(file.getAbsolutePath());
        }
        return create(file);
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationship addExternalRelationship(String str, String str2) {
        return addExternalRelationship(str, str2, null);
    }

    public void addMarshaller(String str, PartMarshaller partMarshaller) {
        try {
            this.partMarshallers.put(new ContentType(str), partMarshaller);
        } catch (InvalidFormatException e2) {
            POILogger pOILogger = logger;
            StringBuilder b2 = a.b("The specified content type is not valid: '");
            b2.append(e2.getMessage());
            b2.append("'. The marshaller will not be added !");
            pOILogger.log(5, b2.toString());
        }
    }

    public PackagePart addPackagePart(PackagePart packagePart) {
        throwExceptionIfReadOnly();
        if (packagePart != null) {
            if (this.partList.containsKey(packagePart._partName)) {
                if (this.partList.get(packagePart._partName).isDeleted()) {
                    packagePart.setDeleted(false);
                    this.partList.remove(packagePart._partName);
                } else {
                    StringBuilder b2 = a.b("A part with the name '");
                    b2.append(packagePart._partName.getName());
                    b2.append("' already exists : Packages shall not contain equivalent part names and package implementers shall neither create nor recognize packages with equivalent part names. [M1.12]");
                    throw new InvalidOperationException(b2.toString());
                }
            }
            this.partList.put(packagePart._partName, packagePart);
            this.isDirty = true;
            return packagePart;
        }
        throw new IllegalArgumentException("part");
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationship addRelationship(PackagePartName packagePartName, TargetMode targetMode, String str, String str2) {
        if (str.equals(PackageRelationshipTypes.CORE_PROPERTIES) && this.packageProperties != null) {
            throw new InvalidOperationException("OPC Compliance error [M4.1]: can't add another core properties part ! Use the built-in package method instead.");
        } else if (!packagePartName.isRelationshipPartURI()) {
            ensureRelationships();
            PackageRelationship addRelationship = this.relationships.addRelationship(packagePartName.getURI(), targetMode, str, str2);
            this.isDirty = true;
            return addRelationship;
        } else {
            throw new InvalidOperationException("Rule M1.25: The Relationships part shall not have relationships to any other part.");
        }
    }

    public void addThumbnail(String str) {
        if (str == null || str.isEmpty()) {
            throw new IllegalArgumentException("path");
        }
        String substring = str.substring(str.lastIndexOf(File.separatorChar) + 1);
        FileInputStream fileInputStream = new FileInputStream(str);
        try {
            addThumbnail(substring, fileInputStream);
        } finally {
            fileInputStream.close();
        }
    }

    public void addUnmarshaller(String str, PartUnmarshaller partUnmarshaller) {
        try {
            this.partUnmarshallers.put(new ContentType(str), partUnmarshaller);
        } catch (InvalidFormatException e2) {
            POILogger pOILogger = logger;
            StringBuilder b2 = a.b("The specified content type is not valid: '");
            b2.append(e2.getMessage());
            b2.append("'. The unmarshaller will not be added !");
            pOILogger.log(5, b2.toString());
        }
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public void clearRelationships() {
        PackageRelationshipCollection packageRelationshipCollection = this.relationships;
        if (packageRelationshipCollection != null) {
            packageRelationshipCollection.clear();
            this.isDirty = true;
        }
    }

    /* JADX INFO: finally extract failed */
    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        if (this.packageAccess == PackageAccess.READ) {
            logger.log(5, "The close() method is intended to SAVE a package. This package is open in READ ONLY mode, use the revert() method instead !");
            revert();
        } else if (this.contentTypeManager == null) {
            logger.log(5, "Unable to call close() on a package that hasn't been fully opened yet");
            revert();
        } else {
            ReentrantReadWriteLock reentrantReadWriteLock = new ReentrantReadWriteLock();
            try {
                reentrantReadWriteLock.writeLock().lock();
                if (this.originalPackagePath != null && !"".equals(this.originalPackagePath.trim())) {
                    File file = new File(this.originalPackagePath);
                    if (file.exists()) {
                        if (this.originalPackagePath.equalsIgnoreCase(file.getAbsolutePath())) {
                            closeImpl();
                        }
                    }
                    save(file);
                } else if (this.output != null) {
                    save(this.output);
                    this.output.close();
                }
                reentrantReadWriteLock.writeLock().unlock();
                this.contentTypeManager.clearAll();
            } catch (Throwable th) {
                reentrantReadWriteLock.writeLock().unlock();
                throw th;
            }
        }
    }

    public abstract void closeImpl();

    public boolean containPart(PackagePartName packagePartName) {
        return getPart(packagePartName) != null;
    }

    public PackagePart createPart(PackagePartName packagePartName, String str) {
        return createPart(packagePartName, str, true);
    }

    public abstract PackagePart createPartImpl(PackagePartName packagePartName, String str, boolean z);

    public void deletePart(PackagePartName packagePartName) {
        if (packagePartName != null) {
            removePart(packagePartName);
            removePart(PackagingURIHelper.getRelationshipPartName(packagePartName));
            return;
        }
        throw new IllegalArgumentException("partName");
    }

    public void deletePartRecursive(PackagePartName packagePartName) {
        if (packagePartName == null || !containPart(packagePartName)) {
            throw new IllegalArgumentException("partName");
        }
        PackagePart part = getPart(packagePartName);
        removePart(packagePartName);
        try {
            Iterator<PackageRelationship> it = part.getRelationships().iterator();
            while (it.hasNext()) {
                deletePartRecursive(PackagingURIHelper.createPartName(PackagingURIHelper.resolvePartUri(packagePartName.getURI(), it.next().getTargetURI())));
            }
            PackagePartName relationshipPartName = PackagingURIHelper.getRelationshipPartName(packagePartName);
            if (relationshipPartName != null && containPart(relationshipPartName)) {
                removePart(relationshipPartName);
            }
        } catch (InvalidFormatException e2) {
            POILogger pOILogger = logger;
            StringBuilder b2 = a.b("An exception occurs while deleting part '");
            b2.append(packagePartName.getName());
            b2.append("'. Some parts may remain in the package. - ");
            b2.append(e2.getMessage());
            pOILogger.log(5, b2.toString());
        }
    }

    public void ensureRelationships() {
        if (this.relationships == null) {
            try {
                this.relationships = new PackageRelationshipCollection(this);
            } catch (InvalidFormatException unused) {
                this.relationships = new PackageRelationshipCollection();
            }
        }
    }

    public void flush() {
        throwExceptionIfReadOnly();
        PackagePropertiesPart packagePropertiesPart = this.packageProperties;
        if (packagePropertiesPart != null) {
            packagePropertiesPart.flush();
        }
        flushImpl();
    }

    public abstract void flushImpl();

    public PackageAccess getPackageAccess() {
        return this.packageAccess;
    }

    public PackageProperties getPackageProperties() {
        throwExceptionIfWriteOnly();
        if (this.packageProperties == null) {
            this.packageProperties = new PackagePropertiesPart(this, PackagingURIHelper.CORE_PROPERTIES_PART_NAME);
        }
        return this.packageProperties;
    }

    public PackagePart getPart(PackagePartName packagePartName) {
        throwExceptionIfWriteOnly();
        if (packagePartName != null) {
            if (this.partList == null) {
                try {
                    getParts();
                } catch (InvalidFormatException unused) {
                    return null;
                }
            }
            return getPartImpl(packagePartName);
        }
        throw new IllegalArgumentException("partName");
    }

    public abstract PackagePart getPartImpl(PackagePartName packagePartName);

    public ArrayList<PackagePart> getParts() {
        throwExceptionIfWriteOnly();
        if (this.partList == null) {
            PackagePart[] partsImpl = getPartsImpl();
            this.partList = new PackagePartCollection();
            boolean z = false;
            boolean z2 = true;
            for (PackagePart packagePart : partsImpl) {
                if (!this.partList.containsKey(packagePart._partName)) {
                    if (packagePart.getContentType().equals(ContentTypes.CORE_PROPERTIES_PART)) {
                        if (!z) {
                            z = true;
                        } else {
                            logger.log(5, "OPC Compliance error [M4.1]: there is more than one core properties relationship in the package! POI will use only the first, but other software may reject this file.");
                        }
                    }
                    PartUnmarshaller partUnmarshaller = this.partUnmarshallers.get(packagePart._contentType);
                    if (partUnmarshaller != null) {
                        try {
                            PackagePart unmarshall = partUnmarshaller.unmarshall(new UnmarshallContext(this, packagePart._partName), packagePart.getInputStream());
                            this.partList.put(unmarshall._partName, unmarshall);
                            if ((unmarshall instanceof PackagePropertiesPart) && z && z2) {
                                this.packageProperties = (PackagePropertiesPart) unmarshall;
                                z2 = false;
                            }
                        } catch (IOException unused) {
                            POILogger pOILogger = logger;
                            StringBuilder b2 = a.b("Unmarshall operation : IOException for ");
                            b2.append(packagePart._partName);
                            pOILogger.log(5, b2.toString());
                        } catch (InvalidOperationException e2) {
                            throw new InvalidFormatException(e2.getMessage(), e2);
                        }
                    } else {
                        try {
                            this.partList.put(packagePart._partName, packagePart);
                        } catch (InvalidOperationException e3) {
                            throw new InvalidFormatException(e3.getMessage(), e3);
                        }
                    }
                } else {
                    StringBuilder b3 = a.b("A part with the name '");
                    b3.append(packagePart._partName);
                    b3.append("' already exist : Packages shall not contain equivalent ");
                    b3.append("part names and package implementers shall neither create ");
                    b3.append("nor recognize packages with equivalent part names. [M1.12]");
                    throw new InvalidFormatException(b3.toString());
                }
            }
        }
        return new ArrayList<>(this.partList.sortedValues());
    }

    public ArrayList<PackagePart> getPartsByContentType(String str) {
        ArrayList<PackagePart> arrayList = new ArrayList<>();
        for (PackagePart packagePart : this.partList.sortedValues()) {
            if (packagePart.getContentType().equals(str)) {
                arrayList.add(packagePart);
            }
        }
        return arrayList;
    }

    public List<PackagePart> getPartsByName(Pattern pattern) {
        if (pattern != null) {
            Matcher matcher = pattern.matcher("");
            ArrayList arrayList = new ArrayList();
            for (PackagePart packagePart : this.partList.sortedValues()) {
                if (matcher.reset(packagePart.getPartName().getName()).matches()) {
                    arrayList.add(packagePart);
                }
            }
            return arrayList;
        }
        throw new IllegalArgumentException("name pattern must not be null");
    }

    public ArrayList<PackagePart> getPartsByRelationshipType(String str) {
        if (str != null) {
            ArrayList<PackagePart> arrayList = new ArrayList<>();
            Iterator<PackageRelationship> it = getRelationshipsByType(str).iterator();
            while (it.hasNext()) {
                PackagePart part = getPart(it.next());
                if (part != null) {
                    arrayList.add(part);
                }
            }
            Collections.sort(arrayList);
            return arrayList;
        }
        throw new IllegalArgumentException("relationshipType");
    }

    public abstract PackagePart[] getPartsImpl();

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationship getRelationship(String str) {
        return this.relationships.getRelationshipByID(str);
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationshipCollection getRelationships() {
        return getRelationshipsHelper(null);
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationshipCollection getRelationshipsByType(String str) {
        throwExceptionIfWriteOnly();
        if (str != null) {
            return getRelationshipsHelper(str);
        }
        throw new IllegalArgumentException("relationshipType");
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public boolean hasRelationships() {
        return this.relationships.size() > 0;
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public boolean isRelationshipExists(PackageRelationship packageRelationship) {
        Iterator<PackageRelationship> it = this.relationships.iterator();
        while (it.hasNext()) {
            if (it.next() == packageRelationship) {
                return true;
            }
        }
        return false;
    }

    public void registerPartAndContentType(PackagePart packagePart) {
        addPackagePart(packagePart);
        this.contentTypeManager.addContentType(packagePart.getPartName(), packagePart.getContentType());
        this.isDirty = true;
    }

    public void removeMarshaller(String str) {
        try {
            this.partMarshallers.remove(new ContentType(str));
        } catch (InvalidFormatException e2) {
            throw new RuntimeException(e2);
        }
    }

    public void removePart(PackagePart packagePart) {
        if (packagePart != null) {
            removePart(packagePart.getPartName());
        }
    }

    public abstract void removePartImpl(PackagePartName packagePartName);

    public void removePartRecursive(PackagePartName packagePartName) {
        PackagePart packagePart = this.partList.get(PackagingURIHelper.getRelationshipPartName(packagePartName));
        PackagePart packagePart2 = this.partList.get(packagePartName);
        if (packagePart != null) {
            Iterator<PackageRelationship> it = new PackageRelationshipCollection(packagePart2).iterator();
            while (it.hasNext()) {
                PackageRelationship next = it.next();
                removePart(PackagingURIHelper.createPartName(PackagingURIHelper.resolvePartUri(next.getSourceURI(), next.getTargetURI())));
            }
            removePart(packagePart._partName);
        }
        removePart(packagePart2._partName);
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public void removeRelationship(String str) {
        PackageRelationshipCollection packageRelationshipCollection = this.relationships;
        if (packageRelationshipCollection != null) {
            packageRelationshipCollection.removeRelationship(str);
            this.isDirty = true;
        }
    }

    public void removeUnmarshaller(String str) {
        try {
            this.partUnmarshallers.remove(new ContentType(str));
        } catch (InvalidFormatException e2) {
            throw new RuntimeException(e2);
        }
    }

    public boolean replaceContentType(String str, String str2) {
        Iterator<PackagePart> it = getPartsByContentType(str).iterator();
        boolean z = false;
        while (it.hasNext()) {
            PackagePart next = it.next();
            if (next.getContentType().equals(str)) {
                this.contentTypeManager.addContentType(next.getPartName(), str2);
                try {
                    next.setContentType(str2);
                    this.isDirty = true;
                    z = true;
                } catch (InvalidFormatException e2) {
                    throw new OpenXML4JRuntimeException(a.b("invalid content type - ", str2), e2);
                }
            }
        }
        return z;
    }

    public void revert() {
        revertImpl();
    }

    public abstract void revertImpl();

    /* JADX WARNING: Removed duplicated region for block: B:18:0x0033  */
    public void save(File file) {
        Throwable th;
        if (file != null) {
            throwExceptionIfReadOnly();
            if (!file.exists() || !file.getAbsolutePath().equals(this.originalPackagePath)) {
                FileOutputStream fileOutputStream = null;
                try {
                    FileOutputStream fileOutputStream2 = new FileOutputStream(file);
                    try {
                        save(fileOutputStream2);
                        fileOutputStream2.close();
                    } catch (Throwable th2) {
                        th = th2;
                        fileOutputStream = fileOutputStream2;
                        if (fileOutputStream != null) {
                        }
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    if (fileOutputStream != null) {
                        fileOutputStream.close();
                    }
                    throw th;
                }
            } else {
                throw new InvalidOperationException("You can't call save(File) to save to the currently open file. To save to the current file, please just call close()");
            }
        } else {
            throw new IllegalArgumentException("targetFile");
        }
    }

    public abstract void saveImpl(OutputStream outputStream);

    public void throwExceptionIfReadOnly() {
        if (this.packageAccess == PackageAccess.READ) {
            throw new InvalidOperationException("Operation not allowed, document open in read only mode!");
        }
    }

    public void throwExceptionIfWriteOnly() {
        if (this.packageAccess == PackageAccess.WRITE) {
            throw new InvalidOperationException("Operation not allowed, document open in write only mode!");
        }
    }

    public void unregisterPartAndContentType(PackagePartName packagePartName) {
        removePart(packagePartName);
        this.contentTypeManager.removeContentType(packagePartName);
        this.isDirty = true;
    }

    @NotImplemented
    public boolean validatePackage(OPCPackage oPCPackage) {
        throw new InvalidOperationException("Not implemented yet !!!");
    }

    public static OPCPackage create(File file) {
        if (file == null || (file.exists() && file.isDirectory())) {
            throw new IllegalArgumentException("file");
        } else if (!file.exists()) {
            ZipPackage zipPackage = new ZipPackage();
            zipPackage.originalPackagePath = file.getAbsolutePath();
            configurePackage(zipPackage);
            return zipPackage;
        } else {
            throw new InvalidOperationException("This package (or file) already exists : use the open() method or delete the file.");
        }
    }

    public static OPCPackage open(File file) {
        return open(file, defaultPackageAccess);
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationship addExternalRelationship(String str, String str2, String str3) {
        if (str == null) {
            throw new IllegalArgumentException("target");
        } else if (str2 != null) {
            try {
                URI uri = new URI(str);
                ensureRelationships();
                PackageRelationship addRelationship = this.relationships.addRelationship(uri, TargetMode.EXTERNAL, str2, str3);
                this.isDirty = true;
                return addRelationship;
            } catch (URISyntaxException e2) {
                throw new IllegalArgumentException("Invalid target - " + e2);
            }
        } else {
            throw new IllegalArgumentException("relationshipType");
        }
    }

    public PackagePart createPart(PackagePartName packagePartName, String str, boolean z) {
        throwExceptionIfReadOnly();
        if (packagePartName == null) {
            throw new IllegalArgumentException("partName");
        } else if (str == null || str.equals("")) {
            throw new IllegalArgumentException("contentType");
        } else if (this.partList.containsKey(packagePartName) && !this.partList.get(packagePartName).isDeleted()) {
            StringBuilder b2 = a.b("A part with the name '");
            b2.append(packagePartName.getName());
            b2.append("'");
            b2.append(" already exists : Packages shall not contain equivalent part names and package");
            b2.append(" implementers shall neither create nor recognize packages with equivalent part names. [M1.12]");
            throw new PartAlreadyExistsException(b2.toString());
        } else if (!str.equals(ContentTypes.CORE_PROPERTIES_PART) || this.packageProperties == null) {
            PackagePart createPartImpl = createPartImpl(packagePartName, str, z);
            this.contentTypeManager.addContentType(packagePartName, str);
            this.partList.put(packagePartName, createPartImpl);
            this.isDirty = true;
            return createPartImpl;
        } else {
            throw new InvalidOperationException("OPC Compliance error [M4.1]: you try to add more than one core properties relationship in the package !");
        }
    }

    public void removePart(PackagePartName packagePartName) {
        PackagePart part;
        throwExceptionIfReadOnly();
        if (packagePartName == null || !containPart(packagePartName)) {
            throw new IllegalArgumentException("partName");
        }
        if (this.partList.containsKey(packagePartName)) {
            this.partList.get(packagePartName).setDeleted(true);
            removePartImpl(packagePartName);
            this.partList.remove(packagePartName);
        } else {
            removePartImpl(packagePartName);
        }
        this.contentTypeManager.removeContentType(packagePartName);
        if (packagePartName.isRelationshipPartURI()) {
            URI sourcePartUriFromRelationshipPartUri = PackagingURIHelper.getSourcePartUriFromRelationshipPartUri(packagePartName.getURI());
            try {
                PackagePartName createPartName = PackagingURIHelper.createPartName(sourcePartUriFromRelationshipPartUri);
                if (createPartName.getURI().equals(PackagingURIHelper.PACKAGE_ROOT_URI)) {
                    clearRelationships();
                } else if (containPart(createPartName) && (part = getPart(createPartName)) != null) {
                    part.clearRelationships();
                }
            } catch (InvalidFormatException unused) {
                POILogger pOILogger = logger;
                pOILogger.log(7, "Part name URI '" + sourcePartUriFromRelationshipPartUri + "' is not valid ! This message is not intended to be displayed !");
                return;
            }
        }
        this.isDirty = true;
    }

    public static OPCPackage open(ZipEntrySource zipEntrySource) {
        ZipPackage zipPackage = new ZipPackage(zipEntrySource, PackageAccess.READ);
        try {
            if (zipPackage.partList == null) {
                zipPackage.getParts();
            }
            return zipPackage;
        } catch (InvalidFormatException e2) {
            IOUtils.closeQuietly(zipPackage);
            throw e2;
        } catch (RuntimeException e3) {
            IOUtils.closeQuietly(zipPackage);
            throw e3;
        }
    }

    public PackagePart getPart(PackageRelationship packageRelationship) {
        ensureRelationships();
        Iterator<PackageRelationship> it = this.relationships.iterator();
        while (it.hasNext()) {
            PackageRelationship next = it.next();
            if (next.getRelationshipType().equals(packageRelationship.getRelationshipType())) {
                try {
                    return getPart(PackagingURIHelper.createPartName(next.getTargetURI()));
                } catch (InvalidFormatException unused) {
                    continue;
                }
            }
        }
        return null;
    }

    public void addThumbnail(String str, InputStream inputStream) {
        PackagePartName packagePartName;
        if (str == null || str.isEmpty()) {
            throw new IllegalArgumentException("filename");
        }
        String contentTypeFromFileExtension = ContentTypes.getContentTypeFromFileExtension(str);
        try {
            packagePartName = PackagingURIHelper.createPartName("/docProps/" + str);
        } catch (InvalidFormatException unused) {
            StringBuilder b2 = a.b("/docProps/thumbnail");
            b2.append(str.substring(str.lastIndexOf(".") + 1));
            try {
                packagePartName = PackagingURIHelper.createPartName(b2.toString());
            } catch (InvalidFormatException e2) {
                throw new InvalidOperationException(a.b("Can't add a thumbnail file named '", str, "'"), e2);
            }
        }
        if (getPart(packagePartName) == null) {
            PackagePart createPart = createPart(packagePartName, contentTypeFromFileExtension, false);
            addRelationship(packagePartName, TargetMode.INTERNAL, PackageRelationshipTypes.THUMBNAIL);
            StreamHelper.copyStream(inputStream, createPart.getOutputStream());
            return;
        }
        throw new InvalidOperationException(a.b("You already add a thumbnail named '", str, "'"));
    }

    @Override // org.apache.poi.openxml4j.opc.RelationshipSource
    public PackageRelationship addRelationship(PackagePartName packagePartName, TargetMode targetMode, String str) {
        return addRelationship(packagePartName, targetMode, str, null);
    }

    public void save(OutputStream outputStream) {
        throwExceptionIfReadOnly();
        saveImpl(outputStream);
    }

    public static OPCPackage create(OutputStream outputStream) {
        ZipPackage zipPackage = new ZipPackage();
        zipPackage.originalPackagePath = null;
        zipPackage.output = outputStream;
        configurePackage(zipPackage);
        return zipPackage;
    }

    public static OPCPackage open(String str, PackageAccess packageAccess2) {
        if (str == null || "".equals(str.trim())) {
            throw new IllegalArgumentException("'path' must be given");
        }
        File file = new File(str);
        if (!file.exists() || !file.isDirectory()) {
            ZipPackage zipPackage = new ZipPackage(str, packageAccess2);
            if (zipPackage.partList == null && packageAccess2 != PackageAccess.WRITE) {
                try {
                    zipPackage.getParts();
                } catch (Throwable th) {
                    IOUtils.closeQuietly(zipPackage);
                    throw th;
                }
            }
            zipPackage.originalPackagePath = new File(str).getAbsolutePath();
            return zipPackage;
        }
        throw new IllegalArgumentException("path must not be a directory");
    }

    public PackagePart createPart(PackagePartName packagePartName, String str, ByteArrayOutputStream byteArrayOutputStream) {
        PackagePart createPart = createPart(packagePartName, str);
        if (!(createPart == null || byteArrayOutputStream == null)) {
            try {
                OutputStream outputStream = createPart.getOutputStream();
                if (outputStream == null) {
                    return null;
                }
                outputStream.write(byteArrayOutputStream.toByteArray(), 0, byteArrayOutputStream.size());
                outputStream.close();
                return createPart;
            } catch (IOException unused) {
            }
        }
        return null;
    }

    public static OPCPackage open(File file, PackageAccess packageAccess2) {
        if (file == null) {
            throw new IllegalArgumentException("'file' must be given");
        } else if (!file.exists() || !file.isDirectory()) {
            ZipPackage zipPackage = new ZipPackage(file, packageAccess2);
            try {
                if (zipPackage.partList == null && packageAccess2 != PackageAccess.WRITE) {
                    zipPackage.getParts();
                }
                zipPackage.originalPackagePath = file.getAbsolutePath();
                return zipPackage;
            } catch (InvalidFormatException e2) {
                IOUtils.closeQuietly(zipPackage);
                throw e2;
            } catch (RuntimeException e3) {
                IOUtils.closeQuietly(zipPackage);
                throw e3;
            }
        } else {
            throw new IllegalArgumentException("file must not be a directory");
        }
    }

    public static OPCPackage open(InputStream inputStream) {
        ZipPackage zipPackage = new ZipPackage(inputStream, PackageAccess.READ_WRITE);
        try {
            if (zipPackage.partList == null) {
                zipPackage.getParts();
            }
            return zipPackage;
        } catch (InvalidFormatException e2) {
            IOUtils.closeQuietly(zipPackage);
            throw e2;
        } catch (RuntimeException e3) {
            IOUtils.closeQuietly(zipPackage);
            throw e3;
        }
    }
}
