package org.apache.poi.openxml4j.opc;

import b.b.a.a.a;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;
import java.util.TreeMap;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.util.DocumentHelper;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;
import org.w3c.dom.Attr;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

public final class PackageRelationshipCollection implements Iterable<PackageRelationship> {
    public static final POILogger logger = POILogFactory.getLogger(PackageRelationshipCollection.class);
    public OPCPackage container;
    public HashMap<String, PackageRelationship> internalRelationshipsByTargetName;
    public int nextRelationshipId;
    public PackagePartName partName;
    public PackagePart relationshipPart;
    public TreeMap<String, PackageRelationship> relationshipsByID;
    public TreeMap<String, PackageRelationship> relationshipsByType;
    public PackagePart sourcePart;

    public PackageRelationshipCollection() {
        this.internalRelationshipsByTargetName = new HashMap<>();
        this.nextRelationshipId = -1;
        this.relationshipsByID = new TreeMap<>();
        this.relationshipsByType = new TreeMap<>();
    }

    public static PackagePartName getRelationshipPartName(PackagePart packagePart) {
        PackagePartName packagePartName;
        if (packagePart == null) {
            packagePartName = PackagingURIHelper.PACKAGE_ROOT_PART_NAME;
        } else {
            packagePartName = packagePart.getPartName();
        }
        return PackagingURIHelper.getRelationshipPartName(packagePartName);
    }

    public void addRelationship(PackageRelationship packageRelationship) {
        this.relationshipsByID.put(packageRelationship.getId(), packageRelationship);
        this.relationshipsByType.put(packageRelationship.getRelationshipType(), packageRelationship);
    }

    public void clear() {
        this.relationshipsByID.clear();
        this.relationshipsByType.clear();
        this.internalRelationshipsByTargetName.clear();
    }

    public PackageRelationship findExistingInternalRelation(PackagePart packagePart) {
        return this.internalRelationshipsByTargetName.get(packagePart.getPartName().getName());
    }

    public PackageRelationship getRelationship(int i2) {
        if (i2 < 0 || i2 > this.relationshipsByID.values().size()) {
            throw new IllegalArgumentException("index");
        }
        int i3 = 0;
        for (PackageRelationship packageRelationship : this.relationshipsByID.values()) {
            int i4 = i3 + 1;
            if (i2 == i3) {
                return packageRelationship;
            }
            i3 = i4;
        }
        return null;
    }

    public PackageRelationship getRelationshipByID(String str) {
        return this.relationshipsByID.get(str);
    }

    public PackageRelationshipCollection getRelationships(String str) {
        return new PackageRelationshipCollection(this, str);
    }

    @Override // java.lang.Iterable
    public Iterator<PackageRelationship> iterator() {
        return this.relationshipsByID.values().iterator();
    }

    public void parseRelationshipsPart(PackagePart packagePart) {
        Exception e2;
        boolean z;
        try {
            POILogger pOILogger = logger;
            pOILogger.log(1, "Parsing relationship: " + packagePart.getPartName());
            NodeList elementsByTagNameNS = DocumentHelper.readDocument(packagePart.getInputStream()).getDocumentElement().getElementsByTagNameNS(PackageNamespaces.RELATIONSHIPS, PackageRelationship.RELATIONSHIP_TAG_NAME);
            int length = elementsByTagNameNS.getLength();
            boolean z2 = false;
            int i2 = 0;
            while (i2 < length) {
                Element element = (Element) elementsByTagNameNS.item(i2);
                String attribute = element.getAttribute(PackageRelationship.ID_ATTRIBUTE_NAME);
                String attribute2 = element.getAttribute(PackageRelationship.TYPE_ATTRIBUTE_NAME);
                if (!attribute2.equals(PackageRelationshipTypes.CORE_PROPERTIES)) {
                    z = z2;
                } else if (!z2) {
                    z = true;
                } else {
                    throw new InvalidFormatException("OPC Compliance error [M4.1]: there is more than one core properties relationship in the package !");
                }
                Attr attributeNode = element.getAttributeNode(PackageRelationship.TARGET_MODE_ATTRIBUTE_NAME);
                TargetMode targetMode = TargetMode.INTERNAL;
                if (attributeNode != null) {
                    targetMode = attributeNode.getValue().toLowerCase(Locale.ROOT).equals("internal") ? TargetMode.INTERNAL : TargetMode.EXTERNAL;
                }
                URI uri = PackagingURIHelper.toURI("http://invalid.uri");
                String attribute3 = element.getAttribute(PackageRelationship.TARGET_ATTRIBUTE_NAME);
                try {
                    uri = PackagingURIHelper.toURI(attribute3);
                } catch (URISyntaxException e3) {
                    POILogger pOILogger2 = logger;
                    pOILogger2.log(7, "Cannot convert " + attribute3 + " in a valid relationship URI-> dummy-URI used", e3);
                }
                try {
                    addRelationship(uri, targetMode, attribute2, attribute);
                    i2++;
                    z2 = z;
                } catch (Exception e4) {
                    e2 = e4;
                    logger.log(7, e2);
                    throw new InvalidFormatException(e2.getMessage());
                }
            }
        } catch (Exception e5) {
            e2 = e5;
            logger.log(7, e2);
            throw new InvalidFormatException(e2.getMessage());
        }
    }

    public void removeRelationship(String str) {
        PackageRelationship packageRelationship;
        TreeMap<String, PackageRelationship> treeMap = this.relationshipsByID;
        if (treeMap != null && this.relationshipsByType != null && (packageRelationship = treeMap.get(str)) != null) {
            this.relationshipsByID.remove(packageRelationship.getId());
            this.relationshipsByType.values().remove(packageRelationship);
            this.internalRelationshipsByTargetName.values().remove(packageRelationship);
        }
    }

    public int size() {
        return this.relationshipsByID.values().size();
    }

    public String toString() {
        String str;
        String str2;
        String str3;
        String str4;
        if (this.relationshipsByID == null) {
            str = "relationshipsByID=null";
        } else {
            str = this.relationshipsByID.size() + " relationship(s) = [";
        }
        PackagePart packagePart = this.relationshipPart;
        if (packagePart == null || packagePart._partName == null) {
            str2 = a.b(str, ",relationshipPart=null");
        } else {
            StringBuilder d2 = a.d(str, XSSFDataValidationConstraint.LIST_SEPARATOR);
            d2.append(this.relationshipPart._partName);
            str2 = d2.toString();
        }
        PackagePart packagePart2 = this.sourcePart;
        if (packagePart2 == null || packagePart2._partName == null) {
            str3 = a.b(str2, ",sourcePart=null");
        } else {
            StringBuilder d3 = a.d(str2, XSSFDataValidationConstraint.LIST_SEPARATOR);
            d3.append(this.sourcePart._partName);
            str3 = d3.toString();
        }
        if (this.partName != null) {
            StringBuilder d4 = a.d(str3, XSSFDataValidationConstraint.LIST_SEPARATOR);
            d4.append(this.partName);
            str4 = d4.toString();
        } else {
            str4 = a.b(str3, ",uri=null)");
        }
        return a.b(str4, "]");
    }

    public Iterator<PackageRelationship> iterator(String str) {
        ArrayList arrayList = new ArrayList();
        for (PackageRelationship packageRelationship : this.relationshipsByID.values()) {
            if (packageRelationship.getRelationshipType().equals(str)) {
                arrayList.add(packageRelationship);
            }
        }
        return arrayList.iterator();
    }

    public PackageRelationship addRelationship(URI uri, TargetMode targetMode, String str, String str2) {
        if (str2 != null) {
            PackageRelationship packageRelationship = new PackageRelationship(this.container, this.sourcePart, uri, targetMode, str, str2);
            this.relationshipsByID.put(packageRelationship.getId(), packageRelationship);
            this.relationshipsByType.put(packageRelationship.getRelationshipType(), packageRelationship);
        } else {
            if (this.nextRelationshipId == -1) {
                this.nextRelationshipId = size() + 1;
            }
            do {
                StringBuilder b2 = a.b("rId");
                int i2 = this.nextRelationshipId;
                this.nextRelationshipId = i2 + 1;
                b2.append(i2);
                str2 = b2.toString();
            } while (this.relationshipsByID.get(str2) != null);
        }
        PackageRelationship packageRelationship2 = new PackageRelationship(this.container, this.sourcePart, uri, targetMode, str, str2);
        this.relationshipsByID.put(packageRelationship2.getId(), packageRelationship2);
        this.relationshipsByType.put(packageRelationship2.getRelationshipType(), packageRelationship2);
        if (targetMode == TargetMode.INTERNAL) {
            this.internalRelationshipsByTargetName.put(uri.toASCIIString(), packageRelationship2);
        }
        return packageRelationship2;
    }

    public PackageRelationshipCollection(PackageRelationshipCollection packageRelationshipCollection, String str) {
        this();
        for (PackageRelationship packageRelationship : packageRelationshipCollection.relationshipsByID.values()) {
            if (str == null || packageRelationship.getRelationshipType().equals(str)) {
                addRelationship(packageRelationship);
            }
        }
    }

    public PackageRelationshipCollection(OPCPackage oPCPackage) {
        this(oPCPackage, (PackagePart) null);
    }

    public PackageRelationshipCollection(PackagePart packagePart) {
        this(packagePart._container, packagePart);
    }

    public PackageRelationshipCollection(OPCPackage oPCPackage, PackagePart packagePart) {
        this();
        if (oPCPackage == null) {
            throw new IllegalArgumentException("container needs to be specified");
        } else if (packagePart == null || !packagePart.isRelationshipPart()) {
            this.container = oPCPackage;
            this.sourcePart = packagePart;
            this.partName = getRelationshipPartName(packagePart);
            if (oPCPackage.getPackageAccess() != PackageAccess.WRITE && oPCPackage.containPart(this.partName)) {
                PackagePart part = oPCPackage.getPart(this.partName);
                this.relationshipPart = part;
                parseRelationshipsPart(part);
            }
        } else {
            throw new IllegalArgumentException("part");
        }
    }
}
