package org.apache.poi.openxml4j.opc;

import b.b.a.a.a;
import java.io.Closeable;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.exceptions.InvalidOperationException;
import org.apache.poi.openxml4j.exceptions.NotOfficeXmlFileException;
import org.apache.poi.openxml4j.exceptions.ODFNotOfficeXmlFileException;
import org.apache.poi.openxml4j.exceptions.OpenXML4JException;
import org.apache.poi.openxml4j.exceptions.OpenXML4JRuntimeException;
import org.apache.poi.openxml4j.opc.internal.ContentTypeManager;
import org.apache.poi.openxml4j.opc.internal.FileHelper;
import org.apache.poi.openxml4j.opc.internal.MemoryPackagePart;
import org.apache.poi.openxml4j.opc.internal.PartMarshaller;
import org.apache.poi.openxml4j.opc.internal.ZipContentTypeManager;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.openxml4j.opc.internal.marshallers.ZipPartMarshaller;
import org.apache.poi.openxml4j.util.ZipEntrySource;
import org.apache.poi.openxml4j.util.ZipFileZipEntrySource;
import org.apache.poi.openxml4j.util.ZipInputStreamZipEntrySource;
import org.apache.poi.openxml4j.util.ZipSecureFile;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.TempFile;

public final class ZipPackage extends OPCPackage {
    public static final POILogger LOG = POILogFactory.getLogger(ZipPackage.class);
    public static final String MIMETYPE = "mimetype";
    public static final String SETTINGS_XML = "settings.xml";
    public final ZipEntrySource zipArchive;

    public ZipPackage() {
        super(OPCPackage.defaultPackageAccess);
        this.zipArchive = null;
        try {
            this.contentTypeManager = new ZipContentTypeManager(null, this);
        } catch (InvalidFormatException e2) {
            LOG.log(5, "Could not parse ZipPackage", e2);
        }
    }

    private PackagePartName buildPartName(ZipEntry zipEntry) {
        try {
            if (zipEntry.getName().equalsIgnoreCase(ContentTypeManager.CONTENT_TYPES_PART_NAME)) {
                return null;
            }
            return PackagingURIHelper.createPartName(ZipHelper.getOPCNameFromZipItemName(zipEntry.getName()));
        } catch (Exception e2) {
            POILogger pOILogger = LOG;
            StringBuilder b2 = a.b("Entry ");
            b2.append(zipEntry.getName());
            b2.append(" is not valid, so this part won't be add to the package.");
            pOILogger.log(5, b2.toString(), e2);
            return null;
        }
    }

    private synchronized String generateTempFileName(File file) {
        File file2;
        do {
            file2 = new File(file.getAbsoluteFile() + File.separator + "OpenXML4J" + System.nanoTime());
        } while (file2.exists());
        return FileHelper.getFilename(file2.getAbsoluteFile());
    }

    public static ZipEntrySource openZipEntrySourceStream(File file) {
        try {
            FileInputStream fileInputStream = new FileInputStream(file);
            try {
                return openZipEntrySourceStream(fileInputStream);
            } catch (Exception e2) {
                IOUtils.closeQuietly(fileInputStream);
                if (e2 instanceof InvalidOperationException) {
                    throw ((InvalidOperationException) e2);
                }
                throw new InvalidOperationException("Failed to read the file input stream from file: '" + file + "'", e2);
            }
        } catch (FileNotFoundException e3) {
            throw new InvalidOperationException("Can't open the specified file input stream from file: '" + file + "'", e3);
        }
    }

    @Override // org.apache.poi.openxml4j.opc.OPCPackage
    public void closeImpl() {
        flush();
        String str = this.originalPackagePath;
        if (str != null && !"".equals(str)) {
            File file = new File(this.originalPackagePath);
            if (file.exists()) {
                File createTempFile = TempFile.createTempFile(generateTempFileName(FileHelper.getDirectory(file)), ".tmp");
                try {
                    save(createTempFile);
                    IOUtils.closeQuietly(this.zipArchive);
                    try {
                        FileHelper.copyFile(createTempFile, file);
                        if (!createTempFile.delete()) {
                            POILogger pOILogger = LOG;
                            StringBuilder b2 = a.b("The temporary file: '");
                            b2.append(file.getAbsolutePath());
                            b2.append("' cannot be deleted ! Make sure that no other application use it.");
                            pOILogger.log(5, b2.toString());
                        }
                    } catch (Throwable th) {
                        if (!createTempFile.delete()) {
                            POILogger pOILogger2 = LOG;
                            StringBuilder b3 = a.b("The temporary file: '");
                            b3.append(file.getAbsolutePath());
                            b3.append("' cannot be deleted ! Make sure that no other application use it.");
                            pOILogger2.log(5, b3.toString());
                        }
                        throw th;
                    }
                } catch (Throwable th2) {
                    if (!createTempFile.delete()) {
                        POILogger pOILogger3 = LOG;
                        StringBuilder b4 = a.b("The temporary file: '");
                        b4.append(file.getAbsolutePath());
                        b4.append("' cannot be deleted ! Make sure that no other application use it.");
                        pOILogger3.log(5, b4.toString());
                    }
                    throw th2;
                }
            } else {
                throw new InvalidOperationException("Can't close a package not previously open with the open() method !");
            }
        }
    }

    @Override // org.apache.poi.openxml4j.opc.OPCPackage
    public PackagePart createPartImpl(PackagePartName packagePartName, String str, boolean z) {
        if (str == null) {
            throw new IllegalArgumentException("contentType");
        } else if (packagePartName != null) {
            try {
                return new MemoryPackagePart(this, packagePartName, str, z);
            } catch (InvalidFormatException e2) {
                LOG.log(5, e2);
                return null;
            }
        } else {
            throw new IllegalArgumentException("partName");
        }
    }

    @Override // org.apache.poi.openxml4j.opc.OPCPackage
    public void flushImpl() {
    }

    @Override // org.apache.poi.openxml4j.opc.OPCPackage
    public PackagePart getPartImpl(PackagePartName packagePartName) {
        if (this.partList.containsKey(packagePartName)) {
            return this.partList.get(packagePartName);
        }
        return null;
    }

    @Override // org.apache.poi.openxml4j.opc.OPCPackage
    public PackagePart[] getPartsImpl() {
        String contentType;
        String contentType2;
        if (this.partList == null) {
            this.partList = new PackagePartCollection();
        }
        ZipEntrySource zipEntrySource = this.zipArchive;
        if (zipEntrySource == null) {
            return (PackagePart[]) this.partList.sortedValues().toArray(new PackagePart[this.partList.size()]);
        }
        Enumeration<? extends ZipEntry> entries = zipEntrySource.getEntries();
        while (true) {
            if (!entries.hasMoreElements()) {
                break;
            }
            ZipEntry zipEntry = (ZipEntry) entries.nextElement();
            if (zipEntry.getName().equalsIgnoreCase(ContentTypeManager.CONTENT_TYPES_PART_NAME)) {
                try {
                    this.contentTypeManager = new ZipContentTypeManager(getZipArchive().getInputStream(zipEntry), this);
                    break;
                } catch (IOException e2) {
                    throw new InvalidFormatException(e2.getMessage(), e2);
                }
            }
        }
        if (this.contentTypeManager == null) {
            Enumeration<? extends ZipEntry> entries2 = this.zipArchive.getEntries();
            boolean z = false;
            boolean z2 = false;
            int i2 = 0;
            while (entries2.hasMoreElements()) {
                String name = ((ZipEntry) entries2.nextElement()).getName();
                if (MIMETYPE.equals(name)) {
                    z = true;
                }
                if (SETTINGS_XML.equals(name)) {
                    z2 = true;
                }
                i2++;
            }
            if (z && z2) {
                throw new ODFNotOfficeXmlFileException("The supplied data appears to be in ODF (Open Document) Format. Formats like these (eg ODS, ODP) are not supported, try Apache ODFToolkit");
            } else if (i2 == 0) {
                throw new NotOfficeXmlFileException("No valid entries or contents found, this is not a valid OOXML (Office Open XML) file");
            } else {
                throw new InvalidFormatException("Package should contain a content type part [M1.13]");
            }
        } else {
            Enumeration<? extends ZipEntry> entries3 = this.zipArchive.getEntries();
            while (entries3.hasMoreElements()) {
                ZipEntry zipEntry2 = (ZipEntry) entries3.nextElement();
                PackagePartName buildPartName = buildPartName(zipEntry2);
                if (!(buildPartName == null || (contentType2 = this.contentTypeManager.getContentType(buildPartName)) == null || !contentType2.equals(ContentTypes.RELATIONSHIPS_PART))) {
                    try {
                        this.partList.put(buildPartName, new ZipPackagePart(this, zipEntry2, buildPartName, contentType2));
                    } catch (InvalidOperationException e3) {
                        throw new InvalidFormatException(e3.getMessage(), e3);
                    }
                }
            }
            Enumeration<? extends ZipEntry> entries4 = this.zipArchive.getEntries();
            while (entries4.hasMoreElements()) {
                ZipEntry zipEntry3 = (ZipEntry) entries4.nextElement();
                PackagePartName buildPartName2 = buildPartName(zipEntry3);
                if (buildPartName2 != null && ((contentType = this.contentTypeManager.getContentType(buildPartName2)) == null || !contentType.equals(ContentTypes.RELATIONSHIPS_PART))) {
                    if (contentType != null) {
                        try {
                            this.partList.put(buildPartName2, new ZipPackagePart(this, zipEntry3, buildPartName2, contentType));
                        } catch (InvalidOperationException e4) {
                            throw new InvalidFormatException(e4.getMessage(), e4);
                        }
                    } else {
                        StringBuilder b2 = a.b("The part ");
                        b2.append(buildPartName2.getURI().getPath());
                        b2.append(" does not have any content type ! Rule: Package require content types when retrieving a part from a package. [M.1.14]");
                        throw new InvalidFormatException(b2.toString());
                    }
                }
            }
            return (PackagePart[]) this.partList.sortedValues().toArray(new PackagePart[this.partList.size()]);
        }
    }

    public ZipEntrySource getZipArchive() {
        return this.zipArchive;
    }

    @Override // org.apache.poi.openxml4j.opc.OPCPackage
    public void removePartImpl(PackagePartName packagePartName) {
        if (packagePartName == null) {
            throw new IllegalArgumentException("partUri");
        }
    }

    @Override // org.apache.poi.openxml4j.opc.OPCPackage
    public void revertImpl() {
        try {
            if (this.zipArchive != null) {
                this.zipArchive.close();
            }
        } catch (IOException unused) {
        }
    }

    @Override // org.apache.poi.openxml4j.opc.OPCPackage
    public void saveImpl(OutputStream outputStream) {
        ZipOutputStream zipOutputStream;
        throwExceptionIfReadOnly();
        try {
            if (!(outputStream instanceof ZipOutputStream)) {
                zipOutputStream = new ZipOutputStream(outputStream);
            } else {
                zipOutputStream = (ZipOutputStream) outputStream;
            }
            if (getPartsByRelationshipType(PackageRelationshipTypes.CORE_PROPERTIES).size() == 0 && getPartsByRelationshipType(PackageRelationshipTypes.CORE_PROPERTIES_ECMA376).size() == 0) {
                LOG.log(1, "Save core properties part");
                getPackageProperties();
                addPackagePart(this.packageProperties);
                this.relationships.addRelationship(this.packageProperties.getPartName().getURI(), TargetMode.INTERNAL, PackageRelationshipTypes.CORE_PROPERTIES, null);
                if (!this.contentTypeManager.isContentTypeRegister(ContentTypes.CORE_PROPERTIES_PART)) {
                    this.contentTypeManager.addContentType(this.packageProperties.getPartName(), ContentTypes.CORE_PROPERTIES_PART);
                }
            }
            LOG.log(1, "Save package relationships");
            ZipPartMarshaller.marshallRelationshipPart(getRelationships(), PackagingURIHelper.PACKAGE_RELATIONSHIPS_ROOT_PART_NAME, zipOutputStream);
            LOG.log(1, "Save content types part");
            this.contentTypeManager.save(zipOutputStream);
            Iterator<PackagePart> it = getParts().iterator();
            while (it.hasNext()) {
                PackagePart next = it.next();
                if (!next.isRelationshipPart()) {
                    PackagePartName partName = next.getPartName();
                    LOG.log(1, "Save part '" + ZipHelper.getZipItemNameFromOPCName(partName.getName()) + "'");
                    PartMarshaller partMarshaller = this.partMarshallers.get(next._contentType);
                    String str = "The part " + partName.getURI() + " failed to be saved in the stream with marshaller ";
                    if (partMarshaller != null) {
                        if (!partMarshaller.marshall(next, zipOutputStream)) {
                            throw new OpenXML4JException(str + partMarshaller);
                        }
                    } else if (!this.defaultPartMarshaller.marshall(next, zipOutputStream)) {
                        throw new OpenXML4JException(str + this.defaultPartMarshaller);
                    }
                }
            }
            zipOutputStream.close();
        } catch (OpenXML4JRuntimeException e2) {
            throw e2;
        } catch (Exception e3) {
            StringBuilder b2 = a.b("Fail to save: an error occurs while saving the package : ");
            b2.append(e3.getMessage());
            throw new OpenXML4JRuntimeException(b2.toString(), e3);
        }
    }

    public ZipPackage(InputStream inputStream, PackageAccess packageAccess) {
        super(packageAccess);
        ZipSecureFile.ThresholdInputStream openZipStream = ZipHelper.openZipStream(inputStream);
        try {
            this.zipArchive = new ZipInputStreamZipEntrySource(openZipStream);
        } catch (IOException e2) {
            IOUtils.closeQuietly(openZipStream);
            throw new IOException("Failed to read zip entry source", e2);
        }
    }

    public static ZipEntrySource openZipEntrySourceStream(FileInputStream fileInputStream) {
        Closeable closeable;
        try {
            try {
                return openZipEntrySourceStream(ZipHelper.openZipStream(fileInputStream));
            } catch (Exception e2) {
                IOUtils.closeQuietly(closeable);
                if (e2 instanceof InvalidOperationException) {
                    throw ((InvalidOperationException) e2);
                }
                throw new InvalidOperationException("Failed to read the zip entry source stream", e2);
            }
        } catch (IOException e3) {
            throw new InvalidOperationException("Could not open the file input stream", e3);
        }
    }

    public ZipPackage(String str, PackageAccess packageAccess) {
        this(new File(str), packageAccess);
    }

    public ZipPackage(File file, PackageAccess packageAccess) {
        super(packageAccess);
        ZipEntrySource zipEntrySource;
        try {
            zipEntrySource = new ZipFileZipEntrySource(ZipHelper.openZipFile(file));
        } catch (IOException e2) {
            if (packageAccess != PackageAccess.WRITE) {
                POILogger pOILogger = LOG;
                pOILogger.log(7, "Error in zip file " + file + " - falling back to stream processing (i.e. ignoring zip central directory)");
                zipEntrySource = openZipEntrySourceStream(file);
            } else {
                throw new InvalidOperationException("Can't open the specified file: '" + file + "'", e2);
            }
        }
        this.zipArchive = zipEntrySource;
    }

    public static ZipEntrySource openZipEntrySourceStream(ZipSecureFile.ThresholdInputStream thresholdInputStream) {
        try {
            return new ZipInputStreamZipEntrySource(thresholdInputStream);
        } catch (IOException e2) {
            throw new InvalidOperationException("Could not open the specified zip entry source stream", e2);
        }
    }

    public ZipPackage(ZipEntrySource zipEntrySource, PackageAccess packageAccess) {
        super(packageAccess);
        this.zipArchive = zipEntrySource;
    }
}
