package org.apache.poi.openxml4j.opc.internal.unmarshallers;

import b.b.a.a.a;
import java.io.IOException;
import java.io.InputStream;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.opc.PackageNamespaces;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.ZipPackage;
import org.apache.poi.openxml4j.opc.internal.PackagePropertiesPart;
import org.apache.poi.openxml4j.opc.internal.PartUnmarshaller;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.util.DocumentHelper;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;
import org.w3c.dom.Attr;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

public final class PackagePropertiesUnmarshaller implements PartUnmarshaller {
    public static final String KEYWORD_CATEGORY = "category";
    public static final String KEYWORD_CONTENT_STATUS = "contentStatus";
    public static final String KEYWORD_CONTENT_TYPE = "contentType";
    public static final String KEYWORD_CREATED = "created";
    public static final String KEYWORD_CREATOR = "creator";
    public static final String KEYWORD_DESCRIPTION = "description";
    public static final String KEYWORD_IDENTIFIER = "identifier";
    public static final String KEYWORD_KEYWORDS = "keywords";
    public static final String KEYWORD_LANGUAGE = "language";
    public static final String KEYWORD_LAST_MODIFIED_BY = "lastModifiedBy";
    public static final String KEYWORD_LAST_PRINTED = "lastPrinted";
    public static final String KEYWORD_MODIFIED = "modified";
    public static final String KEYWORD_REVISION = "revision";
    public static final String KEYWORD_SUBJECT = "subject";
    public static final String KEYWORD_TITLE = "title";
    public static final String KEYWORD_VERSION = "version";

    private String loadCategory(Document document) {
        return readElement(document, "category", "http://schemas.openxmlformats.org/package/2006/metadata/core-properties");
    }

    private String loadContentStatus(Document document) {
        return readElement(document, "contentStatus", "http://schemas.openxmlformats.org/package/2006/metadata/core-properties");
    }

    private String loadContentType(Document document) {
        return readElement(document, "contentType", "http://schemas.openxmlformats.org/package/2006/metadata/core-properties");
    }

    private String loadCreated(Document document) {
        return readElement(document, "created", "http://purl.org/dc/terms/");
    }

    private String loadCreator(Document document) {
        return readElement(document, "creator", "http://purl.org/dc/elements/1.1/");
    }

    private String loadDescription(Document document) {
        return readElement(document, "description", "http://purl.org/dc/elements/1.1/");
    }

    private String loadIdentifier(Document document) {
        return readElement(document, "identifier", "http://purl.org/dc/elements/1.1/");
    }

    private String loadKeywords(Document document) {
        return readElement(document, "keywords", "http://schemas.openxmlformats.org/package/2006/metadata/core-properties");
    }

    private String loadLanguage(Document document) {
        return readElement(document, "language", "http://purl.org/dc/elements/1.1/");
    }

    private String loadLastModifiedBy(Document document) {
        return readElement(document, "lastModifiedBy", "http://schemas.openxmlformats.org/package/2006/metadata/core-properties");
    }

    private String loadLastPrinted(Document document) {
        return readElement(document, "lastPrinted", "http://schemas.openxmlformats.org/package/2006/metadata/core-properties");
    }

    private String loadModified(Document document) {
        return readElement(document, "modified", "http://purl.org/dc/terms/");
    }

    private String loadRevision(Document document) {
        return readElement(document, "revision", "http://schemas.openxmlformats.org/package/2006/metadata/core-properties");
    }

    private String loadSubject(Document document) {
        return readElement(document, "subject", "http://purl.org/dc/elements/1.1/");
    }

    private String loadTitle(Document document) {
        return readElement(document, "title", "http://purl.org/dc/elements/1.1/");
    }

    private String loadVersion(Document document) {
        return readElement(document, "version", "http://schemas.openxmlformats.org/package/2006/metadata/core-properties");
    }

    private String readElement(Document document, String str, String str2) {
        Element element = (Element) document.getDocumentElement().getElementsByTagNameNS(str2, str).item(0);
        if (element == null) {
            return null;
        }
        return element.getTextContent();
    }

    public void checkElementForOPCCompliance(Element element) {
        NamedNodeMap attributes = element.getAttributes();
        int length = attributes.getLength();
        for (int i2 = 0; i2 < length; i2++) {
            Attr attr = (Attr) attributes.item(0);
            if (attr.getNamespaceURI().equals("http://www.w3.org/2000/xmlns/") && attr.getValue().equals(PackageNamespaces.MARKUP_COMPATIBILITY)) {
                throw new InvalidFormatException("OPC Compliance error [M4.2]: A format consumer shall consider the use of the Markup Compatibility namespace to be an error.");
            }
        }
        String localName = element.getLocalName();
        if (element.getNamespaceURI().equals("http://purl.org/dc/terms/") && !localName.equals("created") && !localName.equals("modified")) {
            throw new InvalidFormatException("OPC Compliance error [M4.3]: Producers shall not create a document element that contains refinements to the Dublin Core elements, except for the two specified in the schema: <dcterms:created> and <dcterms:modified> Consumers shall consider a document element that violates this constraint to be an error.");
        } else if (element.getAttributeNodeNS("http://www.w3.org/XML/1998/namespace", "lang") == null) {
            if (element.getNamespaceURI().equals("http://purl.org/dc/terms/")) {
                if (localName.equals("created") || localName.equals("modified")) {
                    Attr attributeNodeNS = element.getAttributeNodeNS("http://www.w3.org/2001/XMLSchema-instance", JamXmlElements.TYPE);
                    if (attributeNodeNS != null) {
                        String value = attributeNodeNS.getValue();
                        if (!value.equals(element.getPrefix() + ":W3CDTF")) {
                            StringBuilder d2 = a.d("The element '", localName, "' must have the 'xsi:type' attribute with the value '");
                            d2.append(element.getPrefix());
                            d2.append(":W3CDTF', but had '");
                            d2.append(attributeNodeNS.getValue());
                            d2.append("' !");
                            throw new InvalidFormatException(d2.toString());
                        }
                    } else {
                        throw new InvalidFormatException(a.b("The element '", localName, "' must have the 'xsi:type' attribute present !"));
                    }
                } else {
                    throw new InvalidFormatException("Namespace error : " + localName + " shouldn't have the following naemspace -> " + "http://purl.org/dc/terms/");
                }
            }
            NodeList elementsByTagName = element.getElementsByTagName("*");
            int length2 = elementsByTagName.getLength();
            for (int i3 = 0; i3 < length2; i3++) {
                checkElementForOPCCompliance((Element) elementsByTagName.item(i3));
            }
        } else {
            throw new InvalidFormatException("OPC Compliance error [M4.4]: Producers shall not create a document element that contains the xml:lang attribute. Consumers shall consider a document element that violates this constraint to be an error.");
        }
    }

    @Override // org.apache.poi.openxml4j.opc.internal.PartUnmarshaller
    public PackagePart unmarshall(UnmarshallContext unmarshallContext, InputStream inputStream) {
        PackagePropertiesPart packagePropertiesPart = new PackagePropertiesPart(unmarshallContext.getPackage(), unmarshallContext.getPartName());
        if (inputStream == null) {
            if (unmarshallContext.getZipEntry() != null) {
                inputStream = ((ZipPackage) unmarshallContext.getPackage()).getZipArchive().getInputStream(unmarshallContext.getZipEntry());
            } else if (unmarshallContext.getPackage() != null) {
                inputStream = ((ZipPackage) unmarshallContext.getPackage()).getZipArchive().getInputStream(ZipHelper.getCorePropertiesZipEntry((ZipPackage) unmarshallContext.getPackage()));
            } else {
                throw new IOException("Error while trying to get the part input stream.");
            }
        }
        try {
            Document readDocument = DocumentHelper.readDocument(inputStream);
            checkElementForOPCCompliance(readDocument.getDocumentElement());
            packagePropertiesPart.setCategoryProperty(loadCategory(readDocument));
            packagePropertiesPart.setContentStatusProperty(loadContentStatus(readDocument));
            packagePropertiesPart.setContentTypeProperty(loadContentType(readDocument));
            packagePropertiesPart.setCreatedProperty(loadCreated(readDocument));
            packagePropertiesPart.setCreatorProperty(loadCreator(readDocument));
            packagePropertiesPart.setDescriptionProperty(loadDescription(readDocument));
            packagePropertiesPart.setIdentifierProperty(loadIdentifier(readDocument));
            packagePropertiesPart.setKeywordsProperty(loadKeywords(readDocument));
            packagePropertiesPart.setLanguageProperty(loadLanguage(readDocument));
            packagePropertiesPart.setLastModifiedByProperty(loadLastModifiedBy(readDocument));
            packagePropertiesPart.setLastPrintedProperty(loadLastPrinted(readDocument));
            packagePropertiesPart.setModifiedProperty(loadModified(readDocument));
            packagePropertiesPart.setRevisionProperty(loadRevision(readDocument));
            packagePropertiesPart.setSubjectProperty(loadSubject(readDocument));
            packagePropertiesPart.setTitleProperty(loadTitle(readDocument));
            packagePropertiesPart.setVersionProperty(loadVersion(readDocument));
            return packagePropertiesPart;
        } catch (SAXException e2) {
            throw new IOException(e2.getMessage());
        }
    }
}
