package org.apache.poi.openxml4j.util;

import b.b.a.a.a;
import java.io.File;
import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PushbackInputStream;
import java.lang.reflect.Field;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.zip.InflaterInputStream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipInputStream;
import org.apache.poi.hpsf.Filetime;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.SuppressForbidden;

public class ZipSecureFile extends ZipFile {
    public static final long GRACE_ENTRY_SIZE = 102400;
    public static final POILogger LOG = POILogFactory.getLogger(ZipSecureFile.class);
    public static long MAX_ENTRY_SIZE = Filetime.UINT_MASK;
    public static long MAX_TEXT_SIZE = 10485760;
    public static double MIN_INFLATE_RATIO = 0.01d;

    public ZipSecureFile(File file, int i2) {
        super(file, i2);
    }

    public static ThresholdInputStream addThreshold(final InputStream inputStream) {
        return new ThresholdInputStream(inputStream, inputStream instanceof InflaterInputStream ? (ThresholdInputStream) AccessController.doPrivileged(new PrivilegedAction<ThresholdInputStream>() {
            /* class org.apache.poi.openxml4j.util.ZipSecureFile.AnonymousClass1 */

            @Override // java.security.PrivilegedAction
            @SuppressForbidden("TODO: Fix this to not use reflection (it will break in Java 9)! Better would be to wrap *before* instead of trying to insert wrapper afterwards.")
            public ThresholdInputStream run() {
                try {
                    Field declaredField = FilterInputStream.class.getDeclaredField("in");
                    declaredField.setAccessible(true);
                    ThresholdInputStream thresholdInputStream = new ThresholdInputStream((InputStream) declaredField.get(inputStream), null);
                    declaredField.set(inputStream, thresholdInputStream);
                    return thresholdInputStream;
                } catch (Exception e2) {
                    ZipSecureFile.LOG.log(5, "SecurityManager doesn't allow manipulation via reflection for zipbomb detection - continue with original input stream", e2);
                    return null;
                }
            }
        }) : null);
    }

    public static long getMaxEntrySize() {
        return MAX_ENTRY_SIZE;
    }

    public static long getMaxTextSize() {
        return MAX_TEXT_SIZE;
    }

    public static double getMinInflateRatio() {
        return MIN_INFLATE_RATIO;
    }

    public static void setMaxEntrySize(long j) {
        if (j < 0 || j > Filetime.UINT_MASK) {
            throw new IllegalArgumentException("Max entry size is bounded [0-4GB], but had " + j);
        }
        MAX_ENTRY_SIZE = j;
    }

    public static void setMaxTextSize(long j) {
        if (j < 0 || j > Filetime.UINT_MASK) {
            throw new IllegalArgumentException("Max text size is bounded [0-4GB], but had " + j);
        }
        MAX_TEXT_SIZE = j;
    }

    public static void setMinInflateRatio(double d2) {
        MIN_INFLATE_RATIO = d2;
    }

    @Override // java.util.zip.ZipFile
    public InputStream getInputStream(ZipEntry zipEntry) {
        return addThreshold(super.getInputStream(zipEntry));
    }

    public static class ThresholdInputStream extends PushbackInputStream {
        public ThresholdInputStream cis;
        public long counter = 0;

        public ThresholdInputStream(InputStream inputStream, ThresholdInputStream thresholdInputStream) {
            super(inputStream, 1);
            this.cis = thresholdInputStream;
        }

        public void advance(int i2) {
            long j = this.counter + ((long) i2);
            this.counter = j;
            if (j > ZipSecureFile.MAX_ENTRY_SIZE) {
                StringBuilder b2 = a.b("Zip bomb detected! The file would exceed the max size of the expanded data in the zip-file. This may indicates that the file is used to inflate memory usage and thus could pose a security risk. You can adjust this limit via ZipSecureFile.setMaxEntrySize() if you need to work with files which are very large. Counter: ");
                b2.append(this.counter);
                b2.append(", cis.counter: ");
                ThresholdInputStream thresholdInputStream = this.cis;
                b2.append(thresholdInputStream == null ? 0 : thresholdInputStream.counter);
                b2.append("Limits: MAX_ENTRY_SIZE: ");
                b2.append(ZipSecureFile.MAX_ENTRY_SIZE);
                throw new IOException(b2.toString());
            }
            ThresholdInputStream thresholdInputStream2 = this.cis;
            if (thresholdInputStream2 != null) {
                long j2 = this.counter;
                if (j2 > ZipSecureFile.GRACE_ENTRY_SIZE && ((double) thresholdInputStream2.counter) / ((double) j2) < ZipSecureFile.MIN_INFLATE_RATIO) {
                    StringBuilder b3 = a.b("Zip bomb detected! The file would exceed the max. ratio of compressed file size to the size of the expanded data. This may indicate that the file is used to inflate memory usage and thus could pose a security risk. You can adjust this limit via ZipSecureFile.setMinInflateRatio() if you need to work with files which exceed this limit. Counter: ");
                    b3.append(this.counter);
                    b3.append(", cis.counter: ");
                    b3.append(this.cis.counter);
                    b3.append(", ratio: ");
                    b3.append(((double) this.cis.counter) / ((double) this.counter));
                    b3.append("Limits: MIN_INFLATE_RATIO: ");
                    b3.append(ZipSecureFile.MIN_INFLATE_RATIO);
                    throw new IOException(b3.toString());
                }
            }
        }

        @Override // java.io.FilterInputStream, java.io.PushbackInputStream, java.io.InputStream
        @SuppressForbidden("just delegating")
        public int available() {
            return ((PushbackInputStream) this).in.available();
        }

        public void closeEntry() {
            if (((PushbackInputStream) this).in instanceof ZipInputStream) {
                this.counter = 0;
                ((ZipInputStream) ((PushbackInputStream) this).in).closeEntry();
                return;
            }
            throw new UnsupportedOperationException("underlying stream is not a ZipInputStream");
        }

        public ZipEntry getNextEntry() {
            if (((PushbackInputStream) this).in instanceof ZipInputStream) {
                this.counter = 0;
                return ((ZipInputStream) ((PushbackInputStream) this).in).getNextEntry();
            }
            throw new UnsupportedOperationException("underlying stream is not a ZipInputStream");
        }

        public synchronized void mark(int i2) {
            ((PushbackInputStream) this).in.mark(i2);
        }

        public boolean markSupported() {
            return ((PushbackInputStream) this).in.markSupported();
        }

        @Override // java.io.FilterInputStream, java.io.PushbackInputStream, java.io.InputStream
        public int read() {
            int read = ((PushbackInputStream) this).in.read();
            if (read > -1) {
                advance(1);
            }
            return read;
        }

        @Override // java.io.FilterInputStream, java.io.PushbackInputStream, java.io.InputStream
        public synchronized void reset() {
            this.counter = 0;
            ((PushbackInputStream) this).in.reset();
        }

        @Override // java.io.FilterInputStream, java.io.PushbackInputStream, java.io.InputStream
        public long skip(long j) {
            this.counter = 0;
            return ((PushbackInputStream) this).in.skip(j);
        }

        @Override // java.io.PushbackInputStream
        public void unread(int i2) {
            if (((PushbackInputStream) this).in instanceof PushbackInputStream) {
                long j = this.counter - 1;
                this.counter = j;
                if (j < 0) {
                    this.counter = 0;
                }
                ((PushbackInputStream) ((PushbackInputStream) this).in).unread(i2);
                return;
            }
            throw new UnsupportedOperationException("underlying stream is not a PushbackInputStream");
        }

        @Override // java.io.FilterInputStream, java.io.PushbackInputStream, java.io.InputStream
        public int read(byte[] bArr, int i2, int i3) {
            int read = ((PushbackInputStream) this).in.read(bArr, i2, i3);
            if (read > -1) {
                advance(read);
            }
            return read;
        }

        @Override // java.io.PushbackInputStream
        public void unread(byte[] bArr, int i2, int i3) {
            if (((PushbackInputStream) this).in instanceof PushbackInputStream) {
                long j = this.counter - ((long) i3);
                this.counter = j;
                long j2 = j - 1;
                this.counter = j2;
                if (j2 < 0) {
                    this.counter = 0;
                }
                ((PushbackInputStream) ((PushbackInputStream) this).in).unread(bArr, i2, i3);
                return;
            }
            throw new UnsupportedOperationException("underlying stream is not a PushbackInputStream");
        }
    }

    public ZipSecureFile(File file) {
        super(file);
    }

    public ZipSecureFile(String str) {
        super(str);
    }
}
