package org.apache.poi.poifs.crypt;

import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import java.security.GeneralSecurityException;
import javax.crypto.Cipher;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndianInputStream;

@Internal
public abstract class ChunkedCipherInputStream extends LittleEndianInputStream {
    public final byte[] chunk;
    public final int chunkBits;
    public boolean chunkIsValid;
    public final int chunkSize;
    public final Cipher cipher;
    public int lastIndex;
    public final byte[] plain;
    public long pos;
    public final long size;

    public ChunkedCipherInputStream(InputStream inputStream, long j, int i2) {
        this(inputStream, j, i2, 0);
    }

    private void nextChunk() {
        int read;
        boolean z = true;
        if (this.chunkSize != -1) {
            int i2 = (int) (this.pos >> this.chunkBits);
            initCipherForBlock(this.cipher, i2);
            int i3 = this.lastIndex;
            if (i3 != i2) {
                long j = (long) ((i2 - i3) << this.chunkBits);
                if (super.skip(j) < j) {
                    throw new EOFException("buffer underrun");
                }
            }
            this.lastIndex = i2 + 1;
        }
        int min = (int) Math.min(this.size, (long) this.chunk.length);
        int i4 = 0;
        do {
            read = super.read(this.plain, i4, min - i4);
            i4 += Math.max(0, read);
            if (read == -1) {
                break;
            }
        } while (i4 < min);
        if (read == -1) {
            long j2 = this.pos + ((long) i4);
            long j3 = this.size;
            if (j2 < j3 && j3 < 2147483647L) {
                throw new EOFException("buffer underrun");
            }
        }
        System.arraycopy(this.plain, 0, this.chunk, 0, i4);
        if (i4 != this.chunkSize) {
            z = false;
        }
        invokeCipher(i4, z);
    }

    private int remainingBytes() {
        return (int) (this.size - this.pos);
    }

    @Override // java.io.FilterInputStream, org.apache.poi.util.LittleEndianInputStream, org.apache.poi.util.LittleEndianInput, java.io.InputStream
    public int available() {
        return remainingBytes();
    }

    public byte[] getChunk() {
        return this.chunk;
    }

    public int getChunkMask() {
        return this.chunk.length - 1;
    }

    public byte[] getPlain() {
        return this.plain;
    }

    public long getPos() {
        return this.pos;
    }

    public final Cipher initCipherForBlock(int i2) {
        if (this.chunkSize == -1) {
            this.chunkIsValid = false;
            return initCipherForBlock(this.cipher, i2);
        }
        throw new GeneralSecurityException("the cipher block can only be set for streaming encryption, e.g. CryptoAPI...");
    }

    public abstract Cipher initCipherForBlock(Cipher cipher2, int i2);

    public int invokeCipher(int i2, boolean z) {
        if (z) {
            Cipher cipher2 = this.cipher;
            byte[] bArr = this.chunk;
            return cipher2.doFinal(bArr, 0, i2, bArr);
        }
        Cipher cipher3 = this.cipher;
        byte[] bArr2 = this.chunk;
        return cipher3.update(bArr2, 0, i2, bArr2);
    }

    public synchronized void mark(int i2) {
        throw new UnsupportedOperationException();
    }

    public boolean markSupported() {
        return false;
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public int read() {
        byte[] bArr = {0};
        if (read(bArr) == 1) {
            return -1;
        }
        return bArr[0];
    }

    @Override // org.apache.poi.util.LittleEndianInputStream, org.apache.poi.util.LittleEndianInput
    public void readPlain(byte[] bArr, int i2, int i3) {
        if (i3 > 0) {
            int i4 = 0;
            do {
                try {
                    int read = read(bArr, i2, i3, true);
                    i4 += Math.max(0, read);
                    if (read <= -1) {
                        break;
                    }
                } catch (IOException e2) {
                    throw new RuntimeException(e2);
                }
            } while (i4 < i3);
            if (i4 < i3) {
                throw new EOFException("buffer underrun");
            }
        }
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public synchronized void reset() {
        throw new UnsupportedOperationException();
    }

    public void setNextRecordSize(int i2) {
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public long skip(long j) {
        long j2 = this.pos;
        long min = Math.min((long) remainingBytes(), j);
        if (((j2 ^ (this.pos + min)) & ((long) (~getChunkMask()))) != 0) {
            this.chunkIsValid = false;
        }
        this.pos += min;
        return min;
    }

    public ChunkedCipherInputStream(InputStream inputStream, long j, int i2, int i3) {
        super(inputStream);
        this.chunkIsValid = false;
        this.size = j;
        this.pos = (long) i3;
        this.chunkSize = i2;
        i2 = i2 == -1 ? 4096 : i2;
        byte[] bArr = new byte[i2];
        this.chunk = bArr;
        this.plain = new byte[i2];
        int bitCount = Integer.bitCount(bArr.length - 1);
        this.chunkBits = bitCount;
        int i4 = (int) (this.pos >> bitCount);
        this.lastIndex = i4;
        this.cipher = initCipherForBlock(null, i4);
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public int read(byte[] bArr, int i2, int i3) {
        return read(bArr, i2, i3, false);
    }

    private int read(byte[] bArr, int i2, int i3, boolean z) {
        if (available() <= 0) {
            return -1;
        }
        int chunkMask = getChunkMask();
        int i4 = 0;
        while (i3 > 0) {
            if (!this.chunkIsValid) {
                try {
                    nextChunk();
                    this.chunkIsValid = true;
                } catch (GeneralSecurityException e2) {
                    throw new EncryptedDocumentException(e2.getMessage(), e2);
                }
            }
            long j = (long) chunkMask;
            int length = (int) (((long) this.chunk.length) - (this.pos & j));
            int available = available();
            if (available == 0) {
                return i4;
            }
            int min = Math.min(available, Math.min(length, i3));
            System.arraycopy(z ? this.plain : this.chunk, (int) (this.pos & j), bArr, i2, min);
            i2 += min;
            i3 -= min;
            long j2 = this.pos + ((long) min);
            this.pos = j2;
            if ((j2 & j) == 0) {
                this.chunkIsValid = false;
            }
            i4 += min;
        }
        return i4;
    }
}
