package org.apache.poi.poifs.crypt;

import java.nio.charset.Charset;
import java.security.DigestException;
import java.security.GeneralSecurityException;
import java.security.Key;
import java.security.MessageDigest;
import java.security.Provider;
import java.security.Security;
import java.security.spec.AlgorithmParameterSpec;
import java.util.Arrays;
import java.util.Locale;
import javax.crypto.Cipher;
import javax.crypto.Mac;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.RC2ParameterSpec;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.ss.formula.functions.TimeFunc;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.StringUtil;

@Internal
public class CryptoFunctions {
    public static final int[][] ENCRYPTION_MATRIX = {new int[]{44796, 19929, 39858, 10053, 20106, 40212, 10761}, new int[]{31585, 63170, 64933, 60267, 50935, 40399, 11199}, new int[]{17763, 35526, 1453, 2906, 5812, 11624, 23248}, new int[]{885, 1770, 3540, 7080, 14160, 28320, 56640}, new int[]{55369, 41139, 20807, 41614, 21821, 43642, 17621}, new int[]{28485, 56970, 44341, 19019, 38038, 14605, 29210}, new int[]{60195, 50791, 40175, 10751, 21502, 43004, 24537}, new int[]{18387, 36774, 3949, 7898, 15796, 31592, 63184}, new int[]{47201, 24803, 49606, 37805, 14203, 28406, 56812}, new int[]{17824, 35648, 1697, 3394, 6788, 13576, 27152}, new int[]{43601, 17539, 35078, 557, 1114, 2228, 4456}, new int[]{30388, 60776, 51953, 34243, 7079, 14158, 28316}, new int[]{14128, 28256, 56512, 43425, 17251, 34502, 7597}, new int[]{13105, 26210, 52420, 35241, 883, 1766, 3532}, new int[]{4129, 8258, 16516, 33032, 4657, 9314, 18628}};
    public static final int[] INITIAL_CODE_ARRAY = {57840, 7439, 52380, 33984, 4364, TimeFunc.SECONDS_PER_HOUR, 61902, 12606, 6258, 57657, 54287, 34041, 10252, 43370, 20163};
    public static final byte[] PAD_ARRAY = {-69, -1, -1, -70, -1, -1, -71, Byte.MIN_VALUE, 0, -66, 15, 0, -65, 15, 0};

    public static byte[] createXorArray1(String str) {
        if (str.length() > 15) {
            str = str.substring(0, 15);
        }
        byte[] bytes = str.getBytes(Charset.forName("ASCII"));
        byte[] bArr = new byte[16];
        System.arraycopy(bytes, 0, bArr, 0, bytes.length);
        byte[] bArr2 = PAD_ARRAY;
        System.arraycopy(bArr2, 0, bArr, bytes.length, (bArr2.length - bytes.length) + 1);
        int createXorKey1 = createXorKey1(str);
        byte[] bArr3 = {(byte) (createXorKey1 & 255), (byte) ((createXorKey1 >>> 8) & 255)};
        for (int i2 = 0; i2 < 16; i2++) {
            bArr[i2] = (byte) (bArr[i2] ^ bArr3[i2 & 1]);
            bArr[i2] = rotateLeft(bArr[i2], 2);
        }
        return bArr;
    }

    public static int createXorKey1(String str) {
        return createXorVerifier2(str) >>> 16;
    }

    public static int createXorVerifier1(String str) {
        byte[] ansiPassword = toAnsiPassword(str);
        short s = 0;
        if (!"".equals(str)) {
            for (int length = ansiPassword.length - 1; length >= 0; length--) {
                s = (short) (rotateLeftBase15Bit(s) ^ ansiPassword[length]);
            }
            s = (short) (((short) (rotateLeftBase15Bit(s) ^ ansiPassword.length)) ^ 52811);
        }
        return 65535 & s;
    }

    public static int createXorVerifier2(String str) {
        byte[] bArr = new byte[4];
        if (!"".equals(str)) {
            String substring = str.substring(0, Math.min(str.length(), 15));
            byte[] ansiPassword = toAnsiPassword(substring);
            int i2 = INITIAL_CODE_ARRAY[ansiPassword.length - 1];
            for (int i3 = 0; i3 < ansiPassword.length; i3++) {
                int length = (15 - ansiPassword.length) + i3;
                for (int i4 = 0; i4 < 7; i4++) {
                    if ((ansiPassword[i3] & (1 << i4)) != 0) {
                        i2 ^= ENCRYPTION_MATRIX[length][i4];
                    }
                }
            }
            LittleEndian.putShort(bArr, 0, (short) createXorVerifier1(substring));
            LittleEndian.putShort(bArr, 2, (short) i2);
        }
        return LittleEndian.getInt(bArr);
    }

    public static byte[] generateIv(HashAlgorithm hashAlgorithm, byte[] bArr, byte[] bArr2, int i2) {
        if (bArr2 != null) {
            MessageDigest messageDigest = getMessageDigest(hashAlgorithm);
            messageDigest.update(bArr);
            bArr = messageDigest.digest(bArr2);
        }
        return getBlock36(bArr, i2);
    }

    public static byte[] generateKey(byte[] bArr, HashAlgorithm hashAlgorithm, byte[] bArr2, int i2) {
        MessageDigest messageDigest = getMessageDigest(hashAlgorithm);
        messageDigest.update(bArr);
        return getBlock36(messageDigest.digest(bArr2), i2);
    }

    public static byte[] getBlock0(byte[] bArr, int i2) {
        return getBlockX(bArr, i2, (byte) 0);
    }

    public static byte[] getBlock36(byte[] bArr, int i2) {
        return getBlockX(bArr, i2, (byte) 54);
    }

    public static byte[] getBlockX(byte[] bArr, int i2, byte b2) {
        if (bArr.length == i2) {
            return bArr;
        }
        byte[] bArr2 = new byte[i2];
        Arrays.fill(bArr2, b2);
        System.arraycopy(bArr, 0, bArr2, 0, Math.min(i2, bArr.length));
        return bArr2;
    }

    public static Cipher getCipher(SecretKey secretKey, CipherAlgorithm cipherAlgorithm, ChainingMode chainingMode, byte[] bArr, int i2) {
        return getCipher(secretKey, cipherAlgorithm, chainingMode, bArr, i2, null);
    }

    public static Mac getMac(HashAlgorithm hashAlgorithm) {
        try {
            if (!hashAlgorithm.needsBouncyCastle) {
                return Mac.getInstance(hashAlgorithm.jceHmacId);
            }
            registerBouncyCastle();
            return Mac.getInstance(hashAlgorithm.jceHmacId, "BC");
        } catch (GeneralSecurityException e2) {
            throw new EncryptedDocumentException("hmac algo not supported", e2);
        }
    }

    public static MessageDigest getMessageDigest(HashAlgorithm hashAlgorithm) {
        try {
            if (!hashAlgorithm.needsBouncyCastle) {
                return MessageDigest.getInstance(hashAlgorithm.jceId);
            }
            registerBouncyCastle();
            return MessageDigest.getInstance(hashAlgorithm.jceId, "BC");
        } catch (GeneralSecurityException e2) {
            throw new EncryptedDocumentException("hash algo not supported", e2);
        }
    }

    public static byte[] hashPassword(String str, HashAlgorithm hashAlgorithm, byte[] bArr, int i2) {
        return hashPassword(str, hashAlgorithm, bArr, i2, true);
    }

    public static void registerBouncyCastle() {
        if (Security.getProvider("BC") == null) {
            try {
                Security.addProvider((Provider) Thread.currentThread().getContextClassLoader().loadClass("org.bouncycastle.jce.provider.BouncyCastleProvider").newInstance());
            } catch (Exception e2) {
                throw new EncryptedDocumentException("Only the BouncyCastle provider supports your encryption settings - please add it to the classpath.", e2);
            }
        }
    }

    public static byte rotateLeft(byte b2, int i2) {
        int i3 = b2 & 255;
        return (byte) ((i3 >>> (8 - i2)) | (i3 << i2));
    }

    public static short rotateLeftBase15Bit(short s) {
        return (short) (((short) ((s << 1) & 32767)) | ((short) ((s & 16384) == 0 ? 0 : 1)));
    }

    public static byte[] toAnsiPassword(String str) {
        byte[] bArr = new byte[str.length()];
        for (int i2 = 0; i2 < str.length(); i2++) {
            char charAt = str.charAt(i2);
            byte b2 = (byte) (charAt & 255);
            byte b3 = (byte) ((charAt >>> '\b') & 255);
            if (b2 == 0) {
                b2 = b3;
            }
            bArr[i2] = b2;
        }
        return bArr;
    }

    public static String xorHashPassword(String str) {
        int createXorVerifier2 = createXorVerifier2(str);
        return String.format(Locale.ROOT, "%1$08X", Integer.valueOf(createXorVerifier2));
    }

    public static String xorHashPasswordReversed(String str) {
        int createXorVerifier2 = createXorVerifier2(str);
        return String.format(Locale.ROOT, "%1$02X%2$02X%3$02X%4$02X", Integer.valueOf((createXorVerifier2 >>> 0) & 255), Integer.valueOf((createXorVerifier2 >>> 8) & 255), Integer.valueOf((createXorVerifier2 >>> 16) & 255), Integer.valueOf((createXorVerifier2 >>> 24) & 255));
    }

    public static Cipher getCipher(Key key, CipherAlgorithm cipherAlgorithm, ChainingMode chainingMode, byte[] bArr, int i2, String str) {
        Cipher cipher;
        AlgorithmParameterSpec algorithmParameterSpec;
        int length = key.getEncoded().length;
        if (str == null) {
            str = "NoPadding";
        }
        try {
            if (Cipher.getMaxAllowedKeyLength(cipherAlgorithm.jceId) >= length * 8) {
                if (cipherAlgorithm == CipherAlgorithm.rc4) {
                    cipher = Cipher.getInstance(cipherAlgorithm.jceId);
                } else if (cipherAlgorithm.needsBouncyCastle) {
                    registerBouncyCastle();
                    cipher = Cipher.getInstance(cipherAlgorithm.jceId + ZipHelper.FORWARD_SLASH + chainingMode.jceId + ZipHelper.FORWARD_SLASH + str, "BC");
                } else {
                    cipher = Cipher.getInstance(cipherAlgorithm.jceId + ZipHelper.FORWARD_SLASH + chainingMode.jceId + ZipHelper.FORWARD_SLASH + str);
                }
                if (bArr == null) {
                    cipher.init(i2, key);
                } else {
                    if (cipherAlgorithm == CipherAlgorithm.rc2) {
                        algorithmParameterSpec = new RC2ParameterSpec(key.getEncoded().length * 8, bArr);
                    } else {
                        algorithmParameterSpec = new IvParameterSpec(bArr);
                    }
                    cipher.init(i2, key, algorithmParameterSpec);
                }
                return cipher;
            }
            throw new EncryptedDocumentException("Export Restrictions in place - please install JCE Unlimited Strength Jurisdiction Policy files");
        } catch (GeneralSecurityException e2) {
            throw new EncryptedDocumentException(e2);
        }
    }

    public static byte[] hashPassword(String str, HashAlgorithm hashAlgorithm, byte[] bArr, int i2, boolean z) {
        if (str == null) {
            str = Decryptor.DEFAULT_PASSWORD;
        }
        MessageDigest messageDigest = getMessageDigest(hashAlgorithm);
        messageDigest.update(bArr);
        byte[] digest = messageDigest.digest(StringUtil.getToUnicodeLE(str));
        byte[] bArr2 = new byte[4];
        byte[] bArr3 = z ? bArr2 : digest;
        byte[] bArr4 = z ? digest : bArr2;
        for (int i3 = 0; i3 < i2; i3++) {
            try {
                LittleEndian.putInt(bArr2, 0, i3);
                messageDigest.reset();
                messageDigest.update(bArr3);
                messageDigest.update(bArr4);
                messageDigest.digest(digest, 0, digest.length);
            } catch (DigestException unused) {
                throw new EncryptedDocumentException("error in password hashing");
            }
        }
        return digest;
    }
}
