package org.apache.poi.poifs.crypt;

import java.io.IOException;
import java.nio.charset.Charset;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.poifs.crypt.standard.EncryptionRecord;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.poifs.filesystem.DocumentEntry;
import org.apache.poi.poifs.filesystem.POIFSWriterEvent;
import org.apache.poi.poifs.filesystem.POIFSWriterListener;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.poi.util.StringUtil;

public class DataSpaceMapUtils {
    public static void addDefaultDataSpace(DirectoryEntry directoryEntry) {
        createEncryptionEntry(directoryEntry, "\u0006DataSpaces/DataSpaceMap", new DataSpaceMap(new DataSpaceMapEntry[]{new DataSpaceMapEntry(new int[]{0}, new String[]{"EncryptedPackage"}, "StrongEncryptionDataSpace")}));
        createEncryptionEntry(directoryEntry, "\u0006DataSpaces/DataSpaceInfo/StrongEncryptionDataSpace", new DataSpaceDefinition(new String[]{"StrongEncryptionTransform"}));
        createEncryptionEntry(directoryEntry, "\u0006DataSpaces/TransformInfo/StrongEncryptionTransform/\u0006Primary", new IRMDSTransformInfo(new TransformInfoHeader(1, "{FF9A3F03-56EF-4613-BDD5-5A41C1D07246}", "Microsoft.Container.EncryptionTransform", 1, 0, 1, 0, 1, 0), 0, null));
        createEncryptionEntry(directoryEntry, "\u0006DataSpaces/Version", new DataSpaceVersionInfo("Microsoft.Container.DataSpaces", 1, 0, 1, 0, 1, 0));
    }

    public static DocumentEntry createEncryptionEntry(DirectoryEntry directoryEntry, String str, EncryptionRecord encryptionRecord) {
        String[] split = str.split(ZipHelper.FORWARD_SLASH);
        for (int i2 = 0; i2 < split.length - 1; i2++) {
            directoryEntry = directoryEntry.hasEntry(split[i2]) ? (DirectoryEntry) directoryEntry.getEntry(split[i2]) : directoryEntry.createDirectory(split[i2]);
        }
        final byte[] bArr = new byte[5000];
        LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream = new LittleEndianByteArrayOutputStream(bArr, 0);
        encryptionRecord.write(littleEndianByteArrayOutputStream);
        String str2 = split[split.length - 1];
        if (directoryEntry.hasEntry(str2)) {
            directoryEntry.getEntry(str2).delete();
        }
        return directoryEntry.createDocument(str2, littleEndianByteArrayOutputStream.getWriteIndex(), new POIFSWriterListener() {
            /* class org.apache.poi.poifs.crypt.DataSpaceMapUtils.AnonymousClass1 */

            @Override // org.apache.poi.poifs.filesystem.POIFSWriterListener
            public void processPOIFSWriterEvent(POIFSWriterEvent pOIFSWriterEvent) {
                try {
                    pOIFSWriterEvent.getStream().write(bArr, 0, pOIFSWriterEvent.getLimit());
                } catch (IOException e2) {
                    throw new EncryptedDocumentException(e2);
                }
            }
        });
    }

    public static String readUnicodeLPP4(LittleEndianInput littleEndianInput) {
        int readInt = littleEndianInput.readInt();
        if (readInt % 2 == 0) {
            String readUnicodeLE = StringUtil.readUnicodeLE(littleEndianInput, readInt / 2);
            if (readInt % 4 == 2) {
                littleEndianInput.readShort();
            }
            return readUnicodeLE;
        }
        throw new EncryptedDocumentException("UNICODE-LP-P4 structure is a multiple of 4 bytes. If Padding is present, it MUST be exactly 2 bytes long");
    }

    public static String readUtf8LPP4(LittleEndianInput littleEndianInput) {
        int readInt = littleEndianInput.readInt();
        if (readInt == 0 || readInt == 4) {
            littleEndianInput.readInt();
            if (readInt == 0) {
                return null;
            }
            return "";
        }
        byte[] bArr = new byte[readInt];
        littleEndianInput.readFully(bArr);
        int i2 = readInt % 4;
        if (i2 > 0) {
            for (int i3 = 0; i3 < 4 - i2; i3++) {
                littleEndianInput.readByte();
            }
        }
        return new String(bArr, 0, readInt, Charset.forName("UTF-8"));
    }

    public static void writeUnicodeLPP4(LittleEndianOutput littleEndianOutput, String str) {
        byte[] toUnicodeLE = StringUtil.getToUnicodeLE(str);
        littleEndianOutput.writeInt(toUnicodeLE.length);
        littleEndianOutput.write(toUnicodeLE);
        if (toUnicodeLE.length % 4 == 2) {
            littleEndianOutput.writeShort(0);
        }
    }

    public static void writeUtf8LPP4(LittleEndianOutput littleEndianOutput, String str) {
        int i2 = 4;
        if (str == null || "".equals(str)) {
            if (str == null) {
                i2 = 0;
            }
            littleEndianOutput.writeInt(i2);
            littleEndianOutput.writeInt(0);
            return;
        }
        byte[] bytes = str.getBytes(Charset.forName("UTF-8"));
        littleEndianOutput.writeInt(bytes.length);
        littleEndianOutput.write(bytes);
        int length = bytes.length % 4;
        if (length > 0) {
            for (int i3 = 0; i3 < 4 - length; i3++) {
                littleEndianOutput.writeByte(0);
            }
        }
    }

    public static class DataSpaceDefinition implements EncryptionRecord {
        public String[] transformer;

        public DataSpaceDefinition(String[] strArr) {
            this.transformer = (String[]) strArr.clone();
        }

        @Override // org.apache.poi.poifs.crypt.standard.EncryptionRecord
        public void write(LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream) {
            littleEndianByteArrayOutputStream.writeInt(8);
            littleEndianByteArrayOutputStream.writeInt(this.transformer.length);
            for (String str : this.transformer) {
                DataSpaceMapUtils.writeUnicodeLPP4(littleEndianByteArrayOutputStream, str);
            }
        }

        public DataSpaceDefinition(LittleEndianInput littleEndianInput) {
            littleEndianInput.readInt();
            int readInt = littleEndianInput.readInt();
            this.transformer = new String[readInt];
            for (int i2 = 0; i2 < readInt; i2++) {
                this.transformer[i2] = DataSpaceMapUtils.readUnicodeLPP4(littleEndianInput);
            }
        }
    }

    public static class DataSpaceMap implements EncryptionRecord {
        public DataSpaceMapEntry[] entries;

        public DataSpaceMap(DataSpaceMapEntry[] dataSpaceMapEntryArr) {
            this.entries = (DataSpaceMapEntry[]) dataSpaceMapEntryArr.clone();
        }

        @Override // org.apache.poi.poifs.crypt.standard.EncryptionRecord
        public void write(LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream) {
            littleEndianByteArrayOutputStream.writeInt(8);
            littleEndianByteArrayOutputStream.writeInt(this.entries.length);
            for (DataSpaceMapEntry dataSpaceMapEntry : this.entries) {
                dataSpaceMapEntry.write(littleEndianByteArrayOutputStream);
            }
        }

        public DataSpaceMap(LittleEndianInput littleEndianInput) {
            littleEndianInput.readInt();
            int readInt = littleEndianInput.readInt();
            this.entries = new DataSpaceMapEntry[readInt];
            for (int i2 = 0; i2 < readInt; i2++) {
                this.entries[i2] = new DataSpaceMapEntry(littleEndianInput);
            }
        }
    }

    public static class DataSpaceMapEntry implements EncryptionRecord {
        public final String dataSpaceName;
        public final String[] referenceComponent;
        public final int[] referenceComponentType;

        public DataSpaceMapEntry(int[] iArr, String[] strArr, String str) {
            this.referenceComponentType = (int[]) iArr.clone();
            this.referenceComponent = (String[]) strArr.clone();
            this.dataSpaceName = str;
        }

        @Override // org.apache.poi.poifs.crypt.standard.EncryptionRecord
        public void write(LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream) {
            int writeIndex = littleEndianByteArrayOutputStream.getWriteIndex();
            LittleEndianOutput createDelayedOutput = littleEndianByteArrayOutputStream.createDelayedOutput(4);
            littleEndianByteArrayOutputStream.writeInt(this.referenceComponent.length);
            for (int i2 = 0; i2 < this.referenceComponent.length; i2++) {
                littleEndianByteArrayOutputStream.writeInt(this.referenceComponentType[i2]);
                DataSpaceMapUtils.writeUnicodeLPP4(littleEndianByteArrayOutputStream, this.referenceComponent[i2]);
            }
            DataSpaceMapUtils.writeUnicodeLPP4(littleEndianByteArrayOutputStream, this.dataSpaceName);
            createDelayedOutput.writeInt(littleEndianByteArrayOutputStream.getWriteIndex() - writeIndex);
        }

        public DataSpaceMapEntry(LittleEndianInput littleEndianInput) {
            littleEndianInput.readInt();
            int readInt = littleEndianInput.readInt();
            this.referenceComponentType = new int[readInt];
            this.referenceComponent = new String[readInt];
            for (int i2 = 0; i2 < readInt; i2++) {
                this.referenceComponentType[i2] = littleEndianInput.readInt();
                this.referenceComponent[i2] = DataSpaceMapUtils.readUnicodeLPP4(littleEndianInput);
            }
            this.dataSpaceName = DataSpaceMapUtils.readUnicodeLPP4(littleEndianInput);
        }
    }

    public static class IRMDSTransformInfo implements EncryptionRecord {
        public int extensibilityHeader;
        public TransformInfoHeader transformInfoHeader;
        public String xrMLLicense;

        public IRMDSTransformInfo(TransformInfoHeader transformInfoHeader2, int i2, String str) {
            this.transformInfoHeader = transformInfoHeader2;
            this.extensibilityHeader = i2;
            this.xrMLLicense = str;
        }

        @Override // org.apache.poi.poifs.crypt.standard.EncryptionRecord
        public void write(LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream) {
            this.transformInfoHeader.write(littleEndianByteArrayOutputStream);
            littleEndianByteArrayOutputStream.writeInt(this.extensibilityHeader);
            DataSpaceMapUtils.writeUtf8LPP4(littleEndianByteArrayOutputStream, this.xrMLLicense);
            littleEndianByteArrayOutputStream.writeInt(4);
        }

        public IRMDSTransformInfo(LittleEndianInput littleEndianInput) {
            this.transformInfoHeader = new TransformInfoHeader(littleEndianInput);
            this.extensibilityHeader = littleEndianInput.readInt();
            this.xrMLLicense = DataSpaceMapUtils.readUtf8LPP4(littleEndianInput);
        }
    }

    public static class DataSpaceVersionInfo implements EncryptionRecord {
        public String featureIdentifier;
        public int readerVersionMajor = 1;
        public int readerVersionMinor = 0;
        public int updaterVersionMajor = 1;
        public int updaterVersionMinor = 0;
        public int writerVersionMajor = 1;
        public int writerVersionMinor = 0;

        public DataSpaceVersionInfo(LittleEndianInput littleEndianInput) {
            this.featureIdentifier = DataSpaceMapUtils.readUnicodeLPP4(littleEndianInput);
            this.readerVersionMajor = littleEndianInput.readShort();
            this.readerVersionMinor = littleEndianInput.readShort();
            this.updaterVersionMajor = littleEndianInput.readShort();
            this.updaterVersionMinor = littleEndianInput.readShort();
            this.writerVersionMajor = littleEndianInput.readShort();
            this.writerVersionMinor = littleEndianInput.readShort();
        }

        @Override // org.apache.poi.poifs.crypt.standard.EncryptionRecord
        public void write(LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream) {
            DataSpaceMapUtils.writeUnicodeLPP4(littleEndianByteArrayOutputStream, this.featureIdentifier);
            littleEndianByteArrayOutputStream.writeShort(this.readerVersionMajor);
            littleEndianByteArrayOutputStream.writeShort(this.readerVersionMinor);
            littleEndianByteArrayOutputStream.writeShort(this.updaterVersionMajor);
            littleEndianByteArrayOutputStream.writeShort(this.updaterVersionMinor);
            littleEndianByteArrayOutputStream.writeShort(this.writerVersionMajor);
            littleEndianByteArrayOutputStream.writeShort(this.writerVersionMinor);
        }

        public DataSpaceVersionInfo(String str, int i2, int i3, int i4, int i5, int i6, int i7) {
            this.featureIdentifier = str;
            this.readerVersionMajor = i2;
            this.readerVersionMinor = i3;
            this.updaterVersionMajor = i4;
            this.updaterVersionMinor = i5;
            this.writerVersionMajor = i6;
            this.writerVersionMinor = i7;
        }
    }

    public static class TransformInfoHeader implements EncryptionRecord {
        public int readerVersionMajor = 1;
        public int readerVersionMinor = 0;
        public int transformType;
        public String transformerId;
        public String transformerName;
        public int updaterVersionMajor = 1;
        public int updaterVersionMinor = 0;
        public int writerVersionMajor = 1;
        public int writerVersionMinor = 0;

        public TransformInfoHeader(int i2, String str, String str2, int i3, int i4, int i5, int i6, int i7, int i8) {
            this.transformType = i2;
            this.transformerId = str;
            this.transformerName = str2;
            this.readerVersionMajor = i3;
            this.readerVersionMinor = i4;
            this.updaterVersionMajor = i5;
            this.updaterVersionMinor = i6;
            this.writerVersionMajor = i7;
            this.writerVersionMinor = i8;
        }

        @Override // org.apache.poi.poifs.crypt.standard.EncryptionRecord
        public void write(LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream) {
            int writeIndex = littleEndianByteArrayOutputStream.getWriteIndex();
            LittleEndianOutput createDelayedOutput = littleEndianByteArrayOutputStream.createDelayedOutput(4);
            littleEndianByteArrayOutputStream.writeInt(this.transformType);
            DataSpaceMapUtils.writeUnicodeLPP4(littleEndianByteArrayOutputStream, this.transformerId);
            createDelayedOutput.writeInt(littleEndianByteArrayOutputStream.getWriteIndex() - writeIndex);
            DataSpaceMapUtils.writeUnicodeLPP4(littleEndianByteArrayOutputStream, this.transformerName);
            littleEndianByteArrayOutputStream.writeShort(this.readerVersionMajor);
            littleEndianByteArrayOutputStream.writeShort(this.readerVersionMinor);
            littleEndianByteArrayOutputStream.writeShort(this.updaterVersionMajor);
            littleEndianByteArrayOutputStream.writeShort(this.updaterVersionMinor);
            littleEndianByteArrayOutputStream.writeShort(this.writerVersionMajor);
            littleEndianByteArrayOutputStream.writeShort(this.writerVersionMinor);
        }

        public TransformInfoHeader(LittleEndianInput littleEndianInput) {
            littleEndianInput.readInt();
            this.transformType = littleEndianInput.readInt();
            this.transformerId = DataSpaceMapUtils.readUnicodeLPP4(littleEndianInput);
            this.transformerName = DataSpaceMapUtils.readUnicodeLPP4(littleEndianInput);
            this.readerVersionMajor = littleEndianInput.readShort();
            this.readerVersionMinor = littleEndianInput.readShort();
            this.updaterVersionMajor = littleEndianInput.readShort();
            this.updaterVersionMinor = littleEndianInput.readShort();
            this.writerVersionMajor = littleEndianInput.readShort();
            this.writerVersionMinor = littleEndianInput.readShort();
        }
    }
}
