package org.apache.poi.poifs.crypt.standard;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FilterOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.security.GeneralSecurityException;
import java.security.SecureRandom;
import java.util.Arrays;
import javax.crypto.Cipher;
import javax.crypto.CipherOutputStream;
import javax.crypto.SecretKey;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.crypt.CryptoFunctions;
import org.apache.poi.poifs.crypt.DataSpaceMapUtils;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.crypt.EncryptionVerifier;
import org.apache.poi.poifs.crypt.Encryptor;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.POIFSWriterEvent;
import org.apache.poi.poifs.filesystem.POIFSWriterListener;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;
import org.apache.poi.util.LittleEndianOutputStream;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.TempFile;

public class StandardEncryptor extends Encryptor implements Cloneable {
    public static final POILogger logger = POILogFactory.getLogger(StandardEncryptor.class);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Cipher getCipher(SecretKey secretKey, String str) {
        EncryptionVerifier verifier = getEncryptionInfo().getVerifier();
        return CryptoFunctions.getCipher(secretKey, verifier.getCipherAlgorithm(), verifier.getChainingMode(), null, 1, str);
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public void confirmPassword(String str) {
        SecureRandom secureRandom = new SecureRandom();
        byte[] bArr = new byte[16];
        byte[] bArr2 = new byte[16];
        secureRandom.nextBytes(bArr);
        secureRandom.nextBytes(bArr2);
        confirmPassword(str, null, null, bArr, bArr2, null);
    }

    public void createEncryptionInfoEntry(DirectoryNode directoryNode) {
        final EncryptionInfo encryptionInfo = getEncryptionInfo();
        final StandardEncryptionHeader standardEncryptionHeader = (StandardEncryptionHeader) encryptionInfo.getHeader();
        final StandardEncryptionVerifier standardEncryptionVerifier = (StandardEncryptionVerifier) encryptionInfo.getVerifier();
        DataSpaceMapUtils.createEncryptionEntry(directoryNode, "EncryptionInfo", new EncryptionRecord() {
            /* class org.apache.poi.poifs.crypt.standard.StandardEncryptor.AnonymousClass1 */

            @Override // org.apache.poi.poifs.crypt.standard.EncryptionRecord
            public void write(LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream) {
                littleEndianByteArrayOutputStream.writeShort(encryptionInfo.getVersionMajor());
                littleEndianByteArrayOutputStream.writeShort(encryptionInfo.getVersionMinor());
                littleEndianByteArrayOutputStream.writeInt(encryptionInfo.getEncryptionFlags());
                standardEncryptionHeader.write(littleEndianByteArrayOutputStream);
                standardEncryptionVerifier.write(littleEndianByteArrayOutputStream);
            }
        });
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public OutputStream getDataStream(DirectoryNode directoryNode) {
        createEncryptionInfoEntry(directoryNode);
        DataSpaceMapUtils.addDefaultDataSpace(directoryNode);
        return new StandardCipherOutputStream(this, directoryNode);
    }

    public int getKeySizeInBytes() {
        return getEncryptionInfo().getHeader().getKeySize() / 8;
    }

    public class StandardCipherOutputStream extends FilterOutputStream implements POIFSWriterListener {
        public long countBytes;
        public final DirectoryNode dir;
        public final File fileOut;

        public StandardCipherOutputStream(DirectoryNode directoryNode, File file) {
            super(new CipherOutputStream(new FileOutputStream(file), StandardEncryptor.this.getCipher(StandardEncryptor.this.getSecretKey(), "PKCS5Padding")));
            this.fileOut = file;
            this.dir = directoryNode;
        }

        @Override // java.io.OutputStream, java.io.Closeable, java.io.FilterOutputStream, java.lang.AutoCloseable
        public void close() {
            super.close();
            writeToPOIFS();
        }

        /* JADX INFO: finally extract failed */
        @Override // org.apache.poi.poifs.filesystem.POIFSWriterListener
        public void processPOIFSWriterEvent(POIFSWriterEvent pOIFSWriterEvent) {
            try {
                LittleEndianOutputStream littleEndianOutputStream = new LittleEndianOutputStream(pOIFSWriterEvent.getStream());
                littleEndianOutputStream.writeLong(this.countBytes);
                FileInputStream fileInputStream = new FileInputStream(this.fileOut);
                try {
                    IOUtils.copy(fileInputStream, littleEndianOutputStream);
                    fileInputStream.close();
                    if (!this.fileOut.delete()) {
                        POILogger pOILogger = StandardEncryptor.logger;
                        pOILogger.log(7, "Can't delete temporary encryption file: " + this.fileOut);
                    }
                    littleEndianOutputStream.close();
                } catch (Throwable th) {
                    fileInputStream.close();
                    throw th;
                }
            } catch (IOException e2) {
                throw new EncryptedDocumentException(e2);
            }
        }

        @Override // java.io.OutputStream, java.io.FilterOutputStream
        public void write(byte[] bArr, int i2, int i3) {
            ((FilterOutputStream) this).out.write(bArr, i2, i3);
            this.countBytes += (long) i3;
        }

        public void writeToPOIFS() {
            this.dir.createDocument("EncryptedPackage", (int) (this.fileOut.length() + 8), this);
        }

        @Override // java.io.OutputStream, java.io.FilterOutputStream
        public void write(int i2) {
            ((FilterOutputStream) this).out.write(i2);
            this.countBytes++;
        }

        public StandardCipherOutputStream(StandardEncryptor standardEncryptor, DirectoryNode directoryNode) {
            this(directoryNode, TempFile.createTempFile("encrypted_package", "crypt"));
        }
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor, org.apache.poi.poifs.crypt.Encryptor, java.lang.Object
    public StandardEncryptor clone() {
        return (StandardEncryptor) super.clone();
    }

    @Override // org.apache.poi.poifs.crypt.Encryptor
    public void confirmPassword(String str, byte[] bArr, byte[] bArr2, byte[] bArr3, byte[] bArr4, byte[] bArr5) {
        StandardEncryptionVerifier standardEncryptionVerifier = (StandardEncryptionVerifier) getEncryptionInfo().getVerifier();
        standardEncryptionVerifier.setSalt(bArr4);
        SecretKey generateSecretKey = StandardDecryptor.generateSecretKey(str, standardEncryptionVerifier, getKeySizeInBytes());
        setSecretKey(generateSecretKey);
        Cipher cipher = getCipher(generateSecretKey, null);
        try {
            byte[] doFinal = cipher.doFinal(bArr3);
            byte[] doFinal2 = cipher.doFinal(Arrays.copyOf(CryptoFunctions.getMessageDigest(standardEncryptionVerifier.getHashAlgorithm()).digest(bArr3), standardEncryptionVerifier.getCipherAlgorithm().encryptedVerifierHashLength));
            standardEncryptionVerifier.setEncryptedVerifier(doFinal);
            standardEncryptionVerifier.setEncryptedVerifierHash(doFinal2);
        } catch (GeneralSecurityException e2) {
            throw new EncryptedDocumentException("Password confirmation failed", e2);
        }
    }
}
