package org.apache.poi.poifs.filesystem;

import java.io.FileNotFoundException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.poi.hpsf.ClassID;

public class FilteringDirectoryNode implements DirectoryEntry {
    public Map<String, List<String>> childExcludes = new HashMap();
    public DirectoryEntry directory;
    public Set<String> excludes = new HashSet();

    public class FilteringIterator implements Iterator<Entry> {
        public Entry next;
        public Iterator<Entry> parent;

        private void locateNext() {
            this.next = null;
            while (this.parent.hasNext() && this.next == null) {
                Entry next2 = this.parent.next();
                if (!FilteringDirectoryNode.this.excludes.contains(next2.getName())) {
                    this.next = FilteringDirectoryNode.this.wrapEntry(next2);
                }
            }
        }

        public boolean hasNext() {
            return this.next != null;
        }

        public void remove() {
            throw new UnsupportedOperationException("Remove not supported");
        }

        public FilteringIterator() {
            this.parent = FilteringDirectoryNode.this.directory.getEntries();
            locateNext();
        }

        @Override // java.util.Iterator
        public Entry next() {
            Entry entry = this.next;
            locateNext();
            return entry;
        }
    }

    public FilteringDirectoryNode(DirectoryEntry directoryEntry, Collection<String> collection) {
        this.directory = directoryEntry;
        for (String str : collection) {
            int indexOf = str.indexOf(47);
            if (indexOf == -1) {
                this.excludes.add(str);
            } else {
                String substring = str.substring(0, indexOf);
                String substring2 = str.substring(indexOf + 1);
                if (!this.childExcludes.containsKey(substring)) {
                    this.childExcludes.put(substring, new ArrayList());
                }
                this.childExcludes.get(substring).add(substring2);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Entry wrapEntry(Entry entry) {
        String name = entry.getName();
        return (!this.childExcludes.containsKey(name) || !(entry instanceof DirectoryEntry)) ? entry : new FilteringDirectoryNode((DirectoryEntry) entry, this.childExcludes.get(name));
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public DirectoryEntry createDirectory(String str) {
        return this.directory.createDirectory(str);
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public DocumentEntry createDocument(String str, InputStream inputStream) {
        return this.directory.createDocument(str, inputStream);
    }

    @Override // org.apache.poi.poifs.filesystem.Entry
    public boolean delete() {
        return this.directory.delete();
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public Iterator<Entry> getEntries() {
        return new FilteringIterator();
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public Entry getEntry(String str) {
        if (!this.excludes.contains(str)) {
            return wrapEntry(this.directory.getEntry(str));
        }
        throw new FileNotFoundException(str);
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public int getEntryCount() {
        int entryCount = this.directory.getEntryCount();
        for (String str : this.excludes) {
            if (this.directory.hasEntry(str)) {
                entryCount--;
            }
        }
        return entryCount;
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public Set<String> getEntryNames() {
        HashSet hashSet = new HashSet();
        for (String str : this.directory.getEntryNames()) {
            if (!this.excludes.contains(str)) {
                hashSet.add(str);
            }
        }
        return hashSet;
    }

    @Override // org.apache.poi.poifs.filesystem.Entry
    public String getName() {
        return this.directory.getName();
    }

    @Override // org.apache.poi.poifs.filesystem.Entry
    public DirectoryEntry getParent() {
        return this.directory.getParent();
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public ClassID getStorageClsid() {
        return this.directory.getStorageClsid();
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public boolean hasEntry(String str) {
        if (this.excludes.contains(str)) {
            return false;
        }
        return this.directory.hasEntry(str);
    }

    @Override // org.apache.poi.poifs.filesystem.Entry
    public boolean isDirectoryEntry() {
        return true;
    }

    @Override // org.apache.poi.poifs.filesystem.Entry
    public boolean isDocumentEntry() {
        return false;
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public boolean isEmpty() {
        return getEntryCount() == 0;
    }

    @Override // java.lang.Iterable
    public Iterator<Entry> iterator() {
        return getEntries();
    }

    @Override // org.apache.poi.poifs.filesystem.Entry
    public boolean renameTo(String str) {
        return this.directory.renameTo(str);
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public void setStorageClsid(ClassID classID) {
        this.directory.setStorageClsid(classID);
    }

    @Override // org.apache.poi.poifs.filesystem.DirectoryEntry
    public DocumentEntry createDocument(String str, int i2, POIFSWriterListener pOIFSWriterListener) {
        return this.directory.createDocument(str, i2, pOIFSWriterListener);
    }
}
