package org.apache.poi.poifs.filesystem;

import java.io.IOException;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.util.Iterator;
import org.apache.poi.poifs.filesystem.BlockStore;

public class NPOIFSStream implements Iterable<ByteBuffer> {
    public BlockStore blockStore;
    public OutputStream outStream;
    public int startBlock;

    public class StreamBlockByteBufferIterator implements Iterator<ByteBuffer> {
        public BlockStore.ChainLoopDetector loopDetector;
        public int nextBlock;

        public StreamBlockByteBufferIterator(int i2) {
            this.nextBlock = i2;
            try {
                this.loopDetector = NPOIFSStream.this.blockStore.getChainLoopDetector();
            } catch (IOException e2) {
                throw new RuntimeException(e2);
            }
        }

        public boolean hasNext() {
            return this.nextBlock != -2;
        }

        public void remove() {
            throw new UnsupportedOperationException();
        }

        @Override // java.util.Iterator
        public ByteBuffer next() {
            int i2 = this.nextBlock;
            if (i2 != -2) {
                try {
                    this.loopDetector.claim(i2);
                    ByteBuffer blockAt = NPOIFSStream.this.blockStore.getBlockAt(this.nextBlock);
                    this.nextBlock = NPOIFSStream.this.blockStore.getNextBlock(this.nextBlock);
                    return blockAt;
                } catch (IOException e2) {
                    throw new RuntimeException(e2);
                }
            } else {
                throw new IndexOutOfBoundsException("Can't read past the end of the stream");
            }
        }
    }

    public NPOIFSStream(BlockStore blockStore2, int i2) {
        this.blockStore = blockStore2;
        this.startBlock = i2;
    }

    public void free() {
        free(this.blockStore.getChainLoopDetector());
    }

    public Iterator<ByteBuffer> getBlockIterator() {
        int i2 = this.startBlock;
        if (i2 != -2) {
            return new StreamBlockByteBufferIterator(i2);
        }
        throw new IllegalStateException("Can't read from a new stream before it has been written to");
    }

    public OutputStream getOutputStream() {
        if (this.outStream == null) {
            this.outStream = new StreamBlockByteBuffer();
        }
        return this.outStream;
    }

    public int getStartBlock() {
        return this.startBlock;
    }

    @Override // java.lang.Iterable
    public Iterator<ByteBuffer> iterator() {
        return getBlockIterator();
    }

    public void updateContents(byte[] bArr) {
        OutputStream outputStream = getOutputStream();
        outputStream.write(bArr);
        outputStream.close();
    }

    public class StreamBlockByteBuffer extends OutputStream {
        public ByteBuffer buffer;
        public BlockStore.ChainLoopDetector loopDetector;
        public int nextBlock;
        public byte[] oneByte = new byte[1];
        public int prevBlock;

        public StreamBlockByteBuffer() {
            this.loopDetector = NPOIFSStream.this.blockStore.getChainLoopDetector();
            this.prevBlock = -2;
            this.nextBlock = NPOIFSStream.this.startBlock;
        }

        @Override // java.io.OutputStream, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            new NPOIFSStream(NPOIFSStream.this.blockStore, this.nextBlock).free(this.loopDetector);
            if (this.prevBlock != -2) {
                NPOIFSStream.this.blockStore.setNextBlock(this.prevBlock, -2);
            }
        }

        public void createBlockIfNeeded() {
            ByteBuffer byteBuffer = this.buffer;
            if (byteBuffer == null || !byteBuffer.hasRemaining()) {
                int i2 = this.nextBlock;
                if (i2 == -2) {
                    i2 = NPOIFSStream.this.blockStore.getFreeBlock();
                    this.loopDetector.claim(i2);
                    this.nextBlock = -2;
                    if (this.prevBlock != -2) {
                        NPOIFSStream.this.blockStore.setNextBlock(this.prevBlock, i2);
                    }
                    NPOIFSStream.this.blockStore.setNextBlock(i2, -2);
                    if (NPOIFSStream.this.startBlock == -2) {
                        NPOIFSStream.this.startBlock = i2;
                    }
                } else {
                    this.loopDetector.claim(i2);
                    this.nextBlock = NPOIFSStream.this.blockStore.getNextBlock(i2);
                }
                this.buffer = NPOIFSStream.this.blockStore.createBlockIfNeeded(i2);
                this.prevBlock = i2;
            }
        }

        @Override // java.io.OutputStream
        public void write(int i2) {
            byte[] bArr = this.oneByte;
            bArr[0] = (byte) (i2 & 255);
            write(bArr);
        }

        @Override // java.io.OutputStream
        public void write(byte[] bArr, int i2, int i3) {
            int i4;
            if (i2 < 0 || i2 > bArr.length || i3 < 0 || (i4 = i2 + i3) > bArr.length || i4 < 0) {
                throw new IndexOutOfBoundsException();
            } else if (i3 != 0) {
                do {
                    createBlockIfNeeded();
                    int min = Math.min(this.buffer.remaining(), i3);
                    this.buffer.put(bArr, i2, min);
                    i2 += min;
                    i3 -= min;
                } while (i3 > 0);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void free(BlockStore.ChainLoopDetector chainLoopDetector) {
        int i2 = this.startBlock;
        while (i2 != -2) {
            chainLoopDetector.claim(i2);
            int nextBlock = this.blockStore.getNextBlock(i2);
            this.blockStore.setNextBlock(i2, -1);
            i2 = nextBlock;
        }
        this.startBlock = -2;
    }

    public NPOIFSStream(BlockStore blockStore2) {
        this.blockStore = blockStore2;
        this.startBlock = -2;
    }
}
