package org.apache.poi.poifs.filesystem;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.apache.poi.poifs.common.POIFSBigBlockSize;
import org.apache.poi.poifs.common.POIFSConstants;
import org.apache.poi.poifs.dev.POIFSViewable;
import org.apache.poi.poifs.property.DirectoryProperty;
import org.apache.poi.poifs.property.Property;
import org.apache.poi.poifs.property.PropertyTable;
import org.apache.poi.poifs.storage.BATBlock;
import org.apache.poi.poifs.storage.BlockAllocationTableReader;
import org.apache.poi.poifs.storage.BlockAllocationTableWriter;
import org.apache.poi.poifs.storage.BlockList;
import org.apache.poi.poifs.storage.BlockWritable;
import org.apache.poi.poifs.storage.HeaderBlock;
import org.apache.poi.poifs.storage.HeaderBlockWriter;
import org.apache.poi.poifs.storage.RawDataBlockList;
import org.apache.poi.poifs.storage.SmallBlockTableReader;
import org.apache.poi.poifs.storage.SmallBlockTableWriter;
import org.apache.poi.util.CloseIgnoringInputStream;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.Removal;

public class OPOIFSFileSystem implements POIFSViewable {
    public static final POILogger _logger = POILogFactory.getLogger(OPOIFSFileSystem.class);
    public List<OPOIFSDocument> _documents;
    public PropertyTable _property_table;
    public DirectoryNode _root;
    public POIFSBigBlockSize bigBlockSize;

    public OPOIFSFileSystem() {
        POIFSBigBlockSize pOIFSBigBlockSize = POIFSConstants.SMALLER_BIG_BLOCK_SIZE_DETAILS;
        this.bigBlockSize = pOIFSBigBlockSize;
        this._property_table = new PropertyTable(new HeaderBlock(pOIFSBigBlockSize));
        this._documents = new ArrayList();
        this._root = null;
    }

    public static InputStream createNonClosingInputStream(InputStream inputStream) {
        return new CloseIgnoringInputStream(inputStream);
    }

    @Removal(version = "4.0")
    @Deprecated
    public static boolean hasPOIFSHeader(InputStream inputStream) {
        return NPOIFSFileSystem.hasPOIFSHeader(inputStream);
    }

    public static void main(String[] strArr) {
        if (strArr.length != 2) {
            System.err.println("two arguments required: input filename and output filename");
            System.exit(1);
        }
        FileInputStream fileInputStream = new FileInputStream(strArr[0]);
        FileOutputStream fileOutputStream = new FileOutputStream(strArr[1]);
        new OPOIFSFileSystem(fileInputStream).writeFilesystem(fileOutputStream);
        fileInputStream.close();
        fileOutputStream.close();
    }

    private void processProperties(BlockList blockList, BlockList blockList2, Iterator<Property> it, DirectoryNode directoryNode, int i2) {
        OPOIFSDocument oPOIFSDocument;
        while (it.hasNext()) {
            Property next = it.next();
            String name = next.getName();
            DirectoryNode root = directoryNode == null ? getRoot() : directoryNode;
            if (next.isDirectory()) {
                DirectoryNode directoryNode2 = (DirectoryNode) root.createDirectory(name);
                directoryNode2.setStorageClsid(next.getStorageClsid());
                processProperties(blockList, blockList2, ((DirectoryProperty) next).getChildren(), directoryNode2, i2);
            } else {
                int startBlock = next.getStartBlock();
                int size = next.getSize();
                if (next.shouldUseSmallBlocks()) {
                    oPOIFSDocument = new OPOIFSDocument(name, blockList.fetchBlocks(startBlock, i2), size);
                } else {
                    oPOIFSDocument = new OPOIFSDocument(name, blockList2.fetchBlocks(startBlock, i2), size);
                }
                root.createDocument(oPOIFSDocument);
            }
        }
    }

    public void addDirectory(DirectoryProperty directoryProperty) {
        this._property_table.addProperty(directoryProperty);
    }

    public void addDocument(OPOIFSDocument oPOIFSDocument) {
        this._documents.add(oPOIFSDocument);
        this._property_table.addProperty(oPOIFSDocument.getDocumentProperty());
    }

    public void closeInputStream(InputStream inputStream, boolean z) {
        if (inputStream.markSupported() && !(inputStream instanceof ByteArrayInputStream)) {
            StringBuilder b2 = a.b("POIFS is closing the supplied input stream of type (");
            b2.append(inputStream.getClass().getName());
            b2.append(") which supports mark/reset.  ");
            b2.append("This will be a problem for the caller if the stream will still be used.  ");
            b2.append("If that is the case the caller should wrap the input stream to avoid this close logic.  ");
            b2.append("This warning is only temporary and will not be present in future versions of POI.");
            String sb = b2.toString();
            _logger.log(5, sb);
        }
        try {
            inputStream.close();
        } catch (IOException e2) {
            if (!z) {
                _logger.log(7, "can't close input stream", e2);
                return;
            }
            throw new RuntimeException(e2);
        }
    }

    public DirectoryEntry createDirectory(String str) {
        return getRoot().createDirectory(str);
    }

    public DocumentEntry createDocument(InputStream inputStream, String str) {
        return getRoot().createDocument(str, inputStream);
    }

    public DocumentInputStream createDocumentInputStream(String str) {
        return getRoot().createDocumentInputStream(str);
    }

    public int getBigBlockSize() {
        return this.bigBlockSize.getBigBlockSize();
    }

    public POIFSBigBlockSize getBigBlockSizeDetails() {
        return this.bigBlockSize;
    }

    public DirectoryNode getRoot() {
        if (this._root == null) {
            this._root = new DirectoryNode(this._property_table.getRoot(), this, (DirectoryNode) null);
        }
        return this._root;
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public String getShortDescription() {
        return "POIFS FileSystem";
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public Object[] getViewableArray() {
        return preferArray() ? getRoot().getViewableArray() : new Object[0];
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public Iterator<Object> getViewableIterator() {
        if (!preferArray()) {
            return getRoot().getViewableIterator();
        }
        return Collections.emptyList().iterator();
    }

    @Override // org.apache.poi.poifs.dev.POIFSViewable
    public boolean preferArray() {
        return getRoot().preferArray();
    }

    public void remove(EntryNode entryNode) {
        this._property_table.removeProperty(entryNode.getProperty());
        if (entryNode.isDocumentEntry()) {
            this._documents.remove(((DocumentNode) entryNode).getDocument());
        }
    }

    public void writeFilesystem(OutputStream outputStream) {
        this._property_table.preWrite();
        SmallBlockTableWriter smallBlockTableWriter = new SmallBlockTableWriter(this.bigBlockSize, this._documents, this._property_table.getRoot());
        BlockAllocationTableWriter blockAllocationTableWriter = new BlockAllocationTableWriter(this.bigBlockSize);
        ArrayList arrayList = new ArrayList();
        arrayList.addAll(this._documents);
        arrayList.add(this._property_table);
        arrayList.add(smallBlockTableWriter);
        arrayList.add(smallBlockTableWriter.getSBAT());
        Iterator it = arrayList.iterator();
        while (it.hasNext()) {
            BATManaged bATManaged = (BATManaged) it.next();
            int countBlocks = bATManaged.countBlocks();
            if (countBlocks != 0) {
                bATManaged.setStartBlock(blockAllocationTableWriter.allocateSpace(countBlocks));
            }
        }
        int createBlocks = blockAllocationTableWriter.createBlocks();
        HeaderBlockWriter headerBlockWriter = new HeaderBlockWriter(this.bigBlockSize);
        BATBlock[] bATBlocks = headerBlockWriter.setBATBlocks(blockAllocationTableWriter.countBlocks(), createBlocks);
        headerBlockWriter.setPropertyStart(this._property_table.getStartBlock());
        headerBlockWriter.setSBATStart(smallBlockTableWriter.getSBAT().getStartBlock());
        headerBlockWriter.setSBATBlockCount(smallBlockTableWriter.getSBATBlockCount());
        ArrayList arrayList2 = new ArrayList();
        arrayList2.add(headerBlockWriter);
        arrayList2.addAll(this._documents);
        arrayList2.add(this._property_table);
        arrayList2.add(smallBlockTableWriter);
        arrayList2.add(smallBlockTableWriter.getSBAT());
        arrayList2.add(blockAllocationTableWriter);
        for (BATBlock bATBlock : bATBlocks) {
            arrayList2.add(bATBlock);
        }
        Iterator it2 = arrayList2.iterator();
        while (it2.hasNext()) {
            ((BlockWritable) it2.next()).writeBlocks(outputStream);
        }
    }

    @Removal(version = "4.0")
    @Deprecated
    public static boolean hasPOIFSHeader(byte[] bArr) {
        return NPOIFSFileSystem.hasPOIFSHeader(bArr);
    }

    public DocumentEntry createDocument(String str, int i2, POIFSWriterListener pOIFSWriterListener) {
        return getRoot().createDocument(str, i2, pOIFSWriterListener);
    }

    /* JADX INFO: finally extract failed */
    public OPOIFSFileSystem(InputStream inputStream) {
        this();
        try {
            HeaderBlock headerBlock = new HeaderBlock(inputStream);
            POIFSBigBlockSize bigBlockSize2 = headerBlock.getBigBlockSize();
            this.bigBlockSize = bigBlockSize2;
            RawDataBlockList rawDataBlockList = new RawDataBlockList(inputStream, bigBlockSize2);
            closeInputStream(inputStream, true);
            new BlockAllocationTableReader(headerBlock.getBigBlockSize(), headerBlock.getBATCount(), headerBlock.getBATArray(), headerBlock.getXBATCount(), headerBlock.getXBATIndex(), rawDataBlockList);
            PropertyTable propertyTable = new PropertyTable(headerBlock, rawDataBlockList);
            processProperties(SmallBlockTableReader.getSmallDocumentBlocks(this.bigBlockSize, rawDataBlockList, propertyTable.getRoot(), headerBlock.getSBATStart()), rawDataBlockList, propertyTable.getRoot().getChildren(), null, headerBlock.getPropertyStart());
            getRoot().setStorageClsid(propertyTable.getRoot().getStorageClsid());
        } catch (Throwable th) {
            closeInputStream(inputStream, false);
            throw th;
        }
    }
}
