package org.apache.poi.poifs.macros;

import b.b.a.a.a;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.Charset;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.DocumentNode;
import org.apache.poi.poifs.filesystem.Entry;
import org.apache.poi.poifs.filesystem.FileMagic;
import org.apache.poi.poifs.filesystem.NPOIFSFileSystem;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.util.CodePageUtil;
import org.apache.poi.util.HexDump;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.RLEDecompressingInputStream;
import org.apache.poi.util.StringUtil;

public class VBAMacroReader implements Closeable {
    public static final int EOF = -1;
    public static final int MODULEOFFSET = 49;
    public static final int MODULETYPE_DOCUMENT_CLASS_OR_DESIGNER = 34;
    public static final int MODULETYPE_PROCEDURAL = 33;
    public static final int MODULE_DOC_STRING = 28;
    public static final int MODULE_NAME = 25;
    public static final int MODULE_NAME_UNICODE = 71;
    public static final int PROJECTCODEPAGE = 3;
    public static final int PROJECTLCID = 2;
    public static final int PROJECTVERSION = 9;
    public static final int STREAMNAME = 26;
    public static final int STREAMNAME_RESERVED = 50;
    public static final Charset UTF_16LE = Charset.forName("UTF-16LE");
    public static final String VBA_PROJECT_OOXML = "vbaProject.bin";
    public static final String VBA_PROJECT_POIFS = "VBA";
    public static final int VERSION_DEPENDENT_TERMINATOR = 43;
    public static final int VERSION_INDEPENDENT_TERMINATOR = 16;
    public NPOIFSFileSystem fs;

    public static class Module {
        public byte[] buf;
        public Integer offset;

        public void read(InputStream inputStream) {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            IOUtils.copy(inputStream, byteArrayOutputStream);
            byteArrayOutputStream.close();
            this.buf = byteArrayOutputStream.toByteArray();
        }
    }

    public static class ModuleMap extends HashMap<String, Module> {
        public Charset charset = Charset.forName("Cp1252");
    }

    public VBAMacroReader(InputStream inputStream) {
        InputStream prepareToCheckMagic = FileMagic.prepareToCheckMagic(inputStream);
        if (FileMagic.valueOf(prepareToCheckMagic) == FileMagic.OLE2) {
            this.fs = new NPOIFSFileSystem(prepareToCheckMagic);
        } else {
            openOOXML(prepareToCheckMagic);
        }
    }

    private void openOOXML(InputStream inputStream) {
        ZipEntry nextEntry;
        ZipInputStream zipInputStream = new ZipInputStream(inputStream);
        do {
            nextEntry = zipInputStream.getNextEntry();
            if (nextEntry == null) {
                zipInputStream.close();
                throw new IllegalArgumentException("No VBA project found");
            }
        } while (!StringUtil.endsWithIgnoreCase(nextEntry.getName(), VBA_PROJECT_OOXML));
        try {
            this.fs = new NPOIFSFileSystem(zipInputStream);
        } catch (IOException e2) {
            zipInputStream.close();
            throw e2;
        }
    }

    public static void readModule(RLEDecompressingInputStream rLEDecompressingInputStream, String str, ModuleMap moduleMap) {
        int readInt = rLEDecompressingInputStream.readInt();
        Module module = (Module) moduleMap.get(str);
        if (module == null) {
            Module module2 = new Module();
            module2.offset = Integer.valueOf(readInt);
            moduleMap.put(str, module2);
            return;
        }
        byte[] bArr = module.buf;
        RLEDecompressingInputStream rLEDecompressingInputStream2 = new RLEDecompressingInputStream(new ByteArrayInputStream(bArr, readInt, bArr.length - readInt));
        module.read(rLEDecompressingInputStream2);
        rLEDecompressingInputStream2.close();
    }

    public static String readString(InputStream inputStream, int i2, Charset charset) {
        byte[] bArr = new byte[i2];
        return new String(bArr, 0, inputStream.read(bArr), charset);
    }

    private String readUnicodeString(RLEDecompressingInputStream rLEDecompressingInputStream, int i2) {
        byte[] bArr = new byte[i2];
        IOUtils.readFully(rLEDecompressingInputStream, bArr);
        return new String(bArr, UTF_16LE);
    }

    public static void trySkip(InputStream inputStream, long j) {
        long skip = inputStream.skip(j);
        if (skip == j) {
            return;
        }
        if (skip < 0) {
            throw new IOException("Tried skipping " + j + " bytes, but no bytes were skipped. " + "The end of the stream has been reached or the stream is closed.");
        }
        throw new IOException("Tried skipping " + j + " bytes, but only " + skip + " bytes were skipped. " + "This should never happen.");
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        this.fs.close();
        this.fs = null;
    }

    public void findMacros(DirectoryNode directoryNode, ModuleMap moduleMap) {
        if (VBA_PROJECT_POIFS.equalsIgnoreCase(directoryNode.getName())) {
            readMacros(directoryNode, moduleMap);
            return;
        }
        Iterator<Entry> it = directoryNode.iterator();
        while (it.hasNext()) {
            Entry next = it.next();
            if (next instanceof DirectoryNode) {
                findMacros((DirectoryNode) next, moduleMap);
            }
        }
    }

    public Map<String, String> readMacros() {
        ModuleMap moduleMap = new ModuleMap();
        findMacros(this.fs.getRoot(), moduleMap);
        HashMap hashMap = new HashMap();
        for (Map.Entry entry : moduleMap.entrySet()) {
            Module module = (Module) entry.getValue();
            byte[] bArr = module.buf;
            if (bArr != null && bArr.length > 0) {
                hashMap.put(entry.getKey(), new String(module.buf, moduleMap.charset));
            }
        }
        return hashMap;
    }

    public VBAMacroReader(File file) {
        try {
            this.fs = new NPOIFSFileSystem(file);
        } catch (OfficeXmlFileException unused) {
            openOOXML(new FileInputStream(file));
        }
    }

    public void readMacros(DirectoryNode directoryNode, ModuleMap moduleMap) {
        Iterator<Entry> it = directoryNode.iterator();
        while (it.hasNext()) {
            Entry next = it.next();
            if (next instanceof DocumentNode) {
                String name = next.getName();
                DocumentInputStream documentInputStream = new DocumentInputStream((DocumentNode) next);
                try {
                    if ("dir".equalsIgnoreCase(name)) {
                        RLEDecompressingInputStream rLEDecompressingInputStream = new RLEDecompressingInputStream(documentInputStream);
                        String str = null;
                        int i2 = 0;
                        while (true) {
                            try {
                                i2 = rLEDecompressingInputStream.readShort();
                                if (-1 == i2) {
                                    break;
                                } else if (16 == i2) {
                                    break;
                                } else {
                                    int readInt = rLEDecompressingInputStream.readInt();
                                    if (i2 == 3) {
                                        moduleMap.charset = Charset.forName(CodePageUtil.codepageToEncoding(rLEDecompressingInputStream.readShort(), true));
                                    } else if (i2 == 9) {
                                        trySkip(rLEDecompressingInputStream, 6);
                                    } else if (i2 == 26) {
                                        str = readString(rLEDecompressingInputStream, readInt, moduleMap.charset);
                                        int readShort = rLEDecompressingInputStream.readShort();
                                        if (readShort == 50) {
                                            readUnicodeString(rLEDecompressingInputStream, rLEDecompressingInputStream.readInt());
                                        } else {
                                            throw new IOException("Expected x0032 after stream name before Unicode stream name, but found: " + Integer.toHexString(readShort));
                                        }
                                    } else if (i2 != 49) {
                                        trySkip(rLEDecompressingInputStream, (long) readInt);
                                    } else {
                                        readModule(rLEDecompressingInputStream, str, moduleMap);
                                    }
                                }
                            } catch (IOException e2) {
                                throw new IOException("Error occurred while reading macros at section id " + i2 + " (" + HexDump.shortToHex(i2) + ")", e2);
                            } catch (Throwable th) {
                                rLEDecompressingInputStream.close();
                                throw th;
                            }
                        }
                        rLEDecompressingInputStream.close();
                    } else if (!StringUtil.startsWithIgnoreCase(name, "__SRP") && !StringUtil.startsWithIgnoreCase(name, "_VBA_PROJECT")) {
                        readModule(documentInputStream, name, moduleMap);
                    }
                } finally {
                    documentInputStream.close();
                }
            }
        }
    }

    public static void readModule(DocumentInputStream documentInputStream, String str, ModuleMap moduleMap) {
        Module module = (Module) moduleMap.get(str);
        if (module == null) {
            Module module2 = new Module();
            moduleMap.put(str, module2);
            module2.read(documentInputStream);
        } else if (module.buf == null) {
            Integer num = module.offset;
            if (num != null) {
                long skip = documentInputStream.skip((long) num.intValue());
                if (skip == ((long) module.offset.intValue())) {
                    RLEDecompressingInputStream rLEDecompressingInputStream = new RLEDecompressingInputStream(documentInputStream);
                    module.read(rLEDecompressingInputStream);
                    rLEDecompressingInputStream.close();
                    return;
                }
                StringBuilder b2 = a.b("tried to skip ");
                b2.append(module.offset);
                b2.append(" bytes, but actually skipped ");
                b2.append(skip);
                b2.append(" bytes");
                throw new IOException(b2.toString());
            }
            throw new IOException(a.b("Module offset for '", str, "' was never read."));
        }
    }

    public VBAMacroReader(NPOIFSFileSystem nPOIFSFileSystem) {
        this.fs = nPOIFSFileSystem;
    }
}
