package org.apache.poi.poifs.nio;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.OutputStream;
import java.io.RandomAccessFile;
import java.lang.reflect.Method;
import java.nio.ByteBuffer;
import java.nio.channels.Channels;
import java.nio.channels.FileChannel;
import java.nio.channels.WritableByteChannel;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.SuppressForbidden;

public class FileBackedDataSource extends DataSource {
    public static final POILogger logger = POILogFactory.getLogger(FileBackedDataSource.class);
    public List<ByteBuffer> buffersToClean;
    public FileChannel channel;
    public RandomAccessFile srcFile;
    public boolean writable;

    public FileBackedDataSource(File file) {
        this(newSrcFile(file, "r"), true);
    }

    public static RandomAccessFile newSrcFile(File file, String str) {
        if (file.exists()) {
            return new RandomAccessFile(file, str);
        }
        throw new FileNotFoundException(file.toString());
    }

    public static void unmap(final ByteBuffer byteBuffer) {
        if (!byteBuffer.getClass().getName().endsWith("HeapByteBuffer")) {
            AccessController.doPrivileged(new PrivilegedAction<Void>() {
                /* class org.apache.poi.poifs.nio.FileBackedDataSource.AnonymousClass1 */

                @Override // java.security.PrivilegedAction
                @SuppressForbidden("Java 9 Jigsaw whitelists access to sun.misc.Cleaner, so setAccessible works")
                public Void run() {
                    try {
                        Method method = byteBuffer.getClass().getMethod("cleaner", new Class[0]);
                        method.setAccessible(true);
                        Object invoke = method.invoke(byteBuffer, new Object[0]);
                        if (invoke == null) {
                            return null;
                        }
                        invoke.getClass().getMethod("clean", new Class[0]).invoke(invoke, new Object[0]);
                        return null;
                    } catch (Exception e2) {
                        FileBackedDataSource.logger.log(5, "Unable to unmap memory mapped ByteBuffer.", e2);
                        return null;
                    }
                }
            });
        }
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public void close() {
        for (ByteBuffer byteBuffer : this.buffersToClean) {
            unmap(byteBuffer);
        }
        this.buffersToClean.clear();
        RandomAccessFile randomAccessFile = this.srcFile;
        if (randomAccessFile != null) {
            randomAccessFile.close();
        } else {
            this.channel.close();
        }
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public void copyTo(OutputStream outputStream) {
        WritableByteChannel newChannel = Channels.newChannel(outputStream);
        FileChannel fileChannel = this.channel;
        fileChannel.transferTo(0, fileChannel.size(), newChannel);
    }

    public FileChannel getChannel() {
        return this.channel;
    }

    public boolean isWriteable() {
        return this.writable;
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public ByteBuffer read(int i2, long j) {
        ByteBuffer byteBuffer;
        if (j < size()) {
            if (this.writable) {
                byteBuffer = this.channel.map(FileChannel.MapMode.READ_WRITE, j, (long) i2);
                this.buffersToClean.add(byteBuffer);
            } else {
                this.channel.position(j);
                byteBuffer = ByteBuffer.allocate(i2);
                if (IOUtils.readFully(this.channel, byteBuffer) == -1) {
                    throw new IndexOutOfBoundsException("Position " + j + " past the end of the file");
                }
            }
            byteBuffer.position(0);
            return byteBuffer;
        }
        throw new IndexOutOfBoundsException("Position " + j + " past the end of the file");
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public long size() {
        return this.channel.size();
    }

    @Override // org.apache.poi.poifs.nio.DataSource
    public void write(ByteBuffer byteBuffer, long j) {
        this.channel.write(byteBuffer, j);
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public FileBackedDataSource(File file, boolean z) {
        this(newSrcFile(file, z ? "r" : "rw"), z);
    }

    public FileBackedDataSource(RandomAccessFile randomAccessFile, boolean z) {
        this(randomAccessFile.getChannel(), z);
        this.srcFile = randomAccessFile;
    }

    public FileBackedDataSource(FileChannel fileChannel, boolean z) {
        this.buffersToClean = new ArrayList();
        this.channel = fileChannel;
        this.writable = !z;
    }
}
