package org.apache.poi.sl.draw;

import java.awt.AlphaComposite;
import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.LinearGradientPaint;
import java.awt.MultipleGradientPaint;
import java.awt.Paint;
import java.awt.PaintContext;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import java.awt.Shape;
import java.awt.geom.AffineTransform;
import java.awt.geom.Area;
import java.awt.geom.IllegalPathStateException;
import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;
import java.awt.image.BufferedImage;
import java.awt.image.ColorModel;
import java.awt.image.Raster;
import java.awt.image.WritableRaster;
import java.util.Hashtable;
import org.apache.poi.ss.formula.functions.NumericFunction;

public class PathGradientPaint implements Paint {
    public final int capStyle;
    public final Color[] colors;
    public final float[] fractions;
    public final int joinStyle;
    public final int transparency;

    public class PathGradientContext implements PaintContext {
        public final Rectangle deviceBounds;
        public final int gradientSteps;
        public final RenderingHints hints;
        public final PaintContext pCtx;
        public WritableRaster raster;
        public final Shape shape;
        public final Rectangle2D userBounds;
        public final AffineTransform xform;

        public PathGradientContext(ColorModel colorModel, Rectangle rectangle, Rectangle2D rectangle2D, AffineTransform affineTransform, RenderingHints renderingHints) {
            Shape shape2 = (Shape) renderingHints.get(Drawable.GRADIENT_SHAPE);
            this.shape = shape2;
            if (shape2 != null) {
                this.deviceBounds = rectangle;
                this.userBounds = rectangle2D;
                this.xform = affineTransform;
                this.hints = renderingHints;
                this.gradientSteps = getGradientSteps(shape2);
                LinearGradientPaint linearGradientPaint = new LinearGradientPaint(new Point2D.Double((double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e), new Point2D.Double((double) this.gradientSteps, (double) NumericFunction.LOG_10_TO_BASE_e), PathGradientPaint.this.fractions, PathGradientPaint.this.colors, MultipleGradientPaint.CycleMethod.NO_CYCLE, MultipleGradientPaint.ColorSpaceType.SRGB, new AffineTransform());
                Rectangle rectangle2 = new Rectangle(0, 0, this.gradientSteps, 1);
                this.pCtx = linearGradientPaint.createContext(colorModel, rectangle2, rectangle2, new AffineTransform(), renderingHints);
                return;
            }
            throw new IllegalPathStateException("PathGradientPaint needs a shape to be set via the rendering hint Drawable.GRADIANT_SHAPE.");
        }

        public void createRaster() {
            ColorModel colorModel = getColorModel();
            this.raster = colorModel.createCompatibleWritableRaster((int) this.deviceBounds.getWidth(), (int) this.deviceBounds.getHeight());
            Graphics2D createGraphics = new BufferedImage(colorModel, this.raster, false, (Hashtable) null).createGraphics();
            createGraphics.setRenderingHints(this.hints);
            createGraphics.translate(-this.deviceBounds.getX(), -this.deviceBounds.getY());
            createGraphics.transform(this.xform);
            Raster raster2 = this.pCtx.getRaster(0, 0, this.gradientSteps, 1);
            int numComponents = colorModel.getNumComponents();
            int[] iArr = new int[numComponents];
            for (int i2 = this.gradientSteps - 1; i2 >= 0; i2--) {
                raster2.getPixel(i2, 0, iArr);
                Color color = new Color(iArr[0], iArr[1], iArr[2]);
                if (numComponents == 4) {
                    createGraphics.setComposite(AlphaComposite.getInstance(2, ((float) iArr[3]) / 255.0f));
                }
                PathGradientPaint pathGradientPaint = PathGradientPaint.this;
                createGraphics.setStroke(new BasicStroke((float) (i2 + 1), pathGradientPaint.capStyle, pathGradientPaint.joinStyle));
                createGraphics.setColor(color);
                createGraphics.draw(this.shape);
            }
            createGraphics.dispose();
        }

        public void dispose() {
        }

        public ColorModel getColorModel() {
            return this.pCtx.getColorModel();
        }

        public int getGradientSteps(Shape shape2) {
            Rectangle bounds = shape2.getBounds();
            int max = (int) (Math.max(bounds.getWidth(), bounds.getHeight()) / 2.0d);
            int i2 = 1;
            while (i2 < max - 1) {
                int i3 = ((max - i2) / 2) + i2;
                PathGradientPaint pathGradientPaint = PathGradientPaint.this;
                if (new Area(new BasicStroke((float) i3, pathGradientPaint.capStyle, pathGradientPaint.joinStyle).createStrokedShape(shape2)).isSingular()) {
                    max = i3;
                } else {
                    i2 = i3;
                }
            }
            return max;
        }

        public Raster getRaster(int i2, int i3, int i4, int i5) {
            ColorModel colorModel = getColorModel();
            if (this.raster == null) {
                createRaster();
            }
            WritableRaster createCompatibleWritableRaster = colorModel.createCompatibleWritableRaster(i4, i5);
            Rectangle2D.Double r10 = new Rectangle2D.Double((double) i2, (double) i3, (double) i4, (double) i5);
            if (!r10.intersects(this.deviceBounds)) {
                return createCompatibleWritableRaster;
            }
            Rectangle2D.Double r12 = new Rectangle2D.Double();
            Rectangle2D.intersect(r10, this.deviceBounds, r12);
            int x = (int) (r12.getX() - this.deviceBounds.getX());
            int y = (int) (r12.getY() - this.deviceBounds.getY());
            int width = (int) r12.getWidth();
            int height = (int) r12.getHeight();
            createCompatibleWritableRaster.setDataElements((int) (r12.getX() - r10.getX()), (int) (r12.getY() - r10.getY()), width, height, this.raster.getDataElements(x, y, width, height, (Object) null));
            return createCompatibleWritableRaster;
        }
    }

    public PathGradientPaint(Color[] colorArr, float[] fArr) {
        this(colorArr, fArr, 1, 1);
    }

    public PaintContext createContext(ColorModel colorModel, Rectangle rectangle, Rectangle2D rectangle2D, AffineTransform affineTransform, RenderingHints renderingHints) {
        return new PathGradientContext(colorModel, rectangle, rectangle2D, affineTransform, renderingHints);
    }

    public int getTransparency() {
        return this.transparency;
    }

    public PathGradientPaint(Color[] colorArr, float[] fArr, int i2, int i3) {
        this.colors = (Color[]) colorArr.clone();
        this.fractions = (float[]) fArr.clone();
        this.capStyle = i2;
        this.joinStyle = i3;
        int i4 = 1;
        boolean z = true;
        for (Color color : colorArr) {
            if (color != null) {
                z = z && color.getAlpha() == 255;
            }
        }
        this.transparency = !z ? 3 : i4;
    }
}
