package org.apache.poi.sl.draw;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Composite;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.GraphicsConfiguration;
import java.awt.GraphicsEnvironment;
import java.awt.Image;
import java.awt.Paint;
import java.awt.Polygon;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import java.awt.Shape;
import java.awt.Stroke;
import java.awt.Toolkit;
import java.awt.font.FontRenderContext;
import java.awt.font.GlyphVector;
import java.awt.font.TextLayout;
import java.awt.geom.AffineTransform;
import java.awt.geom.Arc2D;
import java.awt.geom.Ellipse2D;
import java.awt.geom.GeneralPath;
import java.awt.geom.Line2D;
import java.awt.geom.Path2D;
import java.awt.geom.RoundRectangle2D;
import java.awt.image.BufferedImage;
import java.awt.image.BufferedImageOp;
import java.awt.image.ImageObserver;
import java.awt.image.RenderedImage;
import java.awt.image.renderable.RenderableImage;
import java.text.AttributedCharacterIterator;
import java.util.Map;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.sl.usermodel.FreeformShape;
import org.apache.poi.sl.usermodel.GroupShape;
import org.apache.poi.sl.usermodel.Insets2D;
import org.apache.poi.sl.usermodel.SimpleShape;
import org.apache.poi.sl.usermodel.StrokeStyle;
import org.apache.poi.sl.usermodel.TextBox;
import org.apache.poi.sl.usermodel.TextParagraph;
import org.apache.poi.sl.usermodel.TextRun;
import org.apache.poi.sl.usermodel.VerticalAlignment;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.NotImplemented;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.SuppressForbidden;

public final class SLGraphics extends Graphics2D implements Cloneable {
    public Color _background;
    public Font _font;
    public Color _foreground;
    public GroupShape<?, ?> _group;
    public RenderingHints _hints;
    public Paint _paint;
    public Stroke _stroke;
    public AffineTransform _transform;
    public POILogger log = POILogFactory.getLogger(SLGraphics.class);

    public SLGraphics(GroupShape<?, ?> groupShape) {
        this._group = groupShape;
        this._transform = new AffineTransform();
        this._stroke = new BasicStroke();
        this._paint = Color.black;
        this._font = new Font(HSSFFont.FONT_ARIAL, 0, 12);
        this._background = Color.black;
        this._foreground = Color.white;
        this._hints = new RenderingHints((Map) null);
    }

    public void addRenderingHints(Map<?, ?> map) {
        this._hints.putAll(map);
    }

    public void applyPaint(SimpleShape<?, ?> simpleShape) {
        Color color = this._paint;
        if (color instanceof Color) {
            simpleShape.setFillColor(color);
        }
    }

    public void applyStroke(SimpleShape<?, ?> simpleShape) {
        BasicStroke basicStroke = this._stroke;
        if (basicStroke instanceof BasicStroke) {
            BasicStroke basicStroke2 = basicStroke;
            simpleShape.setStrokeStyle(Double.valueOf((double) basicStroke2.getLineWidth()));
            if (basicStroke2.getDashArray() != null) {
                simpleShape.setStrokeStyle(StrokeStyle.LineDash.DASH);
            }
        }
    }

    public void clearRect(int i2, int i3, int i4, int i5) {
        Paint paint = getPaint();
        setColor(getBackground());
        fillRect(i2, i3, i4, i5);
        setPaint(paint);
    }

    @NotImplemented
    public void clip(Shape shape) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
    }

    public void clipRect(int i2, int i3, int i4, int i5) {
        clip(new Rectangle(i2, i3, i4, i5));
    }

    public void copyArea(int i2, int i3, int i4, int i5, int i6, int i7) {
    }

    public Graphics create() {
        try {
            return (Graphics) clone();
        } catch (CloneNotSupportedException e2) {
            throw new RuntimeException(e2);
        }
    }

    public void dispose() {
    }

    public void draw(Shape shape) {
        Path2D.Double r0 = new Path2D.Double(this._transform.createTransformedShape(shape));
        FreeformShape<?, ?> createFreeform = this._group.createFreeform();
        createFreeform.setPath(r0);
        createFreeform.setFillColor(null);
        applyStroke(createFreeform);
        Color color = this._paint;
        if (color instanceof Color) {
            createFreeform.setStrokeStyle(color);
        }
    }

    public void drawArc(int i2, int i3, int i4, int i5, int i6, int i7) {
        draw(new Arc2D.Double((double) i2, (double) i3, (double) i4, (double) i5, (double) i6, (double) i7, 0));
    }

    public void drawGlyphVector(GlyphVector glyphVector, float f2, float f3) {
        fill(glyphVector.getOutline(f2, f3));
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, Color color, ImageObserver imageObserver) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
        return false;
    }

    public void drawLine(int i2, int i3, int i4, int i5) {
        draw(new Line2D.Double((double) i2, (double) i3, (double) i4, (double) i5));
    }

    public void drawOval(int i2, int i3, int i4, int i5) {
        draw(new Ellipse2D.Double((double) i2, (double) i3, (double) i4, (double) i5));
    }

    public void drawPolygon(int[] iArr, int[] iArr2, int i2) {
        draw(new Polygon(iArr, iArr2, i2));
    }

    public void drawPolyline(int[] iArr, int[] iArr2, int i2) {
        if (i2 > 0) {
            GeneralPath generalPath = new GeneralPath();
            generalPath.moveTo((float) iArr[0], (float) iArr2[0]);
            for (int i3 = 1; i3 < i2; i3++) {
                generalPath.lineTo((float) iArr[i3], (float) iArr2[i3]);
            }
            draw(generalPath);
        }
    }

    public void drawRect(int i2, int i3, int i4, int i5) {
        draw(new Rectangle(i2, i3, i4, i5));
    }

    @NotImplemented
    public void drawRenderableImage(RenderableImage renderableImage, AffineTransform affineTransform) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
    }

    @NotImplemented
    public void drawRenderedImage(RenderedImage renderedImage, AffineTransform affineTransform) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
    }

    public void drawRoundRect(int i2, int i3, int i4, int i5, int i6, int i7) {
        draw(new RoundRectangle2D.Double((double) i2, (double) i3, (double) i4, (double) i5, (double) i6, (double) i7));
    }

    public void drawString(String str, float f2, float f3) {
        TextBox<?, ?> createTextBox = this._group.createTextBox();
        TextRun textRun = (TextRun) ((TextParagraph) createTextBox.getTextParagraphs().get(0)).getTextRuns().get(0);
        textRun.setFontSize(Double.valueOf((double) this._font.getSize()));
        textRun.setFontFamily(this._font.getFamily());
        if (getColor() != null) {
            textRun.setFontColor(DrawPaint.createSolidPaint(getColor()));
        }
        if (this._font.isBold()) {
            textRun.setBold(true);
        }
        if (this._font.isItalic()) {
            textRun.setItalic(true);
        }
        createTextBox.setText(str);
        createTextBox.setInsets(new Insets2D(NumericFunction.LOG_10_TO_BASE_e, NumericFunction.LOG_10_TO_BASE_e, NumericFunction.LOG_10_TO_BASE_e, NumericFunction.LOG_10_TO_BASE_e));
        createTextBox.setWordWrap(false);
        createTextBox.setHorizontalCentered(false);
        createTextBox.setVerticalAlignment(VerticalAlignment.MIDDLE);
        TextLayout textLayout = new TextLayout(str, this._font, getFontRenderContext());
        float ascent = textLayout.getAscent();
        float f4 = ascent * 2.0f;
        createTextBox.setAnchor(new Rectangle((int) f2, (int) (f3 - ((ascent / 2.0f) + (f4 / 2.0f))), (int) ((float) Math.floor((double) textLayout.getAdvance())), (int) f4));
    }

    public void fill(Shape shape) {
        Path2D.Double r0 = new Path2D.Double(this._transform.createTransformedShape(shape));
        FreeformShape<?, ?> createFreeform = this._group.createFreeform();
        createFreeform.setPath(r0);
        applyPaint(createFreeform);
        createFreeform.setStrokeStyle(new Object[0]);
    }

    public void fillArc(int i2, int i3, int i4, int i5, int i6, int i7) {
        fill(new Arc2D.Double((double) i2, (double) i3, (double) i4, (double) i5, (double) i6, (double) i7, 2));
    }

    public void fillOval(int i2, int i3, int i4, int i5) {
        fill(new Ellipse2D.Double((double) i2, (double) i3, (double) i4, (double) i5));
    }

    public void fillPolygon(int[] iArr, int[] iArr2, int i2) {
        fill(new Polygon(iArr, iArr2, i2));
    }

    public void fillRect(int i2, int i3, int i4, int i5) {
        fill(new Rectangle(i2, i3, i4, i5));
    }

    public void fillRoundRect(int i2, int i3, int i4, int i5, int i6, int i7) {
        fill(new RoundRectangle2D.Double((double) i2, (double) i3, (double) i4, (double) i5, (double) i6, (double) i7));
    }

    public Color getBackground() {
        return this._background;
    }

    @NotImplemented
    public Shape getClip() {
        if (!this.log.check(5)) {
            return null;
        }
        this.log.log(5, "Not implemented");
        return null;
    }

    public Rectangle getClipBounds() {
        Shape clip = getClip();
        if (clip == null) {
            return null;
        }
        return clip.getBounds();
    }

    public Color getColor() {
        return this._foreground;
    }

    @NotImplemented
    public Composite getComposite() {
        if (!this.log.check(5)) {
            return null;
        }
        this.log.log(5, "Not implemented");
        return null;
    }

    public GraphicsConfiguration getDeviceConfiguration() {
        return GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice().getDefaultConfiguration();
    }

    public Font getFont() {
        return this._font;
    }

    @SuppressForbidden
    public FontMetrics getFontMetrics(Font font) {
        return Toolkit.getDefaultToolkit().getFontMetrics(font);
    }

    public FontRenderContext getFontRenderContext() {
        return new FontRenderContext(new AffineTransform(), RenderingHints.VALUE_TEXT_ANTIALIAS_ON.equals(getRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING)), RenderingHints.VALUE_FRACTIONALMETRICS_ON.equals(getRenderingHint(RenderingHints.KEY_FRACTIONALMETRICS)));
    }

    public Paint getPaint() {
        return this._paint;
    }

    public Object getRenderingHint(RenderingHints.Key key) {
        return this._hints.get(key);
    }

    public RenderingHints getRenderingHints() {
        return this._hints;
    }

    public GroupShape<?, ?> getShapeGroup() {
        return this._group;
    }

    public Stroke getStroke() {
        return this._stroke;
    }

    public AffineTransform getTransform() {
        return new AffineTransform(this._transform);
    }

    public boolean hit(Rectangle rectangle, Shape shape, boolean z) {
        if (z) {
            shape = getStroke().createStrokedShape(shape);
        }
        return getTransform().createTransformedShape(shape).intersects(rectangle);
    }

    public void rotate(double d2) {
        this._transform.rotate(d2);
    }

    public void scale(double d2, double d3) {
        this._transform.scale(d2, d3);
    }

    public void setBackground(Color color) {
        if (color != null) {
            this._background = color;
        }
    }

    @NotImplemented
    public void setClip(Shape shape) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
    }

    public void setColor(Color color) {
        setPaint(color);
    }

    @NotImplemented
    public void setComposite(Composite composite) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
    }

    public void setFont(Font font) {
        this._font = font;
    }

    public void setPaint(Paint paint) {
        if (paint != null) {
            this._paint = paint;
            if (paint instanceof Color) {
                this._foreground = (Color) paint;
            }
        }
    }

    @NotImplemented
    public void setPaintMode() {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
    }

    public void setRenderingHint(RenderingHints.Key key, Object obj) {
        this._hints.put(key, obj);
    }

    public void setRenderingHints(Map<?, ?> map) {
        RenderingHints renderingHints = new RenderingHints((Map) null);
        this._hints = renderingHints;
        renderingHints.putAll(map);
    }

    public void setStroke(Stroke stroke) {
        this._stroke = stroke;
    }

    public void setTransform(AffineTransform affineTransform) {
        this._transform = new AffineTransform(affineTransform);
    }

    @NotImplemented
    public void setXORMode(Color color) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
    }

    public void shear(double d2, double d3) {
        this._transform.shear(d2, d3);
    }

    public void transform(AffineTransform affineTransform) {
        this._transform.concatenate(affineTransform);
    }

    public void translate(int i2, int i3) {
        this._transform.translate((double) i2, (double) i3);
    }

    public void rotate(double d2, double d3, double d4) {
        this._transform.rotate(d2, d3, d4);
    }

    public void translate(double d2, double d3) {
        this._transform.translate(d2, d3);
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, Color color, ImageObserver imageObserver) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
        return false;
    }

    public void setClip(int i2, int i3, int i4, int i5) {
        setClip(new Rectangle(i2, i3, i4, i5));
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9, ImageObserver imageObserver) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
        return false;
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9, Color color, ImageObserver imageObserver) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
        return false;
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, ImageObserver imageObserver) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
        return false;
    }

    public void drawImage(BufferedImage bufferedImage, BufferedImageOp bufferedImageOp, int i2, int i3) {
        drawImage((Image) bufferedImageOp.filter(bufferedImage, (BufferedImage) null), i2, i3, (ImageObserver) null);
    }

    @NotImplemented
    public boolean drawImage(Image image, AffineTransform affineTransform, ImageObserver imageObserver) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
        return false;
    }

    @NotImplemented
    public boolean drawImage(Image image, int i2, int i3, int i4, int i5, ImageObserver imageObserver) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
        return false;
    }

    public void drawString(String str, int i2, int i3) {
        drawString(str, (float) i2, (float) i3);
    }

    public void drawString(AttributedCharacterIterator attributedCharacterIterator, int i2, int i3) {
        drawString(attributedCharacterIterator, (float) i2, (float) i3);
    }

    @NotImplemented
    public void drawString(AttributedCharacterIterator attributedCharacterIterator, float f2, float f3) {
        if (this.log.check(5)) {
            this.log.log(5, "Not implemented");
        }
    }
}
