package org.apache.poi.ss.formula;

import b.b.a.a.a;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.IdentityHashMap;
import java.util.Map;
import org.apache.poi.ss.usermodel.FormulaEvaluator;
import org.apache.poi.util.Internal;

@Internal
public final class CollaboratingWorkbooksEnvironment {
    public static final CollaboratingWorkbooksEnvironment EMPTY = new CollaboratingWorkbooksEnvironment();
    public final WorkbookEvaluator[] _evaluators;
    public final Map<String, WorkbookEvaluator> _evaluatorsByName;
    public boolean _unhooked;

    public static final class WorkbookNotFoundException extends Exception {
        public static final long serialVersionUID = 8787784539811167941L;

        public WorkbookNotFoundException(String str) {
            super(str);
        }
    }

    public CollaboratingWorkbooksEnvironment() {
        this._evaluatorsByName = Collections.emptyMap();
        this._evaluators = new WorkbookEvaluator[0];
    }

    public static void hookNewEnvironment(WorkbookEvaluator[] workbookEvaluatorArr, CollaboratingWorkbooksEnvironment collaboratingWorkbooksEnvironment) {
        int length = workbookEvaluatorArr.length;
        IEvaluationListener evaluationListener = workbookEvaluatorArr[0].getEvaluationListener();
        for (WorkbookEvaluator workbookEvaluator : workbookEvaluatorArr) {
            if (evaluationListener != workbookEvaluator.getEvaluationListener()) {
                throw new RuntimeException("Workbook evaluators must all have the same evaluation listener");
            }
        }
        EvaluationCache evaluationCache = new EvaluationCache(evaluationListener);
        for (int i2 = 0; i2 < length; i2++) {
            workbookEvaluatorArr[i2].attachToEnvironment(collaboratingWorkbooksEnvironment, evaluationCache, i2);
        }
    }

    public static void setup(String[] strArr, WorkbookEvaluator[] workbookEvaluatorArr) {
        int length = strArr.length;
        if (workbookEvaluatorArr.length != length) {
            StringBuilder a = a.a("Number of workbook names is ", length, " but number of evaluators is ");
            a.append(workbookEvaluatorArr.length);
            throw new IllegalArgumentException(a.toString());
        } else if (length >= 1) {
            new CollaboratingWorkbooksEnvironment(strArr, workbookEvaluatorArr, length);
        } else {
            throw new IllegalArgumentException("Must provide at least one collaborating worbook");
        }
    }

    public static void setupFormulaEvaluator(Map<String, FormulaEvaluator> map) {
        HashMap hashMap = new HashMap(map.size());
        for (Map.Entry<String, FormulaEvaluator> entry : map.entrySet()) {
            String key = entry.getKey();
            FormulaEvaluator value = entry.getValue();
            if (value instanceof WorkbookEvaluatorProvider) {
                hashMap.put(key, ((WorkbookEvaluatorProvider) value)._getWorkbookEvaluator());
            } else {
                throw new IllegalArgumentException("Formula Evaluator " + value + " provides no WorkbookEvaluator access");
            }
        }
        setup(hashMap);
    }

    public static Map<String, WorkbookEvaluator> toUniqueMap(String[] strArr, WorkbookEvaluator[] workbookEvaluatorArr, int i2) {
        HashMap hashMap = new HashMap((i2 * 3) / 2);
        for (int i3 = 0; i3 < i2; i3++) {
            String str = strArr[i3];
            WorkbookEvaluator workbookEvaluator = workbookEvaluatorArr[i3];
            if (!hashMap.containsKey(str)) {
                hashMap.put(str, workbookEvaluator);
            } else {
                throw new IllegalArgumentException(a.b("Duplicate workbook name '", str, "'"));
            }
        }
        return hashMap;
    }

    private void unhook() {
        if (this._evaluators.length >= 1) {
            int i2 = 0;
            while (true) {
                WorkbookEvaluator[] workbookEvaluatorArr = this._evaluators;
                if (i2 < workbookEvaluatorArr.length) {
                    workbookEvaluatorArr[i2].detachFromEnvironment();
                    i2++;
                } else {
                    this._unhooked = true;
                    return;
                }
            }
        }
    }

    private void unhookOldEnvironments(WorkbookEvaluator[] workbookEvaluatorArr) {
        HashSet hashSet = new HashSet();
        for (WorkbookEvaluator workbookEvaluator : workbookEvaluatorArr) {
            hashSet.add(workbookEvaluator.getEnvironment());
        }
        int size = hashSet.size();
        CollaboratingWorkbooksEnvironment[] collaboratingWorkbooksEnvironmentArr = new CollaboratingWorkbooksEnvironment[size];
        hashSet.toArray(collaboratingWorkbooksEnvironmentArr);
        for (int i2 = 0; i2 < size; i2++) {
            collaboratingWorkbooksEnvironmentArr[i2].unhook();
        }
    }

    public WorkbookEvaluator getWorkbookEvaluator(String str) {
        if (!this._unhooked) {
            WorkbookEvaluator workbookEvaluator = this._evaluatorsByName.get(str);
            if (workbookEvaluator != null) {
                return workbookEvaluator;
            }
            StringBuffer stringBuffer = new StringBuffer(256);
            stringBuffer.append("Could not resolve external workbook name '");
            stringBuffer.append(str);
            stringBuffer.append("'.");
            if (this._evaluators.length >= 1) {
                stringBuffer.append(" The following workbook names are valid: (");
                int i2 = 0;
                for (String str2 : this._evaluatorsByName.keySet()) {
                    int i3 = i2 + 1;
                    if (i2 > 0) {
                        stringBuffer.append(", ");
                    }
                    stringBuffer.append("'");
                    stringBuffer.append(str2);
                    stringBuffer.append("'");
                    i2 = i3;
                }
                stringBuffer.append(")");
            } else {
                stringBuffer.append(" Workbook environment has not been set up.");
            }
            throw new WorkbookNotFoundException(stringBuffer.toString());
        }
        throw new IllegalStateException("This environment has been unhooked");
    }

    public CollaboratingWorkbooksEnvironment(String[] strArr, WorkbookEvaluator[] workbookEvaluatorArr, int i2) {
        this(toUniqueMap(strArr, workbookEvaluatorArr, i2), workbookEvaluatorArr);
    }

    public CollaboratingWorkbooksEnvironment(Map<String, WorkbookEvaluator> map, WorkbookEvaluator[] workbookEvaluatorArr) {
        IdentityHashMap identityHashMap = new IdentityHashMap(workbookEvaluatorArr.length);
        for (Map.Entry<String, WorkbookEvaluator> entry : map.entrySet()) {
            String str = (String) identityHashMap.put(entry.getValue(), entry.getKey());
            if (str != null) {
                throw new IllegalArgumentException(a.a(a.d("Attempted to register same workbook under names '", str, "' and '"), entry.getKey(), "'"));
            }
        }
        unhookOldEnvironments(workbookEvaluatorArr);
        hookNewEnvironment(workbookEvaluatorArr, this);
        this._unhooked = false;
        this._evaluators = (WorkbookEvaluator[]) workbookEvaluatorArr.clone();
        this._evaluatorsByName = map;
    }

    public static void setup(Map<String, WorkbookEvaluator> map) {
        if (map.size() >= 1) {
            new CollaboratingWorkbooksEnvironment(map, (WorkbookEvaluator[]) map.values().toArray(new WorkbookEvaluator[map.size()]));
            return;
        }
        throw new IllegalArgumentException("Must provide at least one collaborating worbook");
    }
}
