package org.apache.poi.ss.formula;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.ss.formula.eval.BlankEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.DataValidation;
import org.apache.poi.ss.usermodel.DataValidationConstraint;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellRangeAddressBase;
import org.apache.poi.ss.util.CellRangeAddressList;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.ss.util.SheetUtil;

public class DataValidationEvaluator {
    public final Map<String, List<? extends DataValidation>> validations = new HashMap();
    public final Workbook workbook;
    public final WorkbookEvaluator workbookEvaluator;

    public static class DataValidationContext {
        public final DataValidation dv;
        public final DataValidationEvaluator dve;
        public final CellRangeAddressBase region;
        public final CellReference target;

        public DataValidationContext(DataValidation dataValidation, DataValidationEvaluator dataValidationEvaluator, CellRangeAddressBase cellRangeAddressBase, CellReference cellReference) {
            this.dv = dataValidation;
            this.dve = dataValidationEvaluator;
            this.region = cellRangeAddressBase;
            this.target = cellReference;
        }

        public DataValidationEvaluator getEvaluator() {
            return this.dve;
        }

        public String getFormula1() {
            return this.dv.getValidationConstraint().getFormula1();
        }

        public String getFormula2() {
            return this.dv.getValidationConstraint().getFormula2();
        }

        public int getOffsetColumns() {
            return this.target.getCol() - this.region.getFirstColumn();
        }

        public int getOffsetRows() {
            return this.target.getRow() - this.region.getFirstRow();
        }

        public int getOperator() {
            return this.dv.getValidationConstraint().getOperator();
        }

        public CellRangeAddressBase getRegion() {
            return this.region;
        }

        public int getSheetIndex() {
            return this.dve.getWorkbookEvaluator().getSheetIndex(this.target.getSheetName());
        }

        public CellReference getTarget() {
            return this.target;
        }

        public DataValidation getValidation() {
            return this.dv;
        }
    }

    public enum OperatorEnum {
        BETWEEN {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.OperatorEnum
            public boolean isValid(Double d2, Double d3, Double d4) {
                return d2.compareTo(d3) >= 0 && d2.compareTo(d4) <= 0;
            }
        },
        NOT_BETWEEN {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.OperatorEnum
            public boolean isValid(Double d2, Double d3, Double d4) {
                return d2.compareTo(d3) < 0 || d2.compareTo(d4) > 0;
            }
        },
        EQUAL {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.OperatorEnum
            public boolean isValid(Double d2, Double d3, Double d4) {
                return d2.compareTo(d3) == 0;
            }
        },
        NOT_EQUAL {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.OperatorEnum
            public boolean isValid(Double d2, Double d3, Double d4) {
                return d2.compareTo(d3) != 0;
            }
        },
        GREATER_THAN {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.OperatorEnum
            public boolean isValid(Double d2, Double d3, Double d4) {
                return d2.compareTo(d3) > 0;
            }
        },
        LESS_THAN {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.OperatorEnum
            public boolean isValid(Double d2, Double d3, Double d4) {
                return d2.compareTo(d3) < 0;
            }
        },
        GREATER_OR_EQUAL {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.OperatorEnum
            public boolean isValid(Double d2, Double d3, Double d4) {
                return d2.compareTo(d3) >= 0;
            }
        },
        LESS_OR_EQUAL {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.OperatorEnum
            public boolean isValid(Double d2, Double d3, Double d4) {
                return d2.compareTo(d3) <= 0;
            }
        };
        
        public static final OperatorEnum IGNORED = BETWEEN;

        public abstract boolean isValid(Double d2, Double d3, Double d4);
    }

    public enum ValidationEnum {
        ANY {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.ValidationEnum
            public boolean isValidValue(Cell cell, DataValidationContext dataValidationContext) {
                return true;
            }
        },
        INTEGER {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.ValidationEnum
            public boolean isValidValue(Cell cell, DataValidationContext dataValidationContext) {
                if (!super.isValidValue(cell, dataValidationContext)) {
                    return false;
                }
                double numericCellValue = cell.getNumericCellValue();
                if (Double.valueOf(numericCellValue).compareTo(Double.valueOf((double) ((int) numericCellValue))) == 0) {
                    return true;
                }
                return false;
            }
        },
        DECIMAL,
        LIST {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.ValidationEnum
            public boolean isValidValue(Cell cell, DataValidationContext dataValidationContext) {
                List<ValueEval> validationValuesForConstraint = DataValidationEvaluator.getValidationValuesForConstraint(dataValidationContext);
                if (validationValuesForConstraint == null) {
                    return true;
                }
                Iterator<ValueEval> it = validationValuesForConstraint.iterator();
                while (it.hasNext()) {
                    ValueEval next = it.next();
                    if (next instanceof RefEval) {
                        next = ((RefEval) next).getInnerValueEval(dataValidationContext.getSheetIndex());
                    }
                    if (next instanceof BlankEval) {
                        return true;
                    }
                    if (!(next instanceof ErrorEval)) {
                        if (next instanceof BoolEval) {
                            if (DataValidationEvaluator.isType(cell, CellType.BOOLEAN) && ((BoolEval) next).getBooleanValue() == cell.getBooleanCellValue()) {
                                return true;
                            }
                        } else if (next instanceof NumberEval) {
                            if (DataValidationEvaluator.isType(cell, CellType.NUMERIC) && ((NumberEval) next).getNumberValue() == cell.getNumericCellValue()) {
                                return true;
                            }
                        } else if ((next instanceof StringEval) && DataValidationEvaluator.isType(cell, CellType.STRING) && ((StringEval) next).getStringValue().equalsIgnoreCase(cell.getStringCellValue())) {
                            return true;
                        }
                    }
                }
                return false;
            }
        },
        DATE,
        TIME,
        TEXT_LENGTH {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.ValidationEnum
            public boolean isValidValue(Cell cell, DataValidationContext dataValidationContext) {
                if (!DataValidationEvaluator.isType(cell, CellType.STRING)) {
                    return false;
                }
                return isValidNumericValue(Double.valueOf((double) cell.getStringCellValue().length()), dataValidationContext);
            }
        },
        FORMULA {
            @Override // org.apache.poi.ss.formula.DataValidationEvaluator.ValidationEnum
            public boolean isValidValue(Cell cell, DataValidationContext dataValidationContext) {
                ValueEval evaluate = dataValidationContext.getEvaluator().getWorkbookEvaluator().evaluate(dataValidationContext.getFormula1(), dataValidationContext.getTarget(), dataValidationContext.getRegion());
                if (evaluate instanceof RefEval) {
                    RefEval refEval = (RefEval) evaluate;
                    evaluate = refEval.getInnerValueEval(refEval.getFirstSheetIndex());
                }
                if (evaluate instanceof BlankEval) {
                    return true;
                }
                if (evaluate instanceof ErrorEval) {
                    return false;
                }
                if (evaluate instanceof BoolEval) {
                    return ((BoolEval) evaluate).getBooleanValue();
                }
                if (!(evaluate instanceof NumberEval) || ((NumberEval) evaluate).getNumberValue() == NumericFunction.LOG_10_TO_BASE_e) {
                    return false;
                }
                return true;
            }
        };

        private Double evalOrConstant(String str, DataValidationContext dataValidationContext) {
            if (str == null || str.trim().isEmpty()) {
                return null;
            }
            try {
                return Double.valueOf(str);
            } catch (NumberFormatException unused) {
                ValueEval evaluate = dataValidationContext.getEvaluator().getWorkbookEvaluator().evaluate(str, dataValidationContext.getTarget(), dataValidationContext.getRegion());
                if (evaluate instanceof RefEval) {
                    RefEval refEval = (RefEval) evaluate;
                    evaluate = refEval.getInnerValueEval(refEval.getFirstSheetIndex());
                }
                if (evaluate instanceof BlankEval) {
                    return null;
                }
                if (evaluate instanceof NumberEval) {
                    return Double.valueOf(((NumberEval) evaluate).getNumberValue());
                }
                if (evaluate instanceof StringEval) {
                    String stringValue = ((StringEval) evaluate).getStringValue();
                    if (stringValue == null || stringValue.trim().isEmpty()) {
                        return null;
                    }
                    return Double.valueOf(stringValue);
                }
                throw new NumberFormatException(a.b("Formula '", str, "' evaluates to something other than a number"));
            }
        }

        public static boolean isValid(Cell cell, DataValidationContext dataValidationContext) {
            return values()[dataValidationContext.getValidation().getValidationConstraint().getValidationType()].isValidValue(cell, dataValidationContext);
        }

        public boolean isValidNumericCell(Cell cell, DataValidationContext dataValidationContext) {
            if (!DataValidationEvaluator.isType(cell, CellType.NUMERIC)) {
                return false;
            }
            return isValidNumericValue(Double.valueOf(cell.getNumericCellValue()), dataValidationContext);
        }

        public boolean isValidNumericValue(Double d2, DataValidationContext dataValidationContext) {
            try {
                Double evalOrConstant = evalOrConstant(dataValidationContext.getFormula1(), dataValidationContext);
                if (evalOrConstant == null) {
                    return true;
                }
                Double d3 = null;
                if ((dataValidationContext.getOperator() == 0 || dataValidationContext.getOperator() == 1) && (d3 = evalOrConstant(dataValidationContext.getFormula2(), dataValidationContext)) == null) {
                    return true;
                }
                return OperatorEnum.values()[dataValidationContext.getOperator()].isValid(d2, evalOrConstant, d3);
            } catch (NumberFormatException unused) {
                return false;
            }
        }

        public boolean isValidValue(Cell cell, DataValidationContext dataValidationContext) {
            return isValidNumericCell(cell, dataValidationContext);
        }
    }

    public DataValidationEvaluator(Workbook workbook2, WorkbookEvaluatorProvider workbookEvaluatorProvider) {
        this.workbook = workbook2;
        this.workbookEvaluator = workbookEvaluatorProvider._getWorkbookEvaluator();
    }

    public static List<ValueEval> getValidationValuesForConstraint(DataValidationContext dataValidationContext) {
        DataValidationConstraint validationConstraint = dataValidationContext.getValidation().getValidationConstraint();
        if (validationConstraint.getValidationType() != 3) {
            return null;
        }
        String formula1 = validationConstraint.getFormula1();
        ArrayList arrayList = new ArrayList();
        if (validationConstraint.getExplicitListValues() != null && validationConstraint.getExplicitListValues().length > 0) {
            String[] explicitListValues = validationConstraint.getExplicitListValues();
            for (String str : explicitListValues) {
                if (str != null) {
                    arrayList.add(new StringEval(str));
                }
            }
        } else if (formula1 != null) {
            ValueEval evaluateList = dataValidationContext.getEvaluator().getWorkbookEvaluator().evaluateList(formula1, dataValidationContext.getTarget(), dataValidationContext.getRegion());
            if (evaluateList instanceof TwoDEval) {
                TwoDEval twoDEval = (TwoDEval) evaluateList;
                for (int i2 = 0; i2 < twoDEval.getHeight(); i2++) {
                    arrayList.add(twoDEval.getValue(i2, 0));
                }
            }
        }
        return Collections.unmodifiableList(arrayList);
    }

    private List<? extends DataValidation> getValidations(Sheet sheet) {
        List<? extends DataValidation> list = this.validations.get(sheet.getSheetName());
        if (list != null || this.validations.containsKey(sheet.getSheetName())) {
            return list;
        }
        List<? extends DataValidation> dataValidations = sheet.getDataValidations();
        this.validations.put(sheet.getSheetName(), dataValidations);
        return dataValidations;
    }

    public static boolean isType(Cell cell, CellType cellType) {
        CellType cellTypeEnum = cell.getCellTypeEnum();
        return cellTypeEnum == cellType || (cellTypeEnum == CellType.FORMULA && cell.getCachedFormulaResultTypeEnum() == cellType);
    }

    public void clearAllCachedValues() {
        this.validations.clear();
    }

    public DataValidationContext getValidationContextForCell(CellReference cellReference) {
        List<? extends DataValidation> validations2;
        DataValidation dataValidation;
        CellRangeAddressList regions;
        Sheet sheet = this.workbook.getSheet(cellReference.getSheetName());
        if (sheet == null || (validations2 = getValidations(sheet)) == null) {
            return null;
        }
        Iterator<? extends DataValidation> it = validations2.iterator();
        while (it.hasNext() && (regions = (dataValidation = (DataValidation) it.next()).getRegions()) != null) {
            CellRangeAddress[] cellRangeAddresses = regions.getCellRangeAddresses();
            int length = cellRangeAddresses.length;
            int i2 = 0;
            while (true) {
                if (i2 < length) {
                    CellRangeAddress cellRangeAddress = cellRangeAddresses[i2];
                    if (cellRangeAddress.isInRange(cellReference)) {
                        return new DataValidationContext(dataValidation, this, cellRangeAddress, cellReference);
                    }
                    i2++;
                }
            }
        }
        return null;
    }

    public DataValidation getValidationForCell(CellReference cellReference) {
        DataValidationContext validationContextForCell = getValidationContextForCell(cellReference);
        if (validationContextForCell == null) {
            return null;
        }
        return validationContextForCell.getValidation();
    }

    public List<ValueEval> getValidationValuesForCell(CellReference cellReference) {
        DataValidationContext validationContextForCell = getValidationContextForCell(cellReference);
        if (validationContextForCell == null) {
            return null;
        }
        return getValidationValuesForConstraint(validationContextForCell);
    }

    public WorkbookEvaluator getWorkbookEvaluator() {
        return this.workbookEvaluator;
    }

    public boolean isValidCell(CellReference cellReference) {
        DataValidationContext validationContextForCell = getValidationContextForCell(cellReference);
        if (validationContextForCell == null) {
            return true;
        }
        Cell cell = SheetUtil.getCell(this.workbook.getSheet(cellReference.getSheetName()), cellReference.getRow(), cellReference.getCol());
        if (cell == null || isType(cell, CellType.BLANK) || (isType(cell, CellType.STRING) && (cell.getStringCellValue() == null || cell.getStringCellValue().isEmpty()))) {
            return validationContextForCell.getValidation().getEmptyCellAllowed();
        }
        return ValidationEnum.isValid(cell, validationContextForCell);
    }
}
