package org.apache.poi.ss.formula.functions;

import org.apache.poi.ss.formula.TwoDEval;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.MissingArgEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.RefEval;
import org.apache.poi.ss.formula.eval.ValueEval;

public abstract class BooleanFunction implements Function {
    public static final Function AND = new BooleanFunction() {
        /* class org.apache.poi.ss.formula.functions.BooleanFunction.AnonymousClass1 */

        @Override // org.apache.poi.ss.formula.functions.BooleanFunction
        public boolean getInitialResultValue() {
            return true;
        }

        @Override // org.apache.poi.ss.formula.functions.BooleanFunction
        public boolean partialEvaluate(boolean z, boolean z2) {
            return z && z2;
        }
    };
    public static final Function FALSE = new Fixed0ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.BooleanFunction.AnonymousClass3 */

        @Override // org.apache.poi.ss.formula.functions.Function0Arg
        public ValueEval evaluate(int i2, int i3) {
            return BoolEval.FALSE;
        }
    };
    public static final Function NOT = new Fixed1ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.BooleanFunction.AnonymousClass5 */

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
            try {
                ValueEval singleValue = OperandResolver.getSingleValue(valueEval, i2, i3);
                boolean z = false;
                Boolean coerceValueToBoolean = OperandResolver.coerceValueToBoolean(singleValue, false);
                if (coerceValueToBoolean != null) {
                    z = coerceValueToBoolean.booleanValue();
                }
                return BoolEval.valueOf(!z);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    };
    public static final Function OR = new BooleanFunction() {
        /* class org.apache.poi.ss.formula.functions.BooleanFunction.AnonymousClass2 */

        @Override // org.apache.poi.ss.formula.functions.BooleanFunction
        public boolean getInitialResultValue() {
            return false;
        }

        @Override // org.apache.poi.ss.formula.functions.BooleanFunction
        public boolean partialEvaluate(boolean z, boolean z2) {
            return z || z2;
        }
    };
    public static final Function TRUE = new Fixed0ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.BooleanFunction.AnonymousClass4 */

        @Override // org.apache.poi.ss.formula.functions.Function0Arg
        public ValueEval evaluate(int i2, int i3) {
            return BoolEval.TRUE;
        }
    };

    private boolean calculate(ValueEval[] valueEvalArr) {
        Boolean bool;
        boolean initialResultValue = getInitialResultValue();
        boolean z = false;
        for (ValueEval valueEval : valueEvalArr) {
            if (valueEval instanceof TwoDEval) {
                TwoDEval twoDEval = (TwoDEval) valueEval;
                int height = twoDEval.getHeight();
                int width = twoDEval.getWidth();
                for (int i2 = 0; i2 < height; i2++) {
                    for (int i3 = 0; i3 < width; i3++) {
                        Boolean coerceValueToBoolean = OperandResolver.coerceValueToBoolean(twoDEval.getValue(i2, i3), true);
                        if (coerceValueToBoolean != null) {
                            initialResultValue = partialEvaluate(initialResultValue, coerceValueToBoolean.booleanValue());
                            z = true;
                        }
                    }
                }
            } else if (valueEval instanceof RefEval) {
                RefEval refEval = (RefEval) valueEval;
                int lastSheetIndex = refEval.getLastSheetIndex();
                for (int firstSheetIndex = refEval.getFirstSheetIndex(); firstSheetIndex <= lastSheetIndex; firstSheetIndex++) {
                    Boolean coerceValueToBoolean2 = OperandResolver.coerceValueToBoolean(refEval.getInnerValueEval(firstSheetIndex), true);
                    if (coerceValueToBoolean2 != null) {
                        initialResultValue = partialEvaluate(initialResultValue, coerceValueToBoolean2.booleanValue());
                        z = true;
                    }
                }
            } else {
                if (valueEval == MissingArgEval.instance) {
                    bool = null;
                } else {
                    bool = OperandResolver.coerceValueToBoolean(valueEval, false);
                }
                if (bool != null) {
                    initialResultValue = partialEvaluate(initialResultValue, bool.booleanValue());
                    z = true;
                }
            }
        }
        if (z) {
            return initialResultValue;
        }
        throw new EvaluationException(ErrorEval.VALUE_INVALID);
    }

    @Override // org.apache.poi.ss.formula.functions.Function
    public final ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
        if (valueEvalArr.length < 1) {
            return ErrorEval.VALUE_INVALID;
        }
        try {
            return BoolEval.valueOf(calculate(valueEvalArr));
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public abstract boolean getInitialResultValue();

    public abstract boolean partialEvaluate(boolean z, boolean z2);
}
