package org.apache.poi.ss.formula.functions;

import java.util.Locale;
import org.apache.poi.ss.formula.eval.BoolEval;
import org.apache.poi.ss.formula.eval.ErrorEval;
import org.apache.poi.ss.formula.eval.EvaluationException;
import org.apache.poi.ss.formula.eval.NumberEval;
import org.apache.poi.ss.formula.eval.OperandResolver;
import org.apache.poi.ss.formula.eval.StringEval;
import org.apache.poi.ss.formula.eval.ValueEval;
import org.apache.poi.ss.usermodel.DataFormatter;

public abstract class TextFunction implements Function {
    public static final Function CHAR = new Fixed1ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass1 */

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
            try {
                int evaluateIntArg = TextFunction.evaluateIntArg(valueEval, i2, i3);
                if (evaluateIntArg >= 0 && evaluateIntArg < 256) {
                    return new StringEval(String.valueOf((char) evaluateIntArg));
                }
                throw new EvaluationException(ErrorEval.VALUE_INVALID);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    };
    public static final Function CLEAN = new SingleArgTextFunc() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass7 */

        private boolean isPrintable(char c) {
            return c >= ' ';
        }

        @Override // org.apache.poi.ss.formula.functions.TextFunction.SingleArgTextFunc
        public ValueEval evaluate(String str) {
            StringBuilder sb = new StringBuilder();
            char[] charArray = str.toCharArray();
            for (char c : charArray) {
                if (isPrintable(c)) {
                    sb.append(c);
                }
            }
            return new StringEval(sb.toString());
        }
    };
    public static final Function CONCATENATE = new Function() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass9 */

        @Override // org.apache.poi.ss.formula.functions.Function
        public ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
            StringBuilder sb = new StringBuilder();
            for (ValueEval valueEval : valueEvalArr) {
                try {
                    sb.append(TextFunction.evaluateStringArg(valueEval, i2, i3));
                } catch (EvaluationException e2) {
                    return e2.getErrorEval();
                }
            }
            return new StringEval(sb.toString());
        }
    };
    public static final Function EXACT = new Fixed2ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass10 */

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
            try {
                return BoolEval.valueOf(TextFunction.evaluateStringArg(valueEval, i2, i3).equals(TextFunction.evaluateStringArg(valueEval2, i2, i3)));
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    };
    public static final Function FIND = new SearchFind(true);
    public static final Function LEFT = new LeftRight(true);
    public static final Function LEN = new SingleArgTextFunc() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass2 */

        @Override // org.apache.poi.ss.formula.functions.TextFunction.SingleArgTextFunc
        public ValueEval evaluate(String str) {
            return new NumberEval((double) str.length());
        }
    };
    public static final Function LOWER = new SingleArgTextFunc() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass3 */

        @Override // org.apache.poi.ss.formula.functions.TextFunction.SingleArgTextFunc
        public ValueEval evaluate(String str) {
            return new StringEval(str.toLowerCase(Locale.ROOT));
        }
    };
    public static final Function MID = new Fixed3ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass8 */

        @Override // org.apache.poi.ss.formula.functions.Function3Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3) {
            try {
                String evaluateStringArg = TextFunction.evaluateStringArg(valueEval, i2, i3);
                int evaluateIntArg = TextFunction.evaluateIntArg(valueEval2, i2, i3);
                int evaluateIntArg2 = TextFunction.evaluateIntArg(valueEval3, i2, i3);
                int i4 = evaluateIntArg - 1;
                if (i4 < 0) {
                    return ErrorEval.VALUE_INVALID;
                }
                if (evaluateIntArg2 < 0) {
                    return ErrorEval.VALUE_INVALID;
                }
                int length = evaluateStringArg.length();
                if (evaluateIntArg2 < 0 || i4 > length) {
                    return new StringEval("");
                }
                return new StringEval(evaluateStringArg.substring(i4, Math.min(evaluateIntArg2 + i4, length)));
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    };
    public static final Function PROPER = new SingleArgTextFunc() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass5 */

        @Override // org.apache.poi.ss.formula.functions.TextFunction.SingleArgTextFunc
        public ValueEval evaluate(String str) {
            StringBuilder sb = new StringBuilder();
            char[] charArray = str.toCharArray();
            boolean z = true;
            for (char c : charArray) {
                if (z) {
                    sb.append(String.valueOf(c).toUpperCase(Locale.ROOT));
                } else {
                    sb.append(String.valueOf(c).toLowerCase(Locale.ROOT));
                }
                z = !Character.isLetter(c);
            }
            return new StringEval(sb.toString());
        }
    };
    public static final Function RIGHT = new LeftRight(false);
    public static final Function SEARCH = new SearchFind(false);
    public static final Function TEXT = new Fixed2ArgFunction() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass11 */

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
            try {
                try {
                    return new StringEval(TextFunction.formatter.formatRawCellContents(TextFunction.evaluateDoubleArg(valueEval, i2, i3), -1, TextFunction.evaluateStringArg(valueEval2, i2, i3)));
                } catch (Exception unused) {
                    return ErrorEval.VALUE_INVALID;
                }
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    };
    public static final Function TRIM = new SingleArgTextFunc() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass6 */

        @Override // org.apache.poi.ss.formula.functions.TextFunction.SingleArgTextFunc
        public ValueEval evaluate(String str) {
            return new StringEval(str.trim());
        }
    };
    public static final Function UPPER = new SingleArgTextFunc() {
        /* class org.apache.poi.ss.formula.functions.TextFunction.AnonymousClass4 */

        @Override // org.apache.poi.ss.formula.functions.TextFunction.SingleArgTextFunc
        public ValueEval evaluate(String str) {
            return new StringEval(str.toUpperCase(Locale.ROOT));
        }
    };
    public static final DataFormatter formatter = new DataFormatter();

    public static final class LeftRight extends Var1or2ArgFunction {
        public static final ValueEval DEFAULT_ARG1 = new NumberEval(1.0d);
        public final boolean _isLeft;

        public LeftRight(boolean z) {
            this._isLeft = z;
        }

        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
            return evaluate(i2, i3, valueEval, DEFAULT_ARG1);
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
            String str;
            try {
                String evaluateStringArg = TextFunction.evaluateStringArg(valueEval, i2, i3);
                int evaluateIntArg = TextFunction.evaluateIntArg(valueEval2, i2, i3);
                if (evaluateIntArg < 0) {
                    return ErrorEval.VALUE_INVALID;
                }
                if (this._isLeft) {
                    str = evaluateStringArg.substring(0, Math.min(evaluateStringArg.length(), evaluateIntArg));
                } else {
                    str = evaluateStringArg.substring(Math.max(0, evaluateStringArg.length() - evaluateIntArg));
                }
                return new StringEval(str);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    }

    public static abstract class SingleArgTextFunc extends Fixed1ArgFunction {
        @Override // org.apache.poi.ss.formula.functions.Function1Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval) {
            try {
                return evaluate(TextFunction.evaluateStringArg(valueEval, i2, i3));
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }

        public abstract ValueEval evaluate(String str);
    }

    public static double evaluateDoubleArg(ValueEval valueEval, int i2, int i3) {
        return OperandResolver.coerceValueToDouble(OperandResolver.getSingleValue(valueEval, i2, i3));
    }

    public static int evaluateIntArg(ValueEval valueEval, int i2, int i3) {
        return OperandResolver.coerceValueToInt(OperandResolver.getSingleValue(valueEval, i2, i3));
    }

    public static String evaluateStringArg(ValueEval valueEval, int i2, int i3) {
        return OperandResolver.coerceValueToString(OperandResolver.getSingleValue(valueEval, i2, i3));
    }

    @Override // org.apache.poi.ss.formula.functions.Function
    public final ValueEval evaluate(ValueEval[] valueEvalArr, int i2, int i3) {
        try {
            return evaluateFunc(valueEvalArr, i2, i3);
        } catch (EvaluationException e2) {
            return e2.getErrorEval();
        }
    }

    public abstract ValueEval evaluateFunc(ValueEval[] valueEvalArr, int i2, int i3);

    public static final class SearchFind extends Var2or3ArgFunction {
        public final boolean _isCaseSensitive;

        public SearchFind(boolean z) {
            this._isCaseSensitive = z;
        }

        private ValueEval eval(String str, String str2, int i2) {
            int i3;
            if (this._isCaseSensitive) {
                i3 = str.indexOf(str2, i2);
            } else {
                i3 = str.toUpperCase(Locale.ROOT).indexOf(str2.toUpperCase(Locale.ROOT), i2);
            }
            if (i3 == -1) {
                return ErrorEval.VALUE_INVALID;
            }
            return new NumberEval((double) (i3 + 1));
        }

        @Override // org.apache.poi.ss.formula.functions.Function2Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2) {
            try {
                return eval(TextFunction.evaluateStringArg(valueEval2, i2, i3), TextFunction.evaluateStringArg(valueEval, i2, i3), 0);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }

        @Override // org.apache.poi.ss.formula.functions.Function3Arg
        public ValueEval evaluate(int i2, int i3, ValueEval valueEval, ValueEval valueEval2, ValueEval valueEval3) {
            try {
                String evaluateStringArg = TextFunction.evaluateStringArg(valueEval, i2, i3);
                String evaluateStringArg2 = TextFunction.evaluateStringArg(valueEval2, i2, i3);
                int evaluateIntArg = TextFunction.evaluateIntArg(valueEval3, i2, i3) - 1;
                if (evaluateIntArg < 0) {
                    return ErrorEval.VALUE_INVALID;
                }
                return eval(evaluateStringArg2, evaluateStringArg, evaluateIntArg);
            } catch (EvaluationException e2) {
                return e2.getErrorEval();
            }
        }
    }
}
