package org.apache.poi.ss.formula.ptg;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.ss.formula.ptg.ArrayPtg;
import org.apache.poi.util.LittleEndianByteArrayOutputStream;
import org.apache.poi.util.LittleEndianInput;
import org.apache.poi.util.LittleEndianOutput;
import org.apache.xmlbeans.impl.common.NameUtil;

public abstract class Ptg {
    public static final byte CLASS_ARRAY = 64;
    public static final byte CLASS_REF = 0;
    public static final byte CLASS_VALUE = 32;
    public static final Ptg[] EMPTY_PTG_ARRAY = new Ptg[0];
    public byte ptgClass = 0;

    public static Ptg createBasePtg(byte b2, LittleEndianInput littleEndianInput) {
        switch (b2) {
            case 0:
                return new UnknownPtg(b2);
            case 1:
                return new ExpPtg(littleEndianInput);
            case 2:
                return new TblPtg(littleEndianInput);
            case 3:
                return AddPtg.instance;
            case 4:
                return SubtractPtg.instance;
            case 5:
                return MultiplyPtg.instance;
            case 6:
                return DividePtg.instance;
            case 7:
                return PowerPtg.instance;
            case 8:
                return ConcatPtg.instance;
            case 9:
                return LessThanPtg.instance;
            case 10:
                return LessEqualPtg.instance;
            case 11:
                return EqualPtg.instance;
            case 12:
                return GreaterEqualPtg.instance;
            case 13:
                return GreaterThanPtg.instance;
            case 14:
                return NotEqualPtg.instance;
            case 15:
                return IntersectionPtg.instance;
            case 16:
                return UnionPtg.instance;
            case 17:
                return RangePtg.instance;
            case 18:
                return UnaryPlusPtg.instance;
            case 19:
                return UnaryMinusPtg.instance;
            case 20:
                return PercentPtg.instance;
            case 21:
                return ParenthesisPtg.instance;
            case 22:
                return MissingArgPtg.instance;
            case 23:
                return new StringPtg(littleEndianInput);
            case 24:
            case 26:
            case 27:
            default:
                throw new RuntimeException(a.b("Unexpected base token id (", b2, ")"));
            case 25:
                return new AttrPtg(littleEndianInput);
            case 28:
                return ErrPtg.read(littleEndianInput);
            case 29:
                return BoolPtg.read(littleEndianInput);
            case 30:
                return new IntPtg(littleEndianInput);
            case 31:
                return new NumberPtg(littleEndianInput);
        }
    }

    public static Ptg createClassifiedPtg(byte b2, LittleEndianInput littleEndianInput) {
        int i2 = (b2 & NumberPtg.sid) | 32;
        switch (i2) {
            case 32:
                return new ArrayPtg.Initial(littleEndianInput);
            case 33:
                return FuncPtg.create(littleEndianInput);
            case 34:
                return FuncVarPtg.create(littleEndianInput);
            case 35:
                return new NamePtg(littleEndianInput);
            case 36:
                return new RefPtg(littleEndianInput);
            case 37:
                return new AreaPtg(littleEndianInput);
            case 38:
                return new MemAreaPtg(littleEndianInput);
            case 39:
                return new MemErrPtg(littleEndianInput);
            default:
                switch (i2) {
                    case 41:
                        return new MemFuncPtg(littleEndianInput);
                    case 42:
                        return new RefErrorPtg(littleEndianInput);
                    case 43:
                        return new AreaErrPtg(littleEndianInput);
                    case 44:
                        return new RefNPtg(littleEndianInput);
                    case 45:
                        return new AreaNPtg(littleEndianInput);
                    default:
                        switch (i2) {
                            case 57:
                                return new NameXPtg(littleEndianInput);
                            case 58:
                                return new Ref3DPtg(littleEndianInput);
                            case 59:
                                return new Area3DPtg(littleEndianInput);
                            case 60:
                                return new DeletedRef3DPtg(littleEndianInput);
                            case 61:
                                return new DeletedArea3DPtg(littleEndianInput);
                            default:
                                StringBuilder b3 = a.b(" Unknown Ptg in Formula: 0x");
                                b3.append(Integer.toHexString(b2));
                                b3.append(" (");
                                b3.append((int) b2);
                                b3.append(")");
                                throw new UnsupportedOperationException(b3.toString());
                        }
                }
        }
    }

    public static Ptg createPtg(LittleEndianInput littleEndianInput) {
        byte readByte = littleEndianInput.readByte();
        if (readByte < 32) {
            return createBasePtg(readByte, littleEndianInput);
        }
        Ptg createClassifiedPtg = createClassifiedPtg(readByte, littleEndianInput);
        if (readByte >= 96) {
            createClassifiedPtg.setClass((byte) 64);
        } else if (readByte >= 64) {
            createClassifiedPtg.setClass((byte) 32);
        } else {
            createClassifiedPtg.setClass((byte) 0);
        }
        return createClassifiedPtg;
    }

    public static boolean doesFormulaReferToDeletedCell(Ptg[] ptgArr) {
        for (Ptg ptg : ptgArr) {
            if (isDeletedCellRef(ptg)) {
                return true;
            }
        }
        return false;
    }

    public static int getEncodedSize(Ptg[] ptgArr) {
        int i2 = 0;
        for (Ptg ptg : ptgArr) {
            i2 += ptg.getSize();
        }
        return i2;
    }

    public static int getEncodedSizeWithoutArrayData(Ptg[] ptgArr) {
        int i2 = 0;
        for (Ptg ptg : ptgArr) {
            if (ptg instanceof ArrayPtg) {
                i2 += 8;
            } else {
                i2 = ptg.getSize() + i2;
            }
        }
        return i2;
    }

    public static boolean isDeletedCellRef(Ptg ptg) {
        if (ptg != ErrPtg.REF_INVALID && !(ptg instanceof DeletedArea3DPtg) && !(ptg instanceof DeletedRef3DPtg) && !(ptg instanceof AreaErrPtg) && !(ptg instanceof RefErrorPtg)) {
            return false;
        }
        return true;
    }

    public static Ptg[] readTokens(int i2, LittleEndianInput littleEndianInput) {
        ArrayList arrayList = new ArrayList((i2 / 2) + 4);
        int i3 = 0;
        boolean z = false;
        while (i3 < i2) {
            Ptg createPtg = createPtg(littleEndianInput);
            if (createPtg instanceof ArrayPtg.Initial) {
                z = true;
            }
            i3 += createPtg.getSize();
            arrayList.add(createPtg);
        }
        if (i3 != i2) {
            throw new RuntimeException("Ptg array size mismatch");
        } else if (!z) {
            return toPtgArray(arrayList);
        } else {
            Ptg[] ptgArray = toPtgArray(arrayList);
            for (int i4 = 0; i4 < ptgArray.length; i4++) {
                if (ptgArray[i4] instanceof ArrayPtg.Initial) {
                    ptgArray[i4] = ((ArrayPtg.Initial) ptgArray[i4]).finishReading(littleEndianInput);
                }
            }
            return ptgArray;
        }
    }

    public static int serializePtgs(Ptg[] ptgArr, byte[] bArr, int i2) {
        LittleEndianByteArrayOutputStream littleEndianByteArrayOutputStream = new LittleEndianByteArrayOutputStream(bArr, i2);
        ArrayList<Ptg> arrayList = null;
        for (Ptg ptg : ptgArr) {
            ptg.write(littleEndianByteArrayOutputStream);
            if (ptg instanceof ArrayPtg) {
                if (arrayList == null) {
                    arrayList = new ArrayList(5);
                }
                arrayList.add(ptg);
            }
        }
        if (arrayList != null) {
            for (Ptg ptg2 : arrayList) {
                ((ArrayPtg) ptg2).writeTokenValueBytes(littleEndianByteArrayOutputStream);
            }
        }
        return littleEndianByteArrayOutputStream.getWriteIndex() - i2;
    }

    public static Ptg[] toPtgArray(List<Ptg> list) {
        if (list.isEmpty()) {
            return EMPTY_PTG_ARRAY;
        }
        Ptg[] ptgArr = new Ptg[list.size()];
        list.toArray(ptgArr);
        return ptgArr;
    }

    public abstract byte getDefaultOperandClass();

    public final byte getPtgClass() {
        return this.ptgClass;
    }

    public final char getRVAType() {
        if (isBaseToken()) {
            return NameUtil.PERIOD;
        }
        byte b2 = this.ptgClass;
        if (b2 == 0) {
            return 'R';
        }
        if (b2 == 32) {
            return 'V';
        }
        if (b2 == 64) {
            return 'A';
        }
        throw new RuntimeException(a.a(a.b("Unknown operand class ("), this.ptgClass, ")"));
    }

    public abstract int getSize();

    public abstract boolean isBaseToken();

    public final void setClass(byte b2) {
        if (!isBaseToken()) {
            this.ptgClass = b2;
            return;
        }
        throw new RuntimeException("setClass should not be called on a base token");
    }

    public abstract String toFormulaString();

    public String toString() {
        return getClass().toString();
    }

    public abstract void write(LittleEndianOutput littleEndianOutput);
}
