package org.apache.poi.ss.usermodel;

import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellRangeAddressBase;

public enum TableStyleType {
    wholeTable {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            return new CellRangeAddress(table.getStartRowIndex(), table.getEndRowIndex(), table.getStartColIndex(), table.getEndColIndex());
        }
    },
    pageFieldLabels,
    pageFieldValues,
    firstColumnStripe {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            int i2;
            int i3;
            TableStyleInfo style = table.getStyle();
            if (!style.isShowColumnStripes()) {
                return null;
            }
            DifferentialStyleProvider style2 = style.getStyle().getStyle(TableStyleType.firstColumnStripe);
            DifferentialStyleProvider style3 = style.getStyle().getStyle(TableStyleType.secondColumnStripe);
            int i4 = 1;
            if (style2 == null) {
                i2 = 1;
            } else {
                i2 = Math.max(1, style2.getStripeSize());
            }
            if (style3 != null) {
                i4 = Math.max(1, style3.getStripeSize());
            }
            int startColIndex = table.getStartColIndex();
            int i5 = startColIndex + i2;
            int columnIndex = cell.getColumnIndex();
            while (startColIndex <= columnIndex) {
                if (columnIndex >= startColIndex && columnIndex <= i5 - 1) {
                    return new CellRangeAddress(table.getStartRowIndex(), table.getEndRowIndex(), startColIndex, i3);
                }
                startColIndex = i5 + i4;
                i5 = startColIndex + i2;
            }
            return null;
        }
    },
    secondColumnStripe {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            int i2;
            int i3;
            int i4;
            TableStyleInfo style = table.getStyle();
            if (!style.isShowColumnStripes()) {
                return null;
            }
            DifferentialStyleProvider style2 = style.getStyle().getStyle(TableStyleType.firstColumnStripe);
            DifferentialStyleProvider style3 = style.getStyle().getStyle(TableStyleType.secondColumnStripe);
            if (style2 == null) {
                i2 = 1;
            } else {
                i2 = Math.max(1, style2.getStripeSize());
            }
            if (style3 == null) {
                i3 = 1;
            } else {
                i3 = Math.max(1, style3.getStripeSize());
            }
            int startColIndex = table.getStartColIndex();
            int i5 = startColIndex + i2;
            int columnIndex = cell.getColumnIndex();
            while (startColIndex <= columnIndex) {
                if (columnIndex >= i5 && columnIndex <= (i4 = (i5 + i3) - 1)) {
                    return new CellRangeAddress(table.getStartRowIndex(), table.getEndRowIndex(), i5, i4);
                }
                startColIndex = i5 + i3;
                i5 = startColIndex + i2;
            }
            return null;
        }
    },
    firstRowStripe {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            int i2;
            int i3;
            TableStyleInfo style = table.getStyle();
            if (!style.isShowRowStripes()) {
                return null;
            }
            DifferentialStyleProvider style2 = style.getStyle().getStyle(TableStyleType.firstRowStripe);
            DifferentialStyleProvider style3 = style.getStyle().getStyle(TableStyleType.secondRowStripe);
            int i4 = 1;
            if (style2 == null) {
                i2 = 1;
            } else {
                i2 = Math.max(1, style2.getStripeSize());
            }
            if (style3 != null) {
                i4 = Math.max(1, style3.getStripeSize());
            }
            int headerRowCount = table.getHeaderRowCount() + table.getStartRowIndex();
            int i5 = headerRowCount + i2;
            int rowIndex = cell.getRowIndex();
            while (headerRowCount <= rowIndex) {
                if (rowIndex >= headerRowCount && rowIndex <= i5 - 1) {
                    return new CellRangeAddress(headerRowCount, i3, table.getStartColIndex(), table.getEndColIndex());
                }
                headerRowCount = i5 + i4;
                i5 = headerRowCount + i2;
            }
            return null;
        }
    },
    secondRowStripe {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            int i2;
            int i3;
            int i4;
            TableStyleInfo style = table.getStyle();
            if (!style.isShowRowStripes()) {
                return null;
            }
            DifferentialStyleProvider style2 = style.getStyle().getStyle(TableStyleType.firstRowStripe);
            DifferentialStyleProvider style3 = style.getStyle().getStyle(TableStyleType.secondRowStripe);
            if (style2 == null) {
                i2 = 1;
            } else {
                i2 = Math.max(1, style2.getStripeSize());
            }
            if (style3 == null) {
                i3 = 1;
            } else {
                i3 = Math.max(1, style3.getStripeSize());
            }
            int headerRowCount = table.getHeaderRowCount() + table.getStartRowIndex();
            int i5 = headerRowCount + i2;
            int rowIndex = cell.getRowIndex();
            while (headerRowCount <= rowIndex) {
                if (rowIndex >= i5 && rowIndex <= (i4 = (i5 + i3) - 1)) {
                    return new CellRangeAddress(i5, i4, table.getStartColIndex(), table.getEndColIndex());
                }
                headerRowCount = i5 + i3;
                i5 = headerRowCount + i2;
            }
            return null;
        }
    },
    lastColumn {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            if (!table.getStyle().isShowLastColumn()) {
                return null;
            }
            return new CellRangeAddress(table.getStartRowIndex(), table.getEndRowIndex(), table.getEndColIndex(), table.getEndColIndex());
        }
    },
    firstColumn {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            if (!table.getStyle().isShowFirstColumn()) {
                return null;
            }
            return new CellRangeAddress(table.getStartRowIndex(), table.getEndRowIndex(), table.getStartColIndex(), table.getStartColIndex());
        }
    },
    headerRow {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            if (table.getHeaderRowCount() < 1) {
                return null;
            }
            return new CellRangeAddress(table.getStartRowIndex(), (table.getHeaderRowCount() + table.getStartRowIndex()) - 1, table.getStartColIndex(), table.getEndColIndex());
        }
    },
    totalRow {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            if (table.getTotalsRowCount() < 1) {
                return null;
            }
            return new CellRangeAddress((table.getEndRowIndex() - table.getTotalsRowCount()) + 1, table.getEndRowIndex(), table.getStartColIndex(), table.getEndColIndex());
        }
    },
    firstHeaderCell {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            if (table.getHeaderRowCount() < 1) {
                return null;
            }
            return new CellRangeAddress(table.getStartRowIndex(), table.getStartRowIndex(), table.getStartColIndex(), table.getStartColIndex());
        }
    },
    lastHeaderCell {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            if (table.getHeaderRowCount() < 1) {
                return null;
            }
            return new CellRangeAddress(table.getStartRowIndex(), table.getStartRowIndex(), table.getEndColIndex(), table.getEndColIndex());
        }
    },
    firstTotalCell {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            if (table.getTotalsRowCount() < 1) {
                return null;
            }
            return new CellRangeAddress((table.getEndRowIndex() - table.getTotalsRowCount()) + 1, table.getEndRowIndex(), table.getStartColIndex(), table.getStartColIndex());
        }
    },
    lastTotalCell {
        @Override // org.apache.poi.ss.usermodel.TableStyleType
        public CellRangeAddressBase getRange(Table table, Cell cell) {
            if (table.getTotalsRowCount() < 1) {
                return null;
            }
            return new CellRangeAddress((table.getEndRowIndex() - table.getTotalsRowCount()) + 1, table.getEndRowIndex(), table.getEndColIndex(), table.getEndColIndex());
        }
    },
    firstSubtotalColumn,
    secondSubtotalColumn,
    thirdSubtotalColumn,
    blankRow,
    firstSubtotalRow,
    secondSubtotalRow,
    thirdSubtotalRow,
    firstColumnSubheading,
    secondColumnSubheading,
    thirdColumnSubheading,
    firstRowSubheading,
    secondRowSubheading,
    thirdRowSubheading;

    public CellRangeAddressBase appliesTo(Table table, Cell cell) {
        CellRangeAddressBase range;
        if (table == null || cell == null || !cell.getSheet().getSheetName().equals(table.getSheetName()) || !table.contains(cell) || (range = getRange(table, cell)) == null || !range.isInRange(cell.getRowIndex(), cell.getColumnIndex())) {
            return null;
        }
        return range;
    }

    public CellRangeAddressBase getRange(Table table, Cell cell) {
        return null;
    }
}
