package org.apache.poi.ss.usermodel.charts;

import b.b.a.a.a;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.CellValue;
import org.apache.poi.ss.usermodel.FormulaEvaluator;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.util.CellRangeAddress;

public class DataSources {

    public static abstract class AbstractCellRangeDataSource<T> implements ChartDataSource<T> {
        public final CellRangeAddress cellRangeAddress;
        public FormulaEvaluator evaluator;
        public final int numOfCells;
        public final Sheet sheet;

        public AbstractCellRangeDataSource(Sheet sheet2, CellRangeAddress cellRangeAddress2) {
            this.sheet = sheet2;
            CellRangeAddress copy = cellRangeAddress2.copy();
            this.cellRangeAddress = copy;
            this.numOfCells = copy.getNumberOfCells();
            this.evaluator = sheet2.getWorkbook().getCreationHelper().createFormulaEvaluator();
        }

        public CellValue getCellValueAt(int i2) {
            if (i2 < 0 || i2 >= this.numOfCells) {
                StringBuilder b2 = a.b("Index must be between 0 and ");
                b2.append(this.numOfCells - 1);
                b2.append(" (inclusive), given: ");
                b2.append(i2);
                throw new IndexOutOfBoundsException(b2.toString());
            }
            int firstRow = this.cellRangeAddress.getFirstRow();
            int firstColumn = this.cellRangeAddress.getFirstColumn();
            int lastColumn = (this.cellRangeAddress.getLastColumn() - firstColumn) + 1;
            int i3 = (i2 / lastColumn) + firstRow;
            int i4 = (i2 % lastColumn) + firstColumn;
            Row row = this.sheet.getRow(i3);
            if (row == null) {
                return null;
            }
            return this.evaluator.evaluate(row.getCell(i4));
        }

        @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
        public String getFormulaString() {
            return this.cellRangeAddress.formatAsString(this.sheet.getSheetName(), true);
        }

        @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
        public int getPointCount() {
            return this.numOfCells;
        }

        @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
        public boolean isReference() {
            return true;
        }
    }

    public static class ArrayDataSource<T> implements ChartDataSource<T> {
        public final T[] elements;

        public ArrayDataSource(T[] tArr) {
            this.elements = (T[]) ((Object[]) tArr.clone());
        }

        @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
        public String getFormulaString() {
            throw new UnsupportedOperationException("Literal data source can not be expressed by reference.");
        }

        @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
        public T getPointAt(int i2) {
            return this.elements[i2];
        }

        @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
        public int getPointCount() {
            return this.elements.length;
        }

        @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
        public boolean isNumeric() {
            return Number.class.isAssignableFrom(this.elements.getClass().getComponentType());
        }

        @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
        public boolean isReference() {
            return false;
        }
    }

    public static <T> ChartDataSource<T> fromArray(T[] tArr) {
        return new ArrayDataSource(tArr);
    }

    public static ChartDataSource<Number> fromNumericCellRange(Sheet sheet, CellRangeAddress cellRangeAddress) {
        return new AbstractCellRangeDataSource<Number>(sheet, cellRangeAddress) {
            /* class org.apache.poi.ss.usermodel.charts.DataSources.AnonymousClass1 */

            @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
            public boolean isNumeric() {
                return true;
            }

            @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
            public Number getPointAt(int i2) {
                CellValue cellValueAt = getCellValueAt(i2);
                if (cellValueAt == null || cellValueAt.getCellTypeEnum() != CellType.NUMERIC) {
                    return null;
                }
                return Double.valueOf(cellValueAt.getNumberValue());
            }
        };
    }

    public static ChartDataSource<String> fromStringCellRange(Sheet sheet, CellRangeAddress cellRangeAddress) {
        return new AbstractCellRangeDataSource<String>(sheet, cellRangeAddress) {
            /* class org.apache.poi.ss.usermodel.charts.DataSources.AnonymousClass2 */

            @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
            public boolean isNumeric() {
                return false;
            }

            @Override // org.apache.poi.ss.usermodel.charts.ChartDataSource
            public String getPointAt(int i2) {
                CellValue cellValueAt = getCellValueAt(i2);
                if (cellValueAt == null || cellValueAt.getCellTypeEnum() != CellType.STRING) {
                    return null;
                }
                return cellValueAt.getStringValue();
            }
        };
    }
}
