package org.apache.poi.ss.util;

import b.b.a.a.a;
import java.util.ArrayList;
import java.util.StringTokenizer;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.util.Removal;
import org.apache.poi.xssf.usermodel.XSSFDataValidationConstraint;

public class AreaReference {
    public static final char CELL_DELIMITER = ':';
    public static final SpreadsheetVersion DEFAULT_SPREADSHEET_VERSION = SpreadsheetVersion.EXCEL97;
    public static final char SHEET_NAME_DELIMITER = '!';
    public static final char SPECIAL_NAME_DELIMITER = '\'';
    public final CellReference _firstCell;
    public final boolean _isSingleCell;
    public final CellReference _lastCell;
    public final SpreadsheetVersion _version;

    public AreaReference(String str, SpreadsheetVersion spreadsheetVersion) {
        this._version = spreadsheetVersion == null ? DEFAULT_SPREADSHEET_VERSION : spreadsheetVersion;
        if (isContiguous(str)) {
            String[] separateAreaRefs = separateAreaRefs(str);
            String str2 = separateAreaRefs[0];
            if (separateAreaRefs.length == 1) {
                CellReference cellReference = new CellReference(str2);
                this._firstCell = cellReference;
                this._lastCell = cellReference;
                this._isSingleCell = true;
            } else if (separateAreaRefs.length == 2) {
                String str3 = separateAreaRefs[1];
                if (!isPlainColumn(str2)) {
                    this._firstCell = new CellReference(str2);
                    this._lastCell = new CellReference(str3);
                    this._isSingleCell = str2.equals(str3);
                } else if (isPlainColumn(str3)) {
                    boolean isPartAbsolute = CellReference.isPartAbsolute(str2);
                    boolean isPartAbsolute2 = CellReference.isPartAbsolute(str3);
                    int convertColStringToIndex = CellReference.convertColStringToIndex(str2);
                    int convertColStringToIndex2 = CellReference.convertColStringToIndex(str3);
                    this._firstCell = new CellReference(0, convertColStringToIndex, true, isPartAbsolute);
                    this._lastCell = new CellReference(65535, convertColStringToIndex2, true, isPartAbsolute2);
                    this._isSingleCell = false;
                } else {
                    throw new RuntimeException(a.b("Bad area ref '", str, "'"));
                }
            } else {
                throw new IllegalArgumentException(a.b("Bad area ref '", str, "'"));
            }
        } else {
            throw new IllegalArgumentException("References passed to the AreaReference must be contiguous, use generateContiguous(ref) if you have non-contiguous references");
        }
    }

    @Removal(version = "3.19")
    @Deprecated
    public static AreaReference[] generateContiguous(String str) {
        return generateContiguous(DEFAULT_SPREADSHEET_VERSION, str);
    }

    public static AreaReference getWholeColumn(SpreadsheetVersion spreadsheetVersion, String str, String str2) {
        if (spreadsheetVersion == null) {
            spreadsheetVersion = DEFAULT_SPREADSHEET_VERSION;
        }
        return new AreaReference(str + "$1:" + str2 + "$" + spreadsheetVersion.getMaxRows(), spreadsheetVersion);
    }

    public static AreaReference getWholeRow(SpreadsheetVersion spreadsheetVersion, String str, String str2) {
        if (spreadsheetVersion == null) {
            spreadsheetVersion = DEFAULT_SPREADSHEET_VERSION;
        }
        StringBuilder d2 = a.d("$A", str, ":$");
        d2.append(spreadsheetVersion.getLastColumnName());
        d2.append(str2);
        return new AreaReference(d2.toString(), spreadsheetVersion);
    }

    public static boolean isContiguous(String str) {
        int indexOf = str.indexOf(33);
        if (indexOf != -1) {
            str = str.substring(indexOf);
        }
        return !str.contains(XSSFDataValidationConstraint.LIST_SEPARATOR);
    }

    public static boolean isPlainColumn(String str) {
        for (int length = str.length() - 1; length >= 0; length--) {
            char charAt = str.charAt(length);
            if (!(charAt == '$' && length == 0) && (charAt < 'A' || charAt > 'Z')) {
                return false;
            }
        }
        return true;
    }

    public static boolean isWholeColumnReference(SpreadsheetVersion spreadsheetVersion, CellReference cellReference, CellReference cellReference2) {
        if (spreadsheetVersion == null) {
            spreadsheetVersion = DEFAULT_SPREADSHEET_VERSION;
        }
        return cellReference.getRow() == 0 && cellReference.isRowAbsolute() && cellReference2.getRow() == spreadsheetVersion.getLastRowIndex() && cellReference2.isRowAbsolute();
    }

    public static String[] separateAreaRefs(String str) {
        int length = str.length();
        int i2 = -1;
        int i3 = 0;
        boolean z = false;
        while (i3 < length) {
            char charAt = str.charAt(i3);
            if (charAt != '\'') {
                if (charAt == ':' && !z) {
                    if (i2 < 0) {
                        i2 = i3;
                    } else {
                        throw new IllegalArgumentException(a.b("More than one cell delimiter ':' appears in area reference '", str, "'"));
                    }
                }
            } else if (!z) {
                z = true;
            } else if (i3 < length - 1) {
                int i4 = i3 + 1;
                if (str.charAt(i4) == '\'') {
                    i3 = i4;
                } else {
                    z = false;
                }
            } else {
                throw new IllegalArgumentException("Area reference '" + str + "' ends with special name delimiter '" + '\'' + "'");
            }
            i3++;
        }
        if (i2 < 0) {
            return new String[]{str};
        }
        String substring = str.substring(0, i2);
        String substring2 = str.substring(i2 + 1);
        if (substring2.indexOf(33) < 0) {
            int lastIndexOf = substring.lastIndexOf(33);
            if (lastIndexOf < 0) {
                return new String[]{substring, substring2};
            }
            return new String[]{substring, a.b(substring.substring(0, lastIndexOf + 1), substring2)};
        }
        throw new RuntimeException(a.b("Unexpected ! in second cell reference of '", str, "'"));
    }

    public String formatAsString() {
        if (isWholeColumnReference()) {
            return CellReference.convertNumToColString(this._firstCell.getCol()) + ":" + CellReference.convertNumToColString(this._lastCell.getCol());
        }
        StringBuffer stringBuffer = new StringBuffer(32);
        stringBuffer.append(this._firstCell.formatAsString());
        if (!this._isSingleCell) {
            stringBuffer.append(':');
            if (this._lastCell.getSheetName() == null) {
                stringBuffer.append(this._lastCell.formatAsString());
            } else {
                this._lastCell.appendCellReference(stringBuffer);
            }
        }
        return stringBuffer.toString();
    }

    public CellReference[] getAllReferencedCells() {
        if (this._isSingleCell) {
            return new CellReference[]{this._firstCell};
        }
        int max = Math.max(this._firstCell.getRow(), this._lastCell.getRow());
        int min = Math.min((int) this._firstCell.getCol(), (int) this._lastCell.getCol());
        int max2 = Math.max((int) this._firstCell.getCol(), (int) this._lastCell.getCol());
        String sheetName = this._firstCell.getSheetName();
        ArrayList arrayList = new ArrayList();
        for (int min2 = Math.min(this._firstCell.getRow(), this._lastCell.getRow()); min2 <= max; min2++) {
            for (int i2 = min; i2 <= max2; i2++) {
                arrayList.add(new CellReference(sheetName, min2, i2, this._firstCell.isRowAbsolute(), this._firstCell.isColAbsolute()));
            }
        }
        return (CellReference[]) arrayList.toArray(new CellReference[arrayList.size()]);
    }

    public CellReference getFirstCell() {
        return this._firstCell;
    }

    public CellReference getLastCell() {
        return this._lastCell;
    }

    public boolean isSingleCell() {
        return this._isSingleCell;
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer(64);
        stringBuffer.append(getClass().getName());
        stringBuffer.append(" [");
        stringBuffer.append(formatAsString());
        stringBuffer.append("]");
        return stringBuffer.toString();
    }

    public static AreaReference[] generateContiguous(SpreadsheetVersion spreadsheetVersion, String str) {
        if (spreadsheetVersion == null) {
            spreadsheetVersion = DEFAULT_SPREADSHEET_VERSION;
        }
        ArrayList arrayList = new ArrayList();
        StringTokenizer stringTokenizer = new StringTokenizer(str, XSSFDataValidationConstraint.LIST_SEPARATOR);
        while (stringTokenizer.hasMoreTokens()) {
            arrayList.add(new AreaReference(stringTokenizer.nextToken(), spreadsheetVersion));
        }
        return (AreaReference[]) arrayList.toArray(new AreaReference[arrayList.size()]);
    }

    public boolean isWholeColumnReference() {
        return isWholeColumnReference(this._version, this._firstCell, this._lastCell);
    }

    @Removal(version = "3.19")
    @Deprecated
    public AreaReference(CellReference cellReference, CellReference cellReference2) {
        this(cellReference, cellReference2, DEFAULT_SPREADSHEET_VERSION);
    }

    public AreaReference(CellReference cellReference, CellReference cellReference2, SpreadsheetVersion spreadsheetVersion) {
        int i2;
        boolean z;
        int i3;
        boolean z2;
        boolean z3;
        boolean z4;
        short s;
        short s2;
        this._version = spreadsheetVersion == null ? DEFAULT_SPREADSHEET_VERSION : spreadsheetVersion;
        boolean z5 = true;
        boolean z6 = cellReference.getRow() > cellReference2.getRow();
        z5 = cellReference.getCol() <= cellReference2.getCol() ? false : z5;
        if (z6 || z5) {
            if (z6) {
                i2 = cellReference2.getRow();
                z2 = cellReference2.isRowAbsolute();
                i3 = cellReference.getRow();
                z = cellReference.isRowAbsolute();
            } else {
                i2 = cellReference.getRow();
                z2 = cellReference.isRowAbsolute();
                i3 = cellReference2.getRow();
                z = cellReference2.isRowAbsolute();
            }
            if (z5) {
                s2 = cellReference2.getCol();
                z3 = cellReference2.isColAbsolute();
                s = cellReference.getCol();
                z4 = cellReference.isColAbsolute();
            } else {
                s2 = cellReference.getCol();
                boolean isColAbsolute = cellReference.isColAbsolute();
                s = cellReference2.getCol();
                boolean isColAbsolute2 = cellReference2.isColAbsolute();
                z3 = isColAbsolute;
                z4 = isColAbsolute2;
            }
            this._firstCell = new CellReference(i2, s2, z2, z3);
            this._lastCell = new CellReference(i3, s, z, z4);
        } else {
            this._firstCell = cellReference;
            this._lastCell = cellReference2;
        }
        this._isSingleCell = false;
    }
}
