package org.apache.poi.ss.util;

import b.b.a.a.a;
import java.util.Locale;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.SheetNameFormatter;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.util.StringUtil;

public class CellReference {
    public static final char ABSOLUTE_REFERENCE_MARKER = '$';
    public static final Pattern CELL_REF_PATTERN = Pattern.compile("(\\$?[A-Z]+)?(\\$?[0-9]+)?", 2);
    public static final Pattern COLUMN_REF_PATTERN = Pattern.compile("\\$?([A-Z]+)", 2);
    public static final Pattern NAMED_RANGE_NAME_PATTERN = Pattern.compile("[_A-Z][_.A-Z0-9]*", 2);
    public static final Pattern ROW_REF_PATTERN = Pattern.compile("\\$?([0-9]+)");
    public static final char SHEET_NAME_DELIMITER = '!';
    public static final char SPECIAL_NAME_DELIMITER = '\'';
    public static final Pattern STRICTLY_CELL_REF_PATTERN = Pattern.compile("\\$?([A-Z]+)\\$?([0-9]+)", 2);
    public final int _colIndex;
    public final boolean _isColAbs;
    public final boolean _isRowAbs;
    public final int _rowIndex;
    public final String _sheetName;

    public static final class CellRefParts {
        public final String colRef;
        public final String rowRef;
        public final String sheetName;

        public CellRefParts(String str, String str2, String str3) {
            this.sheetName = str;
            this.rowRef = str2 == null ? "" : str2;
            this.colRef = str3 == null ? "" : str3;
        }
    }

    public enum NameType {
        CELL,
        NAMED_RANGE,
        COLUMN,
        ROW,
        BAD_CELL_OR_NAMED_RANGE
    }

    public CellReference(String str) {
        if (!StringUtil.endsWithIgnoreCase(str, "#REF!")) {
            CellRefParts separateRefParts = separateRefParts(str);
            this._sheetName = separateRefParts.sheetName;
            String str2 = separateRefParts.colRef;
            boolean z = false;
            boolean z2 = str2.length() > 0 && str2.charAt(0) == '$';
            this._isColAbs = z2;
            str2 = z2 ? str2.substring(1) : str2;
            if (str2.length() == 0) {
                this._colIndex = -1;
            } else {
                this._colIndex = convertColStringToIndex(str2);
            }
            String str3 = separateRefParts.rowRef;
            if (str3.length() > 0 && str3.charAt(0) == '$') {
                z = true;
            }
            this._isRowAbs = z;
            str3 = z ? str3.substring(1) : str3;
            if (str3.length() == 0) {
                this._rowIndex = -1;
            } else {
                this._rowIndex = Integer.parseInt(str3) - 1;
            }
        } else {
            throw new IllegalArgumentException(a.b("Cell reference invalid: ", str));
        }
    }

    public static boolean cellReferenceIsWithinRange(String str, String str2, SpreadsheetVersion spreadsheetVersion) {
        if (!isColumnWithinRange(str, spreadsheetVersion)) {
            return false;
        }
        return isRowWithinRange(str2, spreadsheetVersion);
    }

    public static NameType classifyCellReference(String str, SpreadsheetVersion spreadsheetVersion) {
        int length = str.length();
        if (length >= 1) {
            char charAt = str.charAt(0);
            if (charAt != '$' && charAt != '.' && charAt != '_' && !Character.isLetter(charAt) && !Character.isDigit(charAt)) {
                throw new IllegalArgumentException("Invalid first char (" + charAt + ") of cell reference or named range.  Letter expected");
            } else if (!Character.isDigit(str.charAt(length - 1))) {
                return validateNamedRangeName(str, spreadsheetVersion);
            } else {
                Matcher matcher = STRICTLY_CELL_REF_PATTERN.matcher(str);
                if (!matcher.matches()) {
                    return validateNamedRangeName(str, spreadsheetVersion);
                }
                if (cellReferenceIsWithinRange(matcher.group(1), matcher.group(2), spreadsheetVersion)) {
                    return NameType.CELL;
                }
                if (str.indexOf(36) >= 0) {
                    return NameType.BAD_CELL_OR_NAMED_RANGE;
                }
                return NameType.NAMED_RANGE;
            }
        } else {
            throw new IllegalArgumentException("Empty string not allowed");
        }
    }

    public static int convertColStringToIndex(String str) {
        char[] charArray = str.toUpperCase(Locale.ROOT).toCharArray();
        int i2 = 0;
        for (int i3 = 0; i3 < charArray.length; i3++) {
            char c = charArray[i3];
            if (c != '$') {
                i2 = (c - 'A') + 1 + (i2 * 26);
            } else if (i3 != 0) {
                throw new IllegalArgumentException(a.b("Bad col ref format '", str, "'"));
            }
        }
        return i2 - 1;
    }

    public static String convertNumToColString(int i2) {
        int i3 = i2 + 1;
        StringBuilder sb = new StringBuilder(2);
        while (i3 > 0) {
            int i4 = i3 % 26;
            if (i4 == 0) {
                i4 = 26;
            }
            i3 = (i3 - i4) / 26;
            sb.insert(0, (char) (i4 + 64));
        }
        return sb.toString();
    }

    public static boolean isColumnWithinRange(String str, SpreadsheetVersion spreadsheetVersion) {
        String lastColumnName = spreadsheetVersion.getLastColumnName();
        int length = lastColumnName.length();
        int length2 = str.length();
        if (length2 > length) {
            return false;
        }
        if (length2 != length || str.toUpperCase(Locale.ROOT).compareTo(lastColumnName) <= 0) {
            return true;
        }
        return false;
    }

    public static boolean isPartAbsolute(String str) {
        return str.charAt(0) == '$';
    }

    public static boolean isRowWithinRange(String str, SpreadsheetVersion spreadsheetVersion) {
        return isRowWithinRange(Integer.parseInt(str) - 1, spreadsheetVersion);
    }

    public static String parseSheetName(String str, int i2) {
        if (i2 < 0) {
            return null;
        }
        if (str.charAt(0) == '\'') {
            int i3 = i2 - 1;
            if (str.charAt(i3) == '\'') {
                StringBuffer stringBuffer = new StringBuffer(i2);
                int i4 = 1;
                while (i4 < i3) {
                    char charAt = str.charAt(i4);
                    if (charAt != '\'') {
                        stringBuffer.append(charAt);
                    } else {
                        i4++;
                        if (i4 >= i3 || str.charAt(i4) != '\'') {
                            throw new IllegalArgumentException(a.b("Bad sheet name quote escaping: (", str, ")"));
                        }
                        stringBuffer.append(charAt);
                    }
                    i4++;
                }
                return stringBuffer.toString();
            }
            throw new IllegalArgumentException(a.b("Mismatched quotes: (", str, ")"));
        } else if (!str.contains(" ")) {
            return str.substring(0, i2);
        } else {
            throw new IllegalArgumentException(a.b("Sheet names containing spaces must be quoted: (", str, ")"));
        }
    }

    public static CellRefParts separateRefParts(String str) {
        int lastIndexOf = str.lastIndexOf(33);
        String parseSheetName = parseSheetName(str, lastIndexOf);
        Matcher matcher = CELL_REF_PATTERN.matcher(str.substring(lastIndexOf + 1).toUpperCase(Locale.ROOT));
        if (matcher.matches()) {
            return new CellRefParts(parseSheetName, matcher.group(2), matcher.group(1));
        }
        throw new IllegalArgumentException(a.b("Invalid CellReference: ", str));
    }

    public static NameType validateNamedRangeName(String str, SpreadsheetVersion spreadsheetVersion) {
        Matcher matcher = COLUMN_REF_PATTERN.matcher(str);
        if (matcher.matches() && isColumnWithinRange(matcher.group(1), spreadsheetVersion)) {
            return NameType.COLUMN;
        }
        Matcher matcher2 = ROW_REF_PATTERN.matcher(str);
        if (matcher2.matches() && isRowWithinRange(matcher2.group(1), spreadsheetVersion)) {
            return NameType.ROW;
        }
        if (!NAMED_RANGE_NAME_PATTERN.matcher(str).matches()) {
            return NameType.BAD_CELL_OR_NAMED_RANGE;
        }
        return NameType.NAMED_RANGE;
    }

    public void appendCellReference(StringBuffer stringBuffer) {
        if (this._colIndex != -1) {
            if (this._isColAbs) {
                stringBuffer.append('$');
            }
            stringBuffer.append(convertNumToColString(this._colIndex));
        }
        if (this._rowIndex != -1) {
            if (this._isRowAbs) {
                stringBuffer.append('$');
            }
            stringBuffer.append(this._rowIndex + 1);
        }
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof CellReference)) {
            return false;
        }
        CellReference cellReference = (CellReference) obj;
        if (this._rowIndex == cellReference._rowIndex && this._colIndex == cellReference._colIndex && this._isRowAbs == cellReference._isRowAbs && this._isColAbs == cellReference._isColAbs) {
            String str = this._sheetName;
            String str2 = cellReference._sheetName;
            if (str == null) {
                if (str2 == null) {
                    return true;
                }
            } else if (str.equals(str2)) {
                return true;
            }
        }
        return false;
    }

    public String formatAsString() {
        StringBuffer stringBuffer = new StringBuffer(32);
        String str = this._sheetName;
        if (str != null) {
            SheetNameFormatter.appendFormat(stringBuffer, str);
            stringBuffer.append('!');
        }
        appendCellReference(stringBuffer);
        return stringBuffer.toString();
    }

    public String[] getCellRefParts() {
        return new String[]{this._sheetName, Integer.toString(this._rowIndex + 1), convertNumToColString(this._colIndex)};
    }

    public short getCol() {
        return (short) this._colIndex;
    }

    public int getRow() {
        return this._rowIndex;
    }

    public String getSheetName() {
        return this._sheetName;
    }

    public int hashCode() {
        int i2 = (((((((527 + this._rowIndex) * 31) + this._colIndex) * 31) + (this._isRowAbs ? 1 : 0)) * 31) + (this._isColAbs ? 1 : 0)) * 31;
        String str = this._sheetName;
        return i2 + (str == null ? 0 : str.hashCode());
    }

    public boolean isColAbsolute() {
        return this._isColAbs;
    }

    public boolean isRowAbsolute() {
        return this._isRowAbs;
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer(64);
        stringBuffer.append(getClass().getName());
        stringBuffer.append(" [");
        stringBuffer.append(formatAsString());
        stringBuffer.append("]");
        return stringBuffer.toString();
    }

    public static boolean isRowWithinRange(int i2, SpreadsheetVersion spreadsheetVersion) {
        return i2 >= 0 && i2 <= spreadsheetVersion.getLastRowIndex();
    }

    public CellReference(int i2, int i3) {
        this(i2, i3, false, false);
    }

    public CellReference(int i2, short s) {
        this(i2, s & 65535, false, false);
    }

    public CellReference(Cell cell) {
        this(cell.getRowIndex(), cell.getColumnIndex(), false, false);
    }

    public CellReference(int i2, int i3, boolean z, boolean z2) {
        this(null, i2, i3, z, z2);
    }

    public CellReference(String str, int i2, int i3, boolean z, boolean z2) {
        if (i2 < -1) {
            throw new IllegalArgumentException(a.c("row index may not be negative, but had ", i2));
        } else if (i3 >= -1) {
            this._sheetName = str;
            this._rowIndex = i2;
            this._colIndex = i3;
            this._isRowAbs = z;
            this._isColAbs = z2;
        } else {
            throw new IllegalArgumentException(a.c("column index may not be negative, but had ", i3));
        }
    }
}
