package org.apache.poi.ss.util;

import java.awt.Rectangle;
import java.awt.font.FontRenderContext;
import java.awt.font.TextAttribute;
import java.awt.font.TextLayout;
import java.awt.geom.AffineTransform;
import java.text.AttributedString;
import java.util.Locale;
import java.util.Map;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.CellValue;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.usermodel.Font;
import org.apache.poi.ss.usermodel.FormulaEvaluator;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.util.Internal;

public class SheetUtil {
    public static final char defaultChar = '0';
    public static final FormulaEvaluator dummyEvaluator = new FormulaEvaluator() {
        /* class org.apache.poi.ss.util.SheetUtil.AnonymousClass1 */

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public void clearAllCachedResultValues() {
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public CellValue evaluate(Cell cell) {
            return null;
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public void evaluateAll() {
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public int evaluateFormulaCell(Cell cell) {
            return cell.getCachedFormulaResultType();
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        @Internal(since = "POI 3.15 beta 3")
        public CellType evaluateFormulaCellEnum(Cell cell) {
            return cell.getCachedFormulaResultTypeEnum();
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public Cell evaluateInCell(Cell cell) {
            return null;
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public void notifyDeleteCell(Cell cell) {
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public void notifySetFormula(Cell cell) {
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public void notifyUpdateCell(Cell cell) {
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public void setDebugEvaluationOutputForNextEval(boolean z) {
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public void setIgnoreMissingWorkbooks(boolean z) {
        }

        @Override // org.apache.poi.ss.usermodel.FormulaEvaluator
        public void setupReferencedWorkbooks(Map<String, FormulaEvaluator> map) {
        }
    };
    public static final double fontHeightMultiple = 2.0d;
    public static final FontRenderContext fontRenderContext = new FontRenderContext((AffineTransform) null, true, true);

    public static boolean canComputeColumnWidth(Font font) {
        AttributedString attributedString = new AttributedString("1w");
        copyAttributes(font, attributedString, 0, 2);
        if (new TextLayout(attributedString.getIterator(), fontRenderContext).getBounds().getWidth() > NumericFunction.LOG_10_TO_BASE_e) {
            return true;
        }
        return false;
    }

    @Deprecated
    public static boolean containsCell(CellRangeAddress cellRangeAddress, int i2, int i3) {
        return cellRangeAddress.isInRange(i2, i3);
    }

    public static void copyAttributes(Font font, AttributedString attributedString, int i2, int i3) {
        attributedString.addAttribute(TextAttribute.FAMILY, font.getFontName(), i2, i3);
        attributedString.addAttribute(TextAttribute.SIZE, Float.valueOf((float) font.getFontHeightInPoints()));
        if (font.getBold()) {
            attributedString.addAttribute(TextAttribute.WEIGHT, TextAttribute.WEIGHT_BOLD, i2, i3);
        }
        if (font.getItalic()) {
            attributedString.addAttribute(TextAttribute.POSTURE, TextAttribute.POSTURE_OBLIQUE, i2, i3);
        }
        if (font.getUnderline() == 1) {
            attributedString.addAttribute(TextAttribute.UNDERLINE, TextAttribute.UNDERLINE_ON, i2, i3);
        }
    }

    public static Cell getCell(Sheet sheet, int i2, int i3) {
        Row row = sheet.getRow(i2);
        if (row != null) {
            return row.getCell(i3);
        }
        return null;
    }

    public static double getCellWidth(Cell cell, int i2, DataFormatter dataFormatter, boolean z) {
        Sheet sheet = cell.getSheet();
        Workbook workbook = sheet.getWorkbook();
        Row row = cell.getRow();
        int columnIndex = cell.getColumnIndex();
        int i3 = 1;
        for (CellRangeAddress cellRangeAddress : sheet.getMergedRegions()) {
            if (cellRangeAddress.isInRange(row.getRowNum(), columnIndex)) {
                if (!z) {
                    return -1.0d;
                }
                cell = row.getCell(cellRangeAddress.getFirstColumn());
                i3 = (cellRangeAddress.getLastColumn() + 1) - cellRangeAddress.getFirstColumn();
            }
        }
        CellStyle cellStyle = cell.getCellStyle();
        CellType cellTypeEnum = cell.getCellTypeEnum();
        if (cellTypeEnum == CellType.FORMULA) {
            cellTypeEnum = cell.getCachedFormulaResultTypeEnum();
        }
        Font fontAt = workbook.getFontAt(cellStyle.getFontIndex());
        double d2 = -1.0d;
        if (cellTypeEnum == CellType.STRING) {
            for (String str : cell.getRichStringCellValue().getString().split("\\n")) {
                String str2 = str + defaultChar;
                AttributedString attributedString = new AttributedString(str2);
                copyAttributes(fontAt, attributedString, 0, str2.length());
                d2 = getCellWidth(i2, i3, cellStyle, d2, attributedString);
            }
            return d2;
        }
        String str3 = null;
        if (cellTypeEnum == CellType.NUMERIC) {
            try {
                str3 = dataFormatter.formatCellValue(cell, dummyEvaluator);
            } catch (Exception unused) {
                str3 = String.valueOf(cell.getNumericCellValue());
            }
        } else if (cellTypeEnum == CellType.BOOLEAN) {
            str3 = String.valueOf(cell.getBooleanCellValue()).toUpperCase(Locale.ROOT);
        }
        if (str3 == null) {
            return -1.0d;
        }
        String str4 = str3 + defaultChar;
        AttributedString attributedString2 = new AttributedString(str4);
        copyAttributes(fontAt, attributedString2, 0, str4.length());
        return getCellWidth(i2, i3, cellStyle, -1.0d, attributedString2);
    }

    public static Cell getCellWithMerges(Sheet sheet, int i2, int i3) {
        Row row;
        Cell cell = getCell(sheet, i2, i3);
        if (cell != null) {
            return cell;
        }
        for (CellRangeAddress cellRangeAddress : sheet.getMergedRegions()) {
            if (cellRangeAddress.isInRange(i2, i3) && (row = sheet.getRow(cellRangeAddress.getFirstRow())) != null) {
                return row.getCell(cellRangeAddress.getFirstColumn());
            }
        }
        return null;
    }

    public static double getColumnWidth(Sheet sheet, int i2, boolean z) {
        return getColumnWidth(sheet, i2, z, sheet.getFirstRowNum(), sheet.getLastRowNum());
    }

    public static double getColumnWidthForRow(Row row, int i2, int i3, DataFormatter dataFormatter, boolean z) {
        Cell cell;
        if (row == null || (cell = row.getCell(i2)) == null) {
            return -1.0d;
        }
        return getCellWidth(cell, i3, dataFormatter, z);
    }

    @Internal
    public static int getDefaultCharWidth(Workbook workbook) {
        Font fontAt = workbook.getFontAt(0);
        AttributedString attributedString = new AttributedString(String.valueOf((char) defaultChar));
        copyAttributes(fontAt, attributedString, 0, 1);
        return (int) new TextLayout(attributedString.getIterator(), fontRenderContext).getAdvance();
    }

    public static double getColumnWidth(Sheet sheet, int i2, boolean z, int i3, int i4) {
        DataFormatter dataFormatter = new DataFormatter();
        int defaultCharWidth = getDefaultCharWidth(sheet.getWorkbook());
        double d2 = -1.0d;
        while (i3 <= i4) {
            Row row = sheet.getRow(i3);
            if (row != null) {
                d2 = Math.max(d2, getColumnWidthForRow(row, i2, defaultCharWidth, dataFormatter, z));
            }
            i3++;
        }
        return d2;
    }

    public static double getCellWidth(int i2, int i3, CellStyle cellStyle, double d2, AttributedString attributedString) {
        Rectangle rectangle;
        TextLayout textLayout = new TextLayout(attributedString.getIterator(), fontRenderContext);
        if (cellStyle.getRotation() != 0) {
            AffineTransform affineTransform = new AffineTransform();
            affineTransform.concatenate(AffineTransform.getRotateInstance(((((double) cellStyle.getRotation()) * 2.0d) * 3.141592653589793d) / 360.0d));
            affineTransform.concatenate(AffineTransform.getScaleInstance(1.0d, 2.0d));
            rectangle = textLayout.getOutline(affineTransform).getBounds();
        } else {
            rectangle = textLayout.getBounds();
        }
        return Math.max(d2, (((rectangle.getX() + rectangle.getWidth()) / ((double) i3)) / ((double) i2)) + ((double) cellStyle.getIndention()));
    }
}
