package org.apache.poi.util;

import java.io.InputStream;
import javax.xml.XMLConstants;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import org.apache.poi.javax.xml.stream.events.Namespace;
import org.apache.xmlbeans.impl.common.Sax2Dom;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.ErrorHandler;
import org.xml.sax.InputSource;
import org.xml.sax.SAXParseException;

public final class DocumentHelper {
    public static final DocumentBuilderFactory documentBuilderFactory;
    public static final DocumentBuilder documentBuilderSingleton = newDocumentBuilder();
    public static POILogger logger = POILogFactory.getLogger(DocumentHelper.class);

    public static class DocHelperErrorHandler implements ErrorHandler {
        public DocHelperErrorHandler() {
        }

        private void printError(int i2, SAXParseException sAXParseException) {
            StringBuilder sb = new StringBuilder();
            String systemId = sAXParseException.getSystemId();
            if (systemId != null) {
                int lastIndexOf = systemId.lastIndexOf(47);
                if (lastIndexOf != -1) {
                    systemId = systemId.substring(lastIndexOf + 1);
                }
                sb.append(systemId);
            }
            sb.append(':');
            sb.append(sAXParseException.getLineNumber());
            sb.append(':');
            sb.append(sAXParseException.getColumnNumber());
            sb.append(": ");
            sb.append(sAXParseException.getMessage());
            DocumentHelper.logger.log(i2, sb.toString(), sAXParseException);
        }

        @Override // org.xml.sax.ErrorHandler
        public void error(SAXParseException sAXParseException) {
            printError(7, sAXParseException);
        }

        @Override // org.xml.sax.ErrorHandler
        public void fatalError(SAXParseException sAXParseException) {
            printError(9, sAXParseException);
            throw sAXParseException;
        }

        @Override // org.xml.sax.ErrorHandler
        public void warning(SAXParseException sAXParseException) {
            printError(5, sAXParseException);
        }
    }

    static {
        DocumentBuilderFactory newInstance = DocumentBuilderFactory.newInstance();
        documentBuilderFactory = newInstance;
        newInstance.setNamespaceAware(true);
        documentBuilderFactory.setValidating(false);
        trySetSAXFeature(documentBuilderFactory, XMLConstants.FEATURE_SECURE_PROCESSING, true);
        trySetXercesSecurityManager(documentBuilderFactory);
    }

    public static void addNamespaceDeclaration(Element element, String str, String str2) {
        element.setAttributeNS("http://www.w3.org/2000/xmlns/", Sax2Dom.XMLNS_STRING + str, str2);
    }

    public static synchronized Document createDocument() {
        Document newDocument;
        synchronized (DocumentHelper.class) {
            newDocument = documentBuilderSingleton.newDocument();
        }
        return newDocument;
    }

    public static synchronized DocumentBuilder newDocumentBuilder() {
        DocumentBuilder newDocumentBuilder;
        synchronized (DocumentHelper.class) {
            try {
                newDocumentBuilder = documentBuilderFactory.newDocumentBuilder();
                newDocumentBuilder.setEntityResolver(SAXHelper.IGNORING_ENTITY_RESOLVER);
                newDocumentBuilder.setErrorHandler(new DocHelperErrorHandler());
            } catch (ParserConfigurationException e2) {
                throw new IllegalStateException("cannot create a DocumentBuilder", e2);
            }
        }
        return newDocumentBuilder;
    }

    public static Document readDocument(InputStream inputStream) {
        return newDocumentBuilder().parse(inputStream);
    }

    public static void trySetSAXFeature(DocumentBuilderFactory documentBuilderFactory2, String str, boolean z) {
        try {
            documentBuilderFactory2.setFeature(str, z);
        } catch (Exception e2) {
            logger.log(5, "SAX Feature unsupported", str, e2);
        } catch (AbstractMethodError e3) {
            logger.log(5, "Cannot set SAX feature because outdated XML parser in classpath", str, e3);
        }
    }

    public static void trySetXercesSecurityManager(DocumentBuilderFactory documentBuilderFactory2) {
        String[] strArr = {"com.sun.org.apache.xerces.internal.util.SecurityManager", "org.apache.xerces.util.SecurityManager"};
        for (int i2 = 0; i2 < 2; i2++) {
            try {
                Object newInstance = Class.forName(strArr[i2]).newInstance();
                newInstance.getClass().getMethod("setEntityExpansionLimit", Integer.TYPE).invoke(newInstance, 4096);
                documentBuilderFactory2.setAttribute("http://apache.org/xml/properties/security-manager", newInstance);
                return;
            } catch (Throwable th) {
                logger.log(5, "SAX Security Manager could not be setup", th);
            }
        }
    }

    public static void addNamespaceDeclaration(Element element, Namespace namespace) {
        addNamespaceDeclaration(element, namespace.getPrefix(), namespace.getNamespaceURI());
    }

    public static Document readDocument(InputSource inputSource) {
        return newDocumentBuilder().parse(inputSource);
    }
}
