package org.apache.poi.util;

import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.PushbackInputStream;
import java.nio.ByteBuffer;
import java.nio.channels.ReadableByteChannel;
import java.util.zip.CRC32;
import org.apache.poi.EmptyFileException;
import org.apache.poi.POIDocument;
import org.apache.poi.ss.usermodel.Workbook;

public final class IOUtils {
    public static final int SKIP_BUFFER_SIZE = 2048;
    public static byte[] SKIP_BYTE_BUFFER;
    public static final POILogger logger = POILogFactory.getLogger(IOUtils.class);

    public static long calculateChecksum(byte[] bArr) {
        CRC32 crc32 = new CRC32();
        crc32.update(bArr, 0, bArr.length);
        return crc32.getValue();
    }

    public static void closeQuietly(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (Exception e2) {
                POILogger pOILogger = logger;
                pOILogger.log(7, "Unable to close resource: " + e2, e2);
            }
        }
    }

    public static void copy(InputStream inputStream, OutputStream outputStream) {
        byte[] bArr = new byte[4096];
        while (true) {
            int read = inputStream.read(bArr);
            if (read == -1) {
                return;
            }
            if (read < -1) {
                throw new RecordFormatException("Can't have read < -1 bytes");
            } else if (read > 0) {
                outputStream.write(bArr, 0, read);
            }
        }
    }

    public static byte[] peekFirst8Bytes(InputStream inputStream) {
        return peekFirstNBytes(inputStream, 8);
    }

    public static byte[] peekFirstNBytes(InputStream inputStream, int i2) {
        inputStream.mark(i2);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(i2);
        copy(new BoundedInputStream(inputStream, (long) i2), byteArrayOutputStream);
        int size = byteArrayOutputStream.size();
        if (size != 0) {
            if (size < i2) {
                byteArrayOutputStream.write(new byte[(i2 - size)]);
            }
            byte[] byteArray = byteArrayOutputStream.toByteArray();
            if (inputStream instanceof PushbackInputStream) {
                ((PushbackInputStream) inputStream).unread(byteArray, 0, size);
            } else {
                inputStream.reset();
            }
            return byteArray;
        }
        throw new EmptyFileException();
    }

    public static int readFully(InputStream inputStream, byte[] bArr) {
        return readFully(inputStream, bArr, 0, bArr.length);
    }

    public static byte[] safelyAllocate(long j, int i2) {
        if (j < 0) {
            throw new RecordFormatException("Can't allocate an array of length < 0");
        } else if (j > 2147483647L) {
            throw new RecordFormatException("Can't allocate an array > 2147483647");
        } else if (j <= ((long) i2)) {
            return new byte[((int) j)];
        } else {
            throw new RecordFormatException("Not allowed to allocate an array > " + i2 + " for this record type." + "If the file is not corrupt, please open an issue on bugzilla to request " + "increasing the maximum allowable size for this record type");
        }
    }

    public static long skipFully(InputStream inputStream, long j) {
        int i2 = (j > 0 ? 1 : (j == 0 ? 0 : -1));
        if (i2 < 0) {
            throw new IllegalArgumentException("Skip count must be non-negative, actual: " + j);
        } else if (i2 == 0) {
            return 0;
        } else {
            if (SKIP_BYTE_BUFFER == null) {
                SKIP_BYTE_BUFFER = new byte[2048];
            }
            long j2 = j;
            while (j2 > 0) {
                long read = (long) inputStream.read(SKIP_BYTE_BUFFER, 0, (int) Math.min(j2, 2048L));
                if (read < 0) {
                    break;
                }
                j2 -= read;
            }
            if (j == j2) {
                return -1;
            }
            return j - j2;
        }
    }

    public static byte[] toByteArray(InputStream inputStream) {
        return toByteArray(inputStream, Integer.MAX_VALUE);
    }

    public static void write(POIDocument pOIDocument, OutputStream outputStream) {
        try {
            pOIDocument.write(outputStream);
        } finally {
            closeQuietly(outputStream);
        }
    }

    public static void writeAndClose(POIDocument pOIDocument, OutputStream outputStream) {
        try {
            write(pOIDocument, outputStream);
        } finally {
            closeQuietly(pOIDocument);
        }
    }

    public static int readFully(InputStream inputStream, byte[] bArr, int i2, int i3) {
        int i4 = 0;
        do {
            int read = inputStream.read(bArr, i2 + i4, i3 - i4);
            if (read >= 0) {
                i4 += read;
            } else if (i4 == 0) {
                return -1;
            } else {
                return i4;
            }
        } while (i4 != i3);
        return i4;
    }

    public static byte[] toByteArray(InputStream inputStream, int i2) {
        int read;
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(i2 == Integer.MAX_VALUE ? 4096 : i2);
        byte[] bArr = new byte[4096];
        int i3 = 0;
        do {
            read = inputStream.read(bArr, 0, Math.min(4096, i2 - i3));
            i3 += Math.max(read, 0);
            if (read > 0) {
                byteArrayOutputStream.write(bArr, 0, read);
            }
            if (i3 >= i2) {
                break;
            }
        } while (read > -1);
        if (i2 == Integer.MAX_VALUE || i3 >= i2) {
            return byteArrayOutputStream.toByteArray();
        }
        throw new IOException("unexpected EOF");
    }

    public static int readFully(ReadableByteChannel readableByteChannel, ByteBuffer byteBuffer) {
        int i2 = 0;
        do {
            int read = readableByteChannel.read(byteBuffer);
            if (read >= 0) {
                i2 += read;
                if (i2 == byteBuffer.capacity()) {
                    break;
                }
            } else if (i2 == 0) {
                return -1;
            } else {
                return i2;
            }
        } while (byteBuffer.position() != byteBuffer.capacity());
        return i2;
    }

    public static void write(Workbook workbook, OutputStream outputStream) {
        try {
            workbook.write(outputStream);
        } finally {
            closeQuietly(outputStream);
        }
    }

    public static void writeAndClose(POIDocument pOIDocument, File file) {
        try {
            pOIDocument.write(file);
        } finally {
            closeQuietly(pOIDocument);
        }
    }

    public static long calculateChecksum(InputStream inputStream) {
        CRC32 crc32 = new CRC32();
        byte[] bArr = new byte[4096];
        while (true) {
            int read = inputStream.read(bArr);
            if (read == -1) {
                return crc32.getValue();
            }
            if (read > 0) {
                crc32.update(bArr, 0, read);
            }
        }
    }

    public static void writeAndClose(POIDocument pOIDocument) {
        try {
            pOIDocument.write();
        } finally {
            closeQuietly(pOIDocument);
        }
    }

    public static void writeAndClose(Workbook workbook, OutputStream outputStream) {
        try {
            workbook.write(outputStream);
        } finally {
            closeQuietly(workbook);
        }
    }

    public static byte[] toByteArray(ByteBuffer byteBuffer, int i2) {
        if (byteBuffer.hasArray() && byteBuffer.arrayOffset() == 0) {
            return byteBuffer.array();
        }
        byte[] bArr = new byte[i2];
        byteBuffer.get(bArr);
        return bArr;
    }
}
