package org.apache.poi.util;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.util.Locale;

public class RLEDecompressingInputStream extends InputStream {
    public static final int[] POWER2 = {1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384, 32768};
    public final byte[] buf = new byte[4096];
    public final InputStream in;
    public int len;
    public int pos = 0;

    public RLEDecompressingInputStream(InputStream inputStream) {
        this.in = inputStream;
        int read = inputStream.read();
        if (read == 1) {
            this.len = readChunk();
            return;
        }
        throw new IllegalArgumentException(String.format(Locale.ROOT, "Header byte 0x01 expected, received 0x%02X", Integer.valueOf(read & 255)));
    }

    public static byte[] decompress(byte[] bArr) {
        return decompress(bArr, 0, bArr.length);
    }

    public static int getCopyLenBits(int i2) {
        for (int i3 = 11; i3 >= 4; i3--) {
            if ((POWER2[i3] & i2) != 0) {
                return 15 - i3;
            }
        }
        return 12;
    }

    private int readChunk() {
        this.pos = 0;
        int readShort = readShort(this.in);
        if (readShort == -1) {
            return -1;
        }
        int i2 = (readShort & 4095) + 1;
        if ((readShort & 28672) != 12288) {
            throw new IllegalArgumentException(String.format(Locale.ROOT, "Chunksize header A should be 0x3000, received 0x%04X", Integer.valueOf(readShort & 57344)));
        } else if (!((readShort & 32768) == 0)) {
            int i3 = 0;
            int i4 = 0;
            while (i3 < i2) {
                int read = this.in.read();
                i3++;
                if (read == -1) {
                    break;
                }
                for (int i5 = 0; i5 < 8 && i3 < i2; i5++) {
                    if ((POWER2[i5] & read) == 0) {
                        int read2 = this.in.read();
                        if (read2 == -1) {
                            return -1;
                        }
                        this.buf[i4] = (byte) read2;
                        i3++;
                        i4++;
                    } else {
                        int readShort2 = readShort(this.in);
                        if (readShort2 == -1) {
                            return -1;
                        }
                        i3 += 2;
                        int copyLenBits = getCopyLenBits(i4 - 1);
                        int i6 = i4 - ((readShort2 >> copyLenBits) + 1);
                        int i7 = (readShort2 & (POWER2[copyLenBits] - 1)) + 3 + i6;
                        while (i6 < i7) {
                            byte[] bArr = this.buf;
                            bArr[i4] = bArr[i6];
                            i6++;
                            i4++;
                        }
                    }
                }
            }
            return i4;
        } else if (this.in.read(this.buf, 0, i2) >= i2) {
            return i2;
        } else {
            throw new IllegalStateException(String.format(Locale.ROOT, "Not enough bytes read, expected %d", Integer.valueOf(i2)));
        }
    }

    @Override // java.io.InputStream
    public int available() {
        int i2 = this.len;
        if (i2 > 0) {
            return i2 - this.pos;
        }
        return 0;
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, java.io.InputStream
    public void close() {
        this.in.close();
    }

    @Override // java.io.InputStream
    public int read() {
        int i2 = this.len;
        if (i2 == -1) {
            return -1;
        }
        if (this.pos >= i2) {
            int readChunk = readChunk();
            this.len = readChunk;
            if (readChunk == -1) {
                return -1;
            }
        }
        byte[] bArr = this.buf;
        int i3 = this.pos;
        this.pos = i3 + 1;
        return bArr[i3] & 255;
    }

    public int readInt() {
        return readInt(this);
    }

    public int readShort() {
        return readShort(this);
    }

    @Override // java.io.InputStream
    public long skip(long j) {
        long j2 = j;
        while (j2 > 0) {
            if (this.pos >= this.len) {
                int readChunk = readChunk();
                this.len = readChunk;
                if (readChunk == -1) {
                    return -1;
                }
            }
            int min = (int) Math.min(j, (long) (this.len - this.pos));
            this.pos += min;
            j2 -= (long) min;
        }
        return j;
    }

    public static byte[] decompress(byte[] bArr, int i2, int i3) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        RLEDecompressingInputStream rLEDecompressingInputStream = new RLEDecompressingInputStream(new ByteArrayInputStream(bArr, i2, i3));
        IOUtils.copy(rLEDecompressingInputStream, byteArrayOutputStream);
        rLEDecompressingInputStream.close();
        byteArrayOutputStream.close();
        return byteArrayOutputStream.toByteArray();
    }

    private int readInt(InputStream inputStream) {
        int read;
        int read2;
        int read3;
        int read4 = inputStream.read();
        if (read4 == -1 || (read = inputStream.read()) == -1 || (read2 = inputStream.read()) == -1 || (read3 = inputStream.read()) == -1) {
            return -1;
        }
        return ((read3 & 255) << 24) | (read4 & 255) | ((read & 255) << 8) | ((read2 & 255) << 16);
    }

    private int readShort(InputStream inputStream) {
        int read;
        int read2 = inputStream.read();
        if (read2 == -1 || (read = inputStream.read()) == -1) {
            return -1;
        }
        return ((read & 255) << 8) | (read2 & 255);
    }

    @Override // java.io.InputStream
    public int read(byte[] bArr) {
        return read(bArr, 0, bArr.length);
    }

    @Override // java.io.InputStream
    public int read(byte[] bArr, int i2, int i3) {
        if (this.len == -1) {
            return -1;
        }
        int i4 = i2;
        int i5 = i3;
        while (i5 > 0) {
            if (this.pos >= this.len) {
                int readChunk = readChunk();
                this.len = readChunk;
                if (readChunk == -1) {
                    if (i4 > i2) {
                        return i4 - i2;
                    }
                    return -1;
                }
            }
            int min = Math.min(i5, this.len - this.pos);
            System.arraycopy(this.buf, this.pos, bArr, i4, min);
            this.pos += min;
            i5 -= min;
            i4 += min;
        }
        return i3;
    }
}
