package org.apache.poi.xssf.binary;

import java.io.InputStream;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.ss.util.CellAddress;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.CellRangeUtil;
import org.apache.poi.util.Internal;
import org.apache.poi.xssf.usermodel.XSSFRelation;

@Internal
public class XSSFBHyperlinksTable {
    public static final BitSet RECORDS;
    public final List<XSSFHyperlinkRecord> hyperlinkRecords = new ArrayList();
    public Map<String, String> relIdToHyperlink = new HashMap();

    public class HyperlinkSheetScraper extends XSSFBParser {
        public XSSFBCellRange hyperlinkCellRange = new XSSFBCellRange();
        public final StringBuilder xlWideStringBuffer = new StringBuilder();

        public HyperlinkSheetScraper(InputStream inputStream) {
            super(inputStream, XSSFBHyperlinksTable.RECORDS);
        }

        @Override // org.apache.poi.xssf.binary.XSSFBParser
        public void handleRecord(int i2, byte[] bArr) {
            if (i2 == XSSFBRecordType.BrtHLink.getId()) {
                this.hyperlinkCellRange = XSSFBCellRange.parse(bArr, 0, this.hyperlinkCellRange);
                this.xlWideStringBuffer.setLength(0);
                int readXLNullableWideString = XSSFBUtils.readXLNullableWideString(bArr, 16, this.xlWideStringBuffer) + 16;
                String sb = this.xlWideStringBuffer.toString();
                this.xlWideStringBuffer.setLength(0);
                int readXLWideString = XSSFBUtils.readXLWideString(bArr, readXLNullableWideString, this.xlWideStringBuffer) + readXLNullableWideString;
                String sb2 = this.xlWideStringBuffer.toString();
                this.xlWideStringBuffer.setLength(0);
                int readXLWideString2 = XSSFBUtils.readXLWideString(bArr, readXLWideString, this.xlWideStringBuffer) + readXLWideString;
                String sb3 = this.xlWideStringBuffer.toString();
                this.xlWideStringBuffer.setLength(0);
                XSSFBUtils.readXLWideString(bArr, readXLWideString2, this.xlWideStringBuffer);
                String sb4 = this.xlWideStringBuffer.toString();
                XSSFBCellRange xSSFBCellRange = this.hyperlinkCellRange;
                XSSFBHyperlinksTable.this.hyperlinkRecords.add(new XSSFHyperlinkRecord(new CellRangeAddress(xSSFBCellRange.firstRow, xSSFBCellRange.lastRow, xSSFBCellRange.firstCol, xSSFBCellRange.lastCol), sb, (sb2 == null || sb2.length() == 0) ? (String) XSSFBHyperlinksTable.this.relIdToHyperlink.get(sb) : sb2, sb3, sb4));
            }
        }
    }

    public static class TopLeftCellAddressComparator implements Comparator<CellAddress>, Serializable {
        public static final long serialVersionUID = 1;

        public TopLeftCellAddressComparator() {
        }

        public int compare(CellAddress cellAddress, CellAddress cellAddress2) {
            if (cellAddress.getRow() < cellAddress2.getRow()) {
                return -1;
            }
            if (cellAddress.getRow() > cellAddress2.getRow()) {
                return 1;
            }
            if (cellAddress.getColumn() < cellAddress2.getColumn()) {
                return -1;
            }
            if (cellAddress.getColumn() > cellAddress2.getColumn()) {
                return 1;
            }
            return 0;
        }
    }

    static {
        BitSet bitSet = new BitSet();
        RECORDS = bitSet;
        bitSet.set(XSSFBRecordType.BrtHLink.getId());
    }

    public XSSFBHyperlinksTable(PackagePart packagePart) {
        loadUrlsFromSheetRels(packagePart);
        new HyperlinkSheetScraper(packagePart.getInputStream()).parse();
    }

    private void loadUrlsFromSheetRels(PackagePart packagePart) {
        try {
            Iterator<PackageRelationship> it = packagePart.getRelationshipsByType(XSSFRelation.SHEET_HYPERLINKS.getRelation()).iterator();
            while (it.hasNext()) {
                PackageRelationship next = it.next();
                this.relIdToHyperlink.put(next.getId(), next.getTargetURI().toString());
            }
        } catch (InvalidFormatException unused) {
        }
    }

    public List<XSSFHyperlinkRecord> findHyperlinkRecord(CellAddress cellAddress) {
        CellRangeAddress cellRangeAddress = new CellRangeAddress(cellAddress.getRow(), cellAddress.getRow(), cellAddress.getColumn(), cellAddress.getColumn());
        ArrayList arrayList = null;
        for (XSSFHyperlinkRecord xSSFHyperlinkRecord : this.hyperlinkRecords) {
            if (CellRangeUtil.intersect(cellRangeAddress, xSSFHyperlinkRecord.getCellRangeAddress()) != 1) {
                if (arrayList == null) {
                    arrayList = new ArrayList();
                }
                arrayList.add(xSSFHyperlinkRecord);
            }
        }
        return arrayList;
    }

    public Map<CellAddress, List<XSSFHyperlinkRecord>> getHyperLinks() {
        TreeMap treeMap = new TreeMap(new TopLeftCellAddressComparator());
        for (XSSFHyperlinkRecord xSSFHyperlinkRecord : this.hyperlinkRecords) {
            CellAddress cellAddress = new CellAddress(xSSFHyperlinkRecord.getCellRangeAddress().getFirstRow(), xSSFHyperlinkRecord.getCellRangeAddress().getFirstColumn());
            List list = (List) treeMap.get(cellAddress);
            if (list == null) {
                list = new ArrayList();
            }
            list.add(xSSFHyperlinkRecord);
            treeMap.put(cellAddress, list);
        }
        return treeMap;
    }
}
