package org.apache.poi.xssf.eventusermodel;

import b.b.a.a.a;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.xml.parsers.ParserConfigurationException;
import org.apache.poi.POIXMLException;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.PackagePartName;
import org.apache.poi.openxml4j.opc.PackageRelationship;
import org.apache.poi.openxml4j.opc.PackageRelationshipCollection;
import org.apache.poi.openxml4j.opc.PackagingURIHelper;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.SAXHelper;
import org.apache.poi.xssf.model.CommentsTable;
import org.apache.poi.xssf.model.SharedStringsTable;
import org.apache.poi.xssf.model.StylesTable;
import org.apache.poi.xssf.model.ThemesTable;
import org.apache.poi.xssf.usermodel.XSSFDrawing;
import org.apache.poi.xssf.usermodel.XSSFRelation;
import org.apache.poi.xssf.usermodel.XSSFShape;
import org.apache.xmlbeans.XmlException;
import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;

public class XSSFReader {
    public static final POILogger LOGGER = POILogFactory.getLogger(XSSFReader.class);
    public static final Set<String> WORKSHEET_RELS = Collections.unmodifiableSet(new HashSet(Arrays.asList(XSSFRelation.WORKSHEET.getRelation(), XSSFRelation.CHARTSHEET.getRelation())));
    public OPCPackage pkg;
    public PackagePart workbookPart;

    public static class SheetIterator implements Iterator<InputStream> {
        public final Iterator<XSSFSheetRef> sheetIterator;
        public final Map<String, PackagePart> sheetMap;
        public XSSFSheetRef xssfSheetRef;

        public SheetIterator(PackagePart packagePart) {
            try {
                this.sheetMap = new HashMap();
                OPCPackage oPCPackage = packagePart.getPackage();
                Set<String> sheetRelationships = getSheetRelationships();
                Iterator<PackageRelationship> it = packagePart.getRelationships().iterator();
                while (it.hasNext()) {
                    PackageRelationship next = it.next();
                    if (sheetRelationships.contains(next.getRelationshipType())) {
                        this.sheetMap.put(next.getId(), oPCPackage.getPart(PackagingURIHelper.createPartName(next.getTargetURI())));
                    }
                }
                this.sheetIterator = createSheetIteratorFromWB(packagePart);
            } catch (InvalidFormatException e2) {
                throw new POIXMLException(e2);
            }
        }

        public Iterator<XSSFSheetRef> createSheetIteratorFromWB(PackagePart packagePart) {
            XMLSheetRefReader xMLSheetRefReader = new XMLSheetRefReader();
            try {
                XMLReader newXMLReader = SAXHelper.newXMLReader();
                newXMLReader.setContentHandler(xMLSheetRefReader);
                try {
                    newXMLReader.parse(new InputSource(packagePart.getInputStream()));
                    ArrayList arrayList = new ArrayList();
                    for (XSSFSheetRef xSSFSheetRef : xMLSheetRefReader.getSheetRefs()) {
                        String id = xSSFSheetRef.getId();
                        if (id != null && id.length() > 0) {
                            arrayList.add(xSSFSheetRef);
                        }
                    }
                    return arrayList.iterator();
                } catch (SAXException e2) {
                    throw new POIXMLException(e2);
                }
            } catch (ParserConfigurationException e3) {
                throw new POIXMLException(e3);
            } catch (SAXException e4) {
                throw new POIXMLException(e4);
            }
        }

        public List<XSSFShape> getShapes() {
            PackagePart sheetPart = getSheetPart();
            LinkedList linkedList = new LinkedList();
            try {
                PackageRelationshipCollection relationshipsByType = sheetPart.getRelationshipsByType(XSSFRelation.DRAWINGS.getRelation());
                for (int i2 = 0; i2 < relationshipsByType.size(); i2++) {
                    PackagePartName createPartName = PackagingURIHelper.createPartName(relationshipsByType.getRelationship(i2).getTargetURI());
                    PackagePart part = sheetPart.getPackage().getPart(createPartName);
                    if (part == null) {
                        POILogger pOILogger = XSSFReader.LOGGER;
                        pOILogger.log(5, "Missing drawing: " + createPartName + ". Skipping it.");
                    } else {
                        for (XSSFShape xSSFShape : new XSSFDrawing(part).getShapes()) {
                            linkedList.add(xSSFShape);
                        }
                    }
                }
                return linkedList;
            } catch (IOException | InvalidFormatException | XmlException unused) {
                return null;
            }
        }

        public CommentsTable getSheetComments() {
            PackagePart sheetPart = getSheetPart();
            try {
                PackageRelationshipCollection relationshipsByType = sheetPart.getRelationshipsByType(XSSFRelation.SHEET_COMMENTS.getRelation());
                if (relationshipsByType.size() > 0) {
                    return new CommentsTable(sheetPart.getPackage().getPart(PackagingURIHelper.createPartName(relationshipsByType.getRelationship(0).getTargetURI())));
                }
            } catch (IOException | InvalidFormatException unused) {
            }
            return null;
        }

        public String getSheetName() {
            return this.xssfSheetRef.getName();
        }

        public PackagePart getSheetPart() {
            return this.sheetMap.get(this.xssfSheetRef.getId());
        }

        public Set<String> getSheetRelationships() {
            return XSSFReader.WORKSHEET_RELS;
        }

        public boolean hasNext() {
            return this.sheetIterator.hasNext();
        }

        public void remove() {
            throw new IllegalStateException("Not supported");
        }

        @Override // java.util.Iterator
        public InputStream next() {
            XSSFSheetRef next = this.sheetIterator.next();
            this.xssfSheetRef = next;
            try {
                return this.sheetMap.get(next.getId()).getInputStream();
            } catch (IOException e2) {
                throw new POIXMLException(e2);
            }
        }
    }

    public static class XMLSheetRefReader extends DefaultHandler {
        public static final String ID = "id";
        public static final String NAME = "name";
        public static final String SHEET = "sheet";
        public final List<XSSFSheetRef> sheetRefs;

        public XMLSheetRefReader() {
            this.sheetRefs = new LinkedList();
        }

        public List<XSSFSheetRef> getSheetRefs() {
            return Collections.unmodifiableList(this.sheetRefs);
        }

        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void startElement(String str, String str2, String str3, Attributes attributes) {
            if (str2.equalsIgnoreCase(SHEET)) {
                String str4 = null;
                String str5 = null;
                for (int i2 = 0; i2 < attributes.getLength(); i2++) {
                    String localName = attributes.getLocalName(i2);
                    if (localName.equalsIgnoreCase("name")) {
                        str4 = attributes.getValue(i2);
                    } else if (localName.equalsIgnoreCase("id")) {
                        str5 = attributes.getValue(i2);
                    }
                    if (str4 != null && str5 != null) {
                        this.sheetRefs.add(new XSSFSheetRef(str5, str4));
                        return;
                    }
                }
            }
        }
    }

    public static final class XSSFSheetRef {
        public final String id;
        public final String name;

        public XSSFSheetRef(String str, String str2) {
            this.id = str;
            this.name = str2;
        }

        public String getId() {
            return this.id;
        }

        public String getName() {
            return this.name;
        }
    }

    public XSSFReader(OPCPackage oPCPackage) {
        this.pkg = oPCPackage;
        PackageRelationship relationship = oPCPackage.getRelationshipsByType("http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument").getRelationship(0);
        if (relationship != null) {
            this.workbookPart = this.pkg.getPart(relationship);
        } else if (this.pkg.getRelationshipsByType("http://purl.oclc.org/ooxml/officeDocument/relationships/officeDocument").getRelationship(0) != null) {
            throw new POIXMLException("Strict OOXML isn't currently supported, please see bug #57699");
        } else {
            throw new POIXMLException("OOXML file structure broken/invalid - no core document found!");
        }
    }

    public InputStream getSharedStringsData() {
        return XSSFRelation.SHARED_STRINGS.getContents(this.workbookPart);
    }

    public SharedStringsTable getSharedStringsTable() {
        ArrayList<PackagePart> partsByContentType = this.pkg.getPartsByContentType(XSSFRelation.SHARED_STRINGS.getContentType());
        if (partsByContentType.size() == 0) {
            return null;
        }
        return new SharedStringsTable(partsByContentType.get(0));
    }

    public InputStream getSheet(String str) {
        PackageRelationship relationship = this.workbookPart.getRelationship(str);
        if (relationship != null) {
            PackagePart part = this.pkg.getPart(PackagingURIHelper.createPartName(relationship.getTargetURI()));
            if (part != null) {
                return part.getInputStream();
            }
            throw new IllegalArgumentException(a.b("No data found for Sheet with r:id ", str));
        }
        throw new IllegalArgumentException(a.b("No Sheet found with r:id ", str));
    }

    public Iterator<InputStream> getSheetsData() {
        return new SheetIterator(this.workbookPart);
    }

    public InputStream getStylesData() {
        return XSSFRelation.STYLES.getContents(this.workbookPart);
    }

    public StylesTable getStylesTable() {
        ArrayList<PackagePart> partsByContentType = this.pkg.getPartsByContentType(XSSFRelation.STYLES.getContentType());
        if (partsByContentType.size() == 0) {
            return null;
        }
        StylesTable stylesTable = new StylesTable(partsByContentType.get(0));
        ArrayList<PackagePart> partsByContentType2 = this.pkg.getPartsByContentType(XSSFRelation.THEME.getContentType());
        if (partsByContentType2.size() != 0) {
            stylesTable.setTheme(new ThemesTable(partsByContentType2.get(0)));
        }
        return stylesTable;
    }

    public InputStream getThemesData() {
        return XSSFRelation.THEME.getContents(this.workbookPart);
    }

    public InputStream getWorkbookData() {
        return this.workbookPart.getInputStream();
    }
}
