package org.apache.poi.xssf.model;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.xssf.usermodel.XSSFRelation;
import org.apache.xmlbeans.XmlException;
import org.apache.xmlbeans.XmlOptions;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTRst;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTSst;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.SstDocument;

public class SharedStringsTable extends POIXMLDocumentPart {
    public static final XmlOptions options;
    public SstDocument _sstDoc;
    public int count;
    public final Map<String, Integer> stmap = new HashMap();
    public final List<CTRst> strings = new ArrayList();
    public int uniqueCount;

    static {
        XmlOptions xmlOptions = new XmlOptions();
        options = xmlOptions;
        xmlOptions.put(XmlOptions.SAVE_INNER);
        options.put(XmlOptions.SAVE_AGGRESSIVE_NAMESPACES);
        options.put(XmlOptions.SAVE_USE_DEFAULT_NAMESPACE);
        options.setSaveImplicitNamespaces(Collections.singletonMap("", XSSFRelation.NS_SPREADSHEETML));
    }

    public SharedStringsTable() {
        SstDocument newInstance = SstDocument.Factory.newInstance();
        this._sstDoc = newInstance;
        newInstance.addNewSst();
    }

    private String getKey(CTRst cTRst) {
        return cTRst.xmlText(options);
    }

    public int addEntry(CTRst cTRst) {
        String key = getKey(cTRst);
        this.count++;
        if (this.stmap.containsKey(key)) {
            return this.stmap.get(key).intValue();
        }
        this.uniqueCount++;
        CTRst addNewSi = this._sstDoc.getSst().addNewSi();
        addNewSi.set(cTRst);
        int size = this.strings.size();
        this.stmap.put(key, Integer.valueOf(size));
        this.strings.add(addNewSi);
        return size;
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void commit() {
        OutputStream outputStream = getPackagePart().getOutputStream();
        writeTo(outputStream);
        outputStream.close();
    }

    public int getCount() {
        return this.count;
    }

    public CTRst getEntryAt(int i2) {
        return this.strings.get(i2);
    }

    public List<CTRst> getItems() {
        return Collections.unmodifiableList(this.strings);
    }

    public int getUniqueCount() {
        return this.uniqueCount;
    }

    public void readFrom(InputStream inputStream) {
        try {
            SstDocument parse = SstDocument.Factory.parse(inputStream, POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
            this._sstDoc = parse;
            CTSst sst = parse.getSst();
            this.count = (int) sst.getCount();
            this.uniqueCount = (int) sst.getUniqueCount();
            CTRst[] siArray = sst.getSiArray();
            int i2 = 0;
            for (CTRst cTRst : siArray) {
                this.stmap.put(getKey(cTRst), Integer.valueOf(i2));
                this.strings.add(cTRst);
                i2++;
            }
        } catch (XmlException e2) {
            throw new IOException("unable to parse shared strings table", e2);
        }
    }

    public void writeTo(OutputStream outputStream) {
        XmlOptions xmlOptions = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
        xmlOptions.setSaveCDataLengthThreshold(1000000);
        xmlOptions.setSaveCDataEntityCountThreshold(-1);
        CTSst sst = this._sstDoc.getSst();
        sst.setCount((long) this.count);
        sst.setUniqueCount((long) this.uniqueCount);
        this._sstDoc.save(outputStream, xmlOptions);
    }

    public SharedStringsTable(PackagePart packagePart) {
        super(packagePart);
        readFrom(packagePart.getInputStream());
    }
}
