package org.apache.poi.xssf.streaming;

import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.SortedSet;
import java.util.TreeSet;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.util.SheetUtil;
import org.apache.poi.util.Internal;

@Internal
public class AutoSizeColumnTracker {
    public final DataFormatter dataFormatter = new DataFormatter();
    public final int defaultCharWidth;
    public final Map<Integer, ColumnWidthPair> maxColumnWidths = new HashMap();
    public boolean trackAllColumns = false;
    public final Set<Integer> untrackedColumns = new HashSet();

    public static class ColumnWidthPair {
        public double withSkipMergedCells;
        public double withUseMergedCells;

        public ColumnWidthPair() {
            this(-1.0d, -1.0d);
        }

        public double getMaxColumnWidth(boolean z) {
            return z ? this.withUseMergedCells : this.withSkipMergedCells;
        }

        public void setMaxColumnWidths(double d2, double d3) {
            double max = Math.max(this.withUseMergedCells, d3);
            this.withUseMergedCells = max;
            this.withSkipMergedCells = Math.max(max, d2);
        }

        public ColumnWidthPair(double d2, double d3) {
            this.withSkipMergedCells = d2;
            this.withUseMergedCells = d3;
        }
    }

    public AutoSizeColumnTracker(Sheet sheet) {
        this.defaultCharWidth = SheetUtil.getDefaultCharWidth(sheet.getWorkbook());
    }

    private boolean implicitlyTrackColumn(int i2) {
        if (this.untrackedColumns.contains(Integer.valueOf(i2))) {
            return false;
        }
        trackColumn(i2);
        return true;
    }

    private void implicitlyTrackColumnsInRow(Row row) {
        if (this.trackAllColumns) {
            Iterator it = row.iterator();
            while (it.hasNext()) {
                implicitlyTrackColumn(((Cell) it.next()).getColumnIndex());
            }
        }
    }

    private void updateColumnWidth(Cell cell, ColumnWidthPair columnWidthPair) {
        columnWidthPair.setMaxColumnWidths(SheetUtil.getCellWidth(cell, this.defaultCharWidth, this.dataFormatter, false), SheetUtil.getCellWidth(cell, this.defaultCharWidth, this.dataFormatter, true));
    }

    public int getBestFitColumnWidth(int i2, boolean z) {
        if (!this.maxColumnWidths.containsKey(Integer.valueOf(i2))) {
            if (!this.trackAllColumns) {
                IllegalStateException illegalStateException = new IllegalStateException("Column was never explicitly tracked and isAllColumnsTracked() is false (trackAllColumns() was never called or untrackAllColumns() was called after trackAllColumns() was called).");
                throw new IllegalStateException("Cannot get best fit column width on untracked column " + i2 + ". " + "Either explicitly track the column or track all columns.", illegalStateException);
            } else if (!implicitlyTrackColumn(i2)) {
                IllegalStateException illegalStateException2 = new IllegalStateException("Column was explicitly untracked after trackAllColumns() was called.");
                throw new IllegalStateException("Cannot get best fit column width on explicitly untracked column " + i2 + ". " + "Either explicitly track the column or track all columns.", illegalStateException2);
            }
        }
        return (int) (this.maxColumnWidths.get(Integer.valueOf(i2)).getMaxColumnWidth(z) * 256.0d);
    }

    public SortedSet<Integer> getTrackedColumns() {
        return Collections.unmodifiableSortedSet(new TreeSet(this.maxColumnWidths.keySet()));
    }

    public boolean isAllColumnsTracked() {
        return this.trackAllColumns;
    }

    public boolean isColumnTracked(int i2) {
        return this.trackAllColumns || this.maxColumnWidths.containsKey(Integer.valueOf(i2));
    }

    public void trackAllColumns() {
        this.trackAllColumns = true;
        this.untrackedColumns.clear();
    }

    public boolean trackColumn(int i2) {
        this.untrackedColumns.remove(Integer.valueOf(i2));
        if (this.maxColumnWidths.containsKey(Integer.valueOf(i2))) {
            return false;
        }
        this.maxColumnWidths.put(Integer.valueOf(i2), new ColumnWidthPair());
        return true;
    }

    public void trackColumns(Collection<Integer> collection) {
        for (Integer num : collection) {
            trackColumn(num.intValue());
        }
    }

    public void untrackAllColumns() {
        this.trackAllColumns = false;
        this.maxColumnWidths.clear();
        this.untrackedColumns.clear();
    }

    public boolean untrackColumn(int i2) {
        this.untrackedColumns.add(Integer.valueOf(i2));
        return this.maxColumnWidths.keySet().remove(Integer.valueOf(i2));
    }

    public boolean untrackColumns(Collection<Integer> collection) {
        this.untrackedColumns.addAll(collection);
        return this.maxColumnWidths.keySet().removeAll(collection);
    }

    public void updateColumnWidths(Row row) {
        implicitlyTrackColumnsInRow(row);
        if (this.maxColumnWidths.size() < row.getPhysicalNumberOfCells()) {
            for (Map.Entry<Integer, ColumnWidthPair> entry : this.maxColumnWidths.entrySet()) {
                Cell cell = row.getCell(entry.getKey().intValue());
                if (cell != null) {
                    updateColumnWidth(cell, entry.getValue());
                }
            }
            return;
        }
        Iterator it = row.iterator();
        while (it.hasNext()) {
            Cell cell2 = (Cell) it.next();
            int columnIndex = cell2.getColumnIndex();
            if (this.maxColumnWidths.containsKey(Integer.valueOf(columnIndex))) {
                updateColumnWidth(cell2, this.maxColumnWidths.get(Integer.valueOf(columnIndex)));
            }
        }
    }
}
