package org.apache.poi.xssf.streaming;

import java.awt.Dimension;
import java.io.IOException;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.usermodel.Picture;
import org.apache.poi.ss.usermodel.Shape;
import org.apache.poi.ss.util.ImageUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.xssf.usermodel.XSSFAnchor;
import org.apache.poi.xssf.usermodel.XSSFClientAnchor;
import org.apache.poi.xssf.usermodel.XSSFDrawing;
import org.apache.poi.xssf.usermodel.XSSFPicture;
import org.apache.poi.xssf.usermodel.XSSFPictureData;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.openxmlformats.schemas.drawingml.x2006.main.CTPositiveSize2D;
import org.openxmlformats.schemas.drawingml.x2006.main.CTShapeProperties;
import org.openxmlformats.schemas.drawingml.x2006.spreadsheetDrawing.CTPicture;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCol;

public final class SXSSFPicture implements Picture {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public static float DEFAULT_COLUMN_WIDTH = 9.140625f;
    public static final POILogger logger = POILogFactory.getLogger(SXSSFPicture.class);
    public final XSSFPicture _picture;
    public final SXSSFWorkbook _wb;

    public SXSSFPicture(SXSSFWorkbook sXSSFWorkbook, XSSFPicture xSSFPicture) {
        this._wb = sXSSFWorkbook;
        this._picture = xSSFPicture;
    }

    private float getColumnWidthInPixels(int i2) {
        CTCol column = getSheet().getColumnHelper().getColumn((long) i2, false);
        return ((float) ((column == null || !column.isSetWidth()) ? (double) DEFAULT_COLUMN_WIDTH : column.getWidth())) * 7.0017f;
    }

    public static Dimension getImageDimension(PackagePart packagePart, int i2) {
        try {
            return ImageUtils.getImageDimension(packagePart.getInputStream(), i2);
        } catch (IOException e2) {
            logger.log(5, e2);
            return new Dimension();
        }
    }

    private float getRowHeightInPixels(int i2) {
        SXSSFSheet sXSSFSheet = this._wb.getSXSSFSheet(getSheet());
        SXSSFRow row = sXSSFSheet.getRow(i2);
        return ((row != null ? row.getHeightInPoints() : sXSSFSheet.getDefaultRowHeightInPoints()) * 96.0f) / 72.0f;
    }

    @Internal
    public CTPicture getCTPicture() {
        return this._picture.getCTPicture();
    }

    public XSSFDrawing getDrawing() {
        return this._picture.getDrawing();
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public Shape getParent() {
        return this._picture.getParent();
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public String getShapeName() {
        return this._picture.getShapeName();
    }

    public CTShapeProperties getShapeProperties() {
        return getCTPicture().getSpPr();
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public boolean isNoFill() {
        return this._picture.isNoFill();
    }

    @Override // org.apache.poi.ss.usermodel.Picture
    public void resize() {
        resize(1.0d);
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public void setFillColor(int i2, int i3, int i4) {
        this._picture.setFillColor(i2, i3, i4);
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public void setLineStyleColor(int i2, int i3, int i4) {
        this._picture.setLineStyleColor(i2, i3, i4);
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public void setNoFill(boolean z) {
        this._picture.setNoFill(z);
    }

    @Override // org.apache.poi.ss.usermodel.Shape
    public XSSFAnchor getAnchor() {
        return this._picture.getAnchor();
    }

    @Override // org.apache.poi.ss.usermodel.Picture
    public XSSFClientAnchor getClientAnchor() {
        XSSFAnchor anchor = getAnchor();
        if (anchor instanceof XSSFClientAnchor) {
            return (XSSFClientAnchor) anchor;
        }
        return null;
    }

    @Override // org.apache.poi.ss.usermodel.Picture
    public XSSFPictureData getPictureData() {
        return this._picture.getPictureData();
    }

    @Override // org.apache.poi.ss.usermodel.Picture
    public XSSFSheet getSheet() {
        return this._picture.getSheet();
    }

    @Override // org.apache.poi.ss.usermodel.Picture
    public void resize(double d2) {
        XSSFClientAnchor clientAnchor = getClientAnchor();
        XSSFClientAnchor preferredSize = getPreferredSize(d2);
        int row2 = (preferredSize.getRow2() - preferredSize.getRow1()) + clientAnchor.getRow1();
        clientAnchor.setCol2((preferredSize.getCol2() - preferredSize.getCol1()) + clientAnchor.getCol1());
        clientAnchor.setDx1(0);
        clientAnchor.setDx2(preferredSize.getDx2());
        clientAnchor.setRow2(row2);
        clientAnchor.setDy1(0);
        clientAnchor.setDy2(preferredSize.getDy2());
    }

    @Override // org.apache.poi.ss.usermodel.Picture
    public XSSFClientAnchor getPreferredSize() {
        return getPreferredSize(1.0d);
    }

    @Override // org.apache.poi.ss.usermodel.Picture
    public Dimension getImageDimension() {
        return this._picture.getImageDimension();
    }

    public XSSFClientAnchor getPreferredSize(double d2) {
        double d3;
        XSSFClientAnchor clientAnchor = getClientAnchor();
        XSSFPictureData pictureData = getPictureData();
        Dimension imageDimension = getImageDimension(pictureData.getPackagePart(), pictureData.getPictureType());
        double width = imageDimension.getWidth() * d2;
        double height = imageDimension.getHeight() * d2;
        int col1 = clientAnchor.getCol1() - 1;
        float f2 = 0.0f;
        while (true) {
            d3 = (double) f2;
            if (d3 > width) {
                break;
            }
            col1++;
            f2 += getColumnWidthInPixels(col1);
        }
        clientAnchor.setCol2(col1);
        clientAnchor.setDx2((int) ((((double) getColumnWidthInPixels(col1)) - (d3 - width)) * 9525.0d));
        double d4 = NumericFunction.LOG_10_TO_BASE_e;
        int row1 = clientAnchor.getRow1() - 1;
        while (d4 <= height) {
            row1++;
            d4 += (double) getRowHeightInPixels(row1);
        }
        clientAnchor.setRow2(row1);
        clientAnchor.setDy2((int) ((((double) getRowHeightInPixels(row1)) - (d4 - height)) * 9525.0d));
        CTPositiveSize2D ext = getCTPicture().getSpPr().getXfrm().getExt();
        ext.setCx((long) (width * 9525.0d));
        ext.setCy((long) (height * 9525.0d));
        return clientAnchor;
    }

    @Override // org.apache.poi.ss.usermodel.Picture
    public void resize(double d2, double d3) {
        this._picture.resize(d2, d3);
    }

    @Override // org.apache.poi.ss.usermodel.Picture
    public XSSFClientAnchor getPreferredSize(double d2, double d3) {
        return this._picture.getPreferredSize(d2, d3);
    }
}
