package org.apache.poi.xssf.usermodel;

import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.javax.xml.namespace.QName;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.ss.usermodel.Chart;
import org.apache.poi.ss.usermodel.charts.AxisPosition;
import org.apache.poi.ss.usermodel.charts.ChartAxis;
import org.apache.poi.ss.usermodel.charts.ChartAxisFactory;
import org.apache.poi.ss.usermodel.charts.ChartData;
import org.apache.poi.util.Internal;
import org.apache.poi.util.Removal;
import org.apache.poi.xssf.usermodel.charts.XSSFCategoryAxis;
import org.apache.poi.xssf.usermodel.charts.XSSFChartAxis;
import org.apache.poi.xssf.usermodel.charts.XSSFChartDataFactory;
import org.apache.poi.xssf.usermodel.charts.XSSFChartLegend;
import org.apache.poi.xssf.usermodel.charts.XSSFDateAxis;
import org.apache.poi.xssf.usermodel.charts.XSSFManualLayout;
import org.apache.poi.xssf.usermodel.charts.XSSFValueAxis;
import org.apache.xmlbeans.XmlObject;
import org.apache.xmlbeans.XmlOptions;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTCatAx;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTChart;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTChartSpace;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTDateAx;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTPageMargins;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTPlotArea;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTPrintSettings;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTStrRef;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTTitle;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTTx;
import org.openxmlformats.schemas.drawingml.x2006.chart.CTValAx;
import org.openxmlformats.schemas.drawingml.x2006.chart.ChartSpaceDocument;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextBody;
import org.openxmlformats.schemas.drawingml.x2006.main.CTTextParagraph;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;

public final class XSSFChart extends POIXMLDocumentPart implements Chart, ChartAxisFactory {
    public List<XSSFChartAxis> axis = new ArrayList();
    public CTChart chart;
    public CTChartSpace chartSpace;
    public XSSFGraphicFrame frame;

    public XSSFChart() {
        createChart();
    }

    private void createChart() {
        CTChartSpace newInstance = CTChartSpace.Factory.newInstance();
        this.chartSpace = newInstance;
        CTChart addNewChart = newInstance.addNewChart();
        this.chart = addNewChart;
        addNewChart.addNewPlotArea().addNewLayout();
        this.chart.addNewPlotVisOnly().setVal(true);
        CTPrintSettings addNewPrintSettings = this.chartSpace.addNewPrintSettings();
        addNewPrintSettings.addNewHeaderFooter();
        CTPageMargins addNewPageMargins = addNewPrintSettings.addNewPageMargins();
        addNewPageMargins.setB(0.75d);
        addNewPageMargins.setL(0.7d);
        addNewPageMargins.setR(0.7d);
        addNewPageMargins.setT(0.75d);
        addNewPageMargins.setHeader(0.3d);
        addNewPageMargins.setFooter(0.3d);
        addNewPrintSettings.addNewPageSetup();
    }

    private boolean hasAxis() {
        CTPlotArea plotArea = this.chart.getPlotArea();
        return plotArea.sizeOfSerAxArray() + (plotArea.sizeOfDateAxArray() + (plotArea.sizeOfCatAxArray() + plotArea.sizeOfValAxArray())) > 0;
    }

    private void parseAxis() {
        parseCategoryAxis();
        parseDateAxis();
        parseValueAxis();
    }

    private void parseCategoryAxis() {
        for (CTCatAx cTCatAx : this.chart.getPlotArea().getCatAxArray()) {
            this.axis.add(new XSSFCategoryAxis(this, cTCatAx));
        }
    }

    private void parseDateAxis() {
        for (CTDateAx cTDateAx : this.chart.getPlotArea().getDateAxArray()) {
            this.axis.add(new XSSFDateAxis(this, cTDateAx));
        }
    }

    private void parseValueAxis() {
        for (CTValAx cTValAx : this.chart.getPlotArea().getValAxArray()) {
            this.axis.add(new XSSFValueAxis(this, cTValAx));
        }
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void commit() {
        XmlOptions xmlOptions = new XmlOptions(POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
        xmlOptions.setSaveSyntheticDocumentElement(new QName(CTChartSpace.type.getName().getNamespaceURI(), "chartSpace", "c"));
        OutputStream outputStream = getPackagePart().getOutputStream();
        this.chartSpace.save(outputStream, xmlOptions);
        outputStream.close();
    }

    @Override // org.apache.poi.ss.usermodel.Chart
    public void deleteLegend() {
        if (this.chart.isSetLegend()) {
            this.chart.unsetLegend();
        }
    }

    @Override // org.apache.poi.ss.usermodel.Chart
    public List<? extends XSSFChartAxis> getAxis() {
        if (this.axis.isEmpty() && hasAxis()) {
            parseAxis();
        }
        return this.axis;
    }

    @Internal
    public CTChart getCTChart() {
        return this.chart;
    }

    @Internal
    public CTChartSpace getCTChartSpace() {
        return this.chartSpace;
    }

    @Override // org.apache.poi.ss.usermodel.Chart
    public XSSFChart getChartAxisFactory() {
        return this;
    }

    public XSSFGraphicFrame getGraphicFrame() {
        return this.frame;
    }

    @Removal(version = "4.0")
    @Deprecated
    public XSSFRichTextString getTitle() {
        return getTitleText();
    }

    public String getTitleFormula() {
        if (!this.chart.isSetTitle()) {
            return null;
        }
        CTTitle title = this.chart.getTitle();
        if (!title.isSetTx()) {
            return null;
        }
        CTTx tx = title.getTx();
        if (!tx.isSetStrRef()) {
            return null;
        }
        return tx.getStrRef().getF();
    }

    public XSSFRichTextString getTitleText() {
        XmlObject[] selectPath;
        if (!this.chart.isSetTitle()) {
            return null;
        }
        CTTitle title = this.chart.getTitle();
        StringBuffer stringBuffer = new StringBuffer();
        for (XmlObject xmlObject : title.selectPath("declare namespace a='http://schemas.openxmlformats.org/drawingml/2006/main' .//a:t")) {
            NodeList childNodes = xmlObject.getDomNode().getChildNodes();
            int length = childNodes.getLength();
            for (int i2 = 0; i2 < length; i2++) {
                Node item = childNodes.item(i2);
                if (item instanceof Text) {
                    stringBuffer.append(item.getNodeValue());
                }
            }
        }
        return new XSSFRichTextString(stringBuffer.toString());
    }

    public boolean isPlotOnlyVisibleCells() {
        return this.chart.getPlotVisOnly().getVal();
    }

    @Override // org.apache.poi.ss.usermodel.Chart
    public void plot(ChartData chartData, ChartAxis... chartAxisArr) {
        chartData.fillChart(this, chartAxisArr);
    }

    public void setGraphicFrame(XSSFGraphicFrame xSSFGraphicFrame) {
        this.frame = xSSFGraphicFrame;
    }

    public void setPlotOnlyVisibleCells(boolean z) {
        this.chart.getPlotVisOnly().setVal(z);
    }

    @Removal(version = "4.0")
    @Deprecated
    public void setTitle(String str) {
    }

    public void setTitleFormula(String str) {
        CTTitle cTTitle;
        CTTx cTTx;
        CTStrRef cTStrRef;
        if (this.chart.isSetTitle()) {
            cTTitle = this.chart.getTitle();
        } else {
            cTTitle = this.chart.addNewTitle();
        }
        if (cTTitle.isSetTx()) {
            cTTx = cTTitle.getTx();
        } else {
            cTTx = cTTitle.addNewTx();
        }
        if (cTTx.isSetRich()) {
            cTTx.unsetRich();
        }
        if (cTTx.isSetStrRef()) {
            cTStrRef = cTTx.getStrRef();
        } else {
            cTStrRef = cTTx.addNewStrRef();
        }
        cTStrRef.setF(str);
    }

    public void setTitleText(String str) {
        CTTitle cTTitle;
        CTTx cTTx;
        CTTextBody cTTextBody;
        CTTextParagraph cTTextParagraph;
        if (this.chart.isSetTitle()) {
            cTTitle = this.chart.getTitle();
        } else {
            cTTitle = this.chart.addNewTitle();
        }
        if (cTTitle.isSetTx()) {
            cTTx = cTTitle.getTx();
        } else {
            cTTx = cTTitle.addNewTx();
        }
        if (cTTx.isSetStrRef()) {
            cTTx.unsetStrRef();
        }
        if (cTTx.isSetRich()) {
            cTTextBody = cTTx.getRich();
        } else {
            cTTextBody = cTTx.addNewRich();
            cTTextBody.addNewBodyPr();
        }
        if (cTTextBody.sizeOfPArray() > 0) {
            cTTextParagraph = cTTextBody.getPArray(0);
        } else {
            cTTextParagraph = cTTextBody.addNewP();
        }
        if (cTTextParagraph.sizeOfRArray() > 0) {
            cTTextParagraph.getRArray(0).setT(str);
        } else if (cTTextParagraph.sizeOfFldArray() > 0) {
            cTTextParagraph.getFldArray(0).setT(str);
        } else {
            cTTextParagraph.addNewR().setT(str);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v6, resolved type: org.apache.poi.xssf.usermodel.charts.XSSFChartAxis */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // org.apache.poi.ss.usermodel.charts.ChartAxisFactory
    public XSSFCategoryAxis createCategoryAxis(AxisPosition axisPosition) {
        XSSFCategoryAxis xSSFCategoryAxis = new XSSFCategoryAxis(this, (long) (this.axis.size() + 1), axisPosition);
        if (this.axis.size() == 1) {
            ChartAxis chartAxis = this.axis.get(0);
            chartAxis.crossAxis(xSSFCategoryAxis);
            xSSFCategoryAxis.crossAxis(chartAxis);
        }
        this.axis.add(xSSFCategoryAxis);
        return xSSFCategoryAxis;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v6, resolved type: org.apache.poi.xssf.usermodel.charts.XSSFChartAxis */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // org.apache.poi.ss.usermodel.charts.ChartAxisFactory
    public XSSFDateAxis createDateAxis(AxisPosition axisPosition) {
        XSSFDateAxis xSSFDateAxis = new XSSFDateAxis(this, (long) (this.axis.size() + 1), axisPosition);
        if (this.axis.size() == 1) {
            ChartAxis chartAxis = this.axis.get(0);
            chartAxis.crossAxis(xSSFDateAxis);
            xSSFDateAxis.crossAxis(chartAxis);
        }
        this.axis.add(xSSFDateAxis);
        return xSSFDateAxis;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v6, resolved type: org.apache.poi.xssf.usermodel.charts.XSSFChartAxis */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // org.apache.poi.ss.usermodel.charts.ChartAxisFactory
    public XSSFValueAxis createValueAxis(AxisPosition axisPosition) {
        XSSFValueAxis xSSFValueAxis = new XSSFValueAxis(this, (long) (this.axis.size() + 1), axisPosition);
        if (this.axis.size() == 1) {
            ChartAxis chartAxis = this.axis.get(0);
            chartAxis.crossAxis(xSSFValueAxis);
            xSSFValueAxis.crossAxis(chartAxis);
        }
        this.axis.add(xSSFValueAxis);
        return xSSFValueAxis;
    }

    @Override // org.apache.poi.ss.usermodel.Chart
    public XSSFChartDataFactory getChartDataFactory() {
        return XSSFChartDataFactory.getInstance();
    }

    @Override // org.apache.poi.ss.usermodel.charts.ManuallyPositionable
    public XSSFManualLayout getManualLayout() {
        return new XSSFManualLayout(this);
    }

    @Override // org.apache.poi.ss.usermodel.Chart
    public XSSFChartLegend getOrCreateLegend() {
        return new XSSFChartLegend(this);
    }

    public XSSFChart(PackagePart packagePart) {
        super(packagePart);
        CTChartSpace chartSpace2 = ChartSpaceDocument.Factory.parse(packagePart.getInputStream(), POIXMLTypeLoader.DEFAULT_XML_OPTIONS).getChartSpace();
        this.chartSpace = chartSpace2;
        this.chart = chartSpace2.getChart();
    }
}
