package org.apache.poi.xssf.usermodel;

import java.util.Arrays;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.ss.usermodel.Color;
import org.apache.poi.ss.usermodel.ExtendedColor;
import org.apache.poi.ss.usermodel.IndexedColors;
import org.apache.poi.util.Internal;
import org.apache.poi.util.Removal;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTColor;

public class XSSFColor extends ExtendedColor {
    public final CTColor ctColor;
    public final IndexedColorMap indexedColorMap;

    @Removal(version = "3.19")
    @Deprecated
    public XSSFColor(CTColor cTColor) {
        this(cTColor, new DefaultIndexedColorMap());
    }

    private boolean sameARGB(XSSFColor xSSFColor) {
        if (isRGB() != xSSFColor.isRGB()) {
            return false;
        }
        if (isRGB()) {
            return Arrays.equals(getARGB(), xSSFColor.getARGB());
        }
        return true;
    }

    private boolean sameAuto(XSSFColor xSSFColor) {
        return isAuto() == xSSFColor.isAuto();
    }

    private boolean sameIndexed(XSSFColor xSSFColor) {
        if (isIndexed() != xSSFColor.isIndexed()) {
            return false;
        }
        if (!isIndexed() || getIndexed() == xSSFColor.getIndexed()) {
            return true;
        }
        return false;
    }

    private boolean sameTheme(XSSFColor xSSFColor) {
        if (isThemed() != xSSFColor.isThemed()) {
            return false;
        }
        if (!isThemed() || getTheme() == xSSFColor.getTheme()) {
            return true;
        }
        return false;
    }

    private boolean sameTint(XSSFColor xSSFColor) {
        if (hasTint() != xSSFColor.hasTint()) {
            return false;
        }
        if (!hasTint() || getTint() == xSSFColor.getTint()) {
            return true;
        }
        return false;
    }

    public static XSSFColor toXSSFColor(Color color) {
        if (color == null || (color instanceof XSSFColor)) {
            return (XSSFColor) color;
        }
        throw new IllegalArgumentException("Only XSSFColor objects are supported");
    }

    public boolean equals(Object obj) {
        if (!(obj instanceof XSSFColor)) {
            return false;
        }
        XSSFColor xSSFColor = (XSSFColor) obj;
        if (!sameARGB(xSSFColor) || !sameTheme(xSSFColor) || !sameIndexed(xSSFColor) || !sameTint(xSSFColor) || !sameAuto(xSSFColor)) {
            return false;
        }
        return true;
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public byte[] getARGB() {
        byte[] rGBOrARGB = getRGBOrARGB();
        if (rGBOrARGB == null) {
            return null;
        }
        if (rGBOrARGB.length != 3) {
            return rGBOrARGB;
        }
        byte[] bArr = new byte[4];
        bArr[0] = -1;
        System.arraycopy(rGBOrARGB, 0, bArr, 1, 3);
        return bArr;
    }

    @Internal
    public CTColor getCTColor() {
        return this.ctColor;
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public short getIndex() {
        return (short) ((int) this.ctColor.getIndexed());
    }

    public short getIndexed() {
        return getIndex();
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public byte[] getIndexedRGB() {
        if (!isIndexed()) {
            return null;
        }
        IndexedColorMap indexedColorMap2 = this.indexedColorMap;
        if (indexedColorMap2 != null) {
            return indexedColorMap2.getRGB(getIndex());
        }
        return DefaultIndexedColorMap.getDefaultRGB(getIndex());
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public byte[] getRGB() {
        byte[] rGBOrARGB = getRGBOrARGB();
        if (rGBOrARGB == null) {
            return null;
        }
        if (rGBOrARGB.length != 4) {
            return rGBOrARGB;
        }
        byte[] bArr = new byte[3];
        System.arraycopy(rGBOrARGB, 1, bArr, 0, 3);
        return bArr;
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public byte[] getStoredRBG() {
        return this.ctColor.getRgb();
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public int getTheme() {
        return (int) this.ctColor.getTheme();
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public double getTint() {
        return this.ctColor.getTint();
    }

    public boolean hasAlpha() {
        if (this.ctColor.isSetRgb() && this.ctColor.getRgb().length == 4) {
            return true;
        }
        return false;
    }

    public boolean hasTint() {
        if (this.ctColor.isSetTint() && this.ctColor.getTint() != NumericFunction.LOG_10_TO_BASE_e) {
            return true;
        }
        return false;
    }

    public int hashCode() {
        return this.ctColor.toString().hashCode();
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public boolean isAuto() {
        return this.ctColor.getAuto();
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public boolean isIndexed() {
        return this.ctColor.isSetIndexed();
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public boolean isRGB() {
        return this.ctColor.isSetRgb();
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public boolean isThemed() {
        return this.ctColor.isSetTheme();
    }

    public void setAuto(boolean z) {
        this.ctColor.setAuto(z);
    }

    public void setIndexed(int i2) {
        this.ctColor.setIndexed((long) i2);
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public void setRGB(byte[] bArr) {
        this.ctColor.setRgb(bArr);
    }

    public void setTheme(int i2) {
        this.ctColor.setTheme((long) i2);
    }

    @Override // org.apache.poi.ss.usermodel.ExtendedColor
    public void setTint(double d2) {
        this.ctColor.setTint(d2);
    }

    public XSSFColor(CTColor cTColor, IndexedColorMap indexedColorMap2) {
        this.ctColor = cTColor;
        this.indexedColorMap = indexedColorMap2;
    }

    public XSSFColor() {
        this(CTColor.Factory.newInstance(), (IndexedColorMap) null);
    }

    public XSSFColor(org.apache.poi.java.awt.Color color) {
        this();
        setColor(color);
    }

    public XSSFColor(byte[] bArr, IndexedColorMap indexedColorMap2) {
        this(CTColor.Factory.newInstance(), indexedColorMap2);
        this.ctColor.setRgb(bArr);
    }

    public XSSFColor(IndexedColors indexedColors, IndexedColorMap indexedColorMap2) {
        this(CTColor.Factory.newInstance(), indexedColorMap2);
        this.ctColor.setIndexed((long) indexedColors.index);
    }
}
