package org.apache.poi.xssf.usermodel;

import java.util.Arrays;
import java.util.regex.Pattern;
import org.apache.poi.ss.usermodel.DataValidationConstraint;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.STDataValidationOperator;

public class XSSFDataValidationConstraint implements DataValidationConstraint {
    public static final String LIST_SEPARATOR = ",";
    public static final Pattern LIST_SPLIT_REGEX = Pattern.compile("\\s*,\\s*");
    public static final String QUOTE = "\"";
    public String[] explicitListOfValues;
    public String formula1;
    public String formula2;
    public int operator = -1;
    public int validationType = -1;

    public XSSFDataValidationConstraint(String[] strArr) {
        if (strArr == null || strArr.length == 0) {
            throw new IllegalArgumentException("List validation with explicit values must specify at least one value");
        }
        this.validationType = 3;
        setExplicitListValues(strArr);
        validate();
    }

    public static boolean isFormulaEmpty(String str) {
        return str == null || str.trim().length() == 0;
    }

    public static boolean isQuoted(String str) {
        return str.startsWith("\"") && str.endsWith("\"");
    }

    public static String removeLeadingEquals(String str) {
        return (!isFormulaEmpty(str) && str.charAt(0) == '=') ? str.substring(1) : str;
    }

    public static String unquote(String str) {
        return isQuoted(str) ? str.substring(1, str.length() - 1) : str;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public String[] getExplicitListValues() {
        return this.explicitListOfValues;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public String getFormula1() {
        return this.formula1;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public String getFormula2() {
        return this.formula2;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public int getOperator() {
        return this.operator;
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public int getValidationType() {
        return this.validationType;
    }

    public String prettyPrint() {
        StringBuilder sb = new StringBuilder();
        STDataValidationOperator.Enum r2 = XSSFDataValidation.operatorTypeMappings.get(Integer.valueOf(this.operator));
        sb.append(XSSFDataValidation.validationTypeMappings.get(Integer.valueOf(this.validationType)));
        sb.append(' ');
        int i2 = this.validationType;
        if (i2 != 0) {
            if (!(i2 == 3 || i2 == 7)) {
                sb.append(LIST_SEPARATOR);
                sb.append(r2);
                sb.append(", ");
            }
            if (this.validationType != 3 || this.explicitListOfValues == null) {
                sb.append("");
                sb.append(this.formula1);
                sb.append("");
                sb.append(' ');
            } else {
                sb.append("");
                sb.append(Arrays.asList(this.explicitListOfValues));
                sb.append("");
                sb.append(' ');
            }
            if (this.formula2 != null) {
                sb.append("");
                sb.append(this.formula2);
                sb.append("");
                sb.append(' ');
            }
        }
        return sb.toString();
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public void setExplicitListValues(String[] strArr) {
        this.explicitListOfValues = strArr;
        if (strArr != null && strArr.length > 0) {
            StringBuilder sb = new StringBuilder("\"");
            for (String str : strArr) {
                if (sb.length() > 1) {
                    sb.append(LIST_SEPARATOR);
                }
                sb.append(str);
            }
            sb.append("\"");
            setFormula1(sb.toString());
        }
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public void setFormula1(String str) {
        this.formula1 = removeLeadingEquals(str);
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public void setFormula2(String str) {
        this.formula2 = removeLeadingEquals(str);
    }

    @Override // org.apache.poi.ss.usermodel.DataValidationConstraint
    public void setOperator(int i2) {
        this.operator = i2;
    }

    public void validate() {
        int i2 = this.validationType;
        if (i2 != 0) {
            if (i2 == 3) {
                if (isFormulaEmpty(this.formula1)) {
                    throw new IllegalArgumentException("A valid formula or a list of values must be specified for list validation.");
                }
            } else if (isFormulaEmpty(this.formula1)) {
                throw new IllegalArgumentException("Formula is not specified. Formula is required for all validation types except explicit list validation.");
            } else if (this.validationType != 7) {
                int i3 = this.operator;
                if (i3 == -1) {
                    throw new IllegalArgumentException("This validation type requires an operator to be specified.");
                } else if ((i3 == 0 || i3 == 1) && isFormulaEmpty(this.formula2)) {
                    throw new IllegalArgumentException("Between and not between comparisons require two formulae to be specified.");
                }
            }
        }
    }

    public XSSFDataValidationConstraint(int i2, String str) {
        setFormula1(str);
        this.validationType = i2;
        validate();
    }

    public XSSFDataValidationConstraint(int i2, int i3, String str) {
        setFormula1(str);
        this.validationType = i2;
        this.operator = i3;
        validate();
    }

    public XSSFDataValidationConstraint(int i2, int i3, String str, String str2) {
        String str3;
        setFormula1(str);
        setFormula2(str2);
        this.validationType = i2;
        this.operator = i3;
        validate();
        if (3 == i2 && (str3 = this.formula1) != null && isQuoted(str3)) {
            this.explicitListOfValues = LIST_SPLIT_REGEX.split(unquote(this.formula1));
        }
    }
}
