package org.apache.poi.xssf.usermodel;

import b.b.a.a.a;
import org.apache.poi.ss.SpreadsheetVersion;
import org.apache.poi.ss.formula.FormulaParser;
import org.apache.poi.ss.formula.FormulaType;
import org.apache.poi.ss.formula.ptg.Ptg;
import org.apache.poi.ss.usermodel.Name;
import org.apache.poi.ss.util.AreaReference;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.xssf.eventusermodel.XSSFReader;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTDefinedName;

public final class XSSFName implements Name {
    public static final String BUILTIN_CONSOLIDATE_AREA = "_xlnm.Consolidate_Area";
    public static final String BUILTIN_CRITERIA = "_xlnm.Criteria:";
    public static final String BUILTIN_DATABASE = "_xlnm.Database";
    public static final String BUILTIN_EXTRACT = "_xlnm.Extract:";
    public static final String BUILTIN_FILTER_DB = "_xlnm._FilterDatabase";
    public static final String BUILTIN_PRINT_AREA = "_xlnm.Print_Area";
    public static final String BUILTIN_PRINT_TITLE = "_xlnm.Print_Titles";
    public static final String BUILTIN_SHEET_TITLE = "_xlnm.Sheet_Title";
    public CTDefinedName _ctName;
    public XSSFWorkbook _workbook;

    public XSSFName(CTDefinedName cTDefinedName, XSSFWorkbook xSSFWorkbook) {
        this._workbook = xSSFWorkbook;
        this._ctName = cTDefinedName;
    }

    public static void validateName(String str) {
        if (str.length() == 0) {
            throw new IllegalArgumentException("Name cannot be blank");
        } else if (str.length() > 255) {
            throw new IllegalArgumentException(a.b("Invalid name: '", str, "': cannot exceed 255 characters in length"));
        } else if (str.equalsIgnoreCase("R") || str.equalsIgnoreCase("C")) {
            throw new IllegalArgumentException(a.b("Invalid name: '", str, "': cannot be special shorthand R or C"));
        } else {
            char charAt = str.charAt(0);
            if (Character.isLetter(charAt) || "_\\".indexOf(charAt) != -1) {
                char[] charArray = str.toCharArray();
                for (char c : charArray) {
                    if (!(Character.isLetterOrDigit(c) || "_.\\".indexOf(c) != -1)) {
                        throw new IllegalArgumentException(a.b("Invalid name: '", str, "': name must be letter, digit, period, or underscore"));
                    }
                }
                if (str.matches("[A-Za-z]+\\d+")) {
                    try {
                        if (CellReference.cellReferenceIsWithinRange(str.replaceAll("\\d", ""), str.replaceAll("[A-Za-z]", ""), SpreadsheetVersion.EXCEL2007)) {
                            throw new IllegalArgumentException("Invalid name: '" + str + "': cannot be $A$1-style cell reference");
                        }
                    } catch (NumberFormatException unused) {
                    }
                }
                if (str.matches("[Rr]\\d+[Cc]\\d+")) {
                    throw new IllegalArgumentException(a.b("Invalid name: '", str, "': cannot be R1C1-style cell reference"));
                }
                return;
            }
            throw new IllegalArgumentException(a.b("Invalid name: '", str, "': first character must be underscore or a letter"));
        }
    }

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (!(obj instanceof XSSFName)) {
            return false;
        }
        return this._ctName.toString().equals(((XSSFName) obj).getCTName().toString());
    }

    public CTDefinedName getCTName() {
        return this._ctName;
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public String getComment() {
        return this._ctName.getComment();
    }

    public boolean getFunction() {
        return this._ctName.getFunction();
    }

    public int getFunctionGroupId() {
        return (int) this._ctName.getFunctionGroupId();
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public String getNameName() {
        return this._ctName.getName();
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public String getRefersToFormula() {
        String stringValue = this._ctName.getStringValue();
        if (stringValue == null || stringValue.length() < 1) {
            return null;
        }
        return stringValue;
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public int getSheetIndex() {
        if (this._ctName.isSetLocalSheetId()) {
            return (int) this._ctName.getLocalSheetId();
        }
        return -1;
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public String getSheetName() {
        if (!this._ctName.isSetLocalSheetId()) {
            return new AreaReference(getRefersToFormula()).getFirstCell().getSheetName();
        }
        return this._workbook.getSheetName((int) this._ctName.getLocalSheetId());
    }

    public int hashCode() {
        return this._ctName.toString().hashCode();
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public boolean isDeleted() {
        String refersToFormula = getRefersToFormula();
        if (refersToFormula == null) {
            return false;
        }
        return Ptg.doesFormulaReferToDeletedCell(FormulaParser.parse(refersToFormula, XSSFEvaluationWorkbook.create(this._workbook), FormulaType.NAMEDRANGE, getSheetIndex(), -1));
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public boolean isFunctionName() {
        return getFunction();
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public void setComment(String str) {
        this._ctName.setComment(str);
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public void setFunction(boolean z) {
        this._ctName.setFunction(z);
    }

    public void setFunctionGroupId(int i2) {
        this._ctName.setFunctionGroupId((long) i2);
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public void setNameName(String str) {
        validateName(str);
        String nameName = getNameName();
        int sheetIndex = getSheetIndex();
        for (XSSFName xSSFName : this._workbook.getNames(str)) {
            if (xSSFName.getSheetIndex() == sheetIndex && xSSFName != this) {
                StringBuilder b2 = a.b("The ");
                b2.append(sheetIndex == -1 ? "workbook" : XSSFReader.XMLSheetRefReader.SHEET);
                b2.append(" already contains this name: ");
                b2.append(str);
                throw new IllegalArgumentException(b2.toString());
            }
        }
        this._ctName.setName(str);
        this._workbook.updateName(this, nameName);
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public void setRefersToFormula(String str) {
        FormulaParser.parse(str, XSSFEvaluationWorkbook.create(this._workbook), FormulaType.NAMEDRANGE, getSheetIndex(), -1);
        this._ctName.setStringValue(str);
    }

    @Override // org.apache.poi.ss.usermodel.Name
    public void setSheetIndex(int i2) {
        int numberOfSheets = this._workbook.getNumberOfSheets() - 1;
        if (i2 < -1 || i2 > numberOfSheets) {
            StringBuilder a = a.a("Sheet index (", i2, ") is out of range");
            a.append(numberOfSheets == -1 ? "" : a.b(" (0..", numberOfSheets, ")"));
            throw new IllegalArgumentException(a.toString());
        } else if (i2 != -1) {
            this._ctName.setLocalSheetId((long) i2);
        } else if (this._ctName.isSetLocalSheetId()) {
            this._ctName.unsetLocalSheetId();
        }
    }
}
