package org.apache.poi.xssf.usermodel;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import org.apache.poi.POIXMLDocumentPart;
import org.apache.poi.POIXMLTypeLoader;
import org.apache.poi.openxml4j.opc.PackagePart;
import org.apache.poi.openxml4j.opc.internal.ZipHelper;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.usermodel.Table;
import org.apache.poi.ss.usermodel.TableStyleInfo;
import org.apache.poi.ss.util.AreaReference;
import org.apache.poi.ss.util.CellReference;
import org.apache.poi.util.Internal;
import org.apache.poi.util.StringUtil;
import org.apache.poi.xssf.usermodel.helpers.XSSFXmlColumnPr;
import org.apache.xmlbeans.XmlException;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTTable;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTTableColumn;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTTableColumns;
import org.openxmlformats.schemas.spreadsheetml.x2006.main.TableDocument;

public class XSSFTable extends POIXMLDocumentPart implements Table {
    public transient HashMap<String, Integer> columnMap;
    public transient String commonXPath;
    public transient CTTableColumn[] ctColumns;
    public CTTable ctTable;
    public transient CellReference endCellReference;
    public transient String name;
    public transient CellReference startCellReference;
    public transient String styleName;
    public transient List<XSSFXmlColumnPr> xmlColumnPr;

    public XSSFTable() {
        this.ctTable = CTTable.Factory.newInstance();
    }

    public static String caseInsensitive(String str) {
        return str.toUpperCase(Locale.ROOT);
    }

    private CTTableColumn[] getTableColumns() {
        if (this.ctColumns == null) {
            this.ctColumns = this.ctTable.getTableColumns().getTableColumnArray();
        }
        return this.ctColumns;
    }

    @Internal("Return type likely to change")
    public void addColumn() {
        CTTableColumns tableColumns = this.ctTable.getTableColumns();
        if (tableColumns == null) {
            tableColumns = this.ctTable.addNewTableColumns();
        }
        CTTableColumn addNewTableColumn = tableColumns.addNewTableColumn();
        long sizeOfTableColumnArray = (long) tableColumns.sizeOfTableColumnArray();
        tableColumns.setCount(sizeOfTableColumnArray);
        addNewTableColumn.setId(sizeOfTableColumnArray);
        updateHeaders();
    }

    @Override // org.apache.poi.POIXMLDocumentPart
    public void commit() {
        OutputStream outputStream = getPackagePart().getOutputStream();
        writeTo(outputStream);
        outputStream.close();
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public boolean contains(Cell cell) {
        if (cell != null && getSheetName().equals(cell.getSheet().getSheetName()) && cell.getRowIndex() >= getStartRowIndex() && cell.getRowIndex() <= getEndRowIndex() && cell.getColumnIndex() >= getStartColIndex() && cell.getColumnIndex() <= getEndColIndex()) {
            return true;
        }
        return false;
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public int findColumnIndex(String str) {
        if (str == null) {
            return -1;
        }
        if (this.columnMap == null) {
            this.columnMap = new HashMap<>((getTableColumns().length * 3) / 2);
            int i2 = 0;
            for (CTTableColumn cTTableColumn : getTableColumns()) {
                this.columnMap.put(caseInsensitive(cTTableColumn.getName()), Integer.valueOf(i2));
                i2++;
            }
        }
        Integer num = this.columnMap.get(caseInsensitive(str.replace("'", "")));
        if (num == null) {
            return -1;
        }
        return num.intValue();
    }

    @Internal(since = "POI 3.15 beta 3")
    public CTTable getCTTable() {
        return this.ctTable;
    }

    public AreaReference getCellReferences() {
        return new AreaReference(getStartCellReference(), getEndCellReference());
    }

    public String getCommonXpath() {
        if (this.commonXPath == null) {
            String[] strArr = new String[0];
            CTTableColumn[] tableColumns = getTableColumns();
            for (CTTableColumn cTTableColumn : tableColumns) {
                if (cTTableColumn.getXmlColumnPr() != null) {
                    String[] split = cTTableColumn.getXmlColumnPr().getXpath().split(ZipHelper.FORWARD_SLASH);
                    if (strArr.length == 0) {
                        strArr = split;
                    } else {
                        int min = Math.min(strArr.length, split.length);
                        int i2 = 0;
                        while (true) {
                            if (i2 >= min) {
                                break;
                            } else if (!strArr[i2].equals(split[i2])) {
                                strArr = (String[]) Arrays.asList(strArr).subList(0, i2).toArray(new String[0]);
                                break;
                            } else {
                                i2++;
                            }
                        }
                    }
                }
            }
            strArr[0] = "";
            this.commonXPath = StringUtil.join(strArr, ZipHelper.FORWARD_SLASH);
        }
        return this.commonXPath;
    }

    public String getDisplayName() {
        return this.ctTable.getDisplayName();
    }

    public CellReference getEndCellReference() {
        if (this.endCellReference == null) {
            setCellReferences();
        }
        return this.endCellReference;
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public int getEndColIndex() {
        return getEndCellReference().getCol();
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public int getEndRowIndex() {
        return getEndCellReference().getRow();
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public int getHeaderRowCount() {
        return (int) this.ctTable.getHeaderRowCount();
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public String getName() {
        if (this.name == null) {
            setName(this.ctTable.getName());
        }
        return this.name;
    }

    public long getNumberOfMappedColumns() {
        return this.ctTable.getTableColumns().getCount();
    }

    public long getNumerOfMappedColumns() {
        return getNumberOfMappedColumns();
    }

    public int getRowCount() {
        CellReference startCellReference2 = getStartCellReference();
        CellReference endCellReference2 = getEndCellReference();
        if (startCellReference2 == null || endCellReference2 == null) {
            return 0;
        }
        return (endCellReference2.getRow() - startCellReference2.getRow()) + 1;
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public String getSheetName() {
        return getXSSFSheet().getSheetName();
    }

    public CellReference getStartCellReference() {
        if (this.startCellReference == null) {
            setCellReferences();
        }
        return this.startCellReference;
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public int getStartColIndex() {
        return getStartCellReference().getCol();
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public int getStartRowIndex() {
        return getStartCellReference().getRow();
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public TableStyleInfo getStyle() {
        if (!this.ctTable.isSetTableStyleInfo()) {
            return null;
        }
        return new XSSFTableStyleInfo(((XSSFSheet) getParent()).getWorkbook().getStylesSource(), this.ctTable.getTableStyleInfo());
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public String getStyleName() {
        if (this.styleName == null && this.ctTable.isSetTableStyleInfo()) {
            setStyleName(this.ctTable.getTableStyleInfo().getName());
        }
        return this.styleName;
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public int getTotalsRowCount() {
        return (int) this.ctTable.getTotalsRowCount();
    }

    public XSSFSheet getXSSFSheet() {
        return (XSSFSheet) getParent();
    }

    public List<XSSFXmlColumnPr> getXmlColumnPrs() {
        if (this.xmlColumnPr == null) {
            this.xmlColumnPr = new ArrayList();
            CTTableColumn[] tableColumns = getTableColumns();
            for (CTTableColumn cTTableColumn : tableColumns) {
                if (cTTableColumn.getXmlColumnPr() != null) {
                    this.xmlColumnPr.add(new XSSFXmlColumnPr(this, cTTableColumn, cTTableColumn.getXmlColumnPr()));
                }
            }
        }
        return this.xmlColumnPr;
    }

    @Override // org.apache.poi.ss.usermodel.Table
    public boolean isHasTotalsRow() {
        return this.ctTable.getTotalsRowShown();
    }

    public boolean mapsTo(long j) {
        for (XSSFXmlColumnPr xSSFXmlColumnPr : getXmlColumnPrs()) {
            if (xSSFXmlColumnPr.getMapId() == j) {
                return true;
            }
        }
        return false;
    }

    public void readFrom(InputStream inputStream) {
        try {
            this.ctTable = TableDocument.Factory.parse(inputStream, POIXMLTypeLoader.DEFAULT_XML_OPTIONS).getTable();
        } catch (XmlException e2) {
            throw new IOException(e2.getLocalizedMessage());
        }
    }

    public void setCellReferences(AreaReference areaReference) {
        String formatAsString = areaReference.formatAsString();
        if (formatAsString.indexOf(33) != -1) {
            formatAsString = formatAsString.substring(formatAsString.indexOf(33) + 1);
        }
        this.ctTable.setRef(formatAsString);
        if (this.ctTable.isSetAutoFilter()) {
            this.ctTable.getAutoFilter().setRef(formatAsString);
        }
        updateReferences();
        updateHeaders();
    }

    public void setDisplayName(String str) {
        this.ctTable.setDisplayName(str);
    }

    public void setName(String str) {
        if (str == null) {
            this.ctTable.unsetName();
            this.name = null;
            return;
        }
        this.ctTable.setName(str);
        this.name = str;
    }

    public void setStyleName(String str) {
        if (str == null) {
            if (this.ctTable.isSetTableStyleInfo()) {
                this.ctTable.getTableStyleInfo().unsetName();
            }
            this.styleName = null;
            return;
        }
        if (!this.ctTable.isSetTableStyleInfo()) {
            this.ctTable.addNewTableStyleInfo();
        }
        this.ctTable.getTableStyleInfo().setName(str);
        this.styleName = str;
    }

    public void updateHeaders() {
        XSSFSheet xSSFSheet = (XSSFSheet) getParent();
        CellReference startCellReference2 = getStartCellReference();
        if (startCellReference2 != null) {
            int row = startCellReference2.getRow();
            int col = startCellReference2.getCol();
            XSSFRow row2 = xSSFSheet.getRow(row);
            DataFormatter dataFormatter = new DataFormatter();
            if (row2 != null && row2.getCTRow().validate()) {
                CTTableColumn[] tableColumnArray = getCTTable().getTableColumns().getTableColumnArray();
                for (CTTableColumn cTTableColumn : tableColumnArray) {
                    XSSFCell cell = row2.getCell(col);
                    if (cell != null) {
                        cTTableColumn.setName(dataFormatter.formatCellValue(cell));
                    }
                    col++;
                }
                this.ctColumns = null;
                this.columnMap = null;
                this.xmlColumnPr = null;
                this.commonXPath = null;
            }
        }
    }

    public void updateReferences() {
        this.startCellReference = null;
        this.endCellReference = null;
    }

    public void writeTo(OutputStream outputStream) {
        updateHeaders();
        TableDocument newInstance = TableDocument.Factory.newInstance();
        newInstance.setTable(this.ctTable);
        newInstance.save(outputStream, POIXMLTypeLoader.DEFAULT_XML_OPTIONS);
    }

    public XSSFTable(PackagePart packagePart) {
        super(packagePart);
        readFrom(packagePart.getInputStream());
    }

    private void setCellReferences() {
        String ref = this.ctTable.getRef();
        if (ref != null) {
            String[] split = ref.split(":", 2);
            String str = split[0];
            String str2 = split[1];
            this.startCellReference = new CellReference(str);
            this.endCellReference = new CellReference(str2);
        }
    }
}
