package org.apache.poi.xwpf.extractor;

import java.util.List;
import org.apache.poi.POIXMLDocument;
import org.apache.poi.POIXMLTextExtractor;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.apache.poi.ss.formula.ptg.GreaterThanPtg;
import org.apache.poi.xwpf.model.XWPFCommentsDecorator;
import org.apache.poi.xwpf.model.XWPFHeaderFooterPolicy;
import org.apache.poi.xwpf.usermodel.IBodyElement;
import org.apache.poi.xwpf.usermodel.ICell;
import org.apache.poi.xwpf.usermodel.XWPFDocument;
import org.apache.poi.xwpf.usermodel.XWPFHyperlink;
import org.apache.poi.xwpf.usermodel.XWPFHyperlinkRun;
import org.apache.poi.xwpf.usermodel.XWPFParagraph;
import org.apache.poi.xwpf.usermodel.XWPFRelation;
import org.apache.poi.xwpf.usermodel.XWPFRun;
import org.apache.poi.xwpf.usermodel.XWPFSDT;
import org.apache.poi.xwpf.usermodel.XWPFSDTCell;
import org.apache.poi.xwpf.usermodel.XWPFTable;
import org.apache.poi.xwpf.usermodel.XWPFTableCell;
import org.apache.poi.xwpf.usermodel.XWPFTableRow;
import org.openxmlformats.schemas.wordprocessingml.x2006.main.CTSectPr;

public class XWPFWordExtractor extends POIXMLTextExtractor {
    public static final XWPFRelation[] SUPPORTED_TYPES = {XWPFRelation.DOCUMENT, XWPFRelation.TEMPLATE, XWPFRelation.MACRO_DOCUMENT, XWPFRelation.MACRO_TEMPLATE_DOCUMENT};
    public XWPFDocument document;
    public boolean fetchHyperlinks;

    public XWPFWordExtractor(OPCPackage oPCPackage) {
        this(new XWPFDocument(oPCPackage));
    }

    private void appendTableText(StringBuffer stringBuffer, XWPFTable xWPFTable) {
        for (XWPFTableRow xWPFTableRow : xWPFTable.getRows()) {
            List<ICell> tableICells = xWPFTableRow.getTableICells();
            for (int i2 = 0; i2 < tableICells.size(); i2++) {
                ICell iCell = tableICells.get(i2);
                if (iCell instanceof XWPFTableCell) {
                    stringBuffer.append(((XWPFTableCell) iCell).getTextRecursively());
                } else if (iCell instanceof XWPFSDTCell) {
                    stringBuffer.append(((XWPFSDTCell) iCell).getContent().getText());
                }
                if (i2 < tableICells.size() - 1) {
                    stringBuffer.append("\t");
                }
            }
            stringBuffer.append('\n');
        }
    }

    private void extractFooters(StringBuffer stringBuffer, XWPFHeaderFooterPolicy xWPFHeaderFooterPolicy) {
        if (xWPFHeaderFooterPolicy != null) {
            if (xWPFHeaderFooterPolicy.getFirstPageFooter() != null) {
                stringBuffer.append(xWPFHeaderFooterPolicy.getFirstPageFooter().getText());
            }
            if (xWPFHeaderFooterPolicy.getEvenPageFooter() != null) {
                stringBuffer.append(xWPFHeaderFooterPolicy.getEvenPageFooter().getText());
            }
            if (xWPFHeaderFooterPolicy.getDefaultFooter() != null) {
                stringBuffer.append(xWPFHeaderFooterPolicy.getDefaultFooter().getText());
            }
        }
    }

    private void extractHeaders(StringBuffer stringBuffer, XWPFHeaderFooterPolicy xWPFHeaderFooterPolicy) {
        if (xWPFHeaderFooterPolicy != null) {
            if (xWPFHeaderFooterPolicy.getFirstPageHeader() != null) {
                stringBuffer.append(xWPFHeaderFooterPolicy.getFirstPageHeader().getText());
            }
            if (xWPFHeaderFooterPolicy.getEvenPageHeader() != null) {
                stringBuffer.append(xWPFHeaderFooterPolicy.getEvenPageHeader().getText());
            }
            if (xWPFHeaderFooterPolicy.getDefaultHeader() != null) {
                stringBuffer.append(xWPFHeaderFooterPolicy.getDefaultHeader().getText());
            }
        }
    }

    public static void main(String[] strArr) {
        if (strArr.length < 1) {
            System.err.println("Use:");
            System.err.println("  XWPFWordExtractor <filename.docx>");
            System.exit(1);
        }
        XWPFWordExtractor xWPFWordExtractor = new XWPFWordExtractor(POIXMLDocument.openPackage(strArr[0]));
        System.out.println(xWPFWordExtractor.getText());
        xWPFWordExtractor.close();
    }

    public void appendBodyElementText(StringBuffer stringBuffer, IBodyElement iBodyElement) {
        if (iBodyElement instanceof XWPFParagraph) {
            appendParagraphText(stringBuffer, (XWPFParagraph) iBodyElement);
        } else if (iBodyElement instanceof XWPFTable) {
            appendTableText(stringBuffer, (XWPFTable) iBodyElement);
        } else if (iBodyElement instanceof XWPFSDT) {
            stringBuffer.append(((XWPFSDT) iBodyElement).getContent().getText());
        }
    }

    public void appendParagraphText(StringBuffer stringBuffer, XWPFParagraph xWPFParagraph) {
        XWPFHeaderFooterPolicy xWPFHeaderFooterPolicy;
        XWPFHyperlink hyperlink;
        CTSectPr sectPr = xWPFParagraph.getCTP().getPPr() != null ? xWPFParagraph.getCTP().getPPr().getSectPr() : null;
        if (sectPr != null) {
            xWPFHeaderFooterPolicy = new XWPFHeaderFooterPolicy(this.document, sectPr);
            extractHeaders(stringBuffer, xWPFHeaderFooterPolicy);
        } else {
            xWPFHeaderFooterPolicy = null;
        }
        for (XWPFRun xWPFRun : xWPFParagraph.getRuns()) {
            stringBuffer.append(xWPFRun);
            if ((xWPFRun instanceof XWPFHyperlinkRun) && this.fetchHyperlinks && (hyperlink = ((XWPFHyperlinkRun) xWPFRun).getHyperlink(this.document)) != null) {
                stringBuffer.append(" <");
                stringBuffer.append(hyperlink.getURL());
                stringBuffer.append(GreaterThanPtg.GREATERTHAN);
            }
        }
        String commentText = new XWPFCommentsDecorator(xWPFParagraph, null).getCommentText();
        if (commentText.length() > 0) {
            stringBuffer.append(commentText);
            stringBuffer.append('\n');
        }
        String footnoteText = xWPFParagraph.getFootnoteText();
        if (footnoteText != null && footnoteText.length() > 0) {
            stringBuffer.append(footnoteText);
            stringBuffer.append('\n');
        }
        if (sectPr != null) {
            extractFooters(stringBuffer, xWPFHeaderFooterPolicy);
        }
    }

    @Override // org.apache.poi.POITextExtractor
    public String getText() {
        StringBuffer stringBuffer = new StringBuffer();
        XWPFHeaderFooterPolicy headerFooterPolicy = this.document.getHeaderFooterPolicy();
        extractHeaders(stringBuffer, headerFooterPolicy);
        for (IBodyElement iBodyElement : this.document.getBodyElements()) {
            appendBodyElementText(stringBuffer, iBodyElement);
            stringBuffer.append('\n');
        }
        extractFooters(stringBuffer, headerFooterPolicy);
        return stringBuffer.toString();
    }

    public void setFetchHyperlinks(boolean z) {
        this.fetchHyperlinks = z;
    }

    public XWPFWordExtractor(XWPFDocument xWPFDocument) {
        super(xWPFDocument);
        this.fetchHyperlinks = false;
        this.document = xWPFDocument;
    }
}
