package org.apache.xerces.dom;

import org.w3c.dom.DOMException;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.traversal.NodeFilter;
import org.w3c.dom.traversal.TreeWalker;

public class TreeWalkerImpl implements TreeWalker {
    public Node fCurrentNode;
    public boolean fEntityReferenceExpansion = false;
    public NodeFilter fNodeFilter;
    public Node fRoot;
    public boolean fUseIsSameNode;
    public int fWhatToShow = -1;

    public TreeWalkerImpl(Node node, int i2, NodeFilter nodeFilter, boolean z) {
        this.fCurrentNode = node;
        this.fRoot = node;
        this.fUseIsSameNode = useIsSameNode(node);
        this.fWhatToShow = i2;
        this.fNodeFilter = nodeFilter;
        this.fEntityReferenceExpansion = z;
    }

    private boolean isSameNode(Node node, Node node2) {
        return this.fUseIsSameNode ? node.isSameNode(node2) : node == node2;
    }

    private boolean useIsSameNode(Node node) {
        if (node instanceof NodeImpl) {
            return false;
        }
        Document ownerDocument = node.getNodeType() == 9 ? (Document) node : node.getOwnerDocument();
        return ownerDocument != null && ownerDocument.getImplementation().hasFeature("Core", "3.0");
    }

    public short acceptNode(Node node) {
        if (this.fNodeFilter == null) {
            return ((1 << (node.getNodeType() - 1)) & this.fWhatToShow) != 0 ? (short) 1 : 3;
        } else if ((this.fWhatToShow & (1 << (node.getNodeType() - 1))) != 0) {
            return this.fNodeFilter.acceptNode(node);
        } else {
            return 3;
        }
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public Node firstChild() {
        Node node = this.fCurrentNode;
        if (node == null) {
            return null;
        }
        Node firstChild = getFirstChild(node);
        if (firstChild != null) {
            this.fCurrentNode = firstChild;
        }
        return firstChild;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public Node getCurrentNode() {
        return this.fCurrentNode;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public boolean getExpandEntityReferences() {
        return this.fEntityReferenceExpansion;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public NodeFilter getFilter() {
        return this.fNodeFilter;
    }

    public Node getFirstChild(Node node) {
        Node firstChild;
        if (node == null) {
            return null;
        }
        if ((!this.fEntityReferenceExpansion && node.getNodeType() == 5) || (firstChild = node.getFirstChild()) == null) {
            return null;
        }
        short acceptNode = acceptNode(firstChild);
        if (acceptNode == 1) {
            return firstChild;
        }
        if (acceptNode != 3 || !firstChild.hasChildNodes()) {
            return getNextSibling(firstChild, node);
        }
        Node firstChild2 = getFirstChild(firstChild);
        return firstChild2 == null ? getNextSibling(firstChild, node) : firstChild2;
    }

    public Node getLastChild(Node node) {
        Node lastChild;
        if (node == null) {
            return null;
        }
        if ((!this.fEntityReferenceExpansion && node.getNodeType() == 5) || (lastChild = node.getLastChild()) == null) {
            return null;
        }
        short acceptNode = acceptNode(lastChild);
        if (acceptNode == 1) {
            return lastChild;
        }
        if (acceptNode != 3 || !lastChild.hasChildNodes()) {
            return getPreviousSibling(lastChild, node);
        }
        Node lastChild2 = getLastChild(lastChild);
        return lastChild2 == null ? getPreviousSibling(lastChild, node) : lastChild2;
    }

    public Node getNextSibling(Node node) {
        return getNextSibling(node, this.fRoot);
    }

    public Node getNextSibling(Node node, Node node2) {
        if (node == null || isSameNode(node, node2)) {
            return null;
        }
        Node nextSibling = node.getNextSibling();
        if (nextSibling == null) {
            Node parentNode = node.getParentNode();
            if (parentNode == null || isSameNode(parentNode, node2) || acceptNode(parentNode) != 3) {
                return null;
            }
            return getNextSibling(parentNode, node2);
        }
        short acceptNode = acceptNode(nextSibling);
        if (acceptNode == 1) {
            return nextSibling;
        }
        if (acceptNode != 3) {
            return getNextSibling(nextSibling, node2);
        }
        Node firstChild = getFirstChild(nextSibling);
        return firstChild == null ? getNextSibling(nextSibling, node2) : firstChild;
    }

    public Node getParentNode(Node node) {
        Node parentNode;
        if (node == null || isSameNode(node, this.fRoot) || (parentNode = node.getParentNode()) == null) {
            return null;
        }
        return acceptNode(parentNode) == 1 ? parentNode : getParentNode(parentNode);
    }

    public Node getPreviousSibling(Node node) {
        return getPreviousSibling(node, this.fRoot);
    }

    public Node getPreviousSibling(Node node, Node node2) {
        if (node == null || isSameNode(node, node2)) {
            return null;
        }
        Node previousSibling = node.getPreviousSibling();
        if (previousSibling == null) {
            Node parentNode = node.getParentNode();
            if (parentNode == null || isSameNode(parentNode, node2) || acceptNode(parentNode) != 3) {
                return null;
            }
            return getPreviousSibling(parentNode, node2);
        }
        short acceptNode = acceptNode(previousSibling);
        if (acceptNode == 1) {
            return previousSibling;
        }
        if (acceptNode != 3) {
            return getPreviousSibling(previousSibling, node2);
        }
        Node lastChild = getLastChild(previousSibling);
        return lastChild == null ? getPreviousSibling(previousSibling, node2) : lastChild;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public Node getRoot() {
        return this.fRoot;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public int getWhatToShow() {
        return this.fWhatToShow;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public Node lastChild() {
        Node node = this.fCurrentNode;
        if (node == null) {
            return null;
        }
        Node lastChild = getLastChild(node);
        if (lastChild != null) {
            this.fCurrentNode = lastChild;
        }
        return lastChild;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public Node nextNode() {
        Node nextSibling;
        Node node = this.fCurrentNode;
        if (node == null) {
            return null;
        }
        Node firstChild = getFirstChild(node);
        if (firstChild != null) {
            this.fCurrentNode = firstChild;
            return firstChild;
        }
        Node nextSibling2 = getNextSibling(this.fCurrentNode);
        if (nextSibling2 != null) {
            this.fCurrentNode = nextSibling2;
            return nextSibling2;
        }
        Node node2 = this.fCurrentNode;
        do {
            node2 = getParentNode(node2);
            if (node2 == null) {
                return null;
            }
            nextSibling = getNextSibling(node2);
        } while (nextSibling == null);
        this.fCurrentNode = nextSibling;
        return nextSibling;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public Node nextSibling() {
        Node node = this.fCurrentNode;
        if (node == null) {
            return null;
        }
        Node nextSibling = getNextSibling(node);
        if (nextSibling != null) {
            this.fCurrentNode = nextSibling;
        }
        return nextSibling;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public Node parentNode() {
        Node node = this.fCurrentNode;
        if (node == null) {
            return null;
        }
        Node parentNode = getParentNode(node);
        if (parentNode != null) {
            this.fCurrentNode = parentNode;
        }
        return parentNode;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public Node previousNode() {
        Node node = this.fCurrentNode;
        if (node == null) {
            return null;
        }
        Node previousSibling = getPreviousSibling(node);
        if (previousSibling == null) {
            Node parentNode = getParentNode(this.fCurrentNode);
            if (parentNode == null) {
                return null;
            }
            this.fCurrentNode = parentNode;
            return parentNode;
        }
        Node lastChild = getLastChild(previousSibling);
        Node node2 = lastChild;
        while (lastChild != null) {
            node2 = lastChild;
            lastChild = getLastChild(lastChild);
        }
        if (node2 != null) {
            this.fCurrentNode = node2;
            return node2;
        }
        this.fCurrentNode = previousSibling;
        return previousSibling;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public Node previousSibling() {
        Node node = this.fCurrentNode;
        if (node == null) {
            return null;
        }
        Node previousSibling = getPreviousSibling(node);
        if (previousSibling != null) {
            this.fCurrentNode = previousSibling;
        }
        return previousSibling;
    }

    @Override // org.w3c.dom.traversal.TreeWalker
    public void setCurrentNode(Node node) {
        if (node != null) {
            this.fCurrentNode = node;
            return;
        }
        throw new DOMException(9, DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "NOT_SUPPORTED_ERR", null));
    }

    public void setWhatShow(int i2) {
        this.fWhatToShow = i2;
    }
}
