package org.apache.xerces.impl.dtd;

import java.io.IOException;
import org.apache.xerces.impl.Constants;
import org.apache.xerces.impl.RevalidationHandler;
import org.apache.xerces.impl.XMLEntityManager;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.impl.dv.DTDDVFactory;
import org.apache.xerces.impl.dv.DatatypeValidator;
import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.validation.ValidationManager;
import org.apache.xerces.impl.validation.ValidationState;
import org.apache.xerces.impl.xs.SchemaSymbols;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.util.XMLChar;
import org.apache.xerces.util.XMLSymbols;
import org.apache.xerces.xni.Augmentations;
import org.apache.xerces.xni.NamespaceContext;
import org.apache.xerces.xni.QName;
import org.apache.xerces.xni.XMLAttributes;
import org.apache.xerces.xni.XMLDocumentHandler;
import org.apache.xerces.xni.XMLLocator;
import org.apache.xerces.xni.XMLResourceIdentifier;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.grammars.Grammar;
import org.apache.xerces.xni.grammars.XMLGrammarPool;
import org.apache.xerces.xni.parser.XMLComponent;
import org.apache.xerces.xni.parser.XMLComponentManager;
import org.apache.xerces.xni.parser.XMLConfigurationException;
import org.apache.xerces.xni.parser.XMLDocumentFilter;
import org.apache.xerces.xni.parser.XMLDocumentSource;
import org.apache.xmlbeans.impl.jam.xml.JamXmlElements;

public class XMLDTDValidator implements XMLComponent, XMLDocumentFilter, XMLDTDValidatorFilter, RevalidationHandler {
    public static final String BALANCE_SYNTAX_TREES = "http://apache.org/xml/features/validation/balance-syntax-trees";
    public static final String DATATYPE_VALIDATOR_FACTORY = "http://apache.org/xml/properties/internal/datatype-validator-factory";
    public static final boolean DEBUG_ATTRIBUTES = false;
    public static final boolean DEBUG_ELEMENT_CHILDREN = false;
    public static final String DYNAMIC_VALIDATION = "http://apache.org/xml/features/validation/dynamic";
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final Boolean[] FEATURE_DEFAULTS;
    public static final String GRAMMAR_POOL = "http://apache.org/xml/properties/internal/grammar-pool";
    public static final String NAMESPACES = "http://xml.org/sax/features/namespaces";
    public static final String PARSER_SETTINGS = "http://apache.org/xml/features/internal/parser-settings";
    public static final Object[] PROPERTY_DEFAULTS = {null, null, null, null, null};
    public static final String[] RECOGNIZED_FEATURES = {"http://xml.org/sax/features/namespaces", "http://xml.org/sax/features/validation", "http://apache.org/xml/features/validation/dynamic", "http://apache.org/xml/features/validation/balance-syntax-trees"};
    public static final String[] RECOGNIZED_PROPERTIES = {"http://apache.org/xml/properties/internal/symbol-table", "http://apache.org/xml/properties/internal/error-reporter", "http://apache.org/xml/properties/internal/grammar-pool", "http://apache.org/xml/properties/internal/datatype-validator-factory", "http://apache.org/xml/properties/internal/validation-manager"};
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public static final int TOP_LEVEL_SCOPE = -1;
    public static final String VALIDATION = "http://xml.org/sax/features/validation";
    public static final String VALIDATION_MANAGER = "http://apache.org/xml/properties/internal/validation-manager";
    public static final String WARN_ON_DUPLICATE_ATTDEF = "http://apache.org/xml/features/validation/warn-on-duplicate-attdef";
    public boolean fBalanceSyntaxTrees;
    public final StringBuffer fBuffer;
    public int[] fContentSpecTypeStack;
    public int fCurrentContentSpecType;
    public final QName fCurrentElement;
    public int fCurrentElementIndex;
    public DTDGrammar fDTDGrammar;
    public boolean fDTDValidation;
    public DTDDVFactory fDatatypeValidatorFactory;
    public XMLLocator fDocLocation;
    public XMLDocumentHandler fDocumentHandler;
    public XMLDocumentSource fDocumentSource;
    public boolean fDynamicValidation;
    public QName[] fElementChildren;
    public int fElementChildrenLength;
    public int[] fElementChildrenOffsetStack;
    public int fElementDepth;
    public int[] fElementIndexStack;
    public QName[] fElementQNamePartsStack;
    public final XMLEntityDecl fEntityDecl;
    public XMLErrorReporter fErrorReporter;
    public DTDGrammarBucket fGrammarBucket;
    public XMLGrammarPool fGrammarPool;
    public boolean fInCDATASection;
    public boolean fInElementContent;
    public NamespaceContext fNamespaceContext = null;
    public boolean fNamespaces;
    public boolean fPerformValidation;
    public final QName fRootElement;
    public String fSchemaType;
    public boolean fSeenDoctypeDecl;
    public boolean fSeenRootElement;
    public SymbolTable fSymbolTable;
    public final XMLAttributeDecl fTempAttDecl;
    public XMLElementDecl fTempElementDecl;
    public final QName fTempQName;
    public DatatypeValidator fValENTITIES;
    public DatatypeValidator fValENTITY;
    public DatatypeValidator fValID;
    public DatatypeValidator fValIDRef;
    public DatatypeValidator fValIDRefs;
    public DatatypeValidator fValNMTOKEN;
    public DatatypeValidator fValNMTOKENS;
    public DatatypeValidator fValNOTATION;
    public boolean fValidation;
    public ValidationManager fValidationManager = null;
    public final ValidationState fValidationState = new ValidationState();
    public boolean fWarnDuplicateAttdef;

    static {
        Boolean bool = Boolean.FALSE;
        FEATURE_DEFAULTS = new Boolean[]{null, null, bool, bool};
    }

    public XMLDTDValidator() {
        int i2 = 0;
        this.fSeenDoctypeDecl = false;
        this.fCurrentElement = new QName();
        this.fCurrentElementIndex = -1;
        this.fCurrentContentSpecType = -1;
        this.fRootElement = new QName();
        this.fInCDATASection = false;
        this.fElementIndexStack = new int[8];
        this.fContentSpecTypeStack = new int[8];
        this.fElementQNamePartsStack = new QName[8];
        this.fElementChildren = new QName[32];
        this.fElementChildrenLength = 0;
        this.fElementChildrenOffsetStack = new int[32];
        this.fElementDepth = -1;
        this.fSeenRootElement = false;
        this.fInElementContent = false;
        this.fTempElementDecl = new XMLElementDecl();
        this.fTempAttDecl = new XMLAttributeDecl();
        this.fEntityDecl = new XMLEntityDecl();
        this.fTempQName = new QName();
        this.fBuffer = new StringBuffer();
        while (true) {
            QName[] qNameArr = this.fElementQNamePartsStack;
            if (i2 >= qNameArr.length) {
                this.fGrammarBucket = new DTDGrammarBucket();
                return;
            } else {
                qNameArr[i2] = new QName();
                i2++;
            }
        }
    }

    private void charDataInContent() {
        QName[] qNameArr;
        QName[] qNameArr2 = this.fElementChildren;
        if (qNameArr2.length <= this.fElementChildrenLength) {
            QName[] qNameArr3 = new QName[(qNameArr2.length * 2)];
            System.arraycopy(qNameArr2, 0, qNameArr3, 0, qNameArr2.length);
            this.fElementChildren = qNameArr3;
        }
        QName[] qNameArr4 = this.fElementChildren;
        int i2 = this.fElementChildrenLength;
        QName qName = qNameArr4[i2];
        if (qName == null) {
            while (true) {
                qNameArr = this.fElementChildren;
                if (i2 >= qNameArr.length) {
                    break;
                }
                qNameArr[i2] = new QName();
                i2++;
            }
            qName = qNameArr[this.fElementChildrenLength];
        }
        qName.clear();
        this.fElementChildrenLength++;
    }

    private int checkContent(int i2, QName[] qNameArr, int i3, int i4) {
        this.fDTDGrammar.getElementDecl(i2, this.fTempElementDecl);
        String str = this.fCurrentElement.rawname;
        int i5 = this.fCurrentContentSpecType;
        if (i5 == 1) {
            if (i4 != 0) {
                return 0;
            }
        } else if (i5 != 0 && (i5 == 2 || i5 == 3)) {
            return this.fTempElementDecl.contentModelValidator.validate(qNameArr, i3, i4);
        }
        return -1;
    }

    private void ensureStackCapacity(int i2) {
        QName[] qNameArr = this.fElementQNamePartsStack;
        if (i2 == qNameArr.length) {
            int i3 = i2 * 2;
            QName[] qNameArr2 = new QName[i3];
            System.arraycopy(qNameArr, 0, qNameArr2, 0, i2);
            this.fElementQNamePartsStack = qNameArr2;
            if (qNameArr2[i2] == null) {
                int i4 = i2;
                while (true) {
                    QName[] qNameArr3 = this.fElementQNamePartsStack;
                    if (i4 >= qNameArr3.length) {
                        break;
                    }
                    qNameArr3[i4] = new QName();
                    i4++;
                }
            }
            int[] iArr = new int[i3];
            System.arraycopy(this.fElementIndexStack, 0, iArr, 0, i2);
            this.fElementIndexStack = iArr;
            int[] iArr2 = new int[i3];
            System.arraycopy(this.fContentSpecTypeStack, 0, iArr2, 0, i2);
            this.fContentSpecTypeStack = iArr2;
        }
    }

    private String getAttributeTypeName(XMLAttributeDecl xMLAttributeDecl) {
        XMLSimpleType xMLSimpleType = xMLAttributeDecl.simpleType;
        switch (xMLSimpleType.type) {
            case 1:
                return xMLSimpleType.list ? XMLSymbols.fENTITIESSymbol : XMLSymbols.fENTITYSymbol;
            case 2:
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append('(');
                for (int i2 = 0; i2 < xMLAttributeDecl.simpleType.enumeration.length; i2++) {
                    if (i2 > 0) {
                        stringBuffer.append('|');
                    }
                    stringBuffer.append(xMLAttributeDecl.simpleType.enumeration[i2]);
                }
                stringBuffer.append(')');
                return this.fSymbolTable.addSymbol(stringBuffer.toString());
            case 3:
                return XMLSymbols.fIDSymbol;
            case 4:
                return xMLSimpleType.list ? XMLSymbols.fIDREFSSymbol : XMLSymbols.fIDREFSymbol;
            case 5:
                return xMLSimpleType.list ? XMLSymbols.fNMTOKENSSymbol : XMLSymbols.fNMTOKENSymbol;
            case 6:
                return XMLSymbols.fNOTATIONSymbol;
            default:
                return XMLSymbols.fCDATASymbol;
        }
    }

    private int getContentSpecType(int i2) {
        if (i2 <= -1 || !this.fDTDGrammar.getElementDecl(i2, this.fTempElementDecl)) {
            return -1;
        }
        return this.fTempElementDecl.type;
    }

    private boolean normalizeAttrValue(XMLAttributes xMLAttributes, int i2) {
        String value = xMLAttributes.getValue(i2);
        int length = value.length();
        char[] cArr = new char[length];
        this.fBuffer.setLength(0);
        value.getChars(0, value.length(), cArr, 0);
        int i3 = 0;
        boolean z = false;
        boolean z2 = false;
        boolean z3 = true;
        for (int i4 = 0; i4 < length; i4++) {
            if (cArr[i4] == ' ') {
                if (z) {
                    z = false;
                    z2 = true;
                }
                if (z2 && !z3) {
                    this.fBuffer.append(cArr[i4]);
                    i3++;
                    z2 = false;
                }
            } else {
                this.fBuffer.append(cArr[i4]);
                i3++;
                z = true;
                z2 = false;
                z3 = false;
            }
        }
        if (i3 > 0) {
            int i5 = i3 - 1;
            if (this.fBuffer.charAt(i5) == ' ') {
                this.fBuffer.setLength(i5);
            }
        }
        String stringBuffer = this.fBuffer.toString();
        xMLAttributes.setValue(i2, stringBuffer);
        return !value.equals(stringBuffer);
    }

    private final void rootElementSpecified(QName qName) {
        if (this.fPerformValidation) {
            String str = this.fRootElement.rawname;
            String str2 = qName.rawname;
            if (str == null || !str.equals(str2)) {
                this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "RootElementTypeMustMatchDoctypedecl", new Object[]{str, str2}, 1);
            }
        }
    }

    public void addDTDDefaultAttrsAndValidate(QName qName, int i2, XMLAttributes xMLAttributes) {
        DTDGrammar dTDGrammar;
        int i3;
        boolean z;
        String nonNormalizedValue;
        String externalEntityRefInAttrValue;
        boolean z2;
        int i4 = -1;
        if (i2 != -1 && (dTDGrammar = this.fDTDGrammar) != null) {
            int firstAttributeDeclIndex = dTDGrammar.getFirstAttributeDeclIndex(i2);
            while (true) {
                i3 = 2;
                if (firstAttributeDeclIndex == i4) {
                    break;
                }
                this.fDTDGrammar.getAttributeDecl(firstAttributeDeclIndex, this.fTempAttDecl);
                XMLAttributeDecl xMLAttributeDecl = this.fTempAttDecl;
                QName qName2 = xMLAttributeDecl.name;
                String str = qName2.prefix;
                String str2 = qName2.localpart;
                String str3 = qName2.rawname;
                String attributeTypeName = getAttributeTypeName(xMLAttributeDecl);
                XMLSimpleType xMLSimpleType = this.fTempAttDecl.simpleType;
                short s = xMLSimpleType.defaultType;
                String str4 = null;
                String str5 = xMLSimpleType.defaultValue;
                if (str5 != null) {
                    str4 = str5;
                }
                boolean z3 = s == 2;
                if (!(attributeTypeName == XMLSymbols.fCDATASymbol) || z3 || str4 != null) {
                    int length = xMLAttributes.getLength();
                    int i5 = 0;
                    while (true) {
                        if (i5 >= length) {
                            break;
                        } else if (xMLAttributes.getQName(i5) == str3) {
                            z2 = true;
                            break;
                        } else {
                            i5++;
                        }
                    }
                }
                z2 = false;
                if (!z2) {
                    if (z3) {
                        if (this.fPerformValidation) {
                            this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_REQUIRED_ATTRIBUTE_NOT_SPECIFIED", new Object[]{qName.localpart, str3}, 1);
                        }
                    } else if (str4 != null) {
                        if (this.fPerformValidation && this.fGrammarBucket.getStandalone() && this.fDTDGrammar.getAttributeDeclIsExternal(firstAttributeDeclIndex)) {
                            this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_DEFAULTED_ATTRIBUTE_NOT_SPECIFIED", new Object[]{qName.localpart, str3}, 1);
                        }
                        if (this.fNamespaces) {
                            int indexOf = str3.indexOf(58);
                            if (indexOf != -1) {
                                str = this.fSymbolTable.addSymbol(str3.substring(0, indexOf));
                                str2 = this.fSymbolTable.addSymbol(str3.substring(indexOf + 1));
                            }
                        }
                        this.fTempQName.setValues(str, str2, str3, this.fTempAttDecl.name.uri);
                        xMLAttributes.addAttribute(this.fTempQName, attributeTypeName, str4);
                        firstAttributeDeclIndex = this.fDTDGrammar.getNextAttributeDeclIndex(firstAttributeDeclIndex);
                        i4 = -1;
                    }
                }
                firstAttributeDeclIndex = this.fDTDGrammar.getNextAttributeDeclIndex(firstAttributeDeclIndex);
                i4 = -1;
            }
            int length2 = xMLAttributes.getLength();
            int i6 = 0;
            while (i6 < length2) {
                String qName3 = xMLAttributes.getQName(i6);
                if (this.fPerformValidation && this.fGrammarBucket.getStandalone() && (nonNormalizedValue = xMLAttributes.getNonNormalizedValue(i6)) != null && (externalEntityRefInAttrValue = getExternalEntityRefInAttrValue(nonNormalizedValue)) != null) {
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_REFERENCE_TO_EXTERNALLY_DECLARED_ENTITY_WHEN_STANDALONE", new Object[]{externalEntityRefInAttrValue}, 1);
                }
                int firstAttributeDeclIndex2 = this.fDTDGrammar.getFirstAttributeDeclIndex(i2);
                while (true) {
                    if (firstAttributeDeclIndex2 == i4) {
                        z = false;
                        break;
                    }
                    this.fDTDGrammar.getAttributeDecl(firstAttributeDeclIndex2, this.fTempAttDecl);
                    if (this.fTempAttDecl.name.rawname == qName3) {
                        z = true;
                        break;
                    }
                    firstAttributeDeclIndex2 = this.fDTDGrammar.getNextAttributeDeclIndex(firstAttributeDeclIndex2);
                    i4 = -1;
                    i3 = 2;
                }
                if (z) {
                    String attributeTypeName2 = getAttributeTypeName(this.fTempAttDecl);
                    xMLAttributes.setType(i6, attributeTypeName2);
                    xMLAttributes.getAugmentations(i6).putItem(Constants.ATTRIBUTE_DECLARED, Boolean.TRUE);
                    String value = xMLAttributes.getValue(i6);
                    if (xMLAttributes.isSpecified(i6) && attributeTypeName2 != XMLSymbols.fCDATASymbol) {
                        boolean normalizeAttrValue = normalizeAttrValue(xMLAttributes, i6);
                        String value2 = xMLAttributes.getValue(i6);
                        if (this.fPerformValidation && this.fGrammarBucket.getStandalone() && normalizeAttrValue && this.fDTDGrammar.getAttributeDeclIsExternal(firstAttributeDeclIndex2)) {
                            this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_ATTVALUE_CHANGED_DURING_NORMALIZATION_WHEN_STANDALONE", new Object[]{qName3, value, value2}, 1);
                        }
                        value = value2;
                    }
                    if (this.fPerformValidation) {
                        XMLSimpleType xMLSimpleType2 = this.fTempAttDecl.simpleType;
                        if (xMLSimpleType2.defaultType == 1) {
                            String str6 = xMLSimpleType2.defaultValue;
                            if (!value.equals(str6)) {
                                this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_FIXED_ATTVALUE_INVALID", new Object[]{qName.localpart, qName3, value, str6}, 1);
                            }
                        }
                        short s2 = this.fTempAttDecl.simpleType.type;
                        if (s2 == 1 || s2 == 2 || s2 == 3 || s2 == 4 || s2 == 5 || s2 == 6) {
                            validateDTDattribute(qName, value, this.fTempAttDecl);
                        }
                    }
                } else if (this.fPerformValidation) {
                    Object[] objArr = new Object[i3];
                    objArr[0] = qName.rawname;
                    objArr[1] = qName3;
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_ATTRIBUTE_NOT_DECLARED", objArr, 1);
                }
                i6++;
                i4 = -1;
                i3 = 2;
            }
        }
    }

    @Override // org.apache.xerces.impl.RevalidationHandler
    public boolean characterData(String str, Augmentations augmentations) {
        characters(new XMLString(str.toCharArray(), 0, str.length()), augmentations);
        return true;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void characters(XMLString xMLString, Augmentations augmentations) {
        boolean z;
        boolean z2;
        XMLDocumentHandler xMLDocumentHandler;
        XMLDocumentHandler xMLDocumentHandler2;
        int i2 = xMLString.offset;
        while (true) {
            if (i2 >= xMLString.offset + xMLString.length) {
                z = true;
                break;
            } else if (!isSpace(xMLString.ch[i2])) {
                z = false;
                break;
            } else {
                i2++;
            }
        }
        if (!this.fInElementContent || !z || this.fInCDATASection || (xMLDocumentHandler2 = this.fDocumentHandler) == null) {
            z2 = true;
        } else {
            xMLDocumentHandler2.ignorableWhitespace(xMLString, augmentations);
            z2 = false;
        }
        if (this.fPerformValidation) {
            if (this.fInElementContent) {
                if (this.fGrammarBucket.getStandalone() && this.fDTDGrammar.getElementDeclIsExternal(this.fCurrentElementIndex) && z) {
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_WHITE_SPACE_IN_ELEMENT_CONTENT_WHEN_STANDALONE", null, 1);
                }
                if (!z) {
                    charDataInContent();
                }
                if (augmentations != null && augmentations.getItem(Constants.CHAR_REF_PROBABLE_WS) == Boolean.TRUE) {
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_CONTENT_INVALID_SPECIFIED", new Object[]{this.fCurrentElement.rawname, this.fDTDGrammar.getContentSpecAsString(this.fElementDepth), "character reference"}, 1);
                }
            }
            if (this.fCurrentContentSpecType == 1) {
                charDataInContent();
            }
        }
        if (z2 && (xMLDocumentHandler = this.fDocumentHandler) != null) {
            xMLDocumentHandler.characters(xMLString, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void comment(XMLString xMLString, Augmentations augmentations) {
        DTDGrammar dTDGrammar;
        if (this.fPerformValidation && this.fElementDepth >= 0 && (dTDGrammar = this.fDTDGrammar) != null) {
            dTDGrammar.getElementDecl(this.fCurrentElementIndex, this.fTempElementDecl);
            if (this.fTempElementDecl.type == 1) {
                this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_CONTENT_INVALID_SPECIFIED", new Object[]{this.fCurrentElement.rawname, "EMPTY", JamXmlElements.COMMENT}, 1);
            }
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.comment(xMLString, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void doctypeDecl(String str, String str2, String str3, Augmentations augmentations) {
        this.fSeenDoctypeDecl = true;
        String str4 = null;
        this.fRootElement.setValues(null, str, str, null);
        try {
            str4 = XMLEntityManager.expandSystemId(str3, this.fDocLocation.getExpandedSystemId(), false);
        } catch (IOException unused) {
        }
        XMLDTDDescription xMLDTDDescription = new XMLDTDDescription(str2, str3, this.fDocLocation.getExpandedSystemId(), str4, str);
        DTDGrammar grammar = this.fGrammarBucket.getGrammar(xMLDTDDescription);
        this.fDTDGrammar = grammar;
        if (!(grammar != null || this.fGrammarPool == null || (str3 == null && str2 == null))) {
            this.fDTDGrammar = (DTDGrammar) this.fGrammarPool.retrieveGrammar(xMLDTDDescription);
        }
        if (this.fDTDGrammar == null) {
            this.fDTDGrammar = !this.fBalanceSyntaxTrees ? new DTDGrammar(this.fSymbolTable, xMLDTDDescription) : new BalancedDTDGrammar(this.fSymbolTable, xMLDTDDescription);
        } else {
            this.fValidationManager.setCachedDTD(true);
        }
        this.fGrammarBucket.setActiveGrammar(this.fDTDGrammar);
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.doctypeDecl(str, str2, str3, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void emptyElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        boolean handleStartElement = handleStartElement(qName, xMLAttributes, augmentations);
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.emptyElement(qName, xMLAttributes, augmentations);
        }
        if (!handleStartElement) {
            handleEndElement(qName, augmentations, true);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endCDATA(Augmentations augmentations) {
        this.fInCDATASection = false;
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.endCDATA(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endDocument(Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.endDocument(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endElement(QName qName, Augmentations augmentations) {
        handleEndElement(qName, augmentations, false);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void endGeneralEntity(String str, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.endGeneralEntity(str, augmentations);
        }
    }

    public void endNamespaceScope(QName qName, Augmentations augmentations, boolean z) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null && !z) {
            xMLDocumentHandler.endElement(this.fCurrentElement, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentSource
    public XMLDocumentHandler getDocumentHandler() {
        return this.fDocumentHandler;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public XMLDocumentSource getDocumentSource() {
        return this.fDocumentSource;
    }

    public String getExternalEntityRefInAttrValue(String str) {
        String addSymbol;
        int entityDeclIndex;
        int length = str.length();
        int indexOf = str.indexOf(38);
        while (indexOf != -1) {
            int i2 = indexOf + 1;
            if (i2 < length && str.charAt(i2) != '#' && (entityDeclIndex = this.fDTDGrammar.getEntityDeclIndex((addSymbol = this.fSymbolTable.addSymbol(str.substring(i2, str.indexOf(59, i2)))))) > -1) {
                this.fDTDGrammar.getEntityDecl(entityDeclIndex, this.fEntityDecl);
                XMLEntityDecl xMLEntityDecl = this.fEntityDecl;
                if (xMLEntityDecl.inExternal || (addSymbol = getExternalEntityRefInAttrValue(xMLEntityDecl.value)) != null) {
                    return addSymbol;
                }
            }
            indexOf = str.indexOf(38, i2);
        }
        return null;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public Boolean getFeatureDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_FEATURES;
            if (i2 >= strArr.length) {
                return null;
            }
            if (strArr[i2].equals(str)) {
                return FEATURE_DEFAULTS[i2];
            }
            i2++;
        }
    }

    public DTDGrammarBucket getGrammarBucket() {
        return this.fGrammarBucket;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public Object getPropertyDefault(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = RECOGNIZED_PROPERTIES;
            if (i2 >= strArr.length) {
                return null;
            }
            if (strArr[i2].equals(str)) {
                return PROPERTY_DEFAULTS[i2];
            }
            i2++;
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public String[] getRecognizedFeatures() {
        return (String[]) RECOGNIZED_FEATURES.clone();
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public String[] getRecognizedProperties() {
        return (String[]) RECOGNIZED_PROPERTIES.clone();
    }

    public void handleEndElement(QName qName, Augmentations augmentations, boolean z) {
        String checkIDRefID;
        int i2;
        int i3;
        int checkContent;
        boolean z2 = true;
        int i4 = this.fElementDepth - 1;
        this.fElementDepth = i4;
        if (this.fPerformValidation) {
            int i5 = this.fCurrentElementIndex;
            if (!(i5 == -1 || this.fCurrentContentSpecType == -1 || (checkContent = checkContent(i5, this.fElementChildren, i2, (i3 = this.fElementChildrenLength - (i2 = this.fElementChildrenOffsetStack[i4 + 1] + 1)))) == -1)) {
                this.fDTDGrammar.getElementDecl(i5, this.fTempElementDecl);
                String str = "MSG_CONTENT_INVALID";
                if (this.fTempElementDecl.type == 1) {
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", str, new Object[]{qName.rawname, "EMPTY"}, 1);
                } else {
                    if (checkContent == i3) {
                        str = "MSG_CONTENT_INCOMPLETE";
                    }
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", str, new Object[]{qName.rawname, this.fDTDGrammar.getContentSpecAsString(i5)}, 1);
                }
            }
            this.fElementChildrenLength = this.fElementChildrenOffsetStack[this.fElementDepth + 1] + 1;
        }
        endNamespaceScope(this.fCurrentElement, augmentations, z);
        int i6 = this.fElementDepth;
        if (i6 < -1) {
            throw new RuntimeException("FWK008 Element stack underflow");
        } else if (i6 < 0) {
            this.fCurrentElement.clear();
            this.fCurrentElementIndex = -1;
            this.fCurrentContentSpecType = -1;
            this.fInElementContent = false;
            if (this.fPerformValidation && (checkIDRefID = this.fValidationState.checkIDRefID()) != null) {
                this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_ELEMENT_WITH_ID_REQUIRED", new Object[]{checkIDRefID}, 1);
            }
        } else {
            this.fCurrentElement.setValues(this.fElementQNamePartsStack[i6]);
            int[] iArr = this.fElementIndexStack;
            int i7 = this.fElementDepth;
            this.fCurrentElementIndex = iArr[i7];
            int i8 = this.fContentSpecTypeStack[i7];
            this.fCurrentContentSpecType = i8;
            if (i8 != 3) {
                z2 = false;
            }
            this.fInElementContent = z2;
        }
    }

    public boolean handleStartElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        QName[] qNameArr;
        if (!this.fSeenRootElement) {
            this.fPerformValidation = validate();
            this.fSeenRootElement = true;
            this.fValidationManager.setEntityState(this.fDTDGrammar);
            this.fValidationManager.setGrammarFound(this.fSeenDoctypeDecl);
            rootElementSpecified(qName);
        }
        DTDGrammar dTDGrammar = this.fDTDGrammar;
        if (dTDGrammar == null) {
            if (!this.fPerformValidation) {
                this.fCurrentElementIndex = -1;
                this.fCurrentContentSpecType = -1;
                this.fInElementContent = false;
            }
            if (this.fPerformValidation) {
                this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_GRAMMAR_NOT_FOUND", new Object[]{qName.rawname}, 1);
            }
            XMLDocumentSource xMLDocumentSource = this.fDocumentSource;
            if (xMLDocumentSource != null) {
                xMLDocumentSource.setDocumentHandler(this.fDocumentHandler);
                XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
                if (xMLDocumentHandler != null) {
                    xMLDocumentHandler.setDocumentSource(this.fDocumentSource);
                }
                return true;
            }
        } else {
            int elementDeclIndex = dTDGrammar.getElementDeclIndex(qName);
            this.fCurrentElementIndex = elementDeclIndex;
            short contentSpecType = this.fDTDGrammar.getContentSpecType(elementDeclIndex);
            this.fCurrentContentSpecType = contentSpecType;
            if (contentSpecType == -1 && this.fPerformValidation) {
                this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_ELEMENT_NOT_DECLARED", new Object[]{qName.rawname}, 1);
            }
            addDTDDefaultAttrsAndValidate(qName, this.fCurrentElementIndex, xMLAttributes);
        }
        this.fInElementContent = this.fCurrentContentSpecType == 3;
        int i2 = this.fElementDepth + 1;
        this.fElementDepth = i2;
        if (this.fPerformValidation) {
            int[] iArr = this.fElementChildrenOffsetStack;
            if (iArr.length <= i2) {
                int[] iArr2 = new int[(iArr.length * 2)];
                System.arraycopy(iArr, 0, iArr2, 0, iArr.length);
                this.fElementChildrenOffsetStack = iArr2;
            }
            int[] iArr3 = this.fElementChildrenOffsetStack;
            int i3 = this.fElementDepth;
            int i4 = this.fElementChildrenLength;
            iArr3[i3] = i4;
            QName[] qNameArr2 = this.fElementChildren;
            if (qNameArr2.length <= i4) {
                QName[] qNameArr3 = new QName[(i4 * 2)];
                System.arraycopy(qNameArr2, 0, qNameArr3, 0, qNameArr2.length);
                this.fElementChildren = qNameArr3;
            }
            QName[] qNameArr4 = this.fElementChildren;
            int i5 = this.fElementChildrenLength;
            QName qName2 = qNameArr4[i5];
            if (qName2 == null) {
                while (true) {
                    qNameArr = this.fElementChildren;
                    if (i5 >= qNameArr.length) {
                        break;
                    }
                    qNameArr[i5] = new QName();
                    i5++;
                }
                qName2 = qNameArr[this.fElementChildrenLength];
            }
            qName2.setValues(qName);
            this.fElementChildrenLength++;
        }
        this.fCurrentElement.setValues(qName);
        ensureStackCapacity(this.fElementDepth);
        this.fElementQNamePartsStack[this.fElementDepth].setValues(this.fCurrentElement);
        int[] iArr4 = this.fElementIndexStack;
        int i6 = this.fElementDepth;
        iArr4[i6] = this.fCurrentElementIndex;
        this.fContentSpecTypeStack[i6] = this.fCurrentContentSpecType;
        startNamespaceScope(qName, xMLAttributes, augmentations);
        return false;
    }

    @Override // org.apache.xerces.impl.dtd.XMLDTDValidatorFilter
    public final boolean hasGrammar() {
        return this.fDTDGrammar != null;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void ignorableWhitespace(XMLString xMLString, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.ignorableWhitespace(xMLString, augmentations);
        }
    }

    public void init() {
        if (this.fValidation || this.fDynamicValidation) {
            try {
                this.fValID = this.fDatatypeValidatorFactory.getBuiltInDV(XMLSymbols.fIDSymbol);
                this.fValIDRef = this.fDatatypeValidatorFactory.getBuiltInDV(XMLSymbols.fIDREFSymbol);
                this.fValIDRefs = this.fDatatypeValidatorFactory.getBuiltInDV(XMLSymbols.fIDREFSSymbol);
                this.fValENTITY = this.fDatatypeValidatorFactory.getBuiltInDV(XMLSymbols.fENTITYSymbol);
                this.fValENTITIES = this.fDatatypeValidatorFactory.getBuiltInDV(XMLSymbols.fENTITIESSymbol);
                this.fValNMTOKEN = this.fDatatypeValidatorFactory.getBuiltInDV(XMLSymbols.fNMTOKENSymbol);
                this.fValNMTOKENS = this.fDatatypeValidatorFactory.getBuiltInDV(XMLSymbols.fNMTOKENSSymbol);
                this.fValNOTATION = this.fDatatypeValidatorFactory.getBuiltInDV(XMLSymbols.fNOTATIONSymbol);
            } catch (Exception e2) {
                e2.printStackTrace(System.err);
            }
        }
    }

    public boolean invalidStandaloneAttDef(QName qName, QName qName2) {
        return true;
    }

    public boolean isSpace(int i2) {
        return XMLChar.isSpace(i2);
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void processingInstruction(String str, XMLString xMLString, Augmentations augmentations) {
        DTDGrammar dTDGrammar;
        if (this.fPerformValidation && this.fElementDepth >= 0 && (dTDGrammar = this.fDTDGrammar) != null) {
            dTDGrammar.getElementDecl(this.fCurrentElementIndex, this.fTempElementDecl);
            if (this.fTempElementDecl.type == 1) {
                this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_CONTENT_INVALID_SPECIFIED", new Object[]{this.fCurrentElement.rawname, "EMPTY", "processing instruction"}, 1);
            }
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.processingInstruction(str, xMLString, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void reset(XMLComponentManager xMLComponentManager) {
        boolean z;
        this.fDTDGrammar = null;
        this.fSeenDoctypeDecl = false;
        this.fInCDATASection = false;
        this.fSeenRootElement = false;
        this.fInElementContent = false;
        this.fCurrentElementIndex = -1;
        this.fCurrentContentSpecType = -1;
        this.fRootElement.clear();
        this.fValidationState.resetIDTables();
        this.fGrammarBucket.clear();
        this.fElementDepth = -1;
        this.fElementChildrenLength = 0;
        try {
            z = xMLComponentManager.getFeature("http://apache.org/xml/features/internal/parser-settings");
        } catch (XMLConfigurationException unused) {
            z = true;
        }
        if (!z) {
            this.fValidationManager.addValidationState(this.fValidationState);
            return;
        }
        try {
            this.fNamespaces = xMLComponentManager.getFeature("http://xml.org/sax/features/namespaces");
        } catch (XMLConfigurationException unused2) {
            this.fNamespaces = true;
        }
        try {
            this.fValidation = xMLComponentManager.getFeature("http://xml.org/sax/features/validation");
        } catch (XMLConfigurationException unused3) {
            this.fValidation = false;
        }
        try {
            this.fDTDValidation = !xMLComponentManager.getFeature("http://apache.org/xml/features/validation/schema");
        } catch (XMLConfigurationException unused4) {
            this.fDTDValidation = true;
        }
        try {
            this.fDynamicValidation = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/dynamic");
        } catch (XMLConfigurationException unused5) {
            this.fDynamicValidation = false;
        }
        try {
            this.fBalanceSyntaxTrees = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/balance-syntax-trees");
        } catch (XMLConfigurationException unused6) {
            this.fBalanceSyntaxTrees = false;
        }
        try {
            this.fWarnDuplicateAttdef = xMLComponentManager.getFeature("http://apache.org/xml/features/validation/warn-on-duplicate-attdef");
        } catch (XMLConfigurationException unused7) {
            this.fWarnDuplicateAttdef = false;
        }
        try {
            this.fSchemaType = (String) xMLComponentManager.getProperty("http://java.sun.com/xml/jaxp/properties/schemaLanguage");
        } catch (XMLConfigurationException unused8) {
            this.fSchemaType = null;
        }
        ValidationManager validationManager = (ValidationManager) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/validation-manager");
        this.fValidationManager = validationManager;
        validationManager.addValidationState(this.fValidationState);
        this.fValidationState.setUsingNamespaces(this.fNamespaces);
        this.fErrorReporter = (XMLErrorReporter) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/error-reporter");
        this.fSymbolTable = (SymbolTable) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/symbol-table");
        try {
            this.fGrammarPool = (XMLGrammarPool) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/grammar-pool");
        } catch (XMLConfigurationException unused9) {
            this.fGrammarPool = null;
        }
        this.fDatatypeValidatorFactory = (DTDDVFactory) xMLComponentManager.getProperty("http://apache.org/xml/properties/internal/datatype-validator-factory");
        init();
    }

    @Override // org.apache.xerces.xni.parser.XMLDocumentSource
    public void setDocumentHandler(XMLDocumentHandler xMLDocumentHandler) {
        this.fDocumentHandler = xMLDocumentHandler;
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void setDocumentSource(XMLDocumentSource xMLDocumentSource) {
        this.fDocumentSource = xMLDocumentSource;
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void setFeature(String str, boolean z) {
    }

    @Override // org.apache.xerces.xni.parser.XMLComponent
    public void setProperty(String str, Object obj) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startCDATA(Augmentations augmentations) {
        if (this.fPerformValidation && this.fInElementContent) {
            charDataInContent();
        }
        this.fInCDATASection = true;
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.startCDATA(augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startDocument(XMLLocator xMLLocator, String str, NamespaceContext namespaceContext, Augmentations augmentations) {
        XMLGrammarPool xMLGrammarPool = this.fGrammarPool;
        if (xMLGrammarPool != null) {
            Grammar[] retrieveInitialGrammarSet = xMLGrammarPool.retrieveInitialGrammarSet("http://www.w3.org/TR/REC-xml");
            int length = retrieveInitialGrammarSet != null ? retrieveInitialGrammarSet.length : 0;
            for (int i2 = 0; i2 < length; i2++) {
                this.fGrammarBucket.putGrammar((DTDGrammar) retrieveInitialGrammarSet[i2]);
            }
        }
        this.fDocLocation = xMLLocator;
        this.fNamespaceContext = namespaceContext;
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.startDocument(xMLLocator, str, namespaceContext, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startElement(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
        handleStartElement(qName, xMLAttributes, augmentations);
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.startElement(qName, xMLAttributes, augmentations);
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void startGeneralEntity(String str, XMLResourceIdentifier xMLResourceIdentifier, String str2, Augmentations augmentations) {
        DTDGrammar dTDGrammar;
        if (this.fPerformValidation && this.fElementDepth >= 0 && (dTDGrammar = this.fDTDGrammar) != null) {
            dTDGrammar.getElementDecl(this.fCurrentElementIndex, this.fTempElementDecl);
            if (this.fTempElementDecl.type == 1) {
                this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_CONTENT_INVALID_SPECIFIED", new Object[]{this.fCurrentElement.rawname, "EMPTY", SchemaSymbols.ATTVAL_ENTITY}, 1);
            }
            if (this.fGrammarBucket.getStandalone()) {
                XMLDTDProcessor.checkStandaloneEntityRef(str, this.fDTDGrammar, this.fEntityDecl, this.fErrorReporter);
            }
        }
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.startGeneralEntity(str, xMLResourceIdentifier, str2, augmentations);
        }
    }

    public void startNamespaceScope(QName qName, XMLAttributes xMLAttributes, Augmentations augmentations) {
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void textDecl(String str, String str2, Augmentations augmentations) {
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.textDecl(str, str2, augmentations);
        }
    }

    @Override // org.apache.xerces.impl.dtd.XMLDTDValidatorFilter
    public final boolean validate() {
        return this.fSchemaType != Constants.NS_XMLSCHEMA && ((!this.fDynamicValidation && this.fValidation) || (this.fDynamicValidation && this.fSeenDoctypeDecl)) && (this.fDTDValidation || this.fSeenDoctypeDecl);
    }

    public void validateDTDattribute(QName qName, String str, XMLAttributeDecl xMLAttributeDecl) {
        DatatypeValidator datatypeValidator;
        ValidationState validationState;
        boolean z;
        DatatypeValidator datatypeValidator2;
        ValidationState validationState2;
        DatatypeValidator datatypeValidator3;
        ValidationState validationState3;
        XMLSimpleType xMLSimpleType = xMLAttributeDecl.simpleType;
        switch (xMLSimpleType.type) {
            case 1:
                if (xMLSimpleType.list) {
                    try {
                        datatypeValidator = this.fValENTITIES;
                        validationState = this.fValidationState;
                    } catch (InvalidDatatypeValueException e2) {
                        this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", e2.getKey(), e2.getArgs(), 1);
                        return;
                    }
                } else {
                    datatypeValidator = this.fValENTITY;
                    validationState = this.fValidationState;
                }
                datatypeValidator.validate(str, validationState);
                return;
            case 2:
            case 6:
                String[] strArr = xMLSimpleType.enumeration;
                if (strArr != null) {
                    int i2 = 0;
                    while (true) {
                        if (i2 < strArr.length) {
                            if (str == strArr[i2] || str.equals(strArr[i2])) {
                                z = true;
                            } else {
                                i2++;
                            }
                        }
                    }
                }
                z = false;
                if (!z) {
                    StringBuffer stringBuffer = new StringBuffer();
                    if (strArr != null) {
                        for (String str2 : strArr) {
                            StringBuffer stringBuffer2 = new StringBuffer();
                            stringBuffer2.append(str2);
                            stringBuffer2.append(" ");
                            stringBuffer.append(stringBuffer2.toString());
                        }
                    }
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "MSG_ATTRIBUTE_VALUE_NOT_IN_LIST", new Object[]{xMLAttributeDecl.name.rawname, str, stringBuffer}, 1);
                    return;
                }
                return;
            case 3:
                try {
                    this.fValID.validate(str, this.fValidationState);
                    return;
                } catch (InvalidDatatypeValueException e3) {
                    this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", e3.getKey(), e3.getArgs(), 1);
                    return;
                }
            case 4:
                boolean z2 = xMLSimpleType.list;
                if (z2) {
                    try {
                        datatypeValidator2 = this.fValIDRefs;
                        validationState2 = this.fValidationState;
                    } catch (InvalidDatatypeValueException e4) {
                        if (z2) {
                            this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "IDREFSInvalid", new Object[]{str}, 1);
                            return;
                        }
                        this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", e4.getKey(), e4.getArgs(), 1);
                        return;
                    }
                } else {
                    datatypeValidator2 = this.fValIDRef;
                    validationState2 = this.fValidationState;
                }
                datatypeValidator2.validate(str, validationState2);
                return;
            case 5:
                boolean z3 = xMLSimpleType.list;
                if (z3) {
                    try {
                        datatypeValidator3 = this.fValNMTOKENS;
                        validationState3 = this.fValidationState;
                    } catch (InvalidDatatypeValueException unused) {
                        if (z3) {
                            this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "NMTOKENSInvalid", new Object[]{str}, 1);
                            return;
                        }
                        this.fErrorReporter.reportError("http://www.w3.org/TR/1998/REC-xml-19980210", "NMTOKENInvalid", new Object[]{str}, 1);
                        return;
                    }
                } else {
                    datatypeValidator3 = this.fValNMTOKEN;
                    validationState3 = this.fValidationState;
                }
                datatypeValidator3.validate(str, validationState3);
                return;
            default:
                return;
        }
    }

    @Override // org.apache.xerces.xni.XMLDocumentHandler
    public void xmlDecl(String str, String str2, String str3, Augmentations augmentations) {
        this.fGrammarBucket.setStandalone(str3 != null && str3.equals("yes"));
        XMLDocumentHandler xMLDocumentHandler = this.fDocumentHandler;
        if (xMLDocumentHandler != null) {
            xMLDocumentHandler.xmlDecl(str, str2, str3, augmentations);
        }
    }
}
