package org.apache.xerces.impl.io;

import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
import java.util.Locale;
import org.apache.xerces.impl.msg.XMLMessageFormatter;
import org.apache.xerces.util.MessageFormatter;

public final class UTF16Reader extends Reader {
    public static final int DEFAULT_BUFFER_SIZE = 4096;
    public final byte[] fBuffer;
    public final MessageFormatter fFormatter;
    public final InputStream fInputStream;
    public final boolean fIsBigEndian;
    public final Locale fLocale;

    public UTF16Reader(InputStream inputStream, int i2, boolean z, MessageFormatter messageFormatter, Locale locale) {
        this(inputStream, new byte[i2], z, messageFormatter, locale);
    }

    public UTF16Reader(InputStream inputStream, boolean z) {
        this(inputStream, 4096, z, new XMLMessageFormatter(), Locale.getDefault());
    }

    public UTF16Reader(InputStream inputStream, boolean z, MessageFormatter messageFormatter, Locale locale) {
        this(inputStream, 4096, z, messageFormatter, locale);
    }

    public UTF16Reader(InputStream inputStream, byte[] bArr, boolean z, MessageFormatter messageFormatter, Locale locale) {
        this.fInputStream = inputStream;
        this.fBuffer = bArr;
        this.fIsBigEndian = z;
        this.fFormatter = messageFormatter;
        this.fLocale = locale;
    }

    private void expectedTwoBytes() {
        throw new MalformedByteSequenceException(this.fFormatter, this.fLocale, "http://www.w3.org/TR/1998/REC-xml-19980210", "ExpectedByte", new Object[]{"2", "2"});
    }

    private void processBE(char[] cArr, int i2, int i3) {
        int i4 = 0;
        int i5 = 0;
        while (i4 < i3) {
            byte[] bArr = this.fBuffer;
            int i6 = i5 + 1;
            cArr[i2] = (char) (((bArr[i5] & 255) << 8) | (bArr[i6] & 255));
            i4++;
            i2++;
            i5 = i6 + 1;
        }
    }

    private void processLE(char[] cArr, int i2, int i3) {
        int i4 = 0;
        int i5 = 0;
        while (i4 < i3) {
            byte[] bArr = this.fBuffer;
            int i6 = i5 + 1;
            cArr[i2] = (char) ((bArr[i5] & 255) | ((bArr[i6] & 255) << 8));
            i4++;
            i2++;
            i5 = i6 + 1;
        }
    }

    @Override // java.io.Closeable, java.io.Reader, java.lang.AutoCloseable
    public void close() {
        this.fInputStream.close();
    }

    @Override // java.io.Reader
    public void mark(int i2) {
        throw new IOException(this.fFormatter.formatMessage(this.fLocale, "OperationNotSupported", new Object[]{"mark()", "UTF-16"}));
    }

    public boolean markSupported() {
        return false;
    }

    @Override // java.io.Reader
    public int read() {
        int read = this.fInputStream.read();
        if (read == -1) {
            return -1;
        }
        int read2 = this.fInputStream.read();
        if (read2 == -1) {
            expectedTwoBytes();
        }
        return this.fIsBigEndian ? (read << 8) | read2 : read | (read2 << 8);
    }

    @Override // java.io.Reader
    public int read(char[] cArr, int i2, int i3) {
        int i4 = i3 << 1;
        byte[] bArr = this.fBuffer;
        if (i4 > bArr.length) {
            i4 = bArr.length;
        }
        int read = this.fInputStream.read(this.fBuffer, 0, i4);
        if (read == -1) {
            return -1;
        }
        if ((read & 1) != 0) {
            int read2 = this.fInputStream.read();
            if (read2 == -1) {
                expectedTwoBytes();
            }
            this.fBuffer[read] = (byte) read2;
            read++;
        }
        int i5 = read >> 1;
        if (this.fIsBigEndian) {
            processBE(cArr, i2, i5);
        } else {
            processLE(cArr, i2, i5);
        }
        return i5;
    }

    @Override // java.io.Reader
    public boolean ready() {
        return false;
    }

    @Override // java.io.Reader
    public void reset() {
    }

    @Override // java.io.Reader
    public long skip(long j) {
        long skip = this.fInputStream.skip(j << 1);
        if ((skip & 1) != 0) {
            if (this.fInputStream.read() == -1) {
                expectedTwoBytes();
            }
            skip++;
        }
        return skip >> 1;
    }
}
