package org.apache.xerces.jaxp.validation;

import java.lang.ref.Reference;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.SoftReference;
import org.apache.xerces.xni.grammars.Grammar;
import org.apache.xerces.xni.grammars.XMLGrammarDescription;
import org.apache.xerces.xni.grammars.XMLGrammarPool;
import org.apache.xerces.xni.grammars.XMLSchemaDescription;

public final class SoftReferenceGrammarPool implements XMLGrammarPool {
    public static final int TABLE_SIZE = 11;
    public static final Grammar[] ZERO_LENGTH_GRAMMAR_ARRAY = new Grammar[0];
    public int fGrammarCount;
    public Entry[] fGrammars;
    public boolean fPoolIsLocked;
    public final ReferenceQueue fReferenceQueue;

    public static final class Entry {
        public int bucket;
        public XMLGrammarDescription desc;
        public SoftGrammarReference grammar;
        public int hash;
        public Entry next;
        public Entry prev = null;

        public Entry(int i2, int i3, XMLGrammarDescription xMLGrammarDescription, Grammar grammar2, Entry entry, ReferenceQueue referenceQueue) {
            this.hash = i2;
            this.bucket = i3;
            this.next = entry;
            if (entry != null) {
                entry.prev = this;
            }
            this.desc = xMLGrammarDescription;
            this.grammar = new SoftGrammarReference(this, grammar2, referenceQueue);
        }

        public void clear() {
            this.desc = null;
            this.grammar = null;
            Entry entry = this.next;
            if (entry != null) {
                entry.clear();
                this.next = null;
            }
        }
    }

    public static final class SoftGrammarReference extends SoftReference {
        public Entry entry;

        public SoftGrammarReference(Entry entry2, Grammar grammar, ReferenceQueue referenceQueue) {
            super(grammar, referenceQueue);
            this.entry = entry2;
        }
    }

    public SoftReferenceGrammarPool() {
        this.fGrammars = null;
        this.fGrammarCount = 0;
        this.fReferenceQueue = new ReferenceQueue();
        this.fGrammars = new Entry[11];
        this.fPoolIsLocked = false;
    }

    public SoftReferenceGrammarPool(int i2) {
        this.fGrammars = null;
        this.fGrammarCount = 0;
        this.fReferenceQueue = new ReferenceQueue();
        this.fGrammars = new Entry[i2];
        this.fPoolIsLocked = false;
    }

    private void clean() {
        while (true) {
            Reference poll = this.fReferenceQueue.poll();
            if (poll != null) {
                Entry entry = ((SoftGrammarReference) poll).entry;
                if (entry != null) {
                    removeEntry(entry);
                }
            } else {
                return;
            }
        }
    }

    private Grammar removeEntry(Entry entry) {
        Entry entry2 = entry.prev;
        if (entry2 != null) {
            entry2.next = entry.next;
        } else {
            this.fGrammars[entry.bucket] = entry.next;
        }
        Entry entry3 = entry.next;
        if (entry3 != null) {
            entry3.prev = entry.prev;
        }
        this.fGrammarCount--;
        SoftGrammarReference softGrammarReference = entry.grammar;
        softGrammarReference.entry = null;
        return (Grammar) softGrammarReference.get();
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public void cacheGrammars(String str, Grammar[] grammarArr) {
        if (!this.fPoolIsLocked) {
            for (Grammar grammar : grammarArr) {
                putGrammar(grammar);
            }
        }
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public void clear() {
        int i2 = 0;
        while (true) {
            Entry[] entryArr = this.fGrammars;
            if (i2 >= entryArr.length) {
                this.fGrammarCount = 0;
                return;
            }
            if (entryArr[i2] != null) {
                entryArr[i2].clear();
                this.fGrammars[i2] = null;
            }
            i2++;
        }
    }

    public boolean containsGrammar(XMLGrammarDescription xMLGrammarDescription) {
        synchronized (this.fGrammars) {
            clean();
            int hashCode = hashCode(xMLGrammarDescription);
            for (Entry entry = this.fGrammars[(Integer.MAX_VALUE & hashCode) % this.fGrammars.length]; entry != null; entry = entry.next) {
                if (((Grammar) entry.grammar.get()) == null) {
                    removeEntry(entry);
                } else if (entry.hash == hashCode && equals(entry.desc, xMLGrammarDescription)) {
                    return true;
                }
            }
            return false;
        }
    }

    public boolean equals(XMLGrammarDescription xMLGrammarDescription, XMLGrammarDescription xMLGrammarDescription2) {
        if (!(xMLGrammarDescription instanceof XMLSchemaDescription)) {
            return xMLGrammarDescription.equals(xMLGrammarDescription2);
        }
        if (!(xMLGrammarDescription2 instanceof XMLSchemaDescription)) {
            return false;
        }
        XMLSchemaDescription xMLSchemaDescription = (XMLSchemaDescription) xMLGrammarDescription;
        XMLSchemaDescription xMLSchemaDescription2 = (XMLSchemaDescription) xMLGrammarDescription2;
        String targetNamespace = xMLSchemaDescription.getTargetNamespace();
        if (targetNamespace != null) {
            if (!targetNamespace.equals(xMLSchemaDescription2.getTargetNamespace())) {
                return false;
            }
        } else if (xMLSchemaDescription2.getTargetNamespace() != null) {
            return false;
        }
        String expandedSystemId = xMLSchemaDescription.getExpandedSystemId();
        return expandedSystemId != null ? expandedSystemId.equals(xMLSchemaDescription2.getExpandedSystemId()) : xMLSchemaDescription2.getExpandedSystemId() == null;
    }

    public Grammar getGrammar(XMLGrammarDescription xMLGrammarDescription) {
        synchronized (this.fGrammars) {
            clean();
            int hashCode = hashCode(xMLGrammarDescription);
            for (Entry entry = this.fGrammars[(Integer.MAX_VALUE & hashCode) % this.fGrammars.length]; entry != null; entry = entry.next) {
                Grammar grammar = (Grammar) entry.grammar.get();
                if (grammar == null) {
                    removeEntry(entry);
                } else if (entry.hash == hashCode && equals(entry.desc, xMLGrammarDescription)) {
                    return grammar;
                }
            }
            return null;
        }
    }

    public int hashCode(XMLGrammarDescription xMLGrammarDescription) {
        if (!(xMLGrammarDescription instanceof XMLSchemaDescription)) {
            return xMLGrammarDescription.hashCode();
        }
        XMLSchemaDescription xMLSchemaDescription = (XMLSchemaDescription) xMLGrammarDescription;
        String targetNamespace = xMLSchemaDescription.getTargetNamespace();
        String expandedSystemId = xMLSchemaDescription.getExpandedSystemId();
        int i2 = 0;
        int hashCode = targetNamespace != null ? targetNamespace.hashCode() : 0;
        if (expandedSystemId != null) {
            i2 = expandedSystemId.hashCode();
        }
        return hashCode ^ i2;
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public void lockPool() {
        this.fPoolIsLocked = true;
    }

    public void putGrammar(Grammar grammar) {
        if (!this.fPoolIsLocked) {
            synchronized (this.fGrammars) {
                clean();
                XMLGrammarDescription grammarDescription = grammar.getGrammarDescription();
                int hashCode = hashCode(grammarDescription);
                int length = (Integer.MAX_VALUE & hashCode) % this.fGrammars.length;
                for (Entry entry = this.fGrammars[length]; entry != null; entry = entry.next) {
                    if (entry.hash == hashCode && equals(entry.desc, grammarDescription)) {
                        if (entry.grammar.get() != grammar) {
                            entry.grammar = new SoftGrammarReference(entry, grammar, this.fReferenceQueue);
                        }
                        return;
                    }
                }
                this.fGrammars[length] = new Entry(hashCode, length, grammarDescription, grammar, this.fGrammars[length], this.fReferenceQueue);
                this.fGrammarCount++;
            }
        }
    }

    public Grammar removeGrammar(XMLGrammarDescription xMLGrammarDescription) {
        synchronized (this.fGrammars) {
            clean();
            int hashCode = hashCode(xMLGrammarDescription);
            for (Entry entry = this.fGrammars[(Integer.MAX_VALUE & hashCode) % this.fGrammars.length]; entry != null; entry = entry.next) {
                if (entry.hash == hashCode && equals(entry.desc, xMLGrammarDescription)) {
                    return removeEntry(entry);
                }
            }
            return null;
        }
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public Grammar retrieveGrammar(XMLGrammarDescription xMLGrammarDescription) {
        return getGrammar(xMLGrammarDescription);
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public Grammar[] retrieveInitialGrammarSet(String str) {
        Grammar[] grammarArr;
        synchronized (this.fGrammars) {
            clean();
            grammarArr = ZERO_LENGTH_GRAMMAR_ARRAY;
        }
        return grammarArr;
    }

    @Override // org.apache.xerces.xni.grammars.XMLGrammarPool
    public void unlockPool() {
        this.fPoolIsLocked = false;
    }
}
