package org.apache.xerces.parsers;

import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Locale;
import org.apache.xerces.impl.XMLEntityManager;
import org.apache.xerces.impl.XMLErrorReporter;
import org.apache.xerces.util.SymbolTable;
import org.apache.xerces.xni.grammars.Grammar;
import org.apache.xerces.xni.grammars.XMLGrammarLoader;
import org.apache.xerces.xni.grammars.XMLGrammarPool;
import org.apache.xerces.xni.parser.XMLEntityResolver;
import org.apache.xerces.xni.parser.XMLErrorHandler;
import org.apache.xerces.xni.parser.XMLInputSource;

public class XMLGrammarPreparser {
    public static final String CONTINUE_AFTER_FATAL_ERROR = "http://apache.org/xml/features/continue-after-fatal-error";
    public static final String ENTITY_RESOLVER = "http://apache.org/xml/properties/internal/entity-resolver";
    public static final String ERROR_HANDLER = "http://apache.org/xml/properties/internal/error-handler";
    public static final String ERROR_REPORTER = "http://apache.org/xml/properties/internal/error-reporter";
    public static final String GRAMMAR_POOL = "http://apache.org/xml/properties/internal/grammar-pool";
    public static final Hashtable KNOWN_LOADERS;
    public static final String[] RECOGNIZED_PROPERTIES = {"http://apache.org/xml/properties/internal/symbol-table", "http://apache.org/xml/properties/internal/error-reporter", "http://apache.org/xml/properties/internal/error-handler", "http://apache.org/xml/properties/internal/entity-resolver", "http://apache.org/xml/properties/internal/grammar-pool"};
    public static final String SYMBOL_TABLE = "http://apache.org/xml/properties/internal/symbol-table";
    public XMLEntityResolver fEntityResolver;
    public final XMLErrorReporter fErrorReporter;
    public XMLGrammarPool fGrammarPool;
    public final Hashtable fLoaders;
    public Locale fLocale;
    public int fModCount;
    public final SymbolTable fSymbolTable;

    public static class XMLGrammarLoaderContainer {
        public final XMLGrammarLoader loader;
        public int modCount = 0;

        public XMLGrammarLoaderContainer(XMLGrammarLoader xMLGrammarLoader) {
            this.loader = xMLGrammarLoader;
        }
    }

    static {
        Hashtable hashtable = new Hashtable();
        KNOWN_LOADERS = hashtable;
        hashtable.put("http://www.w3.org/2001/XMLSchema", "org.apache.xerces.impl.xs.XMLSchemaLoader");
        KNOWN_LOADERS.put("http://www.w3.org/TR/REC-xml", "org.apache.xerces.impl.dtd.XMLDTDLoader");
    }

    public XMLGrammarPreparser() {
        this(new SymbolTable());
    }

    public XMLGrammarPreparser(SymbolTable symbolTable) {
        this.fModCount = 1;
        this.fSymbolTable = symbolTable;
        this.fLoaders = new Hashtable();
        this.fErrorReporter = new XMLErrorReporter();
        setLocale(Locale.getDefault());
        this.fEntityResolver = new XMLEntityManager();
    }

    private void clearModCounts() {
        Enumeration elements = this.fLoaders.elements();
        while (elements.hasMoreElements()) {
            ((XMLGrammarLoaderContainer) elements.nextElement()).modCount = 0;
        }
        this.fModCount = 1;
    }

    public XMLEntityResolver getEntityResolver() {
        return this.fEntityResolver;
    }

    public XMLErrorHandler getErrorHandler() {
        return this.fErrorReporter.getErrorHandler();
    }

    public boolean getFeature(String str, String str2) {
        return ((XMLGrammarLoaderContainer) this.fLoaders.get(str)).loader.getFeature(str2);
    }

    public XMLGrammarPool getGrammarPool() {
        return this.fGrammarPool;
    }

    public XMLGrammarLoader getLoader(String str) {
        XMLGrammarLoaderContainer xMLGrammarLoaderContainer = (XMLGrammarLoaderContainer) this.fLoaders.get(str);
        if (xMLGrammarLoaderContainer != null) {
            return xMLGrammarLoaderContainer.loader;
        }
        return null;
    }

    public Locale getLocale() {
        return this.fLocale;
    }

    public Object getProperty(String str, String str2) {
        return ((XMLGrammarLoaderContainer) this.fLoaders.get(str)).loader.getProperty(str2);
    }

    public Grammar preparseGrammar(String str, XMLInputSource xMLInputSource) {
        if (!this.fLoaders.containsKey(str)) {
            return null;
        }
        XMLGrammarLoaderContainer xMLGrammarLoaderContainer = (XMLGrammarLoaderContainer) this.fLoaders.get(str);
        XMLGrammarLoader xMLGrammarLoader = xMLGrammarLoaderContainer.loader;
        if (xMLGrammarLoaderContainer.modCount != this.fModCount) {
            xMLGrammarLoader.setProperty("http://apache.org/xml/properties/internal/symbol-table", this.fSymbolTable);
            xMLGrammarLoader.setProperty("http://apache.org/xml/properties/internal/entity-resolver", this.fEntityResolver);
            xMLGrammarLoader.setProperty("http://apache.org/xml/properties/internal/error-reporter", this.fErrorReporter);
            XMLGrammarPool xMLGrammarPool = this.fGrammarPool;
            if (xMLGrammarPool != null) {
                try {
                    xMLGrammarLoader.setProperty("http://apache.org/xml/properties/internal/grammar-pool", xMLGrammarPool);
                } catch (Exception unused) {
                }
            }
            xMLGrammarLoaderContainer.modCount = this.fModCount;
        }
        return xMLGrammarLoader.loadGrammar(xMLInputSource);
    }

    public boolean registerPreparser(String str, XMLGrammarLoader xMLGrammarLoader) {
        if (xMLGrammarLoader == null) {
            if (KNOWN_LOADERS.containsKey(str)) {
                try {
                    this.fLoaders.put(str, new XMLGrammarLoaderContainer((XMLGrammarLoader) ObjectFactory.newInstance((String) KNOWN_LOADERS.get(str), ObjectFactory.findClassLoader(), true)));
                    return true;
                } catch (Exception unused) {
                }
            }
            return false;
        }
        this.fLoaders.put(str, new XMLGrammarLoaderContainer(xMLGrammarLoader));
        return true;
    }

    public void setEntityResolver(XMLEntityResolver xMLEntityResolver) {
        if (this.fEntityResolver != xMLEntityResolver) {
            int i2 = this.fModCount + 1;
            this.fModCount = i2;
            if (i2 < 0) {
                clearModCounts();
            }
            this.fEntityResolver = xMLEntityResolver;
        }
    }

    public void setErrorHandler(XMLErrorHandler xMLErrorHandler) {
        this.fErrorReporter.setProperty("http://apache.org/xml/properties/internal/error-handler", xMLErrorHandler);
    }

    public void setFeature(String str, boolean z) {
        Enumeration elements = this.fLoaders.elements();
        while (elements.hasMoreElements()) {
            try {
                ((XMLGrammarLoaderContainer) elements.nextElement()).loader.setFeature(str, z);
            } catch (Exception unused) {
            }
        }
        if (str.equals("http://apache.org/xml/features/continue-after-fatal-error")) {
            this.fErrorReporter.setFeature("http://apache.org/xml/features/continue-after-fatal-error", z);
        }
    }

    public void setGrammarPool(XMLGrammarPool xMLGrammarPool) {
        if (this.fGrammarPool != xMLGrammarPool) {
            int i2 = this.fModCount + 1;
            this.fModCount = i2;
            if (i2 < 0) {
                clearModCounts();
            }
            this.fGrammarPool = xMLGrammarPool;
        }
    }

    public void setLocale(Locale locale) {
        this.fLocale = locale;
        this.fErrorReporter.setLocale(locale);
    }

    public void setProperty(String str, Object obj) {
        Enumeration elements = this.fLoaders.elements();
        while (elements.hasMoreElements()) {
            try {
                ((XMLGrammarLoaderContainer) elements.nextElement()).loader.setProperty(str, obj);
            } catch (Exception unused) {
            }
        }
    }
}
