package org.apache.xmlbeans.impl.jam.xml;

import java.io.Writer;
import org.apache.poi.javax.xml.stream.XMLOutputFactory;
import org.apache.poi.javax.xml.stream.XMLStreamException;
import org.apache.poi.javax.xml.stream.XMLStreamWriter;
import org.apache.xmlbeans.impl.jam.JAnnotatedElement;
import org.apache.xmlbeans.impl.jam.JAnnotation;
import org.apache.xmlbeans.impl.jam.JAnnotationValue;
import org.apache.xmlbeans.impl.jam.JClass;
import org.apache.xmlbeans.impl.jam.JComment;
import org.apache.xmlbeans.impl.jam.JConstructor;
import org.apache.xmlbeans.impl.jam.JField;
import org.apache.xmlbeans.impl.jam.JInvokable;
import org.apache.xmlbeans.impl.jam.JMethod;
import org.apache.xmlbeans.impl.jam.JParameter;
import org.apache.xmlbeans.impl.jam.JSourcePosition;

public class JamXmlWriter implements JamXmlElements {
    public boolean mInBody = false;
    public XMLStreamWriter mOut;
    public boolean mWriteSourceURI = false;

    public JamXmlWriter(Writer writer) {
        if (writer != null) {
            this.mOut = XMLOutputFactory.newInstance().createXMLStreamWriter(writer);
            return;
        }
        throw new IllegalArgumentException("null out");
    }

    private void assertStarted() {
        if (!this.mInBody) {
            throw new XMLStreamException("begin() not called");
        }
    }

    private void writeAnnotatedElement(JAnnotatedElement jAnnotatedElement) {
        JAnnotation[] annotations;
        String text;
        for (JAnnotation jAnnotation : jAnnotatedElement.getAnnotations()) {
            writeAnnotation(jAnnotation);
        }
        JComment comment = jAnnotatedElement.getComment();
        if (!(comment == null || (text = comment.getText()) == null || text.trim().length() <= 0)) {
            this.mOut.writeStartElement(JamXmlElements.COMMENT);
            this.mOut.writeCData(comment.getText());
            this.mOut.writeEndElement();
        }
        JSourcePosition sourcePosition = jAnnotatedElement.getSourcePosition();
        if (sourcePosition != null) {
            this.mOut.writeStartElement(JamXmlElements.SOURCEPOSITION);
            if (sourcePosition.getLine() != -1) {
                writeValueElement(JamXmlElements.LINE, sourcePosition.getLine());
            }
            if (sourcePosition.getColumn() != -1) {
                writeValueElement(JamXmlElements.COLUMN, sourcePosition.getColumn());
            }
            if (this.mWriteSourceURI && sourcePosition.getSourceURI() != null) {
                writeValueElement(JamXmlElements.SOURCEURI, sourcePosition.getSourceURI().toString());
            }
            this.mOut.writeEndElement();
        }
    }

    private void writeAnnotation(JAnnotation jAnnotation) {
        JAnnotationValue[] values;
        this.mOut.writeStartElement(JamXmlElements.ANNOTATION);
        writeValueElement("name", jAnnotation.getQualifiedName());
        for (JAnnotationValue jAnnotationValue : jAnnotation.getValues()) {
            writeAnnotationValue(jAnnotationValue);
        }
        this.mOut.writeEndElement();
    }

    private void writeAnnotationValue(JAnnotationValue jAnnotationValue) {
        this.mOut.writeStartElement(JamXmlElements.ANNOTATIONVALUE);
        writeValueElement("name", jAnnotationValue.getName());
        writeValueElement(JamXmlElements.TYPE, jAnnotationValue.getType().getFieldDescriptor());
        if (jAnnotationValue.getType().isArrayType()) {
            writeValueElement("value", jAnnotationValue.asStringArray());
        } else {
            writeValueElement("value", jAnnotationValue.asString());
        }
        this.mOut.writeEndElement();
    }

    private void writeClassList(String str, JClass[] jClassArr) {
        for (JClass jClass : jClassArr) {
            this.mOut.writeStartElement(str);
            this.mOut.writeCharacters(jClass.getFieldDescriptor());
            this.mOut.writeEndElement();
        }
    }

    private void writeInvokable(JInvokable jInvokable) {
        writeModifiers(jInvokable.getModifiers());
        JParameter[] parameters = jInvokable.getParameters();
        for (int i2 = 0; i2 < parameters.length; i2++) {
            this.mOut.writeStartElement(JamXmlElements.PARAMETER);
            writeValueElement("name", parameters[i2].getSimpleName());
            writeValueElement(JamXmlElements.TYPE, parameters[i2].getType().getFieldDescriptor());
            writeAnnotatedElement(parameters[i2]);
            this.mOut.writeEndElement();
        }
        writeAnnotatedElement(jInvokable);
    }

    private void writeModifiers(int i2) {
        this.mOut.writeStartElement(JamXmlElements.MODIFIERS);
        this.mOut.writeCharacters(String.valueOf(i2));
        this.mOut.writeEndElement();
    }

    private void writeValueElement(String str, boolean z) {
        this.mOut.writeStartElement(str);
        this.mOut.writeCharacters(String.valueOf(z));
        this.mOut.writeEndElement();
    }

    public void begin() {
        if (!this.mInBody) {
            this.mOut.writeStartElement(JamXmlElements.JAMSERVICE);
            this.mInBody = true;
            return;
        }
        throw new XMLStreamException("begin() already called");
    }

    public void end() {
        if (this.mInBody) {
            this.mOut.writeEndElement();
            this.mInBody = false;
            return;
        }
        throw new XMLStreamException("begin() never called");
    }

    public void write(JClass jClass) {
        JField[] declaredFields;
        JConstructor[] constructors;
        JMethod[] declaredMethods;
        assertStarted();
        this.mOut.writeStartElement(JamXmlElements.CLASS);
        writeValueElement("name", jClass.getFieldDescriptor());
        writeValueElement(JamXmlElements.ISINTERFACE, jClass.isInterface());
        writeModifiers(jClass.getModifiers());
        JClass superclass = jClass.getSuperclass();
        if (superclass != null) {
            writeValueElement(JamXmlElements.SUPERCLASS, superclass.getFieldDescriptor());
        }
        writeClassList(JamXmlElements.INTERFACE, jClass.getInterfaces());
        for (JField jField : jClass.getDeclaredFields()) {
            write(jField);
        }
        for (JConstructor jConstructor : jClass.getConstructors()) {
            write(jConstructor);
        }
        for (JMethod jMethod : jClass.getDeclaredMethods()) {
            write(jMethod);
        }
        writeAnnotatedElement(jClass);
        this.mOut.writeEndElement();
    }

    private void writeValueElement(String str, int i2) {
        this.mOut.writeStartElement(str);
        this.mOut.writeCharacters(String.valueOf(i2));
        this.mOut.writeEndElement();
    }

    public JamXmlWriter(XMLStreamWriter xMLStreamWriter) {
        if (xMLStreamWriter != null) {
            this.mOut = xMLStreamWriter;
            return;
        }
        throw new IllegalArgumentException("null out");
    }

    private void writeValueElement(String str, String str2) {
        this.mOut.writeStartElement(str);
        this.mOut.writeCharacters(str2);
        this.mOut.writeEndElement();
    }

    private void writeValueElement(String str, String[] strArr) {
        for (String str2 : strArr) {
            writeValueElement(str, str2);
        }
    }

    private void write(JMethod jMethod) {
        this.mOut.writeStartElement("method");
        writeValueElement("name", jMethod.getSimpleName());
        writeValueElement(JamXmlElements.RETURNTYPE, jMethod.getReturnType().getFieldDescriptor());
        writeInvokable(jMethod);
        this.mOut.writeEndElement();
    }

    private void write(JConstructor jConstructor) {
        this.mOut.writeStartElement(JamXmlElements.CONSTRUCTOR);
        writeInvokable(jConstructor);
        this.mOut.writeEndElement();
    }

    private void write(JField jField) {
        this.mOut.writeStartElement(JamXmlElements.FIELD);
        writeValueElement("name", jField.getSimpleName());
        writeModifiers(jField.getModifiers());
        writeValueElement(JamXmlElements.TYPE, jField.getType().getFieldDescriptor());
        writeAnnotatedElement(jField);
        this.mOut.writeEndElement();
    }
}
