package org.apache.poi.hwmf.record;

import java.awt.geom.Rectangle2D;
import java.nio.charset.Charset;
import org.apache.poi.hwmf.draw.HwmfDrawProperties;
import org.apache.poi.hwmf.draw.HwmfGraphics;
import org.apache.poi.ss.formula.functions.NumericFunction;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndianInputStream;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;

public class HwmfText {
    public static final int MAX_RECORD_LENGTH = 1000000;
    public static final POILogger logger = POILogFactory.getLogger(HwmfText.class);

    public enum HwmfTextAlignment {
        LEFT,
        RIGHT,
        CENTER
    }

    public enum HwmfTextVerticalAlignment {
        TOP,
        BOTTOM,
        BASELINE
    }

    public static class WmfCreateFontIndirect implements HwmfRecord, HwmfObjectTableEntry {
        public HwmfFont font;

        @Override // org.apache.poi.hwmf.record.HwmfObjectTableEntry
        public void applyObject(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.getProperties().setFont(this.font);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.addObjectTableEntry(this);
        }

        public HwmfFont getFont() {
            return this.font;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.createFontIndirect;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            HwmfFont hwmfFont = new HwmfFont();
            this.font = hwmfFont;
            return hwmfFont.init(littleEndianInputStream);
        }
    }

    public static class WmfExtTextOut implements HwmfRecord {
        public static final BitField ETO_CLIPPED = BitFieldFactory.getInstance(4);
        public static final BitField ETO_GLYPH_INDEX = BitFieldFactory.getInstance(16);
        public static final BitField ETO_NUMERICSLATIN = BitFieldFactory.getInstance(2048);
        public static final BitField ETO_NUMERICSLOCAL = BitFieldFactory.getInstance(1024);
        public static final BitField ETO_OPAQUE = BitFieldFactory.getInstance(2);
        public static final BitField ETO_PDY = BitFieldFactory.getInstance(8192);
        public static final BitField ETO_RTLREADING = BitFieldFactory.getInstance(128);
        public int bottom;
        public int[] dx;
        public int fwOpts;
        public int left;
        public byte[] rawTextBytes;
        public int right;
        public int stringLength;
        public int top;
        public int x;
        public int y;

        private byte[] getTextBytes() {
            byte[] safelyAllocate = IOUtils.safelyAllocate((long) this.stringLength, 1000000);
            System.arraycopy(this.rawTextBytes, 0, safelyAllocate, 0, this.stringLength);
            return safelyAllocate;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.drawString(getTextBytes(), new Rectangle2D.Double((double) this.x, (double) this.y, (double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e), this.dx);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.extTextOut;
        }

        public String getText(Charset charset) {
            return new String(getTextBytes(), charset);
        }

        /* JADX WARNING: Removed duplicated region for block: B:10:0x0067  */
        /* JADX WARNING: Removed duplicated region for block: B:12:0x0076  */
        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            int i3;
            int length;
            int i4 = (int) (j - 6);
            this.y = littleEndianInputStream.readShort();
            this.x = littleEndianInputStream.readShort();
            this.stringLength = littleEndianInputStream.readShort();
            int readUShort = littleEndianInputStream.readUShort();
            this.fwOpts = readUShort;
            if (ETO_OPAQUE.isSet(readUShort) || ETO_CLIPPED.isSet(this.fwOpts)) {
                i3 = 16;
                if (16 <= i4) {
                    this.left = littleEndianInputStream.readShort();
                    this.top = littleEndianInputStream.readShort();
                    this.right = littleEndianInputStream.readShort();
                    this.bottom = littleEndianInputStream.readShort();
                    int i5 = this.stringLength;
                    byte[] safelyAllocate = IOUtils.safelyAllocate((long) (i5 + (i5 & 1)), 1000000);
                    this.rawTextBytes = safelyAllocate;
                    littleEndianInputStream.readFully(safelyAllocate);
                    length = i3 + this.rawTextBytes.length;
                    if (length < i4) {
                        HwmfText.logger.log(3, "META_EXTTEXTOUT doesn't contain character tracking info");
                        return length;
                    }
                    int min = Math.min(this.stringLength, (i4 - length) / 2);
                    if (min < this.stringLength) {
                        HwmfText.logger.log(5, "META_EXTTEXTOUT tracking info doesn't cover all characters");
                    }
                    this.dx = new int[this.stringLength];
                    for (int i6 = 0; i6 < min; i6++) {
                        this.dx[i6] = littleEndianInputStream.readShort();
                        length += 2;
                    }
                    return length;
                }
            }
            i3 = 8;
            int i52 = this.stringLength;
            byte[] safelyAllocate2 = IOUtils.safelyAllocate((long) (i52 + (i52 & 1)), 1000000);
            this.rawTextBytes = safelyAllocate2;
            littleEndianInputStream.readFully(safelyAllocate2);
            length = i3 + this.rawTextBytes.length;
            if (length < i4) {
            }
        }
    }

    public static class WmfSetTextAlign implements HwmfRecord {
        public static final BitField TA_BASELINE = BitFieldFactory.getInstance(24);
        public static final BitField TA_BOTTOM = BitFieldFactory.getInstance(8);
        public static final BitField TA_CENTER = BitFieldFactory.getInstance(6);
        public static final BitField TA_LEFT = BitFieldFactory.getInstance(0);
        public static final BitField TA_NOUPDATECP = BitFieldFactory.getInstance(0);
        public static final BitField TA_RIGHT = BitFieldFactory.getInstance(2);
        public static final BitField TA_RTLREADING = BitFieldFactory.getInstance(256);
        public static final BitField TA_TOP = BitFieldFactory.getInstance(0);
        public static final BitField TA_UPDATECP = BitFieldFactory.getInstance(1);
        public static final BitField VTA_BASELINE = BitFieldFactory.getInstance(24);
        public static final BitField VTA_BOTTOM = BitFieldFactory.getInstance(2);
        public static final BitField VTA_CENTER = BitFieldFactory.getInstance(6);
        public static final BitField VTA_LEFT = BitFieldFactory.getInstance(8);
        public static final BitField VTA_RIGHT = BitFieldFactory.getInstance(0);
        public static final BitField VTA_TOP = BitFieldFactory.getInstance(0);
        public int textAlignmentMode;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            HwmfDrawProperties properties = hwmfGraphics.getProperties();
            if (TA_CENTER.isSet(this.textAlignmentMode)) {
                properties.setTextAlignLatin(HwmfTextAlignment.CENTER);
            } else if (TA_RIGHT.isSet(this.textAlignmentMode)) {
                properties.setTextAlignLatin(HwmfTextAlignment.RIGHT);
            } else {
                properties.setTextAlignLatin(HwmfTextAlignment.LEFT);
            }
            if (VTA_CENTER.isSet(this.textAlignmentMode)) {
                properties.setTextAlignAsian(HwmfTextAlignment.CENTER);
            } else if (VTA_LEFT.isSet(this.textAlignmentMode)) {
                properties.setTextAlignAsian(HwmfTextAlignment.LEFT);
            } else {
                properties.setTextAlignAsian(HwmfTextAlignment.RIGHT);
            }
            if (TA_BASELINE.isSet(this.textAlignmentMode)) {
                properties.setTextVAlignLatin(HwmfTextVerticalAlignment.BASELINE);
            } else if (TA_BOTTOM.isSet(this.textAlignmentMode)) {
                properties.setTextVAlignLatin(HwmfTextVerticalAlignment.BOTTOM);
            } else {
                properties.setTextVAlignLatin(HwmfTextVerticalAlignment.TOP);
            }
            if (VTA_BASELINE.isSet(this.textAlignmentMode)) {
                properties.setTextVAlignAsian(HwmfTextVerticalAlignment.BASELINE);
            } else if (VTA_BOTTOM.isSet(this.textAlignmentMode)) {
                properties.setTextVAlignAsian(HwmfTextVerticalAlignment.BOTTOM);
            } else {
                properties.setTextVAlignAsian(HwmfTextVerticalAlignment.TOP);
            }
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setTextAlign;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.textAlignmentMode = littleEndianInputStream.readUShort();
            return 2;
        }
    }

    public static class WmfSetTextCharExtra implements HwmfRecord {
        public int charExtra;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setTextCharExtra;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.charExtra = littleEndianInputStream.readUShort();
            return 2;
        }
    }

    public static class WmfSetTextColor implements HwmfRecord {
        public HwmfColorRef colorRef;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.getProperties().setTextColor(this.colorRef);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setTextColor;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            HwmfColorRef hwmfColorRef = new HwmfColorRef();
            this.colorRef = hwmfColorRef;
            return hwmfColorRef.init(littleEndianInputStream);
        }
    }

    public static class WmfSetTextJustification implements HwmfRecord {
        public int breakCount;
        public int breakExtra;

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.setBkColor;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            this.breakCount = littleEndianInputStream.readUShort();
            this.breakExtra = littleEndianInputStream.readUShort();
            return 4;
        }
    }

    public static class WmfTextOut implements HwmfRecord {
        public byte[] rawTextBytes;
        public int stringLength;
        public int xStart;
        public int yStart;

        private byte[] getTextBytes() {
            byte[] safelyAllocate = IOUtils.safelyAllocate((long) this.stringLength, 1000000);
            System.arraycopy(this.rawTextBytes, 0, safelyAllocate, 0, this.stringLength);
            return safelyAllocate;
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public void draw(HwmfGraphics hwmfGraphics) {
            hwmfGraphics.drawString(getTextBytes(), new Rectangle2D.Double((double) this.xStart, (double) this.yStart, (double) NumericFunction.LOG_10_TO_BASE_e, (double) NumericFunction.LOG_10_TO_BASE_e));
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public HwmfRecordType getRecordType() {
            return HwmfRecordType.textOut;
        }

        public String getText(Charset charset) {
            return new String(getTextBytes(), charset);
        }

        @Override // org.apache.poi.hwmf.record.HwmfRecord
        public int init(LittleEndianInputStream littleEndianInputStream, long j, int i2) {
            short readShort = littleEndianInputStream.readShort();
            this.stringLength = readShort;
            byte[] safelyAllocate = IOUtils.safelyAllocate((long) (readShort + (readShort & 1)), 1000000);
            this.rawTextBytes = safelyAllocate;
            littleEndianInputStream.readFully(safelyAllocate);
            this.yStart = littleEndianInputStream.readShort();
            this.xStart = littleEndianInputStream.readShort();
            return this.rawTextBytes.length + 6;
        }
    }
}
