package org.apache.poi.poifs.crypt;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FilterOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.security.GeneralSecurityException;
import java.util.BitSet;
import javax.crypto.Cipher;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentOutputStream;
import org.apache.poi.poifs.filesystem.POIFSWriterEvent;
import org.apache.poi.poifs.filesystem.POIFSWriterListener;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.Internal;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.POILogFactory;
import org.apache.poi.util.POILogger;
import org.apache.poi.util.TempFile;

@Internal
public abstract class ChunkedCipherOutputStream extends FilterOutputStream {
    public static final POILogger LOG = POILogFactory.getLogger(ChunkedCipherOutputStream.class);
    public static final int STREAMING = -1;
    public final byte[] chunk;
    public final int chunkBits;
    public final int chunkSize;
    public Cipher cipher;
    public final DirectoryNode dir;
    public final File fileOut;
    public boolean isClosed = false;
    public final BitSet plainByteFlags;
    public long pos;
    public long totalPos;
    public long written;

    public class EncryptedPackageWriter implements POIFSWriterListener {
        public EncryptedPackageWriter() {
        }

        /* JADX INFO: finally extract failed */
        @Override // org.apache.poi.poifs.filesystem.POIFSWriterListener
        public void processPOIFSWriterEvent(POIFSWriterEvent pOIFSWriterEvent) {
            try {
                DocumentOutputStream stream = pOIFSWriterEvent.getStream();
                byte[] bArr = new byte[8];
                LittleEndian.putLong(bArr, 0, ChunkedCipherOutputStream.this.pos);
                stream.write(bArr);
                FileInputStream fileInputStream = new FileInputStream(ChunkedCipherOutputStream.this.fileOut);
                try {
                    IOUtils.copy(fileInputStream, stream);
                    fileInputStream.close();
                    stream.close();
                    if (!ChunkedCipherOutputStream.this.fileOut.delete()) {
                        POILogger pOILogger = ChunkedCipherOutputStream.LOG;
                        pOILogger.log(7, "Can't delete temporary encryption file: " + ChunkedCipherOutputStream.this.fileOut);
                    }
                } catch (Throwable th) {
                    fileInputStream.close();
                    throw th;
                }
            } catch (IOException e2) {
                throw new EncryptedDocumentException(e2);
            }
        }
    }

    public ChunkedCipherOutputStream(DirectoryNode directoryNode, int i2) {
        super(null);
        this.chunkSize = i2;
        i2 = i2 == -1 ? 4096 : i2;
        this.chunk = new byte[i2];
        this.plainByteFlags = new BitSet(i2);
        this.chunkBits = Integer.bitCount(i2 - 1);
        File createTempFile = TempFile.createTempFile("encrypted_package", "crypt");
        this.fileOut = createTempFile;
        createTempFile.deleteOnExit();
        ((FilterOutputStream) this).out = new FileOutputStream(this.fileOut);
        this.dir = directoryNode;
        this.cipher = initCipherForBlock(null, 0, false);
    }

    public abstract void calculateChecksum(File file, int i2);

    @Override // java.io.OutputStream, java.io.Closeable, java.io.FilterOutputStream, java.lang.AutoCloseable
    public void close() {
        if (this.isClosed) {
            LOG.log(1, "ChunkedCipherOutputStream was already closed - ignoring");
            return;
        }
        this.isClosed = true;
        try {
            writeChunk(false);
            super.close();
            if (this.fileOut != null) {
                int length = (int) (this.fileOut.length() + 8);
                calculateChecksum(this.fileOut, (int) this.pos);
                this.dir.createDocument("EncryptedPackage", length, new EncryptedPackageWriter());
                createEncryptionInfoEntry(this.dir, this.fileOut);
            }
        } catch (GeneralSecurityException e2) {
            throw new IOException(e2);
        }
    }

    public abstract void createEncryptionInfoEntry(DirectoryNode directoryNode, File file);

    public byte[] getChunk() {
        return this.chunk;
    }

    public int getChunkMask() {
        return this.chunk.length - 1;
    }

    public BitSet getPlainByteFlags() {
        return this.plainByteFlags;
    }

    public long getPos() {
        return this.pos;
    }

    public long getTotalPos() {
        return this.totalPos;
    }

    public final Cipher initCipherForBlock(int i2, boolean z) {
        return initCipherForBlock(this.cipher, i2, z);
    }

    public abstract Cipher initCipherForBlock(Cipher cipher2, int i2, boolean z);

    public int invokeCipher(int i2, boolean z) {
        int i3;
        byte[] bArr = this.plainByteFlags.isEmpty() ? null : (byte[]) this.chunk.clone();
        int i4 = 0;
        if (z) {
            Cipher cipher2 = this.cipher;
            byte[] bArr2 = this.chunk;
            i3 = cipher2.doFinal(bArr2, 0, i2, bArr2);
        } else {
            Cipher cipher3 = this.cipher;
            byte[] bArr3 = this.chunk;
            i3 = cipher3.update(bArr3, 0, i2, bArr3);
        }
        BitSet bitSet = this.plainByteFlags;
        while (true) {
            int nextSetBit = bitSet.nextSetBit(i4);
            if (nextSetBit < 0 || nextSetBit >= i2) {
                return i3;
            }
            this.chunk[nextSetBit] = bArr[nextSetBit];
            bitSet = this.plainByteFlags;
            i4 = nextSetBit + 1;
        }
        return i3;
    }

    public void setNextRecordSize(int i2, boolean z) {
    }

    @Override // java.io.OutputStream, java.io.FilterOutputStream
    public void write(int i2) {
        write(new byte[]{(byte) i2});
    }

    public void writeChunk(boolean z) {
        boolean z2;
        long j = this.pos;
        if (j != 0 && this.totalPos != this.written) {
            int chunkMask = (int) (j & ((long) getChunkMask()));
            int i2 = (int) (this.pos >> this.chunkBits);
            boolean z3 = true;
            if (chunkMask == 0) {
                i2--;
                chunkMask = this.chunk.length;
                z2 = false;
            } else {
                z2 = true;
            }
            try {
                long j2 = this.pos;
                this.pos = 0;
                if (this.chunkSize != -1) {
                    this.cipher = initCipherForBlock(this.cipher, i2, z2);
                    this.pos = j2;
                } else if (z) {
                    z3 = false;
                }
                int invokeCipher = invokeCipher(chunkMask, z3);
                ((FilterOutputStream) this).out.write(this.chunk, 0, invokeCipher);
                this.plainByteFlags.clear();
                this.written += (long) invokeCipher;
            } catch (GeneralSecurityException e2) {
                throw new IOException("can't re-/initialize cipher", e2);
            }
        }
    }

    public void writePlain(byte[] bArr, int i2, int i3) {
        write(bArr, i2, i3, true);
    }

    @Override // java.io.OutputStream, java.io.FilterOutputStream
    public void write(byte[] bArr) {
        write(bArr, 0, bArr.length);
    }

    @Override // java.io.OutputStream, java.io.FilterOutputStream
    public void write(byte[] bArr, int i2, int i3) {
        write(bArr, i2, i3, false);
    }

    public void write(byte[] bArr, int i2, int i3, boolean z) {
        if (i3 != 0) {
            if (i3 < 0 || bArr.length < i2 + i3) {
                throw new IOException("not enough bytes in your input buffer");
            }
            int chunkMask = getChunkMask();
            while (i3 > 0) {
                long j = (long) chunkMask;
                int i4 = (int) (this.pos & j);
                int min = Math.min(this.chunk.length - i4, i3);
                System.arraycopy(bArr, i2, this.chunk, i4, min);
                if (z) {
                    this.plainByteFlags.set(i4, i4 + min);
                }
                long j2 = (long) min;
                long j3 = this.pos + j2;
                this.pos = j3;
                this.totalPos += j2;
                i2 += min;
                i3 -= min;
                if ((j3 & j) == 0) {
                    writeChunk(i3 > 0);
                }
            }
        }
    }

    public ChunkedCipherOutputStream(OutputStream outputStream, int i2) {
        super(outputStream);
        this.chunkSize = i2;
        i2 = i2 == -1 ? 4096 : i2;
        this.chunk = new byte[i2];
        this.plainByteFlags = new BitSet(i2);
        this.chunkBits = Integer.bitCount(i2 - 1);
        this.fileOut = null;
        this.dir = null;
        this.cipher = initCipherForBlock(null, 0, false);
    }
}
