package org.apache.poi.poifs.crypt.cryptoapi;

import java.io.ByteArrayOutputStream;
import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import java.security.GeneralSecurityException;
import java.security.MessageDigest;
import java.util.Arrays;
import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import org.apache.poi.EncryptedDocumentException;
import org.apache.poi.poifs.crypt.ChunkedCipherInputStream;
import org.apache.poi.poifs.crypt.CryptoFunctions;
import org.apache.poi.poifs.crypt.Decryptor;
import org.apache.poi.poifs.crypt.EncryptionHeader;
import org.apache.poi.poifs.crypt.EncryptionInfo;
import org.apache.poi.poifs.crypt.EncryptionVerifier;
import org.apache.poi.poifs.crypt.HashAlgorithm;
import org.apache.poi.poifs.filesystem.DirectoryNode;
import org.apache.poi.poifs.filesystem.DocumentInputStream;
import org.apache.poi.poifs.filesystem.DocumentNode;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.apache.poi.util.BitField;
import org.apache.poi.util.BitFieldFactory;
import org.apache.poi.util.BoundedInputStream;
import org.apache.poi.util.IOUtils;
import org.apache.poi.util.LittleEndian;
import org.apache.poi.util.LittleEndianInputStream;
import org.apache.poi.util.StringUtil;

public class CryptoAPIDecryptor extends Decryptor implements Cloneable {
    public static final /* synthetic */ boolean $assertionsDisabled = false;
    public int chunkSize = -1;
    public long length = -1;

    public class CryptoAPICipherInputStream extends ChunkedCipherInputStream {
        public CryptoAPICipherInputStream(InputStream inputStream, long j, int i2) {
            super(inputStream, j, CryptoAPIDecryptor.this.chunkSize, i2);
        }

        @Override // org.apache.poi.poifs.crypt.ChunkedCipherInputStream
        public Cipher initCipherForBlock(Cipher cipher, int i2) {
            return CryptoAPIDecryptor.this.initCipherForBlock(cipher, i2);
        }
    }

    public static class StreamDescriptorEntry {
        public static BitField flagStream = BitFieldFactory.getInstance(1);
        public int block;
        public int flags;
        public int reserved2;
        public String streamName;
        public int streamOffset;
        public int streamSize;
    }

    public static SecretKey generateSecretKey(String str, EncryptionVerifier encryptionVerifier) {
        if (str.length() > 255) {
            str = str.substring(0, 255);
        }
        MessageDigest messageDigest = CryptoFunctions.getMessageDigest(encryptionVerifier.getHashAlgorithm());
        messageDigest.update(encryptionVerifier.getSalt());
        return new SecretKeySpec(messageDigest.digest(StringUtil.getToUnicodeLE(str)), encryptionVerifier.getCipherAlgorithm().jceId);
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public long getLength() {
        long j = this.length;
        if (j != -1) {
            return j;
        }
        throw new IllegalStateException("Decryptor.getDataStream() was not called");
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x00bf A[Catch:{ all -> 0x00b5 }] */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x00cf A[Catch:{ all -> 0x00b5 }] */
    public POIFSFileSystem getSummaryEntries(DirectoryNode directoryNode, String str) {
        Exception e2;
        DocumentInputStream createDocumentInputStream = directoryNode.createDocumentInputStream((DocumentNode) directoryNode.getEntry(str));
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        IOUtils.copy(createDocumentInputStream, byteArrayOutputStream);
        createDocumentInputStream.close();
        CryptoAPIDocumentInputStream cryptoAPIDocumentInputStream = new CryptoAPIDocumentInputStream(this, byteArrayOutputStream.toByteArray());
        LittleEndianInputStream littleEndianInputStream = new LittleEndianInputStream(cryptoAPIDocumentInputStream);
        POIFSFileSystem pOIFSFileSystem = null;
        try {
            littleEndianInputStream.readUInt();
            long readUInt = ((long) ((int) littleEndianInputStream.readUInt())) - 8;
            if (cryptoAPIDocumentInputStream.skip(readUInt) >= readUInt) {
                cryptoAPIDocumentInputStream.setBlock(0);
                int readUInt2 = (int) littleEndianInputStream.readUInt();
                StreamDescriptorEntry[] streamDescriptorEntryArr = new StreamDescriptorEntry[readUInt2];
                for (int i2 = 0; i2 < readUInt2; i2++) {
                    StreamDescriptorEntry streamDescriptorEntry = new StreamDescriptorEntry();
                    streamDescriptorEntryArr[i2] = streamDescriptorEntry;
                    streamDescriptorEntry.streamOffset = (int) littleEndianInputStream.readUInt();
                    streamDescriptorEntry.streamSize = (int) littleEndianInputStream.readUInt();
                    streamDescriptorEntry.block = littleEndianInputStream.readUShort();
                    int readUByte = littleEndianInputStream.readUByte();
                    streamDescriptorEntry.flags = littleEndianInputStream.readUByte();
                    streamDescriptorEntry.reserved2 = littleEndianInputStream.readInt();
                    streamDescriptorEntry.streamName = StringUtil.readUnicodeLE(littleEndianInputStream, readUByte);
                    littleEndianInputStream.readShort();
                }
                POIFSFileSystem pOIFSFileSystem2 = new POIFSFileSystem();
                for (int i3 = 0; i3 < readUInt2; i3++) {
                    try {
                        StreamDescriptorEntry streamDescriptorEntry2 = streamDescriptorEntryArr[i3];
                        cryptoAPIDocumentInputStream.seek(streamDescriptorEntry2.streamOffset);
                        cryptoAPIDocumentInputStream.setBlock(streamDescriptorEntry2.block);
                        BoundedInputStream boundedInputStream = new BoundedInputStream(cryptoAPIDocumentInputStream, (long) streamDescriptorEntry2.streamSize);
                        pOIFSFileSystem2.createDocument(boundedInputStream, streamDescriptorEntry2.streamName);
                        boundedInputStream.close();
                    } catch (Exception e3) {
                        e2 = e3;
                        pOIFSFileSystem = pOIFSFileSystem2;
                        try {
                            IOUtils.closeQuietly(pOIFSFileSystem);
                            if (!(e2 instanceof GeneralSecurityException)) {
                            }
                        } catch (Throwable th) {
                            IOUtils.closeQuietly(littleEndianInputStream);
                            IOUtils.closeQuietly(cryptoAPIDocumentInputStream);
                            throw th;
                        }
                    }
                }
                IOUtils.closeQuietly(littleEndianInputStream);
                IOUtils.closeQuietly(cryptoAPIDocumentInputStream);
                return pOIFSFileSystem2;
            }
            throw new EOFException("buffer underrun");
        } catch (Exception e4) {
            e2 = e4;
            IOUtils.closeQuietly(pOIFSFileSystem);
            if (!(e2 instanceof GeneralSecurityException)) {
                throw ((GeneralSecurityException) e2);
            } else if (e2 instanceof IOException) {
                throw ((IOException) e2);
            } else {
                throw new IOException("summary entries can't be read", e2);
            }
        }
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public Cipher initCipherForBlock(Cipher cipher, int i2) {
        return initCipherForBlock(cipher, i2, getEncryptionInfo(), getSecretKey(), 2);
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public void setChunkSize(int i2) {
        this.chunkSize = i2;
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public boolean verifyPassword(String str) {
        EncryptionVerifier verifier = getEncryptionInfo().getVerifier();
        SecretKey generateSecretKey = generateSecretKey(str, verifier);
        try {
            Cipher initCipherForBlock = initCipherForBlock(null, 0, getEncryptionInfo(), generateSecretKey, 2);
            byte[] encryptedVerifier = verifier.getEncryptedVerifier();
            byte[] bArr = new byte[encryptedVerifier.length];
            initCipherForBlock.update(encryptedVerifier, 0, encryptedVerifier.length, bArr);
            setVerifier(bArr);
            if (!Arrays.equals(CryptoFunctions.getMessageDigest(verifier.getHashAlgorithm()).digest(bArr), initCipherForBlock.doFinal(verifier.getEncryptedVerifierHash()))) {
                return false;
            }
            setSecretKey(generateSecretKey);
            return true;
        } catch (GeneralSecurityException e2) {
            throw new EncryptedDocumentException(e2);
        }
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor, org.apache.poi.poifs.crypt.Decryptor, java.lang.Object
    public CryptoAPIDecryptor clone() {
        return (CryptoAPIDecryptor) super.clone();
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public ChunkedCipherInputStream getDataStream(DirectoryNode directoryNode) {
        throw new IOException("not supported");
    }

    public static Cipher initCipherForBlock(Cipher cipher, int i2, EncryptionInfo encryptionInfo, SecretKey secretKey, int i3) {
        HashAlgorithm hashAlgorithm = encryptionInfo.getVerifier().getHashAlgorithm();
        byte[] bArr = new byte[4];
        LittleEndian.putUInt(bArr, 0, (long) i2);
        MessageDigest messageDigest = CryptoFunctions.getMessageDigest(hashAlgorithm);
        messageDigest.update(secretKey.getEncoded());
        byte[] digest = messageDigest.digest(bArr);
        EncryptionHeader header = encryptionInfo.getHeader();
        int keySize = header.getKeySize();
        byte[] block0 = CryptoFunctions.getBlock0(digest, keySize / 8);
        if (keySize == 40) {
            block0 = CryptoFunctions.getBlock0(block0, 16);
        }
        SecretKeySpec secretKeySpec = new SecretKeySpec(block0, secretKey.getAlgorithm());
        if (cipher == null) {
            return CryptoFunctions.getCipher(secretKeySpec, header.getCipherAlgorithm(), null, null, i3);
        }
        cipher.init(i3, secretKeySpec);
        return cipher;
    }

    @Override // org.apache.poi.poifs.crypt.Decryptor
    public ChunkedCipherInputStream getDataStream(InputStream inputStream, int i2, int i3) {
        return new CryptoAPICipherInputStream(inputStream, (long) i2, i3);
    }
}
